#!/usr/bin/perl

# check if required modules are installed on this machine and output intelligible error messages if not.
$missing_module="";
$load_module=eval{require File::Path;File::Path->import();1;};
if(!$load_module){print"\nPerl module File::Path (in core since 1995-03-14) is not installed on this machine!";$missing_module="File::Path";}
$load_module=eval{require File::Copy;File::Copy->import();1;};
if(!$load_module){print"\nPerl module File::Copy (in core since 1996-02-29) is not installed on this machine!";$missing_module="File::Copy";}
$load_module=eval{require File::Basename;File::Basename->import();1;};
if(!$load_module){print"\nPerl module File::Basename (in core since 1994-10-17) is not installed on this machine!";$missing_module="File::Basename";}
$load_module=eval{require Getopt::Long;Getopt::Long->import();1;};
if(!$load_module){print"\nPerl module Getopt::Long (in core since 1994-10-17) is not installed on this machine!";$missing_module="Getopt::Long";}
$load_module=eval{require LWP::Simple;LWP::Simple->import();1;};
if(!$load_module){print"\nPerl module LWP::Simple is not installed on this machine!";$missing_module="LWP::Simple";}
$load_module=eval{require Archive::Extract;Archive::Extract->import();1;};
if(!$load_module){print"\nPerl module Archive::Extract (in core since 2007-07-07) is not installed on this machine!";$missing_module="Archive::Extract";}
$load_module=eval{require Scalar::Util;Scalar::Util->import();1;};
if(!$load_module){print"\nPerl module Scalar::Util (in core since 2002-03-05) is not installed on this machine!";$missing_module="Scalar::Util";}
else{eval'use Scalar::Util qw( looks_like_number );';}
if(length$missing_module>0)
	{
	print"
Perl modules are available for download at http://www.cpan.org/\n\nIf you have CPAN installed try the following:
 cpan
 install $missing_module
 exit

If you are on Mac or Unix you should run cpan with sudo:
 sudo cpan
 install $missing_module
 exit

";
	exit;
	}

$|=1;
$unitas_version="1.4.6";
$last_modified="15. November 2017"; # output all matches to a ncRNA class in full annotation matrix (not only the first)
$t0=time;

if($^O eq'MSWin32')
	{
	$usage_command="unitas.exe -input path/to/sequence.file -species genus_species";
	}
else
	{
	$usage_command="./unitas -input path/to/sequence.file -species genus_species";
	}

########## USAGE ##########
$usage="

                                                           X
                                                          oXX.o
                                                         .XXXX
                                                        .XXXXX
                                                       .XXXXX.
                                                      .XXXXXXXXXo
                                                     oXXXXXX' 'XXX.
            XXX                                   .oXXXXXXXX. .XXXXo
           XXXXX.  .oXXXXoo..                 ...oXXXXXXXXXXXXXXXXXX
            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo'''
               XXXXXXXXXXXXXXX------------------XXXXXXXXXXXX'
           .X.   'XXXXXXXXXXXX      unitas      XXXXXXXXXXXXX
         XXXXXXooXXXXXXXXXXXXX------------------XXXXXXXXXXXXXoooooo...XXXX
       .XXXX'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX'''XXXXXXXXXXXXXXX''
    .oXXXX'    ''XXXXXXXXXXX' 'XXXXXXXXXXXXXXX'''''        '''       ''
   oXXXX'          'XXXXX''
   XXXX'


 Version: ..... $unitas_version
 Date: ........ $last_modified


                              ### Usage ###
 All you need to start is a file that contains your sequence data in FASTQ,
 FASTA, SAM or ELAND3 format and a connection to the internet. Start the unitas
 Perl script from the command line (terminal) using the following command:

    perl unitas.pl -input path/to/sequence.file -species genus_species

 When you run the standalone executable file use this command instead:

    $usage_command

 unitas uses ncRNA (and cDNA) sequences from Ensembl and thus supports species
 included in the latest Ensembl release. Use the option -supp_spec to display a
 list of all supported species/strains. If you want to annotate sRNA sequences
 from a different species chose a closely related species or use the option
 -species like this:

    -species x

 In the latter case you must provide your own reference sequence file(s) using
 the option

    -refseq sequence_1.fas [-refseq sequence_2.fas ...]

 Use the option -show_options to display a list with all available command line
 options.


                          ### How to cite unitas ###
 Gebert D, Hewel C, Rosenkranz D. unitas: the universal tool for annotation of
 small RNAs. BMC Genomics 2017 18:644.


                               ### Contact ###
 David Rosenkranz
 Institute of Organismic and Molecular Evolutionary Biology, Anthropology
 Johannes Gutenberg University Mainz, Germany
 email: rosenkranz\@uni-mainz.de
 web: www.smallRNAgroup.uni-mainz.de

 You can find a more detailed documentation here:
 www.smallRNAgroup.uni-mainz.de/software/unitas_documentation.pdf

 ==============================================================================

 ";

 $usage_all_options="

                                ### Options ###
 Allowed values for options: [s]=string, [i]=integer, [f]=floating point number

 -i OR -input [s]          Name of the input file. You can use multiple input
                           files at once, e.g.:
                           -i file1.fas -i file2.fq -i file3.sam
                           Alternatively you can provide the name of a
                           directory that contains all of your input files,
                           e.g:
                           -i path/to/your/input/files
 -s OR -species [s]        Species name. Use the binominal nomenclature with
                           genus and species seperated by an underline, e.g.:
                           -s mus_musculus
 -latest_ref               Force unitaz to download the latest database
                           sequences. Otherwise unitas will use previously
                           downloaded sequences (if available) from the
                           UNITAS_refdump folder.
 -refdump                  Create a reference sequence dump folder, download
                           species-specific reference sequences and QUIT.
                           This folder and sequences herein can be used for
                           later offline unitas runs.
 -refseq [s]               Use an arbitrary number of additional files that
                           contain reference sequeces in FASTA format. FASTA
                           headers should have the following format:
                           >ncRNA_type|ncRNA_name
 -riborase                 Find all rRNA-like sequences in your input file
                           by using a complete NCBI rRNA nucleotide collection
                           in addition to the available ncRNA data for your
                           species.
 -trim                     Use this option to search for and remove any 3'
                           adapter sequence in input files. There is no need
                           to provide a specific sequence.
 -trim_minlength [i]       Minimum allowed read length [nt] after removal of
                           adapter sequence. Default=10.
 -trim_maxlength [i]       Maximum allowed read length [nt] after removal of
                           adapter sequence. Default=50.
 -trim_ignore_5p [i]       Ignore first n basepairs for 3 adapter prediction.
                           Default=22.
 -trim_skip_reads [i]      Skip the first n reads when searching for frequent
                           motifs. Default=10000
 -trim_check_reads [i]     Check n reads for 3 adapter prediction.
                           Deafult=500000
 -trim_polyA               Allow polyA tails to be recognized as 3' adapter.
                           Useful when library was prepared with polyA-tailing
                           rather than 3' adapter ligation.
 -trim_maxfinalbias [f]    Maximum allowed 3' nucleotide bias after trimming.
                           If this value is exceeded, unitas will trim further
                           3' positions. Default=0.8.
 -quick                    Allow less mismatch. Equivalent to:
                           -tail 1 -intmod 0 -mismatch 0 -insdel 0
                           Faster, less memory usage, less sensitive.
 -slow                     Allow more mismatch. Equivalent to:
                           -tail 3 -intmod 2 -mismatch 2 -insdel 1
                           Slower, more memory usage, more sensitive.
 -tail [i]                 Maximum number of allowed non-template 3'
                           nucleotides when mapping user sequences to reference
                           miRNA (miRNA-precursor) and piRNA cluster sequences.
                           Default=2. Summed values for -tail and -intmod must
                           not exceed 5.
 -intmod [i]               Maximum number of allowed internal mismatches when
                           mapping user sequences to reference miRNA (miRNA-
                           precursor). Default=1. Summed values for -tail and
                           -intmod must not exceed 5.
 -mismatch [i]             Maximum number of allowed mismatches when mapping
                           user sequences to reference ncRNA sequences (does
                           not apply to miRNAs and putative piRNAs). Default=1.
 -insdel [i]               Maximum number of insertions/deletions when mapping
                           user sequences to reference ncRNA sequences (does
                           not apply to miRNAs and putative piRNAs). Default=0.
 -threads [i]              Maximum number of parallel threads. Applies only if
                           using more than one input file. Default=1.
 -memory [i]               Limit memory usage [GB] for SeqMap mapping. Default
                           is no limit. When using a limit, unitas will quit
                           before the limit will be exceeded.
 -less_memory              Will use modified parameters for SeqMap mapping to
                           reduce memory usage. Will increase running time.
 -even_less_memory         Will use modified parameters for SeqMap mapping to
                           reduce memory usage even more. Will increase running
                           time.
 -phasi [i]                Search for phased siRNAs (phasiRNAs or tasiRNAs)
                           with specified length = [integer]. When using this
                           option, the input file must be a map file in either
                           SAM or ELAND3 format. You can use this option
                           multiple times, e.g: -phasi 21 -phasi 24.
 -na_for_phasi             Only sequences without annotation will be considered
                           for phasiRNA prediction.
 -pp                       Analyze 5' overlaps of mapped reads to identify so-
                           called ping-pong signatures (preference for 10 bp
                           overlaps) which is a footprint of secondary piRNA
                           biogenesis. When using this option, the input file
                           must be a map file in SAM or ELAND3 format.
 -keep_temp                Do not remove temporary files from data dump folder.
 -skip_mapping             Skip mapping to reference sequences. Equivalent to:
                           -skip_miR -skip_cDNA -skip_ncRNA -skip_piR
                           Use this when you want to trim 3' adapters and/or
                           want to search for phasiRNAs only.
 -skip_miR                 Skip search for miRNA reads, search for other ncRNAs
                           only.
 -skip_cDNA                Skip search for reads that map to Ensembl cDNA
                           sequences.
 -skip_ncRNA               Skip search for reads that map to ncRNA collection.
 -skip_piR                 Skip search for reads that map to known piRNA
                           producing loci.
 -skip_dust                Skip filtering low complexity sequences.
 -dust_limit [f]           Threshold for fraction of a sequence that consists
                           of simple sequence repeats When filtering low
                           complexity reads from input files. Default=0.75.
 -dust_max [i]             Maximum motif size for simple sequence repeats.
                           Default=5.
 -dust_maxN [f]            Maximum fraction of Ns in a read. Default=0.5.
 -noCCAcheck               Mature tRNAs carry a CCA-3' which is enzymatically
                           added to tRNA transcripts unless it it present
                           already. unitas will check 3' termini of tRNAs and
                           add the CCA-3' unless this option is turned on.
 -CC_is_CCA                Treat 3' tRFs with CC-3' as CCA-3'. Makes sense
                           when protocols for library construction use poly-A
                           tailing with subsequent A(n)-3' trimming.
 -no_html                  Do not output html files with visualization of
                           sncRNA annotation and analysis.
 -diffexpr                 Search for differentially expressed sRNAs accross
                           different probes. Define 2 groups with a recommended
                           minimum of 2 probes per group using the options -g1
                           and -g2 as described below. When using this option
                           unitas will do the comparison and quit. Change the
                           name of the output file using the option
                           -diffexpr_out.
 -diffexpr_p [f]           Critical p value for differential expression
                           analysis. Default=0.05.
 -diffexpr_acorrection [i] Correction of alpha error (multiple testing).
                           Allowed values are 0 (=no correction), 1
                           (=Bonferroni-Holm, default) and 2 (=Bonferroni).
 -diffexpr_estdev [f]      If one group comprises only one replicate, the
                           variance can be estimated by means of this factor
                           which is 0.05 by default. That means if sequence A
                           has 100 reads in the given replicate, unitas
                           virtually adds two replicates with read count values
                           105 and 95 (+- 5%).
 -diffexpr_nostrays        Only consider sequences that are present in all
                           replicates.
 -g1 [s]                   unitas output folder for probe assigned to group 1.
                           Use this option multiple times for every probe that
                           you want to assign to group 1. E.g:
                           -g1 UNITAS_04-01-2017_SRR123456.fasta_#1
 -g2 [s]                   Probes assigned to group 2 (see above).
 -diffexpr_out [s]         Specifies file names were the results of the
                           differentially expressed RNAs analysis will be
                           written to. Extensions .up1 and .up2 will be added
                           to the name. Default file names are:
                           'unitas.diff-expr.up1' and
                           'unitas.diff-expr.up2'.
                           (~.up1->higher expression in group 1, ~.up2->higher
                           expression in group 2).
 -silent                   Less console (STDOUT) output during annotation.
 -supp_spec                Prints the complete list of supported species and
                           quits.
 -h OR -help               Shows usage information and quits.
 -show_options             Shows available options and quits.

 ==============================================================================

";

### SET DEFAULTS ###

# trimming
$ignore_5p=22;
$skip_first_X_reads=10000;
$check_seq=500000; # set to -1 if all sequences should be checked
$check_seq_for_size=100000;
$min_size=10;
$max_size=50;
$adapter_mismatch=2;
$clipped_fraction_warning=0.5;
$post_check_3p_ends=30;
$refinement_threshold=0.8;

# main
$max_miRtail_length=2;
$intmod_miR=1;
$seqmap_max_mm=1;
$seqmap_max_insdel=0;
$threads=1;
$memory=99999;

# low complexity filter
$dust_limit=0.75;
$dust_min=1;
$dust_max=5;
$dust_maxN=0.5;

# diff. expr.
$diffexpr_outfile="unitas.diff-expr";
$diff_expr_p=0.05;
$alpha_correction=1; # 0 = no correction / 1 = Bonferroni-Holm / 2 = Bonferroni
$estimated_deviation=0.05;

# phasiRNA
$max_factorials_stored=100; # maximum  number of factorials stored in memory
$min_phasi_fraction=0.25; # minimum fraction of phased reads in a given sliding window
$min_phasi_reads=0; # minimum number of normalized phased reads
$min_phasi_loci=5; # minimum number of phased loci within the sliding window
$max_allowed_strandbias=0.95; # maximum strand bias of mapped reads. Avoid false positive phasiRNA prediction (e.g. rRNA fragments)
$min_in_line=0; # minimum number of loci directly adjacent to each other
$min_distance_between_clusters=1000; # minimum distance of loci to allocate different cluster ID
$phasi_sw_size=1000; # must be an even number
$phasi_p=0.05;

# miscellaneous
$dump_folder_prefix="UNITAS";
$outfile_prefix="unitas";
%miRtails=('A'=>1,'T'=>1,'G'=>1,'C'=>1);

# collect and check command line arguments
GetOptions
	(
	# mandatory
	"i|input=s"=>\@input,
	"s|species=s"=>\$species,

	# optional
	"refseq=s"=>\@user_refseq, # use additional reference sequences provided by the user
	"riborase"=>\$riborase, # use NCBI rRNA sequence collection to strictly filter rRNA sequences
	"trim"=>\$do_trimming, # search and remove 3' adapter sequences
	"trim_ignore_5p=i"=>\$ignore_5p, # ignore 5p sequence [nt] when searching for frequent motifs
	"trim_skip_reads=i"=>\$skip_first_X_reads, # skip first n reads in input file (often low quality and lots of N)
	"trim_check_reads=i"=>\$check_seq, # check only a specified number of reads (will make it faster)
	"trim_polyA"=>\$trim_polyA, # allow polyA tailings to be recognized as 3' adapter sequence
	"trim_minlength=i"=>\$min_size, # minimum length of a read after adapter removal
	"trim_maxlength=i"=>\$max_size, # maximum length of a read after adapter removal
	"trim_maxfinalbias=f"=>\$refinement_threshold, # maximum allowed 3' nucleotide bias after trimming
	"quick"=>\$quick_annotation, # maximum number of nontemplate 3' nucleotides
	"slow"=>\$slow_annotation, # maximum number of nontemplate 3' nucleotides
	"tail=i"=>\$max_miRtail_length, # maximum number of nontemplate 3' nucleotides
	"intmod=i"=>\$intmod_miR, # maximum number mismatches to ncRNA (not miR)
	"mismatch=i"=>\$seqmap_max_mm, # maximum number mismatches to ncRNA (not miR)
	"insdel=i"=>\$seqmap_max_insdel, # maximum number of indels to ncRNA (not miR)
	"memory=i"=>\$memory, # limit memory usage for SeqMap
	"less_memory"=>\$less_memory, # use special options for SeqMap to reduce memory usage
	"even_less_memory"=>\$even_less_memory, # use special options for SeqMap to reduce memory usage
	"phasi=i"=>\@phasi, # search for phased siRNAs with length [integer]
	"min_phasi_fraction=f"=>\$min_phasi_fraction, # minimum fraction of phased reads in a given sliding window
	"min_phasi_reads=f"=>\$min_phasi_reads, # minimum number of normalized phased reads
	"min_phasi_loci=i"=>\$min_phasi_loci, # minimum number of phased loci within the sliding window
	"min_phasi_in_line=i"=>\$min_in_line, # minimum number of loci directly adjacent to each other
	"min_distance_between_clusters=i"=>\$min_distance_between_clusters, # minimum distance of loci to allocate different cluster ID
	"max_allowed_strandbias=f"=>\$max_allowed_strandbias, # maximum strand bias of mapped reads. Avoid false positive phasiRNA prediction (e.g. rRNA fragments)
	"phasi_sw_size=i"=>\$phasi_sw_size, # must be an even number
	"phasi_p=f"=>\$phasi_p, # critical p-value for significant enrichment of phasiRNAs
	"na_for_phasi"=>\$na_for_phasi, # only sequences without annotation will be considered for phasiRNA prediction
	"calc_big_factorials"=>\$calc_big_factorials, # calculate big (>100) factorials. Without this option reads will be downscaled to n=100 which may decrease sensitivity
	"pp"=>\$check_pp_signature, # analyze 5' overlaps for total dataset and ncRNA sub-fractions
	"threads=i"=>\$threads, # maximum number of parallel threads
	"silent"=>\$silent, # less output in console
	"diffexpr"=>\$diffexpr, # do differentially expression analysis and quit
	"diffexpr_p=f"=>\$diff_expr_p, # critical p value
	"diffexpr_out"=>\$diffexpr_outfile, # name of the output file for differentially expressed RNAs
	"diffexpr_acorrection=i"=>\$alpha_correction, # 0 = no correction / 1 = Bonferroni-Holm / 2 = Bonferroni
	"diffexpr_estdev=f"=>\$estimated_deviation, # estimated deviation (+ and -) when using only one replicate
	"diffexpr_nostrays"=>\$diffexpr_nostrays, # only consider sequences that are present in all replicates
	"g1=s"=>\@diffex_g1, # unitas results folders for group 1
	"g2=s"=>\@diffex_g2, # unitas results  folders for group 2
	"latest_ref"=>\$latestref, # force program to download latest reference sequences
	"refdump"=>\$refdump_and_quit, # download reference sequences and quit
	"dump_prefix=s"=>\$dump_folder_prefix, # prefix for dump folders
	"output_prefix=s"=>\$outfile_prefix, # prefix for output files
	"keep_temp"=>\$keep_temp, # do not remove temporary files from data dump folder
	"skip_mapping"=>\$skip_mapping, # skip all mapping steps
	"skip_miR"=>\$skip_miR, # skip search for sequences derived from known piRNA producing loci
	"skip_cDNA"=>\$skip_cDNA, # skip search for sequences derived from annotated mRNA transcripts
	"skip_ncDNA"=>\$skip_ncRNA, # skip search for ncRNA fragments other than miRNA
	"skip_piR"=>\$skip_piR, # skip search for sequences derived from known piRNA producing loci
	"skip_dust"=>\$skip_dust, # skip low complexitiy filter
	"dust_limit=f"=>\$dust_limit, # threshold for dusty fraction of a sequence
	"dust_max=i"=>\$dust_max, # maximum motif size for simple sequence repeat
	"dust_maxN=f"=>\$dust_maxN, # maximum number of Ns within a sequence
	"dust_ignore_2bases_bias"=>\$no_overrepresentation_check, # do not check for overrepresentation of 2 bases
	"CC_is_CCA"=>\$CC_is_CCA, # treat 3'tRFs with CC-3' as CCA-3', makes sense when library construction was done with poly-A tailing
	"noCCAcheck"=>\$noCCAcheck, # do not check tRNAs in order to add CCA to the 3' end
	"no_html"=>\$no_html, # do not output html files
	"supp_spec"=>\$print_supported_species, # print supported species
	"h|help"=>\$print_help, # print help desk and quit
	"show_options"=>\$show_all_options, # print available options and quit
	)||die print"\nError in command line arguments.\n";

# print help / options and quit
if($print_help)
	{
	print$usage;
	exit;
	}
elsif($show_all_options)
	{
	print$usage_all_options;
	exit;
	}

# optionally make differentiall expression analysis and quit
if($diffexpr)
	{
	if($alpha_correction!~/^[012]$/)
		{
		print"\nERROR! Allowed values for alpha correction are 0 (no correction), 1 (Bonferroni-Holm) and 2 (Bonferroni).\n\n";
		exit;
		}
	open(DIFFEX_OUT_1,">${diffexpr_outfile}.up1")||die print"\nERROR! Unable to open output file ${diffexpr_outfile}.up1.\n$!\n\n";
	open(DIFFEX_OUT_2,">${diffexpr_outfile}.up2")||die print"\nERROR! Unable to open output file ${diffexpr_outfile}.up2.\n$!\n\n";
	diff_expr();
	exit;
	}
$species=lc$species;
$species=~s/^\s*//;
$species=~s/\s*$//;
foreach(@phasi)
	{
	$phasi{$_}=1;
	}

if(@input==0)
	{
	if(!$refdump_and_quit&&!$print_supported_species) # continue if the user only wants to safe reference sequences or print supported species
		{
		print"\nError. No input files specified. Use the option -input [file_or_folder.name] to specify input files.\n\n";
		exit;
		}
	}

# Check for latest unitas version
$current_versions=get('http://www.smallrnagroup.uni-mainz.de/software/current_versions');
if(length$current_versions>0)
	{
	@current_versions=split("\t",$current_versions);
	foreach(@current_versions)
		{
		@info=split(':',$_);
		if($info[0]eq"unitas")
			{
			if($info[1]eq$unitas_version)
				{
				print"\n Congrats! You are using the latest unitas version.\n";
				$update_available="";
				}
			else
				{
				if(!$silent){print"\n There is an updated version of unitas (v.$info[1]) available for download.\n Check it out at http://www.smallRNAgroup.uni-mainz.de/software.html\n";}
				$update_available=" There is an updated version of unitas (v.$info[1]) available for download.\n Check it out at http://www.smallRNAgroup.uni-mainz.de/software.html\n\n";
				}
			}
		}
	}
load_species_dictionary();

# use SeqMap options that will lead to less memory usage
$less_memory_options_miR="";
$less_memory_options_ncR="";
if($even_less_memory&&$max_miRtail_length+$intmod_miR>0)
	{
	$max_num_part=int(((($max_miRtail_length+$intmod_miR)**2)/3)+0.5);
	$less_memory_options_miR="/limit_num_part:$max_num_part "; #/no_fast_index /no_store_key /shift_mask
	}
elsif($less_memory&&$max_miRtail_length+$intmod_miR>0)
	{
	$max_num_part=int(((($max_miRtail_length+$intmod_miR)**2)/2)+0.5);
	$less_memory_options_miR="/limit_num_part:$max_num_part ";
	}
if($even_less_memory&&$seqmap_max_mm+$seqmap_max_insdel>0)
	{
	$max_num_part=int(((($seqmap_max_mm+$seqmap_max_insdel)**2)/3)+0.5);
	$less_memory_options_ncR="/limit_num_part:$max_num_part "; #/no_fast_index /no_store_key /shift_mask
	}
elsif($less_memory&&$seqmap_max_mm+$seqmap_max_insdel>0)
	{
	$max_num_part=int(((($seqmap_max_mm+$seqmap_max_insdel)**2)/2)+0.5);
	$less_memory_options_ncR="/limit_num_part:$max_num_part ";
	}

# override mismatch settings when using the options -quick or -slow
if($quick_annotation&&$slow_annotation)
	{
	print"\nError. Do not use the options -quick and -slow at the same time.\n\n";
	exit;
	}
elsif($quick_annotation)
	{
	$max_miRtail_length=1;
	$intmod_miR=0;
	$seqmap_max_mm=0;
	$seqmap_max_insdel=0;
	}
elsif($slow_annotation)
	{
	$max_miRtail_length=3;
	$intmod_miR=2;
	$seqmap_max_mm=2;
	$seqmap_max_insdel=1;
	}

# optionally skip all mapping steps
if($skip_mapping)
	{
	$skip_ncRNA=1;
	$skip_cDNA=1;
	$skip_miR=1;
	$skip_piR=1;
	}

# check command line arguments
if($max_miRtail_length>5)
	{
	print"\nError. Maximum number of non-template 3' nucleotides =5.\n\n";
	exit;
	}
if($max_miRtail_length+$intmod_miR>5)
	{
	print"\nError. Maximum sum for non-template 3' nucleotides and internal modifications must not exceed 5.\n\n";
	exit;
	}
if($seqmap_max_mm>5)
	{
	print"\nError. Maximum number of mismatches for ncRNA annotation =5.\n\n";
	exit;
	}
if($seqmap_max_insdel>3)
	{
	print"\nError. Maximum number of indels for ncRNA annotation =3.\n\n";
	exit;
	}
if($dust_limit<0.25||$dust_limit>1)
	{
	print"\nError. -dust_limit must be >=0.25 and <=1.";
	exit;
	}
if($dust_min<1)
	{
	print"\nError. -dust_min must be >0";
	exit;
	}
if($dust_min>$dust_max)
	{
	print"\nError. -dust_min must not be larger than -dust_max";
	exit;
	}

$total_number_of_supported_species=keys%species;
if($print_supported_species)
	{
	print"\nSupported species:";
	foreach(sort{$a cmp $b}keys%species)
		{
		next if($_ eq'x'||$_ eq'other');
		print"\n - $_";
		}
	print"\n\nTotal number of supported species: $total_number_of_supported_species.\nIf your species is not listed here use a closely related species instead.\nAlternatively start unitas with '-species x' or '-species other'\ntogether with your own input reference sequences: '-refseq reference.fasta'.\n\n";
	exit;
	}

# check input files/folders (exist, redundant, identical file names)
%input=();
foreach(@input)
	{
	$input{$_}=1;
	}
@input=keys%input;
@input=sort@input;
@files_only_input=();
%input=();
foreach$file(@input)
	{
	if(-d $file)
		{
		opendir(DIR,$file)||print"\nError. Unable to open directory $file.\n$!\n\n";
		while(readdir DIR)
			{
			if(-f "$file/$_")
				{
				if(!$input{$_})
					{
					$input{$_}=1;
					}
				else
					{
					print"\nError. Do not use files with identical names (from different directories): /$_.\n\n";
					exit;
					}
				push(@files_only_input,"$file/$_");
				}
			}
		close DIR;
		}
	elsif(!-e $file)
		{
		die print"\nError! Input file or folder $file does not exist.\n\n";
		}
	else
		{
		$parsed_filename=$file;
		$parsed_filename=~s/^.*[\\\/]//;
		if(!$input{$parsed_filename})
			{
			$input{$parsed_filename}=1;
			push(@files_only_input,$file);
			}
		else
			{
			print"\nError. Do not use files with identical names (from different directories): /$parsed_filename.\n\n";
			exit;
			}
		}
	}
@input=@files_only_input;
undef%input;
undef@files_only_input;

#check user refseq files (exist, redundant, correct format)
if(@user_refseq>0)
	{
	%user_refseq=();
	foreach(@user_refseq)
		{
		$user_refseq{$_}=1;
		}
	@user_refseq=keys%user_refseq;
	@user_refseq=sort@user_refseq;
	%user_refseq=();
	%refseq_headers=();
	foreach$file(@user_refseq)
		{
		if(!-e$file)
			{
			die print"\nError! Refseq file $file does not exist.\n\n";
			}
		else
			{
			# check format
			open(REFSEQ,$file)||die print"\nError! Unable to read Refseq file $file.\n$!\n\n";
			$i=0;
			while(<REFSEQ>)
				{
				$_=~s/\s*$//;
				if($_=~s/^>//)
					{
					$i++;
					$head=$_;
					if(length$head>30)
						{
						$head=substr($head,0,27)."...";
						}
					$refseq_headers{$head}++;
					if($refseq_headers{$head}>1)
						{
						$head.="_[$refseq_headers{$head}]";
						print"\nNote: Multiple use of FASTA header:\n>$_\nWill change it to: >$head\n";
						}
					if($head!~/^[^| ]+|[^| ]+$/)
						{
						print"\nError! Bad format in FASTA header of Refseq file $file.\n>$_\n\nYou should use the following format (avoid white space):\n >ncRNA_class|ncRNA_name\n";
						$new_head=$head;
						$new_head=~s/\|//g;
						$new_head=~s/ /_/g;
						$new_head="refseq|$head";
						print"Changed FASTA header to: >$new_head\n";
						}
					}
				else
					{
					$user_refseq{$head}.=$_;
					}
				}
			close REFSEQ;
			if($i==0)
				{
				print"\nWarning! No FASTA headers found in Refseq file $file.\n\n";
				}
			}
		}
	}

# use scientific species name as trivial name for those species that do not have a trivial name.
foreach$species(keys%species)
	{
	if($species{$species}eq'')
		{
		$species{$species}=$species;
		}
	}

# search for supported species
if(!$species{$species})
	{
	print"\n\nERROR: Typo or $species is not a supported species!";
	%suggested_species=();
	$clip=-1;
	while(1)
		{
		$clip++;
		%name_fragments=();
		last if(length$species<6);
		foreach$p(0..$clip)
			{
			$name_fragments{substr($species,$p,(length$species)-$clip)}=1;
			}
		foreach$fragment(keys%name_fragments)
			{
			foreach$sspec(keys%species)
				{
				if($sspec=~/$fragment/)
					{
					$suggested_species{$sspec}=1;
					}
				}
			}
		last if (keys%suggested_species>0);
		undef%name_fragments;
		}
	if(keys%suggested_species>0)
		{
		print"\n\nDid you mean:";
		foreach(keys%suggested_species)
			{
			print"\n  $_";
			}
		}
	else
		{
		print"\nNo fuzzy match to any supported species found.";
		}
	print"\n\nYou can start unitas with the option -supp_spec to print a complete\nlist of supported species.\n\n";
	exit;
	}

if(!$silent){print"

                                                          X
                                                          oXX.o
                                                         .XXXX
                                                        .XXXXX
                                                       .XXXXX.
                                                      .XXXXXXXXXo
                                                     oXXXXXX' 'XXX.
            XXX                                   .oXXXXXXXX. .XXXXo
           XXXXX.  .oXXXXoo..                 ...oXXXXXXXXXXXXXXXXXX
            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo'''
               XXXXXXXXXXXXXXX------------------XXXXXXXXXXXX'
           .X.   'XXXXXXXXXXXX      unitas      XXXXXXXXXXXXX
         XXXXXXooXXXXXXXXXXXXX------------------XXXXXXXXXXXXXoooooo...XXXX
       .XXXX'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX'''XXXXXXXXXXXXXXX''
    .oXXXX'    ''XXXXXXXXXXX' 'XXXXXXXXXXXXXXX'''''        '''       ''
   oXXXX'          'XXXXX''
   XXXX'


 Version: ..... $unitas_version
 Date: ........ $last_modified

 Input file(s):";}
foreach$file(@input)
	{
	if(!$silent){print"\n   - $file";}
	}
if(!$silent){print
"

 Parallel threads: ................ $threads
 Species: ......................... $species -> $species{$species}
 Max. miR-tail length: ............ $max_miRtail_length
 Max. internal miR modifications .. $intmod_miR
 Max. mismatch (not miR): ......... $seqmap_max_mm
 Max. indels (not miR): ........... $seqmap_max_insdel

";}

# prepare information on data base release or date
$db_versions_info="";
($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=localtime(time);
$year+=1900;
$mon++;
$mday=substr("0".$mday,-2);
$mon=substr("0".$mon,-2);

# load reference sequences and quit if the user only wants to download reference sequences for later offline runs
if($refdump_and_quit)
	{
	if(!-d"UNITAS_refdump_$species"&&$species{$species} ne 'undefined')
		{
		mkdir("UNITAS_refdump_$species")||die print"\nError. Unable to create dump folder for reference sequences.\n$!\n\n";
		}
	$download_reference=1;
	load_reference_sequences();
	exit;
	}

# download reference sequences to reference dump folder if option latestref is used, this folder does not exist or does not contain all required files
if($species{$species} eq 'undefined')
	{
	if(@user_refseq==0)
		{
		print"\nError: Use -species x only together with -refseq [your_reference.file]\n\n";exit;
		}
	$skip_miR=1;
	$skip_cDNA=1;
	if(!-e"UNITAS_refdump_$species")
		{
		mkdir("UNITAS_refdump_$species")||die print"\nError. Unable to create dump folder for reference sequences.\n$!\n\n";
		}
	print"\nCreate file with complete user refseq data...";
	open(USERREFSEQ,">UNITAS_refdump_$species/ncRNA.fas")||die print"\nUnable to create reference file UNITAS_refdump_$species/ncRNA.fas.\n$!\n\n";
	foreach$head(sort{$a cmp $b}keys%user_refseq)
		{
		print USERREFSEQ">$head\n$user_refseq{$head}\n";
		}
	close USERREFSEQ;
	print" done.";
	}
elsif(!-d"UNITAS_refdump_$species"&&$species{$species} ne 'undefined')
	{
	mkdir("UNITAS_refdump_$species")||die print"\nError. Unable to create dump folder for reference sequences.\n$!\n\n";
	$download_reference=1;
	}
elsif($latestref)
	{
	$download_reference=1;
	}
else
	{
	if(!-e"UNITAS_refdump_$species/db_versions.info"||!-e"UNITAS_refdump_$species/ncRNA.fas"||!-e"UNITAS_refdump_$species/tRF-1.fas"||!-e"UNITAS_refdump_$species/tRNA_leader.fas"||!-e"UNITAS_refdump_$species/miRBase_mature"||!-e"UNITAS_refdump_$species/miRBase_hairpin_$species{$species}.fas"||!-e"UNITAS_refdump_$species/miRBase_hairpin_non-$species{$species}.fas")
		{
		print"\nAttention: At least one reference file is missing in folder UNITAS_refdump_$species.\nWill download latest reference sequences.\n";
		$download_reference=1;
		}
	elsif(!$skip_cDNA&&!-e"UNITAS_refdump_$species/cDNA.fas")
		{
		print"\nAttention: Reference file cDNA.fas missing in folder UNITAS_refdump_$species.\nWill download latest reference sequences.\n";
		$download_reference=1;
		}
	else
		{
		# UNITAS_refdump folder contains the required files, no download necessary
		open(DBVERSIONS,"UNITAS_refdump_$species/db_versions.info");
		while(<DBVERSIONS>)
			{
			$db_versions_info.=$_;
			}
		$download_reference=0;
		if(!$silent){print"\nFound valid UNITAS_refdump folder. No downloads required.\nUsing the option -latest_ref will force unitas to download latest\nreference sequences.\n";}
		}
	}

# download NCBI rRNA sequence collection (if it does not exist in the current working directory)
if($riborase&&!-e"NCBI_rRNA_collection.fasta")
	{
	$NCBI_rRNA_collection='http://www.smallrnagroup.uni-mainz.de/data/UNITAS/NCBI_rRNA_collection.zip';
	if(!$silent){print"\nDownload NCBI rRNA sequence collection...";}
	$status=getstore($NCBI_rRNA_collection,"NCBI_rRNA_collection.zip");
	if(is_success($status))
		{
		if(!$silent){print" OK.";}
		if(!$silent){print"\nExtract file...";}
		$ae=Archive::Extract->new(archive=>"NCBI_rRNA_collection.zip");
		$ae->extract||print"\nERROR! Unable to decompress NCBI_rRNA_collection.zip.\n$!\n\n";
		unlink"NCBI_rRNA_collection.zip"||print"\nERROR! Unable to remove compressed file NCBI_rRNA_collection.zip.\n$!\n\n";
		if(!-e"NCBI_rRNA_collection.fasta")
			{
			if(!$silent){print"\nFailed to download and extract NCBI rRNA sequence collection!";}
			undef$riborase;
			}
		else
			{
			if(!$silent){print" OK.";}
			push(@user_refseq,"NCBI_rRNA_collection.fasta");
			}
		}
	else
		{
		if(!$silent){print" FAILED! $status\n\n";}
		}
	}

# download SeqMap source and compile it (if executable is not present in current working directory)
$SeqMap_source='http://www.smallrnagroup.uni-mainz.de/data/UNITAS/SeqMap/seqmap-1.0.13-src.zip';
$version=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/SeqMap/release');
$db_versions_info.="SeqMap version/date: ...................... $version\n";
if(!-e"seqmap.exe")
	{
	if(!$silent){print"\nDownload SeqMap source code...";}
	$status=getstore($SeqMap_source,"UNITAS_refdump_$species/SeqMap.zip");
	if(is_success($status))
		{
		print" OK.";
		}
	else
		{
		print" FAILED! $status\n\n";
		}
	if(!$silent){print"\nExtract file...";}
	$ae=Archive::Extract->new(archive=>"UNITAS_refdump_$species/SeqMap.zip");
	$ae->extract(to=>"UNITAS_refdump_$species")||die print"\nERROR! Unable to decompress UNITAS_refdump_$species/SeqMap.zip.\n$!\n\n";
	if(!$silent){print" OK.\nRemove compressed file...";}
	unlink"UNITAS_refdump_$species/SeqMap.zip"||print"\nERROR! Unable to remove compressed file UNITAS_refdump_$species/SeqMap.zip.\n$!\n\n";
	if(!$silent){print" OK.\nCompile SeqMap source code... ";}
	system("g++ -O3 -m64 -o seqmap.exe UNITAS_refdump_$species/seqmap-1.0.13-src/match.cpp");
	if(-e'seqmap.exe')
		{
		if(!$silent){print" OK.";}
		}
	else
		{
		print"\nERROR! No success when building SeqMap from source. Will download pre-compiled SeqMap version from smallRNAgroup-SERVER.\n";
		if($^O eq'linux')
			{
			$status=getstore('http://www.smallrnagroup.uni-mainz.de/software/Linux/seqmap.exe',"seqmap.exe");
			if(is_success($status))
				{
				# set file permission to executable
				chmod(0755,"seqmap.exe");
				print" OK.\nCheck executability (file permission)...";
				if(-x"seqmap.exe")
					{
					print" OK.";
					}
				else
					{
					print" Permission denied.\nYou have to change file permission for file 'seqmap.exe' manually. Try the following command:\n\n chmod 755 seqmap.exe\n\nThen restart unitas.\n\n";
					exit;
					}
				}
			else
				{
				die print" FAILED! $status\n\n";
				}
			}
		elsif($^O eq'darwin')
			{
			$status=getstore('http://www.smallrnagroup.uni-mainz.de/software/MacOS/seqmap.exe',"seqmap.exe");
			if(is_success($status))
				{
				# remove apple quarantine and set file permission to executable
				system("xattr -d com.apple.quarantine seqmap.exe");
				chmod(0755,"seqmap.exe");
				print" OK.\nCheck executability (file permission)...";
				if(-x"seqmap.exe")
					{
					print" OK.";
					}
				else
					{
					print" Permission denied.\nYou have to change file permission for file 'seqmap.exe' manually. Try the following command:\n\n chmod 755 seqmap.exe\n\nThen restart unitas.\n\n";
					exit;
					}
				}
			else
				{
				die print" FAILED! $status\n\n";
				}
			}
		elsif($^O eq'MSWin32')
			{
			$status=getstore('http://www.smallrnagroup.uni-mainz.de/software/Windows/seqmap.exe',"seqmap.exe");
			if(is_success($status))
				{
				print" OK.";
				}
			else
				{
				die print" FAILED! $status\n\n";
				}
			}
		}
	}

load_reference_sequences();

# prepare a list with refseq files provided by the user
$list_user_refseq="";
if(@user_refseq>0)
	{
	$list_user_refseq="\nAdditional files with reference sequences:";
	foreach(@user_refseq)
		{
		$list_user_refseq.="\n -$_";
		}
	$list_user_refseq.="\n";
	}
elsif($species{$species}eq'undefined')
	{
	print"\nError! You must provide reference sequence file(s) when using undefined species.\n\n";
	exit;
	}


if(!$silent){print"

####################################################################

The following sources will be used for small RNA annotation:

$db_versions_info
$list_user_refseq
PLEASE MAKE SURE TO CITE THE ACCORDING DATABASE PAPERS WHEN
PUBLISHING THESE RESULTS!

####################################################################

";}

# remove old unitas_pid files
@pid_files=glob("*.unitas_pid");
foreach(@pid_files)
	{
	unlink($_);
	}
@childs=();
foreach$input(@input)
	{
	# fork only when less than $threads pid-files exist in the current directory.
	while(1)
		{
		sleep(1);
		@pid_files=glob("*.unitas_pid");
		if(@pid_files<$threads)
			{
			$pid=fork;
			if($pid)
				{
				push(@childs,$pid);
				}
			elsif($pid==0)
				{
				open(WIZ_PID,">$$.unitas_pid");
				close WIZ_PID;
				process_file();
				unlink("$$.unitas_pid")||print"\nError. Unable to remove $$.unitas_pid.\n$!\n\n";
				exit 0;
				}
			else
				{
				die print"\nError. Unable to fork annotation of $input.\n\n";
				}
			last;
			}
		}
	}
foreach$pid(@childs)
	{
	waitpid($pid,0);
	}

sub process_file
	{
	# declare hashes that are valid only in this subroutine
	my%input;
	my%extracted_sequences;
	my%input_map_seq;
	my%miR_species;
	my%miR_nonspecies;
	my%tails_per_miR_species;
	my%tails_per_miR_nonspecies;
	my%miRBase_species;
	my%miRBase_nonspecies;
	my%miR_canonical_species;
	my%miR_canonical_nonspecies;
	my%output_miR_species;
	my%output_miR_nonspecies;
	my%count_internal_mods_species;
	my%count_internal_mods_nonspecies;
	my%non_annotated;
	my%valid_species_hits;
	my%tails_species;
	my%tails_nonspecies;
	my%tails_per_miR_species;
	my%tails_per_miR_nonspecies;
	my%miR_table_out_species;
	my%miR_table_out_nonspecies;
	my%miR_noncanonical_species;
	my%miR_noncanonical_nonspecies;
	my%miR_spec_seq;
	my%miR_nonspec_seq;
	my%nonmiR_seq;
	my%tRF_seqs;
	my%tRNA_half5;
	my%tRF5;
	my%tRNA_half3;
	my%tRF3_CCA;
	my%tRF3;
	my%misc_tRF;
	my%ncRNA_counts_1; # class only
	my%ncRNA_counts_2; # class and id
	my%sorted_sequences;
	my%phasiRNA_readcount;
	my%phasi_positions;
	my%sense_antisense_counts;
	my%global_annotation_matrix;

	# create data dump folder and copy reference sequences
	$i=0;
	$parsed_input=$input;
	$parsed_input=~s/^.*[\\\/]//;
	while(1)
		{
		$i++;
		$dump_folder=$dump_folder_prefix."_$mday-$mon-$year"."_$parsed_input"."_#$i";
		if(-d$dump_folder)
			{
			next;
			}
		else
			{
			if(!$silent){print"\nCreate data dump folder $dump_folder...";}
			mkdir($dump_folder)||die print"\nERROR! Unable to create folder.\n$!\n\n";
			copy("UNITAS_refdump_$species/ncRNA.fas","$dump_folder/ncRNA.fas")||die print"\nERROR! Unable to copy UNITAS_refdump_$species/ncRNA.fas to dump folder.\n$!\n\n";
			if(!$skip_cDNA&&$species{$species}ne'undefined')
				{
				copy("UNITAS_refdump_$species/cDNA.fas","$dump_folder/cDNA.fas")||die print"\nERROR! Unable to copy UNITAS_refdump_$species/cDNA.fas to dump folder.\n$!\n\n";
				}
			# add user RefSeq files to ncRNA.fas
			if(@user_refseq>0)
				{
				$user_refseq_added=0;
				if(!$silent){print"\nAdd sequences from files defined by user...";}
				open(NCRNA,">>$dump_folder/ncRNA.fas")||print"\nError! Failed to add user defined RefSeq to file $dump_folder/ncRNA.fas.\n$!\n\n";
				foreach$header(keys%user_refseq)
					{
					$user_refseq_added++;
					print NCRNA">$header\n$user_refseq{$header}\n";
					}
				close NCRNA;
				if(!$silent){print" OK. Added $user_refseq_added sequences.";}
				}
			if($species{$species}ne'undefined')
				{
				copy("UNITAS_refdump_$species/miRBase_mature","$dump_folder/miRBase_mature")||die print"\nERROR! Unable to copy UNITAS_refdump_$species/miRBase_mature to dump folder.\n$!\n\n";
				copy("UNITAS_refdump_$species/miRBase_hairpin_$species{$species}.fas","$dump_folder/miRBase_hairpin_$species{$species}.fas")||die print"\nERROR! Unable to copy UNITAS_refdump_$species/miRBase_hairpin_$species{$species}.fas to dump folder.\n$!\n\n";
				copy("UNITAS_refdump_$species/miRBase_hairpin_non-$species{$species}.fas","$dump_folder/miRBase_hairpin_non-$species{$species}.fas")||die print"\nERROR! Unable to copy UNITAS_refdump_$species/miRBase_hairpin_non-$species{$species}.fas to dump folder.\n$!\n\n";
				}
			if(-e"UNITAS_refdump_$species/piRclDB")
				{
				copy("UNITAS_refdump_$species/piRclDB","$dump_folder/piRclDB")||die print"\nERROR! Unable to copy UNITAS_refdump_$species/piRclDB to dump folder.\n$!\n\n";
				}
			if(!$silent){print" OK.";}
			last;
			}
		}

	# check total amount of reference sequence to estimate time to be used for SeqMap mapping
	$total_ncRNA_reference_bp=0;
	if(!$silent){print"\nCheck total amount of ncRNA reference sequence (excl. miRs)...";}
	open(REF,"$dump_folder/ncRNA.fas")||die print"\nERROR! Unable to open $dump_folder/ncRNA.fas.\n$!\n\n";
	while(<REF>)
		{
		if($_!~/^>/)
			{
			$_=~s/\s*$//;
			$total_ncRNA_reference_bp+=length$_;
			}
		}
	close REF;
	if(!$silent){print" $total_ncRNA_reference_bp bp.";}

	# check input file
	if(!$silent){print"\nCheck input file format...";}
	if(!-e$input)
		{
		die print"\nERROR! Input file $input not found.\n\n";
		}
	else
		{
		open(INPUT,$input)||die print"\nERROR! Unable to open input file $input.\n$!\n\n";
		$i=0;
		$fasta_heads=0;
		$fastq_heads=0;
		$sam_lines=0;
		$eland3_lines=0;
		$collapsed='collapsed ';
		$head_is_over=0;
		while(<INPUT>)
			{
			if($_!~/^trans_id/&&$_!~/^[#\@]/)# skip all the header lines in map files
				{
				$head_is_over=1;
				}
			next if($head_is_over==0);
			$_=~s/\s*$//;
			@d=split("\t",$_);
			$i++;
			last if($i==1000); # check 1000 lines after the header section
			if($_=~/^>/)
				{
				if($_!~/^>\s*\d+\s*$/)
					{
					$collapsed='uncollapsed ';
					}
				$fasta_heads++;
				}
			elsif($_=~/^@/)
				{
				if($_!~/^@\s*\d+\s*$/)
					{
					$collapsed='uncollapsed ';
					}
				$fastq_heads++;
				}
			elsif(looks_like_number($d[1])&&$d[1]>-1&&$d[1]<2**16&&$d[3]=~/^\d+$/&&$d[9]=~/^[ATGCUN]+$/)
				{
				$sam_lines++;
				}
			elsif($d[1]=~/^\d+$/&&$d[2]=~/^[ATGCUN]+$/&&$d[4]=~/^[ATGCUN]+$/&&$d[5]=~/^\d+$/&&$d[6]=~/^[\+-]$/)
				{
				$eland3_lines++;
				}
			}
		close INPUT;
		if($fasta_heads>$fastq_heads&&$fasta_heads>$sam_lines&&$fasta_heads>$eland3_lines)
			{
			$format='FASTA';
			}
		elsif($fastq_heads>$fasta_heads&&$fastq_heads>$sam_lines&&$fastq_heads>$eland3_lines)
			{
			$format='FASTQ';
			}
		elsif($sam_lines>$eland3_lines)
			{
			$format='SAM';
			$collapsed='';
			}
		elsif($eland3_lines>$sam_lines)
			{
			$format='ELAND3';
			$collapsed='';
			}
		else
			{
			print"\nERROR! Unknown file format of input file $input.\nUse FASTA, FASTQ, SAM or ELAND3 (from sRNAmapper: http://www.smallrnagroup.uni-mainz.de/software.html).\n\n";
			exit;
			}
		if(!$silent){print" ${collapsed}$format.";}
		close INPUT;

		if(@phasi>0&&$format ne'SAM'&&$format ne'ELAND3')
			{
			print"\nERROR! When searching for phased RNAs the input file must be a map file in SAM or ELAND3 format (ELAND3 is standard output format of sRNAmapper: http://www.smallrnagroup.uni-mainz.de/software.html).\n\n";
			exit;
			}
		if($check_pp_signature)
			{
			if($format ne'SAM'&&$format ne'ELAND3')
				{
				print"\nERROR! When searching for ping pong signatures the input file must be a map file in SAM or ELAND3 format (ELAND3 is standard output format of sRNAmapper: http://www.smallrnagroup.uni-mainz.de/software.html).\n\n";
				exit;
				}
			}
		if($do_trimming)
			{
			if($format eq'SAM'||$format eq'ELAND3')
				{
				print"\nNOTE! Do not use the trimming option (-trim) when the input file is a map file.\n\n";
				undef$do_trimming;
				}
			}
		}

	# convert FASTQ/SAM/ELAND3 to FASTA (SeqMap accepts FASTA only)
	if($format eq'FASTQ')
		{
		if(!$silent){print"\nConvert input file to FASTA...";}
		open(FASTQ,$input)||die print"\nUnable to open input file $input.\n$!\n\n";
		open(FASTA,">$dump_folder/$parsed_input.fas")||die print"\nError! Unable to create output file $dump_folder/$parsed_input.fas.\n$!\n\n";
		$i=0;
		@seq_data=();
		while(<FASTQ>)
			{
			$_=~s/\s*$//;
			push(@seq_data,$_);
			$i+=0.25;
			if($i==1)
				{
				$i=0;
				$seq_data[0]=~s/^\@/>/;
				if(length$seq_data[1]>0)
					{
					print FASTA"$seq_data[0]\n$seq_data[1]\n";
					}
				@seq_data=();
				}
			}
		close FASTA;
		close FASTQ;
		$parsed_input.=".fas";
		$input_for_DNApi=$input;
		$input="$dump_folder/$parsed_input";
		if(!$silent){print" OK.";}
		}
	elsif($format eq'SAM')
		{
		$input_map=$input;
		if(!$silent){print"\nExtract sequences from $input...";}
		# save flags that refer to '-' or '+' strand and mapped/unmapped reads in SAM files
		foreach$bit1(0,1)
		{foreach$bit2(0,2)
		{foreach$bit3(0,4)
		{foreach$bit4(0,8)
		{foreach$bit5(0,16)
		{foreach$bit6(0,32)
		{foreach$bit7(0,64)
		{foreach$bit8(0,128)
		{foreach$bit9(0,256)
		{foreach$bit10(0,512)
		{foreach$bit11(0,1024)
		{foreach$bit12(0,2048)
			{
			$flag=$bit1+$bit2+$bit3+$bit4+$bit5+$bit6+$bit7+$bit8+$bit9+$bit10+$bit11+$bit12;
			if($bit3==4)
				{
				$sam_mapped{$flag}=0;
				}
			else
				{
				$sam_mapped{$flag}=1;
				}
			if($bit5==16)
				{
				$sam_strand{$flag}='-';
				}
			else
				{
				$sam_strand{$flag}='+';
			}}}}}}}}}}}}}
		open(SAM,$input)||die print"\nERROR! Unable to open input file $input.\n$!\n\n";
		$extracted_sequences_nonid=0;
		$extracted_sequence_reads=0;
		$all_identifiers_are_numeric=1;
		while(<SAM>)
			{
			next if($_=~/^@/); # skip SAM header lines
			@sam=split("\t",$_);
			next if($sam_mapped{$sam[1]}==0||$sam[3]==0); # skip unmapped reads
			if(!looks_like_number($sam[0]))
				{
				$all_identifiers_are_numeric=0;
				}

			# reverse complement if sequence was mapped to the minus strand (SAM gives sequence of the locus, not of the mapped sequence)
			if($sam_strand{$sam[1]}eq'-')
				{
				$sam[9]=reverse$sam[9];
				$sam[9]=~tr/ATGC/TACG/;
				}

			$extracted_sequences{$sam[9]}{$sam[0]}++;
			}
		close SAM;

		# make a collapsed FASTA file from map file
		fasta_from_map_file();
		sub fasta_from_map_file
			{
			open(EXTRACTED,">$dump_folder/$parsed_input.mapped_sequences")||die print"\nError! Unable to create output file $dump_folder/$parsed_input.mapped_sequences.\n$!\n\n";
			if($all_identifiers_are_numeric==0)
				{
				foreach$seq(keys%extracted_sequences)
					{
					next if(length$seq==0);
					$read_counts=keys%{$extracted_sequences{$seq}};
					print EXTRACTED">$read_counts\n$seq\n";
					$input_map_seq{$seq}=$read_counts;
					$extracted_sequence_reads+=$read_counts;
					$extracted_sequences_nonid++;
					}
				}
			elsif($all_identifiers_are_numeric==1)
				{
				foreach$seq(keys%extracted_sequences)
					{
					next if(length$seq==0);
					foreach$val(keys%{$extracted_sequences{$seq}}) # there will be only one key!
						{
						$read_counts=$val;
						}
					print EXTRACTED">$read_counts\n$seq\n";
					$input_map_seq{$seq}=$read_counts;
					$extracted_sequence_reads+=$read_counts;
					$extracted_sequences_nonid++;
					}
				}
			$input="$dump_folder/$parsed_input.mapped_sequences";
			$collapsed='collapsed';
			if(!$silent){print" done. $extracted_sequences_nonid non-identical sequences represented by $extracted_sequence_reads reads.";}
			if(@phasi==0&&!$check_pp_signature)
				{
				undef%extracted_sequences;
				undef%input_map_seq;
				}
			close EXTRACTED;
			}
		}
	elsif($format eq'ELAND3')
		{
		$input_map=$input;
		if(!$silent){print"\nExtract sequences from $input...";}
		open(ELAND3,$input)||die print"\nERROR! Unable to open input file $input.\n$!\n\n";
		%extracted_sequences=();
		$all_identifiers_are_numeric=1;
		while(<ELAND3>)
			{
			next if($_=~/^trans_id/||$_=~/^#/);
			@eland3=split("\t",$_);
			if(!looks_like_number($eland3[3]))
				{
				$all_identifiers_are_numeric=0;
				}
			$extracted_sequences{$eland3[4]}{$eland3[3]}++;
			}
		close ELAND3;
		fasta_from_map_file(); # see above (SAM)
		}

	# remove 3' adapter sequence
	if($do_trimming)
		{
		if(!$silent){print"\nSearch and remove 3' adapter sequences.";}
		my %motifs=();
		my %length=();
		my %new_3p=();
		my %trimmed_out=();

		# check for read length in input file, adjust adapter motif length
		open(TRIM,$input)||die print"\nERROR! Unable to open input file $input for trimming.\n$!\n\n";
		if(!$silent){print"\nCheck read length in input file (first $check_seq_for_size reads)...";}
		$i=0;
		%length=();
		while(<TRIM>)
			{
			if($_!~/^>/)
				{
				$i++;
				$_=~s/\s*$//;
				$length{length$_}++;
				last if($i==$check_seq_for_size);
				}
			}
		close TRIM;
		if(!$silent){print" OK.";}
		foreach$l(sort{$length{$a}<=>$length{$b}}keys%length)
			{
			$length=$l;
			if(!$silent){print"\n - length:$l nt -> $length{$l} reads.";}
			}
		if(keys%length==1)
			{
			if(!$silent){print"\nLooks good (untrimmed). All reads have equal length.\n";}
			$init_motif_length=$length-$ignore_5p;
			$min_motif_length=6;
			if($init_motif_length>12)
				{
				$init_motif_length=12;
				}
			if($init_motif_length<6)
				{
				print"\n
  ------------------------------------------------------------------------
  WARNING: Reads in input file are very short. Searching for 3' adapter
  sequences is challenging, considering the typical miRNA length of 22 nt.
  Parameters are modified to search for frequent 5 nt motifs in last 8 nt
  of the reads. The final minimum motif length at 3' ends is set to 2 nt.

  NOTE:
  You may also consider to map your reads using a popular aligner such as
  STAR, bowtie or bowtie2, allowing softclipping at the 3' end. Then you
  can use the map file (SAM format) as input for unitas. We recommend this
  procedure for all unclipped sRNA datasets with sequence length <=26 nt.
  ------------------------------------------------------------------------

";
				$init_motif_length=4;
				$min_motif_length=4;
				$ignore_5p=$length-8;
				}
			if($init_motif_length<$min_motif_length)
				{
				$min_motif_length=$init_motif_length;
				}
			}
		else
			{
			if(!$silent){print"\nNOTE: Input file looks trimmed (found sequences with different length)!\nContinue nevertheless.\n";}
			$init_motif_length=12;
			$min_motif_length=6;
			}

		# search adapter sequence with DNApi
		$dnapi_success=0;
		if($format eq "FASTQ" && -e "dnapi.py" && -x "dnapi.py")
			{
			if(!$silent){print"\nSearch for adapter sequence with DNApi...";}
			if($^O eq'linux'||$^O eq'darwin')
				{
				qx/python dnapi.py $input_for_DNApi > $dump_folder\/adapter.dnapi/;
				}
			elsif($^O eq'MSWin32')
				{
				system("python dnapi.py $input_for_DNApi > $dump_folder/adapter.dnapi");
				}
			else
				{
				if(!$silent){print" WARNING! Unknown operating system.";}
				# try unix command
				qx/python dnapi.py $input_for_DNApi > $dump_folder\/adapter.dnapi/;
				if(!-e"$dump_folder/adapter.dnapi")
					{
					# try windows command
					system("python dnapi.py $input_for_DNApi > $dump_folder/adapter.dnapi");
					}
				}
			if(!-e"$dump_folder/adapter.dnapi")
				{
				if(!$silent){print"\nERROR. Tried to execute DNApi but cannot find its output file.\nWill use internal algorithm to search for 3' adapter sequence.";}
				}
			else
				{
				open(DNAPI,"$dump_folder/adapter.dnapi");
				while(<DNAPI>)
					{
					$_=~s/\s*$//;
					if($_=~/^[ATGC]+$/)
						{
						$dnapi_success=1;
						$adapter_abundance="??";
						$adapter_to_clip=$_;
						last;
						}
					}
				close DNAPI;
				if($dnapi_success==0)
					{
					if(!$silent){print"\nERROR. DNApi did not run properly (missing file?).\nWill use internal algorithm to search for 3' adapter sequence.";}
					}
				}
			}

		# check for motif (internal algorithm)
		if($dnapi_success==0)
			{
			$i=0;
			open(TRIM,$input)||die print"\nERROR. Unable to open input file $input.\n$!\n\n";
			if(!$silent){print"\nSearch for frequent 3' motifs ($init_motif_length nt) in input file...";}
			while(<TRIM>)
				{
				if($_!~/^>/)
					{
					$i++;
					$_=~s/\s*$//;
					next if($i<=$skip_first_X_reads);
					last if($i==$check_seq+$skip_first_X_reads);
					$_=~s/^.{$ignore_5p}//;
					while(length$_>$init_motif_length)
						{
						$motifs{substr$_,0,$init_motif_length}++;
						$_=~s/.//;
						}
					}
				}
			close TRIM;
			foreach$seq(sort{$motifs{$b}<=>$motifs{$a}}keys%motifs)
				{
				next if($seq=~/N/);
				next if($seq=~/^A+$/&&!$trim_polyA);
				next if($seq=~/^T+$/);
				next if($seq=~/^G+$/);
				next if($seq=~/^C+$/);
				$adapter_to_clip=$seq;
				$adapter_abundance=(int((($motifs{$seq}/$i)*10000)+0.5))/100;
				last;
				}
			if(!$silent){print" OK.";}
			if($adapter_abundance<$clipped_fraction_warning*100)
				{
				if(!$silent){print"\nNOTE: Fraction of reads containing putative adapter sequence is low!\nContinue nevertheless.\n";}
				}
			}

		# 1st round of motif clipping ("KNIPSER" by Daniel Gebert)
		open(TRIM,$input)||die print"\nERROR. Unable to open input file $input.\n$!\n\n";
		open(OUT,">$dump_folder/$parsed_input.trimmed")||die print"\nERROR. Unable to open output file $dump_folder/$parsed_input.trimmed.\n$!\n\n";
		if(!$silent){print"\nClip most abundant sequence ($adapter_abundance%): $adapter_to_clip-(N)x-3'...";}
		$j=0; # fasta heads
		$k=0; # trimmed
		$k_ok=0; # trimmed, length ok
		$win_start=$min_size;
		while($line=<TRIM>)
			{
			$line=~s/\s*$//;
			if($line=~s/^>//)
				{
				$j++;
				$header = $line;
				}
			else
				{
				# Get sequence, adapter motif and max. Hamming Distance
				my $seq = $line;
				my $motif = $adapter_to_clip;
				my $hd_max = $adapter_mismatch;
				# Slide window through sequence and search for motif
				for (my $i=$win_start; $i <= length($seq)-$min_motif_length; $i++)
					{
						# Chop motif if window hits end of sequence
						if ($i > length($seq)-length($motif)) {
							chop($motif);
						}
						# Get window sequence
						my $window = substr($seq, $i, length $motif);
						# Check if motif matches window
						if ($window eq $motif) {
							$k++;
							if($i<=$max_size){
							$k_ok++;
							# Save clipped sequence and leave loop
							$clip_seq = substr($seq, 0, $i);
							$trimmed_out{$clip_seq}.="##$header";
							check_new_3p();
							last;
							}
						}
						# If no exact match found and mismatches allowed
						elsif ($hd_max > 0) {
							# Reduce max. Hamming Distance if motif chopped
							if ($motif ne $adapter_to_clip) { $hd_max = 1 }
							if (length($motif) < 9) { $hd_max = 0 }
							# Get Hamming Distance
							my $hd = ($window ^ $motif) =~ tr/\0//c;
							if ($hd <= $hd_max) {
								$k++;
								if($i<=$max_size){
								$k_ok++;
								# Save clipped sequence and leave loop
								$clip_seq = substr($seq, 0, $i);
								$trimmed_out{$clip_seq}.="##$header";
								check_new_3p();
								last;
								}
							}
						}
					}
				}
			}
		close TRIM;
		sub check_new_3p
			{
			foreach$p(1..$post_check_3p_ends)
				{
				$new_3p{-$p}{substr($clip_seq,-$p,1)}++;
				}
			}

		if(!$silent){print" OK.\n\nTotal processed reads: $j\nClipped reads: $k\n$min_size-$max_size nt: $k_ok\n";}
		if($k/$j<$clipped_fraction_warning)
			{
			if(!$silent){print"\nNOTE: Fraction of clipped reads is low!\nContinue nevertheless.\n";}
			}

		# refinement
		$i=0;
		$nibble=0;
		$nibble_motif="";
		if(!$silent){print"\nCheck new 3' ends for bias in positional nucleotide composition.\nNucleotide compositions of new 3' ends [%]:";}
		foreach$p(1..$post_check_3p_ends)
			{
			$i++;
			$N=$new_3p{-$p}{'A'}+$new_3p{-$p}{'T'}+$new_3p{-$p}{'G'}+$new_3p{-$p}{'C'};
			$A_perc=(int((($new_3p{-$p}{'A'}/$N)*10000)+0.5))/100;
			$T_perc=(int((($new_3p{-$p}{'T'}/$N)*10000)+0.5))/100;
			$G_perc=(int((($new_3p{-$p}{'G'}/$N)*10000)+0.5))/100;
			$C_perc=(int((($new_3p{-$p}{'C'}/$N)*10000)+0.5))/100;
			if(!$silent){print"\nPosition -$p: A:$A_perc T:$T_perc G:$G_perc C:$C_perc";}
			if($new_3p{-$p}{'A'}/$N>$refinement_threshold)
				{
				$nibble++;
				$nibble_motif="A".$nibble_motif;
				if(!$silent){print"\tBAD! Too much 'A'!";}
				}
			elsif($new_3p{-$p}{'T'}/$N>$refinement_threshold)
				{
				$nibble++;
				$nibble_motif="T".$nibble_motif;
				if(!$silent){print"\tBAD! Too much 'T'!";}
				}
			elsif($new_3p{-$p}{'G'}/$N>$refinement_threshold)
				{
				$nibble++;
				$nibble_motif="G".$nibble_motif;
				if(!$silent){print"\tBAD! Too much 'G'!";}
				}
			elsif($new_3p{-$p}{'C'}/$N>$refinement_threshold)
				{
				$nibble++;
				$nibble_motif="C".$nibble_motif;
				if(!$silent){print"\tBAD! Too much 'C'!";}
				}
			else
				{
				if(!$silent){print"\tOK.";}
				last;
				}
			}
		if($i==$post_check_3p_ends)
			{
			if(!$silent){print"\nNOTE: Sequence file needs attention!\nLow heterogenety in last $post_check_3p_ends nucleotides!\nTrimming is presumably not correct!\nContinue nevertheless.\n\n";}
			}
			$i=0;
		if($nibble==0)
			{
			if(!$silent){print"\n\n3' ends of processed sequences look fine.\nPrint sequences to $input.trimmed...";}
			foreach$seq(keys%trimmed_out)
				{
				$trimmed_out{$seq}=~s/^##//;
				@titles=split('##',$trimmed_out{$seq});
				foreach$title(@titles)
					{
					$i++;
					print OUT">$title\n$seq\n";
					}
				}
			if(!$silent){print" OK.";}
			}
		else
			{
			if(!$silent){print"\n\n3' ends of processed sequences need further refinement.\nRemove $nibble_motif-3' and print sequences to $input.trimmed...";}
			foreach$seq(keys%trimmed_out)
				{
				$trimmed_seq=$seq;
				if($trimmed_seq=~s/$nibble_motif$//)
					{
					if(length$trimmed_seq>=$min_size)
						{
						$trimmed_out{$seq}=~s/^##//;
						@titles=split('##',$trimmed_out{$seq});
						foreach$title(@titles)
							{
							$i++;
							print OUT">$title\n$trimmed_seq\n";
							}
						}
					}
				}
			if(!$silent){print"\nRemaining reads $min_size-$max_size nt: $i";}
			}
		close OUT;
		if(!$silent){print"\n\nDetermined adapter sequence: ${nibble_motif}${adapter_to_clip}-(N)x-3'.\n";}
		$input=$trimmmed_file;
		$parsed_input.=".trimmed";
		$input="$dump_folder/$parsed_input";
		}

	# collapse if input is uncollapsed FASTA or FASTQ (or map file from uncollapsed FASTA or FASTQ)
	if($collapsed eq'uncollapsed ')
		{
		if(!$silent){print"\nCollapse input file...";}
		open(INPUT,$input)||die print"\nError! Unable to open input file $input.\n$!\n\n";
		open(COLLAPSED,">$dump_folder/$parsed_input.collapsed")||die print"\nError! Unable to create input file $dump_folder/$parsed_input.\n$!\n\n";
		while(<INPUT>)
			{
			$_=~s/\s*$//;
			if($_!~/^>/)
				{
				$input{$_}++;
				}
			}
		foreach$seq(sort{$input{$b}<=>$input{$a}}keys%input)
			{
			next if(length$seq==0);
			print COLLAPSED">$input{$seq}\n$seq\n";
			}
		close INPUT;
		close COLLAPSED;
		$parsed_input.=".collapsed";
		$input="$dump_folder/$parsed_input";
		undef%input;
		if(!$silent){print" OK.";}
		}

	# low complexity filter | use default parameters from the duster tool (NGS TOOLBOX)
	if(!$skip_dust)
		{
		if(!$silent){print"\nFilter low complexity reads from $parsed_input...";}
		open(IN,$input)||die print"\nError! Unable to open input file $input.\n$!\n\n";
		open(OK,">$dump_folder/$parsed_input.no-dust")||die print"\nError! Unable to create file $dump_folder/$parsed_input.no-dust.\n$!\n\n";
		open(DUST,">$dump_folder/$parsed_input.dust")||die print"\nError! Unable to create file $dump_folder/$parsed_input.dust.\n$!\n\n";
		$i=0;
		$simple_reads=0;
		$complex_reads=0;
		$threshold_2nt=$dust_limit+((1-$dust_limit)*$dust_limit);
		$simple_1nt=0;
		$simple_2nt=0;
		my%simple_motif=();
		@seq_data=();
		while(<IN>)
			{
			$_=~s/\s*$//;
			if($_=~s/^>//)
				{
				$reads=$_;
				}
			else
				{
				$ok=1;
				next if(length$_==0);
				$read_length=length$_;

				# simple monomer over-representation check
				$monomer_check=$_;
				$amount_N=($monomer_check=~tr/N//);
				$non_N=length$monomer_check;
				$amount_A=($monomer_check=~tr/A//);
				$amount_T=($monomer_check=~tr/T//);
				$amount_G=($monomer_check=~tr/G//);
				$amount_C=($monomer_check=~tr/C//);
				if($non_N/$read_length<$dust_maxN||$amount_A/$non_N>$dust_limit||$amount_T/$non_N>$dust_limit||$amount_G/$non_N>$dust_limit||$amount_C/$non_N>$dust_limit)
					{
					$ok=0;
					$simple_1nt++;
					}

				# motif enrichment check
				if($ok==1)
					{
					my%fragments=();
					foreach$frag_size(2..$dust_max)
						{
						$gnaw=$_;
						while(length$gnaw>=$frag_size)
							{
							$gnaw=~s/^.{$frag_size}//;
							$fragments{$&}=$frag_size;
							}
						}
					foreach$fragment(sort{$fragments{$a}<=>$fragments{$b}}keys%fragments) # make it faster by searching for short motifs first
						{
						$check=$_;
						$check=~s/$fragment//g;
						if(length$check<=$read_length*(1-$dust_limit))
							{
							$ok=0;
							$simple_motif{length$fragment}++;
							last;
							}
						}
					undef%fragments;
					}

				# 2 bases over-representation check
				if($ok==1&&!$no_overrepresentation_check)
					{
					if(($amount_A+$amount_T)/$non_N>$threshold_2nt||($amount_A+$amount_G)/$non_N>$threshold_2nt||($amount_A+$amount_C)/$non_N>$threshold_2nt||($amount_T+$amount_G)/$non_N>$threshold_2nt||($amount_T+$amount_C)/$non_N>$threshold_2nt||($amount_G+$amount_C)/$non_N>$threshold_2nt)
						{
						$ok=0;
						$simple_2nt++;
						}
					}

				$output=">$reads\n$_\n";
				if($ok==1)
					{
					$complex_reads+=$reads;
					print OK$output;
					$global_annotation_matrix{$_}{$reads}.="";
					}
				else
					{
					$simple_reads+=$reads;
					print DUST$output;
					$global_annotation_matrix{$_}{$reads}="low_complexity\t";
					}
				}
			}
		$parsed_input.=".no-dust";
		$input="$dump_folder/$parsed_input";
		if(!$silent){print" done.\n$complex_reads sequences are ok.\n$simple_reads sequences are dusty (low-complexity).\n  Monomer:             $simple_1nt\n  Biased for 2 bases:  $simple_2nt";}
		if(!$silent)
			{
			foreach$i(2..$dust_max)
				{
				if(!$simple_motif{$i})
					{
					$simple_motif{$i}=0;
					}
				print"\n  $i nt motif enriched: $simple_motif{$i}";
				}
			}
		if($complex_reads==0)
			{
			print"\nNo reads passed low complexity filter!";
			exit;
			}
		}
	close IN;
	close OK;
	close DUST;

	# load mature miRNA sequences to memory
	$no_nonmiRs=0;
	if(!$skip_miR)
		{
		if(!$silent){print"\nLoad mature miRNA sequences for $species{$species} to memory...";}
		open(MIR_MAT,"$dump_folder/miRBase_mature")||die print"\nERROR! Unable to open miRBase file $dump_folder/miRBase_mature.\n$!\n\n";
		$i=0;
		while(<MIR_MAT>)
			{
			$_=~s/\s*$//;
			if($_=~s/^>//)
				{
				@head=split(' ',$_);
				}
			else
				{
				$_=~s/U/T/g;
				if(lc$head[2].'_'.$head[3]eq$species)
					{
					$i++;
					$miRBase_species{$_}=$head[4];
					}
				}
			}
		close MIR_MAT;
		if(!$silent){print" OK ($i sequences loaded).\nLoad mature miRNA sequences for other species to memory...";}
		open(MIR_MAT,"$dump_folder/miRBase_mature")||die print"\nERROR! Unable to open miRBase file $dump_folder/miRBase_mature.\n$!\n\n";
		$i=0;
		while(<MIR_MAT>)
			{
			$_=~s/\s*$//;
			if($_=~s/^>//)
				{
				@head=split(' ',$_);
				}
			else
				{
				$_=~s/U/T/g;
				if(!$miRBase_species{$_})
					{
					$i++;
					$miRBase_nonspecies{$_}.="$head[0] ";
					}
				}
			}
		close MIR_MAT;
		foreach(keys%miRBase_nonspecies)
			{
			$miRBase_nonspecies{$_}=~s/ $//;
			}
		if(!$silent){print" OK ($i sequences loaded).";}

		# search mature canonical miRNAs, perfect full-length hits.
		if(!$silent){print"\nSearch for mature, canonical miRNAs...";}
		open(OUT_MIR_SPECIES,">$dump_folder/$outfile_prefix.miR.$species{$species}.fas")||die print"\nERROR! Unable to create output file $dump_folder/$outfile_prefix.mature-miR.$species{$species}.fas.\n$!\n\n";
		open(OUT_MIR_NONSPECIES,">$dump_folder/$outfile_prefix.miR.non-$species{$species}.fas")||die print"\nERROR! Unable to create output file $dump_folder/$outfile_prefix.mature-miR.non-$species{$species}.fas.\n$!\n\n";
		open(OUT_NONMIR,">$dump_folder/$outfile_prefix.non-miR.fas")||die print"\nERROR! Unable to create output file $dump_folder/$outfile_prefix.non-miR.fas.\n$!\n\n";
		open(INPUT,$input)||die print" ERROR! Unable to open input file $input.\n$!\n\n";
		while(<INPUT>)
			{
			$_=~s/\s*$//;
			if($_=~s/^>//)
				{
				$reads=$_;
				}
			elsif($miRBase_species{$_})
				{
				$miR_canonical_species{$_}=$reads;
				$miR_table_out_species{$_}{0}=$reads;
				$output_miR_species{$_}=1;
				if($global_annotation_matrix{$_}{$reads}!~/\Q$miRBase_species{$_}/){$global_annotation_matrix{$_}{$reads}.="$miRBase_species{$_}\t";}
				}
			elsif($miR_nonspecies{$_})
				{
				$miR_canonical_nonspecies{$_}=$reads;
				$miR_table_out_nonspecies{$_}{0}=$reads;
				$output_miR_nonspecies{$_}=1;
				if($global_annotation_matrix{$_}{$reads}!~/\Q$miR_nonspecies{$_}/){$global_annotation_matrix{$_}{$reads}.="$miR_nonspecies{$_}\t";}
				}
			else
				{
				$non_annotated{$_}=$reads;
				}
			}
		close INPUT;
		if(!$silent){print" OK.\nSearch for non-canonical and 3' tailed miRNAs ($species{$species})...";}

		# create SeqMap input file for SPECIES run
		open(INPUT,$input)||die print"\nERROR! Unable to open input file $input.\n$!\n\n";
		open(NEW_INPUT,">$dump_folder/SeqMap_input1.temp")||die print"\nERROR! Unable to create temporary SeqMap input file $dump_folder/SeqMap_input1.temp.\n$!\n\n";
		while($input_line=<INPUT>)
			{
			$input_line=~s/\s*$//;
			if($input_line=~s/^>//)
				{
				$reads=$input_line;
				}
			elsif(!$miR_canonical_species{$input_line})
				{
				print NEW_INPUT">$reads\n$input_line\n";
				}
			}
		close INPUT;
		close NEW_INPUT;

		# check length of miRNA precursors
		%miR_hairpin_length=();
		foreach$index("$species{$species}","non-$species{$species}")
			{
			open(MIR_PREC,"$dump_folder/miRBase_hairpin_$index.fas")||die print"\nERROR! Unable to check miR-precursor lengths from $dump_folder/miRBase_hairpin_$index.fas.\n$!\n\n";
			while(<MIR_PREC>)
				{
				$_=~s/\s*$//;
				if($_=~s/^>//)
					{
					$head=$_;
					}
				else
					{
					$miR_hairpin_length{$head}=length$_;
					}
				}
			close MIR_PREC;
			}

		# run SeqMap on SPECIES miRNA hairpins
		$mm_for_SeqMap_run=$intmod_miR+$max_miRtail_length;
		if($^O eq'linux'||$^O eq'darwin')
			{
			qx/.\/seqmap.exe $mm_for_SeqMap_run $dump_folder\/SeqMap_input1.temp $dump_folder\/miRBase_hairpin_$species{$species}.fas $dump_folder\/SeqMap_species.temp \/output_all_matches \/forward_strand \/available_memory:${memory}000 $less_memory_options_miR> $dump_folder\/SeqMap_report1.txt/;
			}
		elsif($^O eq'MSWin32')
			{
			system("seqmap.exe $mm_for_SeqMap_run $dump_folder/SeqMap_input1.temp $dump_folder/miRBase_hairpin_$species{$species}.fas $dump_folder/SeqMap_species.temp /output_all_matches /forward_strand /available_memory:${memory}000 ${less_memory_options_miR}2>&1 > $dump_folder/SeqMap_report1.txt");
			}
		else
			{
			if(!$silent){print" WARNING! Unknown operating system.";}
			# try unix command
			qx/.\/seqmap.exe $mm_for_SeqMap_run $dump_folder\/SeqMap_input1.temp $dump_folder\/miRBase_hairpin_$species{$species}.fas $dump_folder\/SeqMap_species.temp \/output_all_matches \/forward_strand \/available_memory:${memory}000 $less_memory_options_miR> $dump_folder\/SeqMap_report1.txt/;
			if(!-e"$dump_folder/SeqMap_species.temp")
				{
				# try windows command
				system("seqmap.exe $mm_for_SeqMap_run $dump_folder/SeqMap_input1.temp $dump_folder/miRBase_hairpin_$species{$species}.fas $dump_folder/SeqMap_species.temp /output_all_matches /forward_strand /available_memory:${memory}000 ${less_memory_options_miR}2>&1 > $dump_folder/SeqMap_report1.txt");
				}
			}
		# check SeqMap report
		open(SMR,"$dump_folder/SeqMap_report1.txt");
		while(<SMR>)
			{
			if($_=~/not enough memory/)
				{
				print"\n\nERROR. Not enough memory available for SeqMap. Check $dump_folder/SeqMap_report1.txt for more details. Try less mismatch (-mismatch [n]), less insertions/deletions (-insdel [n]), fewer non-template 3' nucleotides (-tail [n]). Alternatively you may want to use the options -less_memory or -even_less_memory.\n\n";
				exit;
				}
			}
		close SMR;

		# clean up SeqMap output for SPECIES
		$file_id="species";
		clean_SeqMap_miRNA();
		open(SEQMAP,"$dump_folder/SeqMap_species.clean-2.temp");
		%hits_per_miRspecies=();
		while(<SEQMAP>)
			{
			$_=~s/\s*$//;
			@seqmap=split("\t",$_);
			$hits_per_miRspecies{$seqmap[4]}++;

			# save targets of this sequence (without the tail)
			if(!$targets_per_miRspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])})
				{
				$targets_per_miRspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])}.="$seqmap[0] ";
				}

			# save valid hits to exclude these from non-species search
			$valid_species_hits{$seqmap[4]}=1;
			}
		close SEQMAP;

		# search non-canonical (tailed and untailed) SPECIES miRNAs
		unless(open(SEQMAP,"$dump_folder/SeqMap_species.clean-2.temp"))
			{
			print"\nERROR! Unable to open temporary SeqMap output file.\n$!\n\n";
			open(REPORT,"$dump_folder/SeqMap_report1.txt");
			while(<REPORT>)
				{
				print$_;
				}
			exit;
			}
		while(<SEQMAP>)
			{
			$_=~s/\s*$//;
			@seqmap=split("\t",$_);

			# count internal modifications
			if($seqmap[0]=~/\(.+\)/)
				{
				$mod=$&;
				$mod=~s/[\(\)]//g;
				$mod=~s/\d+//;
				$modpos=$&;
				$mod=~s/^-/?-/;
				$count_internal_mods_species{$mod}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
				$count_internal_mods_species{$modpos}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
				$mods_per_pos_species{$modpos}{$mod}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
				}

			if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/\Q$seqmap[0]/){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="$seqmap[0]\t";}

			# perfect hit to species precursor but not to canonical miRNA according to miRBase
			if($seqmap[6]==0&&!$miRBase_species{$seqmap[4]})
				{
				$miR_noncanonical_species{$seqmap[4]}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
				$miR_table_out_species{$seqmap[4]}{0}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
				$output_miR_species{$seqmap[4]}=1;
				delete$miR_canonical_nonspecies{$seqmap[4]};
				delete$miR_table_out_nonspecies{$seqmap[4]};
				delete$output_miR_nonspecies{$seqmap[4]};
				}

			# not tailed, only internal modification
			elsif($seqmap[5]==0&&!$miRBase_species{$seqmap[4]})
				{
				$miR_noncanonical_species{$seqmap[4]}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
				$miR_table_out_species{$seqmap[4]}{0}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
				$output_miR_species{$seqmap[4]}=1;
				delete$miR_canonical_nonspecies{$seqmap[4]};
				delete$miR_table_out_nonspecies{$seqmap[4]};
				delete$output_miR_nonspecies{$seqmap[4]};
				}

			# check for 3' tailed hit to species precursor
			else
				{
				$output_miR_species{$seqmap[4]}=1;
				$tail=substr($seqmap[4],-$seqmap[5]);
				$tails_species{$tail}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
				$tails_per_miR_species{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])}{$tail}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};

				# check if this is a tailed canonical miRNA according to miRBase
				if($miRBase_species{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])})
					{
					$miR_table_out_species{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])}{length$tail}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
					$miR_canonical_species{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
					}

				# this is a tailed non-canonical miRNA according to miRBase
				else
					{
					$miR_table_out_species{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])}{length$tail}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
					$miR_noncanonical_species{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])}+=$seqmap[3]/$hits_per_miRspecies{$seqmap[4]};
					}

				# remove tailed and non-tailed versions of this miRNA from non-species and non-annotated hashes
				delete$miR_canonical_nonspecies{$seqmap[4]};
				delete$miR_table_out_nonspecies{$seqmap[4]};
				delete$output_miR_nonspecies{$seqmap[4]};
				delete$miR_canonical_nonspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])};
				delete$miR_table_out_nonspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])};
				delete$output_miR_nonspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])};
				}
			}
		close SEQMAP;
		undef%hits_per_miRspecies;

		# create SeqMap input file for NON-SPECIES run
		if(!$silent){print" OK.\nSearch for non-canonical and 3' tailed miRNAs (non-$species{$species})...";}
		open(INPUT,"$dump_folder/SeqMap_input1.temp")||die print"\nERROR! Unable to open temporary SeqMap input file $dump_folder/SeqMap_input1.temp.\n$!\n\n";
		open(NEW_INPUT,">$dump_folder/SeqMap_input2.temp")||die print"\nERROR! Unable to create temporary SeqMap input file $dump_folder/SeqMap_input2.temp.\n$!\n\n";
		$n_remaining_seqs=0;
		while(<INPUT>)
			{
			$_=~s/\s*$//;
			if($_=~s/^>//)
				{
				$reads=$_;
				}
			elsif(!$valid_species_hits{$_}&&!$miR_canonical_nonspecies{$_})
				{
				$n_remaining_seqs++;
				print NEW_INPUT">$reads\n$_\n";
				}
			}
		close INPUT;
		close NEW_INPUT;

		if($n_remaining_seqs>0)
			{
			# run SeqMap on NON-SPECIES miRNA hairpins IF THERE ARE SEQUENCES THAT COULD NOT BE ANNOTATED AS SPECIES MIR!!!
			if($^O eq'linux'||$^O eq'darwin')
				{
				qx/.\/seqmap.exe $mm_for_SeqMap_run $dump_folder\/SeqMap_input2.temp $dump_folder\/miRBase_hairpin_non-$species{$species}.fas $dump_folder\/SeqMap_nonspecies.temp \/output_all_matches \/forward_strand \/available_memory:${memory}000 $less_memory_options_miR> $dump_folder\/SeqMap_report2.txt/;
				}
			elsif($^O eq'MSWin32')
				{
				system("seqmap.exe $mm_for_SeqMap_run $dump_folder/SeqMap_input2.temp $dump_folder/miRBase_hairpin_non-$species{$species}.fas $dump_folder/SeqMap_nonspecies.temp /output_all_matches /forward_strand /available_memory:${memory}000 ${less_memory_options_miR}2>&1 > $dump_folder/SeqMap_report2.txt");
				}
			else
				{
				if(!$silent){print" WARNING! Unknown operating system.";}
				# try unix command
				qx/.\/seqmap.exe $mm_for_SeqMap_run $dump_folder\/SeqMap_input2.temp $dump_folder\/miRBase_hairpin_non-$species{$species}.fas $dump_folder\/SeqMap_nonspecies.temp \/output_all_matches \/forward_strand \/available_memory:${memory}000 $less_memory_options_miR> $dump_folder\/SeqMap_report2.txt/;
				if(!-e"$dump_folder/SeqMap_nonspecies.temp")
					{
					# try windows command
					system("seqmap.exe $mm_for_SeqMap_run $dump_folder/SeqMap_input2.temp $dump_folder/miRBase_hairpin_non-$species{$species}.fas $dump_folder/SeqMap_nonspecies.temp /output_all_matches /forward_strand /available_memory:${memory}000 ${less_memory_options_miR}2>&1 > $dump_folder/SeqMap_report2.txt");
					}
				}
			# check SeqMap report
			open(SMR,"$dump_folder/SeqMap_report2.txt");
			while(<SMR>)
				{
				if($_=~/not enough memory/)
					{
					print"\n\nERROR. Not enough memory available for SeqMap. Check $dump_folder/SeqMap_report2.txt for more details. Try less mismatch (-mismatch [n]), less insertions/deletions (-insdel [n]), fewer non-template 3' nucleotides (-tail [n]). Alternatively you may want to use the options -less_memory or -even_less_memory.\n\n";
					exit;
					}
				}
			close SMR;

			# clean up SeqMap output
			$file_id="nonspecies";
			clean_SeqMap_miRNA();
			open(SEQMAP,"$dump_folder/SeqMap_nonspecies.clean-2.temp");
			%hits_per_miRnonspecies=();
			while(<SEQMAP>)
				{
				$_=~s/\s*$//;
				@seqmap=split("\t",$_);
				$hits_per_miRnonspecies{$seqmap[4]}++;

				# save targets of this sequence (without the tail)
				if(!$targets_per_miRnonspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])})
					{
					$targets_per_miRnonspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])}.="$seqmap[0] ";
					}
				}
			close SEQMAP;

			# search non-canonical (tailed and untailed) NON-SPECIES miRNAs
			unless(open(SEQMAP,"$dump_folder/SeqMap_nonspecies.clean-2.temp"))
				{
				print"\nERROR! Unable to open temporary SeqMap output file.\n$!\n\n";
				open(REPORT,"$dump_folder/SeqMap_report2.txt");
				while(<REPORT>)
					{
					print$_;
					}
				exit;
				}
			while(<SEQMAP>)
				{
				$_=~s/\s*$//;
				@seqmap=split("\t",$_);

				# count internal modifications
				if($seqmap[0]=~/\(.+\)/)
					{
					$mod=$&;
					$mod=~s/[\(\)]//g;
					$mod=~s/\d+//;
					$modpos=$&;
					$mod=~s/^-/?-/;
					$count_internal_mods_nonspecies{$mod}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
					$count_internal_mods_nonspecies{$modpos}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
					$mods_per_pos_nonspecies{$modpos}{$mod}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
					}

				if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/\Q$seqmap[0]/){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="$seqmap[0]\t";}

				# perfect hit to non-species precursor but not to canonical non-species miRNA according to miRBase
				if($seqmap[6]==0&&!$miRBase_nonspecies{$seqmap[4]})
					{
					$miR_noncanonical_nonspecies{$seqmap[4]}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
					$miR_table_out_nonspecies{$seqmap[4]}{0}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
					$output_miR_nonspecies{$seqmap[4]}=1;
					}

				# not tailed, only internal modification
				elsif($seqmap[5]==0&&!$miRBase_nonspecies{$seqmap[4]})
					{
					$miR_noncanonical_nonspecies{$seqmap[4]}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
					$miR_table_out_nonspecies{$seqmap[4]}{0}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
					$output_miR_nonspecies{$seqmap[4]}=1;
					}

				# check for 3' tailed hit to non-species precursor
				else
					{
					$output_miR_nonspecies{$seqmap[4]}=1;
					$tail=substr($seqmap[4],-$seqmap[5]);
					$tails_nonspecies{$tail}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
					$tails_per_miR_nonspecies{substr($seqmap[4],0,$p)}{$tail}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};

					# check if this is a tailed canonical non-species miRNA
					if($miRBase_nonspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])})
						{
						$miR_table_out_nonspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])}{length$tail}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
						$miR_canonical_nonspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
						}
					# this must be a tailed non-canonical non-species miRNA
					else
						{
						$miR_table_out_nonspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])}{length$tail}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
						$miR_noncanonical_nonspecies{substr($seqmap[4],0,(length$seqmap[4])-$seqmap[5])}+=$seqmap[3]/$hits_per_miRnonspecies{$seqmap[4]};
						}
					}
				}
			close SEQMAP;
			undef%hits_per_miRnonspecies;
			}

		# make miRNA output files
		$i_miRspecies=0;
		$i_miRnonspecies=0;
		$nonid_miRspecies=0;
		$nonid_miRnonspecies=0;
		open(INPUT,$input)||die print"\nERROR! Unable to open input file $input.\n$!\n\n";
		while(<INPUT>)
			{
			$_=~s/\s*$//;
			if($_=~s/^>//)
				{
				$reads=$_;
				}
			else
				{
				if($output_miR_species{$_})
					{
					$nonid_miRspecies++;
					$i_miRspecies+=$reads;
					$miR_spec_seq{$_}=$reads;
					}
				elsif($output_miR_nonspecies{$_})
					{
					$nonid_miRnonspecies++;
					$i_miRnonspecies+=$reads;
					$miR_nonspec_seq{$_}=$reads;
					}
				else
					{
					$nonmiR_seq{$_}=$reads;
					}
				}
			}
		close INPUT;
		foreach(sort{$miR_spec_seq{$b}<=>$miR_spec_seq{$a} or $a cmp $b}keys%miR_spec_seq)
			{
			print OUT_MIR_SPECIES">$miR_spec_seq{$_}\n$_\n";
			}
		foreach(sort{$miR_nonspec_seq{$b}<=>$miR_nonspec_seq{$a} or $a cmp $b}keys%miR_nonspec_seq)
			{
			print OUT_MIR_NONSPECIES">$miR_nonspec_seq{$_}\n$_\n";
			}
		foreach(sort{$nonmiR_seq{$b}<=>$nonmiR_seq{$a} or $a cmp $b}keys%nonmiR_seq)
			{
			print OUT_NONMIR">$nonmiR_seq{$_}\n$_\n";
			}

		if(keys%nonmiR_seq==0)
			{
			$no_nonmiRs=1; # skip ncRNA annotation when non-miR fasta file is empty
			}
		undef%miR_spec_seq;
		undef%miR_nonspec_seq;
		undef%nonmiR_seq;

		close OUT_MIR_SPECIES;
		close OUT_MIR_NONSPECIES;
		close OUT_NONMIR;
		$ba_in="$dump_folder/$outfile_prefix.miR.non-$species{$species}.fas";
		$ba_out="$dump_folder/$outfile_prefix.miR.non-$species{$species}.info";
		basic_analysis();
		$ba_in="$dump_folder/$outfile_prefix.miR.$species{$species}.fas";
		$ba_out="$dump_folder/$outfile_prefix.miR.$species{$species}.info";
		basic_analysis();

		# make miRNA-modifications files
		open(OUT_MODS_SPECIES,">$dump_folder/$outfile_prefix.miR-modifications_$species{$species}.txt")||die print"\nERROR! Unable to create output file $dump_folder/$outfile_prefix.miR-modifications_$species{$species}.txt.\n$!\n\n";
		open(OUT_MODS_NONSPECIES,">$dump_folder/$outfile_prefix.miR-modifications_non-$species{$species}.txt")||die print"\nERROR! Unable to create output file $dump_folder/$outfile_prefix.miR-modifications_non-$species{$species}.txt.\n$!\n\n";
		print OUT_MODS_SPECIES"3'-tailings (non-template nucleotides)\n";
		print OUT_MODS_NONSPECIES"3'-tailings (non-template nucleotides)\n";
		%new=();
		%old=%miRtails;
		foreach(1..$max_miRtail_length-1)
			{
			%new=%old;
			foreach$nt(keys%miRtails)
				{
				foreach(keys%old)
					{
					$new{$_.$nt}=1;
					}
				}
			%old=(%old,%new)
			}
		@combs=keys%old;
		@combs=sort@combs;
		foreach$tail(@combs)
			{
			if(!$tails_species{$tail})
				{
				$tails_species{$tail}=0;
				}
			if(!$tails_nonspecies{$tail})
				{
				$tails_nonspecies{$tail}=0;
				}
			print OUT_MODS_SPECIES"$tail\t$tails_species{$tail}\n";
			print OUT_MODS_NONSPECIES"$tail\t$tails_nonspecies{$tail}\n";
			}

		print OUT_MODS_SPECIES"\nInternal modifications (?->[ATGCN] = mapped sequence exceeds precursor sequence)\n";
		print OUT_MODS_NONSPECIES"\nInternal modifications (?->[ATGCN] = mapped sequence exceeds precursor sequence)\n";
		foreach$mod(sort{$count_internal_mods_species{$b}<=>$count_internal_mods_species{$a}}keys%count_internal_mods_species)
			{
			if($mod!~/\d/){print OUT_MODS_SPECIES"$mod\t$count_internal_mods_species{$mod}\n";}
			}
		foreach$mod(sort{$count_internal_mods_nonspecies{$b}<=>$count_internal_mods_nonspecies{$a}}keys%count_internal_mods_nonspecies)
			{
			if($mod!~/\d/){print OUT_MODS_NONSPECIES"$mod\t$count_internal_mods_nonspecies{$mod}\n";}
			}
		print OUT_MODS_SPECIES"\nPositions were internal modifications occur\n";
		print OUT_MODS_NONSPECIES"\nPositions were internal modifications occur\n";
		foreach$mod(1..100)
			{
			if($count_internal_mods_species{$mod}>0){print OUT_MODS_SPECIES"$mod\t$count_internal_mods_species{$mod}\n";}
			}
		foreach$mod(1..100)
			{
			if($count_internal_mods_species{$mod}>0){print OUT_MODS_NONSPECIES"$mod\t$count_internal_mods_nonspecies{$mod}\n";}
			}

		print OUT_MODS_SPECIES"\nModifications per position\n";
		print OUT_MODS_NONSPECIES"\nModifications per position\n";
		foreach$mod(sort{$count_internal_mods_species{$b}<=>$count_internal_mods_species{$a}}keys%count_internal_mods_species)
			{
			if($mod!~/\d/){print OUT_MODS_SPECIES"\t$mod";}
			}
		foreach$pos(1..100)
			{
			if($count_internal_mods_species{$pos}>0)
				{
				print OUT_MODS_SPECIES"\n$pos";
				foreach$mod(sort{$count_internal_mods_species{$b}<=>$count_internal_mods_species{$a}}keys%count_internal_mods_species)
					{
					next if($mod=~/\d/);
					if(!$mods_per_pos_species{$pos}{$mod})
						{
						$mods_per_pos_species{$pos}{$mod}=0;
						}
					print OUT_MODS_SPECIES"\t$mods_per_pos_species{$pos}{$mod}";
					}
				}
			}
		foreach$mod(sort{$count_internal_mods_nonspecies{$b}<=>$count_internal_mods_nonspecies{$a}}keys%count_internal_mods_nonspecies)
			{
			if($mod!~/\d/){print OUT_MODS_NONSPECIES"\t$mod";}
			}
		foreach$pos(1..100)
			{
			if($count_internal_mods_nonspecies{$pos}>0)
				{
				print OUT_MODS_NONSPECIES"\n$pos";
				foreach$mod(sort{$count_internal_mods_nonspecies{$b}<=>$count_internal_mods_nonspecies{$a}}keys%count_internal_mods_nonspecies)
					{
					next if($mod=~/\d/);
					if(!$mods_per_pos_nonspecies{$pos}{$mod})
						{
						$mods_per_pos_nonspecies{$pos}{$mod}=0;
						}
					print OUT_MODS_NONSPECIES"\t$mods_per_pos_nonspecies{$pos}{$mod}";
					}
				}
			}
		close OUT_MODS_SPECIES;
		close OUT_MODS_NONSPECIES;

		# make miRNA tables
		open(OUT_TABLE_SPECIES,">$dump_folder/$outfile_prefix.miR-table_$species{$species}.txt")||die print"\nERROR! Unable to create output file $dump_folder/$outfile_prefix.miR-table_$species{$species}.txt.\n$!\n\n";
		open(OUT_TABLE_NONSPECIES,">$dump_folder/$outfile_prefix.miR-table_non-$species{$species}.txt")||die print"\nERROR! Unable to create output file $dump_folder/$outfile_prefix.miR-table_non-$species{$species}.txt.\n$!\n\n";
		print OUT_TABLE_SPECIES"miR-name\tsequence\ttotal_reads";
		print OUT_TABLE_NONSPECIES"miR-name\tsequence\ttotal_reads";
		foreach$n(0..$max_miRtail_length)
			{
			print OUT_TABLE_SPECIES"\t+N$n-3'";
			print OUT_TABLE_NONSPECIES"\t+N$n-3'";
			}
		foreach$tail(@combs)
			{
			print OUT_TABLE_SPECIES"\t$tail-tailed_reads";
			print OUT_TABLE_NONSPECIES"\t$tail-tailed_reads";
			}
		print OUT_TABLE_SPECIES"\n";
		print OUT_TABLE_NONSPECIES"\n";

		foreach$seq(sort{$a cmp $b}keys%miR_table_out_species)
			{
			# get miRNA name
			if($miRBase_species{$seq})
				{
				$miR_name=$miRBase_species{$seq};
				}
			else
				{
				$miR_name=$targets_per_miRspecies{$seq};
				}

			# get total miRNA counts
			$miR_counts=0;
			foreach$i(0..$max_miRtail_length)
				{
				$miR_counts+=$miR_table_out_species{$seq}{$i};
				}

			print OUT_TABLE_SPECIES"$miR_name\t$seq\t$miR_counts\t";
			foreach$n(0..$max_miRtail_length)
				{
				if(!$miR_table_out_species{$seq}{$n})
					{
					$miR_table_out_species{$seq}{$n}=0;
					}
				print OUT_TABLE_SPECIES"$miR_table_out_species{$seq}{$n}\t";
				}
			foreach$tail(@combs)
				{
				if(!$tails_per_miR_species{$seq}{$tail})
					{
					$tails_per_miR_species{$seq}{$tail}=0;
					}
				print OUT_TABLE_SPECIES"$tails_per_miR_species{$seq}{$tail}\t";
				}
			print OUT_TABLE_SPECIES"\n";
			}

		foreach$seq(sort{$a cmp $b}keys%miR_table_out_nonspecies)
			{
			# get miRNA name
			if($miRBase_nonspecies{$seq})
				{
				$miR_name=$miRBase_nonspecies{$seq};
				}
			else
				{
				$miR_name=$targets_per_miRnonspecies{$seq};
				}

			# get total miRNA counts
			$miR_counts=0;
			foreach$i(0..$max_miRtail_length)
				{
				$miR_counts+=$miR_table_out_nonspecies{$seq}{$i};
				}

			print OUT_TABLE_NONSPECIES"$miR_name\t$seq\t$miR_counts\t";
			foreach$n(0..$max_miRtail_length)
				{
				if(!$miR_table_out_nonspecies{$seq}{$n})
					{
					$miR_table_out_nonspecies{$seq}{$n}=0;
					}
				print OUT_TABLE_NONSPECIES"$miR_table_out_nonspecies{$seq}{$n}\t";
				}
			foreach$tail(@combs)
				{
				if(!$tails_per_miR_nonspecies{$seq}{$tail})
					{
					$tails_per_miR_nonspecies{$seq}{$tail}=0;
					}
				print OUT_TABLE_NONSPECIES"$tails_per_miR_nonspecies{$seq}{$tail}\t";
				}
			print OUT_TABLE_NONSPECIES"\n";
			}
		close OUT_TABLE_SPECIES;
		close OUT_TABLE_NONSPECIES;
		}
	else # make a non-miR file to search for other ncRNA classes
		{
		if(!$silent){print" \nSkip miRNA annotation. Prepare file for ncRNA annotation...";}
		$i_miRspecies=0;
		$i_miRnonspecies=0;
		$nonid_miRspecies=0;
		$nonid_miRnonspecies=0;
		copy($input,"$dump_folder/$outfile_prefix.non-miR.fas")||die print"\nERROR! Unable to create input file for ncRNA search.\n$!\n\n";
		}

	# search ncRNAs other than miRNAs or mRNA fragments (if non-miR.fas is not empty)
	if(!$skip_cDNA||!$skip_ncRNA)
		{
		if($no_nonmiRs==0)
			{
			$map_to_what="";
			# add cDNA sequences to ncRNA file
			if(!$skip_cDNA&&!$skip_ncRNA)
				{
				$map_to_what="ncRNA and cDNA";
				open(SEQMAP_REF,">>$dump_folder\/ncRNA.fas")||die print"ERROR! Unable to open $dump_folder/ncRNA.fas to add cDNA sequences.\n$!\n\n";
				open(CDNA,"$dump_folder\/cDNA.fas")||die print"ERROR! Unable to open $dump_folder/cDNA.fas to add cDNA sequences.\n$!\n\n";
				$total_cDNA_reference_bp=0;
				while(<CDNA>)
					{
					print SEQMAP_REF$_;
					if($_!~/^>/)
						{
						$_=~s/\s*$//;
						$total_cDNA_reference_bp+=length$_;
						}
					}
				close SEQMAP_REF;
				close CDNA;
				$reference_file="$dump_folder\/ncRNA.fas";
				}
			# map to ncRNA only
			elsif(!$skip_ncRNA)
				{
				$map_to_what="ncRNA";
				$reference_file="$dump_folder\/ncRNA.fas";
				}
			# map to cDNA only
			elsif(!$skip_cDNA)
				{
				$map_to_what="cDNA";
				$reference_file="$dump_folder\/cDNA.fas";
				}

			# get lengths of tRNAs to identify 3' fragments, optionally add CCA to 3' end and save added sequences in a new file: .CCAcheck
			open(NCRNA,"$dump_folder/ncRNA.fas")||die print"\nERROR! Unable to open $dump_folder/ncRNA.fas.\n$!\n\n";
			if(!$noCCAcheck)
				{
				open(CCACHECK,">$dump_folder/ncRNA.fas.CCAcheck")||die print"\nERROR! Unable to create file $dump_folder/ncRNA.fas.CCAcheck.\n$!\n\n";
				}
			%tRNA_length=();
			while(<NCRNA>)
				{
				$_=~s/\s*$//;
				if($_=~s/^>//)
					{
					if($_=~/tRNA\|/)
						{
						$head=$_;
						# add CCA to 3' terminal end of tRNAs (opt-out)
						if($_!~/tRF-1_/&&$_!~/tRNA-leader_/&&!$noCCAcheck)
							{
							$doCCAcheck=1;
							}
						else
							{
							$doCCAcheck=0;
							}
						}
					else
						{
						$head="X";
						}
					if(!$noCCAcheck)
						{
						print CCACHECK">$_\n";
						}
					}
				elsif($head ne"X")
					{
					#print"\ndatabase_version:\n$_";
					if($_=~/[^C]C$/&&$doCCAcheck==1)
						{
						$_.="CA";
						}
					elsif($_=~/CC$/&&$doCCAcheck==1)
						{
						$_.="A";
						}
					elsif($_!~/CCA$/&&$doCCAcheck==1)
						{
						$_.="CCA";
						}
					$tRNA_length{$head}=length$_;
					print CCACHECK"$_\n";
					#print"\nedited_version:\n$_\n";
					}
				else
					{
					print CCACHECK"$_\n";
					}
				}
			close NCRNA;
			if(!$noCCAcheck)
				{
				close CCACHECK;
				unlink("$dump_folder/ncRNA.fas");
				rename("$dump_folder/ncRNA.fas.CCAcheck","$dump_folder/ncRNA.fas")||die print"\nERROR! Unable to rename file $dump_folder/ncRNA.fas.CCAcheck.\n$!\n\n";
				}

			$total_reference_bp=$total_cDNA_reference_bp+$total_ncRNA_reference_bp;
			if(!$silent){print" OK.\nCompare non-miR sequences with $map_to_what sequences (total reference sequence: $total_reference_bp bp)...";}
			if($^O eq'linux'||$^O eq'darwin')
				{
				qx/.\/seqmap.exe $seqmap_max_mm $dump_folder\/$outfile_prefix.non-miR.fas $reference_file $dump_folder\/SeqMap_ncRNA.temp \/allow_insdel:$seqmap_max_insdel \/output_all_matches \/forward_strand \/available_memory:${memory}000 $less_memory_options_ncR> $dump_folder\/SeqMap_report3.txt/;
				}
			elsif($^O eq'MSWin32')
				{
				system("seqmap.exe $seqmap_max_mm $dump_folder/$outfile_prefix.non-miR.fas $reference_file $dump_folder/SeqMap_ncRNA.temp /allow_insdel:$seqmap_max_insdel /output_all_matches \/forward_strand /available_memory:${memory}000 ${less_memory_options_ncR}2>&1 > $dump_folder/SeqMap_report3.txt");
				}
			else
				{
				print" WARNING! Unknown operating system.";
				#try unix command
				qx/.\/seqmap.exe $seqmap_max_mm $dump_folder\/$outfile_prefix.non-miR.fas $reference_file $dump_folder\/SeqMap_ncRNA.temp \/allow_insdel:$seqmap_max_insdel \/output_all_matches \/forward_strand \/available_memory:${memory}000 $less_memory_options_ncR> $dump_folder\/SeqMap_report3.txt/;
				if(!-e"$dump_folder\/SeqMap_ncRNA.temp")
					{
					# try windows command
					system("seqmap.exe $seqmap_max_mm $dump_folder/$outfile_prefix.non-miR.fas $reference_file $dump_folder/SeqMap_ncRNA.temp /allow_insdel:$seqmap_max_insdel /output_all_matches \/forward_strand /available_memory:${memory}000 ${less_memory_options_ncR}2>&1 > $dump_folder/SeqMap_report3.txt");
					}
				}

			# check SeqMap report
			open(SMR,"$dump_folder/SeqMap_report3.txt");
			while(<SMR>)
				{
				if($_=~/not enough memory/)
					{
					print"\n\nERROR. Not enough memory available for SeqMap. Check $dump_folder/SeqMap_report3.txt for more details. Try less mismatch (-mismatch [n]), less insertions/deletions (-insdel [n]), fewer non-template 3' nucleotides (-tail [n]). Alternatively you may want to use the options -less_memory or -even_less_memory.\n\n";
					exit;
					}
				}
			close SMR;

			if($seqmap_max_mm+$seqmap_max_insdel>0)
				{
				clean_SeqMap_ncRNA();
				open(SEQMAP,"$dump_folder/SeqMap_ncRNA.clean.temp")||die print"\nERROR! Unable to open $dump_folder/SeqMap_ncRNA.clean.temp.\n$!\n\n";
				}
			else
				{
				open(SEQMAP,"$dump_folder/SeqMap_ncRNA.temp")||die print"\nERROR! Unable to open $dump_folder/SeqMap_ncRNA.temp.\n$!\n\n";
				$head=<SEQMAP>;
				}
			%hits_per_seq=();
			while(<SEQMAP>)
				{
				$_=~s/\s*$//;
				@seqmap=split("\t",$_);
				$hits_per_seq{$seqmap[4]}++;
				}
			close SEQMAP;

			$tRNA_half5{"genomic"}=0;
			$tRF5{"genomic"}=0;
			$tRNA_half3{"genomic"}=0;
			$tRF3{"genomic"}=0;
			$tRF3_CCA{"genomic"}=0;
			$tRF1{"genomic"}=0;
			$tRNAleader{"genomic"}=0;
			$misc_tRF{"genomic"}=0;
			$tRNA_half5{"Mt"}=0;
			$tRF5{"Mt"}=0;
			$tRNA_half3{"Mt"}=0;
			$tRF3{"Mt"}=0;
			$tRF3_CCA{"Mt"}=0;
			$tRF1{"Mt"}=0;
			$tRNAleader{"Mt"}=0;
			$misc_tRF{"Mt"}=0;

			if($seqmap_max_mm+$seqmap_max_insdel>0)
				{
				open(SEQMAP,"$dump_folder/SeqMap_ncRNA.clean.temp")||die print"\nERROR! Unable to open $dump_folder/SeqMap_ncRNA.clean.temp.\n$!\n\n";
				}
			else
				{
				open(SEQMAP,"$dump_folder/SeqMap_ncRNA.temp")||die print"\nERROR! Unable to open $dump_folder/SeqMap_ncRNA.temp.\n$!\n\n";
				$head=<SEQMAP>;
				}
			while(<SEQMAP>)
				{
				$_=~s/\s*$//;
				@seqmap=split("\t",$_);

				# avoid nested quantifiers in sequence names such as 'trna3197-Undet???'
				$seqmap[0]=~s/\?/X/g;
				$seqmap[0]=~s/\*/x/g;
				$seqmap[0]=~s/\+/plus/g;

				@id=split(/\|/,$seqmap[0]);
				$sorted_sequences{$id[0]}{$seqmap[4]}=$seqmap[3];
				$ncRNA_counts_1{$id[0]}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
				$ncRNA_counts_2{$id[0]}{$id[1]}+=$seqmap[3]/$hits_per_seq{$seqmap[4]}; # hits per transcript table

				# check tRNA derived sequences
				if($seqmap[0]=~/^tRNA\|/||$seqmap[0]=~/^Mt_tRNA\|/)
					{
					$origin="genomic";
					if($seqmap[0]=~/^Mt_tRNA\|/)
						{
						$origin="Mt";
						}
					$source_tRNA=$seqmap[0];
					$source_tRNA=~s/^[^\|]+\|//;

					# tRF-1 (derived from tRNA trailer)
					if($seqmap[0]=~/tRNA\|tRF-1_/)
						{
						$source_tRNA=~s/^tRF-1_\[*\d*\]*_*//;
						$tRF1{$origin}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
						$tRF_seqs{"tRF-1"}{$origin}{$seqmap[4]}=$seqmap[3];
						$tRF_data_table{$source_tRNA}{"tRF-1"}{"total"}+=$seqmap[3];
						$tRF_data_table{$source_tRNA}{"tRF-1"}{"normalized"}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
						if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/tRF-1 from $source_tRNA/){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="tRF-1 from $source_tRNA\t";}
						}
					# tRNA leader sequence
					elsif($seqmap[0]=~/tRNA\|tRNA-leader_/)
						{
						$source_tRNA=~s/^tRNA-leader_\[*\d*\]*_*//;
						$tRNAleader{$origin}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
						$tRF_seqs{"tRNA-leader"}{$origin}{$seqmap[4]}=$seqmap[3];
						$tRF_data_table{$source_tRNA}{"tRNA-leader"}{"total"}+=$seqmap[3];
						$tRF_data_table{$source_tRNA}{"tRNA-leader"}{"normalized"}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
						if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/tRF-leader from $source_tRNA/){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="tRF-leader from $source_tRNA\t";}
						}
					# 5' fragment
					elsif($seqmap[1]==1)
						{
						if(length$seqmap[4]>=30)
							{
							$tRNA_half5{$origin}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
							$tRF_seqs{"5p-tR-halves"}{$origin}{$seqmap[4]}=$seqmap[3];
							$tRF_data_table{$source_tRNA}{"5p-tR-halves"}{"total"}+=$seqmap[3];
							$tRF_data_table{$source_tRNA}{"5p-tR-halves"}{"normalized"}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
							if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/5p-tR-half from $source_tRNA/){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="5p-tR-half from $source_tRNA\t";}
							}
						else
							{
							$tRF5{$origin}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
							$tRF_seqs{"5p-tRFs"}{$origin}{$seqmap[4]}=$seqmap[3];
							$tRF_data_table{$source_tRNA}{"5p-tRFs"}{"total"}+=$seqmap[3];
							$tRF_data_table{$source_tRNA}{"5p-tRFs"}{"normalized"}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
							if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/5p-tRF from $source_tRNA/){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="5p-tRF from $source_tRNA\t";}
							}
						}
					# 3' fragment (not necessarily the very 3' end, tRNA may have up to 3bp 3' overhang in the alignment [-3])
					elsif($seqmap[1]+(length$seqmap[4])-1>=($tRNA_length{$seqmap[0]})-3)
						{
						if(length$seqmap[4]>=30)
							{
							$tRNA_half3{$origin}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
							$tRF_seqs{"3p-tR-halves"}{$origin}{$seqmap[4]}=$seqmap[3];
							$tRF_data_table{$source_tRNA}{"3p-tR-halves"}{"total"}+=$seqmap[3];
							$tRF_data_table{$source_tRNA}{"3p-tR-halves"}{"normalized"}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
							if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/3p-tR-half from $source_tRNA/){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="3p-tR-half from $source_tRNA\t";}
							}
						else
							{
							# CCA fragments have to match the very 3' end of the tRNA
							if($seqmap[4]=~/CCA$/i&&$seqmap[1]+(length$seqmap[4])-1==$tRNA_length{$seqmap[0]})
								{
								CCA();
								sub CCA
									{
									$tRF3_CCA{$origin}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
									$tRF_seqs{"3p-CCA-tRFs"}{$origin}{$seqmap[4]}=$seqmap[3];
									$tRF_data_table{$source_tRNA}{"3p-CCA-tRFs"}{"total"}+=$seqmap[3];
									$tRF_data_table{$source_tRNA}{"3p-CCA-tRFs"}{"normalized"}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
									if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/3p-CCA-tRF from $source_tRNA/){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="3p-CCA-tRF from $source_tRNA\t";}
									}
								}
							elsif($seqmap[4]=~/CC$/i&&$CC_is_CCA&&$seqmap[1]+(length$seqmap[4])==$tRNA_length{$seqmap[0]}) # allows to identify 3p-CCA-tRFs if poly-A tails were trimmed
								{
								CCA();
								}
							else
								{
								$tRF3{$origin}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
								$tRF_seqs{"3p-tRFs"}{$origin}{$seqmap[4]}=$seqmap[3];
								$tRF_data_table{$source_tRNA}{"3p-tRFs"}{"total"}+=$seqmap[3];
								$tRF_data_table{$source_tRNA}{"3p-tRFs"}{"normalized"}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
								if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/3p-tRF from $source_tRNA/){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="3p-tRF from $source_tRNA\t";}
								}
							}
						}
					else
						{
						$misc_tRF{$origin}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
						$tRF_seqs{"misc-tRFs"}{$origin}{$seqmap[4]}=$seqmap[3];
						$tRF_data_table{$source_tRNA}{"misc-tRFs"}{"total"}+=$seqmap[3];
						$tRF_data_table{$source_tRNA}{"misc-tRFs"}{"normalized"}+=$seqmap[3]/$hits_per_seq{$seqmap[4]};
						if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/misc-tRF from $source_tRNA/){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="misc-tRF from $source_tRNA\t";}
						}
					}
				else
					{
					if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/\Q$seqmap[0]/i){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="$seqmap[0]\t";}
					}
				}
			close SEQMAP;
			}
		}

	# create tRF fasta files
	foreach$tRF_type("5p-tR-halves","5p-tRFs","3p-tR-halves","3p-CCA-tRFs","3p-tRFs","tRF-1","tRNA-leader","misc-tRFs")
		{
		foreach$origin("genomic","Mt")
			{
			if(keys%{$tRF_seqs{$tRF_type}{$origin}}>0)
				{
				open(TRF,">$dump_folder/$outfile_prefix.${origin}_$tRF_type.fas")||die print"\nERROR! Unable to create file $dump_folder/$outfile_prefix.${origin}_$tRF_type.fas.\n$!\n\n";
				foreach$seq(sort{$tRF_seqs{$tRF_type}{$origin}{$b}<=>$tRF_seqs{$tRF_type}{$origin}{$a} or $a cmp $b} keys%{$tRF_seqs{$tRF_type}{$origin}})
					{
					print TRF">$tRF_seqs{$tRF_type}{$origin}{$seq}\n$seq\n";
					}
				close TRF;
				$ba_in="$dump_folder/$outfile_prefix.${origin}_$tRF_type.fas";
				$ba_out="$dump_folder/$outfile_prefix.${origin}_$tRF_type.info";
				basic_analysis();
				}
			}
		}

	# create tRF table
	if(!$skip_ncRNA)
		{
		open(TRF_TABLE,">$dump_folder/${outfile_prefix}.tRF-table.txt")||die print"\nERROR! Unable to create file $dump_folder/$outfile_prefix.${origin}_tRF-table.txt.\n$!\n\n";
		print TRF_TABLE"NOTE: SEQUENCE READS MAY MAP TO MORE THAN ONE REFERENCE SEQUENCE.\nFRACTIONATED READ COUNTS ACCOUNT FOR MULTIPLE HITS OF ONE SEQUENCE.\n\nsource_tRNA\t5p-tR-halves (fractionated)\t5p-tR-halves (absolute)\t5p-tRFs (fractionated)\t5p-tRFs (absolute)\t3p-tR-halves (fractionated)\t3p-tR-halves (absolute)\t3p-CCA-tRFs (fractionated)\t3p-CCA-tRFs (absolute)\t3p-tRFs (fractionated)\t3p-tRFs (absolute)\ttRF-1 (fractionated)\ttRF-1 (absolute)\ttRNA-leader (fractionated)\ttRNA-leader (absolute)\tmisc-tRFs (fractionated)\tmisc-tRFs (absolute)";
		foreach$source_tRNA(sort{$a cmp $b}keys%tRF_data_table)
			{
			if(!$tRF_data_table{$source_tRNA}{"5p-tR-halves"}{"total"}){$tRF_data_table{$source_tRNA}{"5p-tR-halves"}{"total"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"5p-tR-halves"}{"normalized"}){$tRF_data_table{$source_tRNA}{"5p-tR-halves"}{"normalized"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"5p-tRFs"}{"total"}){$tRF_data_table{$source_tRNA}{"5p-tRFs"}{"total"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"5p-tRFs"}{"normalized"}){$tRF_data_table{$source_tRNA}{"5p-tRFs"}{"normalized"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"3p-tR-halves"}{"total"}){$tRF_data_table{$source_tRNA}{"3p-tR-halves"}{"total"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"3p-tR-halves"}{"normalized"}){$tRF_data_table{$source_tRNA}{"3p-tR-halves"}{"normalized"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"3p-CCA-tRFs"}{"total"}){$tRF_data_table{$source_tRNA}{"3p-CCA-tRFs"}{"total"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"3p-CCA-tRFs"}{"normalized"}){$tRF_data_table{$source_tRNA}{"3p-CCA-tRFs"}{"normalized"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"3p-tRFs"}{"total"}){$tRF_data_table{$source_tRNA}{"3p-tRFs"}{"total"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"3p-tRFs"}{"normalized"}){$tRF_data_table{$source_tRNA}{"3p-tRFs"}{"normalized"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"tRF-1"}{"total"}){$tRF_data_table{$source_tRNA}{"tRF-1"}{"total"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"tRF-1"}{"normalized"}){$tRF_data_table{$source_tRNA}{"tRF-1"}{"normalized"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"tRNA-leader"}{"total"}){$tRF_data_table{$source_tRNA}{"tRNA-leader"}{"total"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"tRNA-leader"}{"normalized"}){$tRF_data_table{$source_tRNA}{"tRNA-leader"}{"normalized"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"misc-tRFs"}{"total"}){$tRF_data_table{$source_tRNA}{"misc-tRFs"}{"total"}=0;}
			if(!$tRF_data_table{$source_tRNA}{"misc-tRFs"}{"normalized"}){$tRF_data_table{$source_tRNA}{"misc-tRFs"}{"normalized"}=0;}
			print TRF_TABLE"\n$source_tRNA\t".$tRF_data_table{$source_tRNA}{"5p-tR-halves"}{"normalized"}."\t".$tRF_data_table{$source_tRNA}{"5p-tR-halves"}{"total"};
			print TRF_TABLE"\t".$tRF_data_table{$source_tRNA}{"5p-tRFs"}{"normalized"}."\t".$tRF_data_table{$source_tRNA}{"5p-tRFs"}{"total"};
			print TRF_TABLE"\t".$tRF_data_table{$source_tRNA}{"3p-tR-halves"}{"normalized"}."\t".$tRF_data_table{$source_tRNA}{"3p-tR-halves"}{"total"};
			print TRF_TABLE"\t".$tRF_data_table{$source_tRNA}{"3p-CCA-tRFs"}{"normalized"}."\t".$tRF_data_table{$source_tRNA}{"3p-CCA-tRFs"}{"total"};
			print TRF_TABLE"\t".$tRF_data_table{$source_tRNA}{"3p-tRFs"}{"normalized"}."\t".$tRF_data_table{$source_tRNA}{"3p-tRFs"}{"total"};
			print TRF_TABLE"\t".$tRF_data_table{$source_tRNA}{"tRF-1"}{"normalized"}."\t".$tRF_data_table{$source_tRNA}{"tRF-1"}{"total"};
			print TRF_TABLE"\t".$tRF_data_table{$source_tRNA}{"tRNA-leader"}{"normalized"}."\t".$tRF_data_table{$source_tRNA}{"tRNA-leader"}{"total"};
			print TRF_TABLE"\t".$tRF_data_table{$source_tRNA}{"misc-tRFs"}{"normalized"}."\t".$tRF_data_table{$source_tRNA}{"misc-tRFs"}{"total"};
			}
		close TRF_TABLE;
		}

	# create ncRNA/cDNA fasta files, ncRNA/cDNA count table and non-annotated file
	open(NCRNA_TABLE,">$dump_folder/$outfile_prefix.annotation_summary.txt")||die print"\nERROR! Unable to create file $dump_folder/$outfile_prefix.annotation_summary.txt.\n$!\n\n";
	if(!$skip_dust)
		{
		print NCRNA_TABLE"low_complexity\t$simple_reads\n";
		}
	if(!$ncRNA_counts_1{"tRNA"}){$ncRNA_counts_1{"tRNA"}=0;}
	if(!$ncRNA_counts_1{"Mt_tRNA"}){$ncRNA_counts_1{"Mt_tRNA"}=0;}
	if(!$ncRNA_counts_1{"rRNA"}){$ncRNA_counts_1{"rRNA"}=0;}
	if(!$ncRNA_counts_1{"Mt_rRNA"}){$ncRNA_counts_1{"Mt_rRNA"}=0;}
	$total_miR_reads=$i_miRspecies+$i_miRnonspecies;
	$total_tRNA_reads=$ncRNA_counts_1{"tRNA"}+$ncRNA_counts_1{"Mt_tRNA"};
	$total_rRNA_reads=$ncRNA_counts_1{"rRNA"}+$ncRNA_counts_1{"Mt_rRNA"};
	print NCRNA_TABLE"miRNA\t$total_miR_reads\n   miRNA:$species\t$i_miRspecies\n   miRNA:other\t$i_miRnonspecies\n";
	print NCRNA_TABLE"rRNA\t$total_rRNA_reads\n   genomic_rRNA\t$ncRNA_counts_1{rRNA}\n   Mt_rRNA\t$ncRNA_counts_1{Mt_rRNA}\n";
	print NCRNA_TABLE"tRNA\t$total_tRNA_reads\n   genomic_tRNA\t$ncRNA_counts_1{tRNA}\n      5'tR-halves\t$tRNA_half5{genomic}\n      5'tRFs\t$tRF5{genomic}\n      3'tR-halves\t$tRNA_half3{genomic}\n      3'tRFs\t$tRF3{genomic}\n      3'CCA-tRFs\t$tRF3_CCA{genomic}\n      tRF-1\t$tRF1{genomic}\n      tRNA-leader\t$tRNAleader{genomic}\n      misc-tRFs\t$misc_tRF{genomic}\n   Mt_tRNA\t$ncRNA_counts_1{Mt_tRNA}\n      5'tR-halves\t$tRNA_half5{Mt}\n      5'tRFs\t$tRF5{Mt}\n      3'tR-halves\t$tRNA_half3{Mt}\n      3'tRFs\t$tRF3{Mt}\n      3'CCA-tRFs\t$tRF3_CCA{Mt}\n      tRF-1\t$tRF1{Mt}\n      tRNA-leader\t$tRNAleader{Mt}\n      misc-tRFs\t$misc_tRF{Mt}\n";

	my%ncRNA_annotated;
	foreach$biotype(keys%sorted_sequences)
		{
		if($biotype ne"tRNA"&&$biotype ne"Mt_tRNA"&&$biotype ne"rRNA"&&$biotype ne"Mt_rRNA")
			{
			print NCRNA_TABLE"$biotype\t$ncRNA_counts_1{$biotype}\n";
			}
		open(NCRNA_OUT,">$dump_folder/$outfile_prefix.$biotype.fas")||die print"\nERROR! Unable to create file $dump_folder/$outfile_prefix.$biotype.fas.\n$!\n\n";
		foreach$seq(sort{$sorted_sequences{$biotype}{$b}<=>$sorted_sequences{$biotype}{$a} or $a cmp $b}keys%{$sorted_sequences{$biotype}})
			{
			$ncRNA_annotated{$seq}=1;
			print NCRNA_OUT">$sorted_sequences{$biotype}{$seq}\n$seq\n";
			}
		close NCRNA_OUT;
		$ba_in="$dump_folder/$outfile_prefix.$biotype.fas";
		$ba_out="$dump_folder/$outfile_prefix.$biotype.info";
		basic_analysis();
		}

	open(NO_ANNOTATION,">$dump_folder/$outfile_prefix.no-annotation.fas")||die print"\nERROR! Unable to create output file $dump_folder/$outfile_prefix.no-annotation.fas.\n$!\n\n";
	open(INPUT,$input)||die print"\nERROR! Unable to open input file $input.\n$!\n\n";
	$no_annotation=0;
	my%no_annotation_seqs;
	while(<INPUT>)
		{
		$_=~s/\s*$//;
		if($_=~s/^>//)
			{
			$reads=$_;
			}
		elsif(!$ncRNA_annotated{$_}&&!$output_miR_species{$_}&&!$output_miR_nonspecies{$_})
			{
			$no_annotation+=$reads;
			$no_annotation_seqs{$_}=$reads;
			}
		}
	close INPUT;
	foreach(sort{$no_annotation_seqs{$b}<=>$no_annotation_seqs{$a}}keys%no_annotation_seqs)
		{
		print NO_ANNOTATION">$no_annotation_seqs{$_}\n$_\n";
		}
	close NO_ANNOTATION;
	$ba_in="$dump_folder/$outfile_prefix.no-annotation.fas";
	$ba_out="$dump_folder/$outfile_prefix.no-annotation.info";
	basic_analysis();

	print NCRNA_TABLE"no annotation\t$no_annotation\n";
	# NCRNA_TABLE is finished when piRNA cluster matching reads are added
	if(!$silent){print" OK.";}

	# map reads without annotation to piRNA cluster sequences (if available and if $no_annotation!=0)
	if(-e"$dump_folder/piRclDB"&&!$skip_piR&&$no_annotation!=0)
		{
		if(!$silent){print"\nMap sequences without annotation to $species{$species} piRNA cluster sequences...";}
		if($^O eq'linux'||$^O eq'darwin')
			{
			qx/.\/seqmap.exe $max_miRtail_length $dump_folder\/$outfile_prefix.no-annotation.fas $dump_folder\/piRclDB $dump_folder\/SeqMap_piR.temp \/output_all_matches \/available_memory:${memory}000 $less_memory_options_ncR> $dump_folder\/SeqMap_report4.txt/;
			}
		elsif($^O eq'MSWin32')
			{
			system("seqmap.exe $max_miRtail_length $dump_folder/$outfile_prefix.no-annotation.fas $dump_folder/piRclDB $dump_folder/SeqMap_piR.temp /output_all_matches /available_memory:${memory}000 ${less_memory_options_ncR}2>&1 > $dump_folder/SeqMap_report4.txt");
			}
		else
			{
			if(!$silent){print" WARNING! Unknown operating system.";}
			# try unix command
			qx/.\/seqmap.exe $max_miRtail_length $dump_folder\/$outfile_prefix.no-annotation.fas piRclDB $dump_folder\/SeqMap_piR.temp \/output_all_matches \/available_memory:${memory}000 $less_memory_options_ncR> $dump_folder\/SeqMap_report4.txt/;
			if(!-e"$dump_folder/SeqMap_species.temp")
				{
				# try windows command
				system("seqmap.exe $max_miRtail_length $dump_folder/$outfile_prefix.no-annotation.fas piRclDB $dump_folder/SeqMap_piR.temp /output_all_matches /available_memory:${memory}000 ${less_memory_options_ncR}2>&1 > $dump_folder/SeqMap_report4.txt");
				}
			}

		# check SeqMap report
		open(SMR,"$dump_folder/SeqMap_report4.txt");
		while(<SMR>)
			{
			if($_=~/not enough memory/)
				{
				print"\n\nERROR. Not enough memory available for SeqMap. Check $dump_folder/SeqMap_report4.txt for more details. Try less mismatch (-mismatch [n]), less insertions/deletions (-insdel [n]), fewer non-template 3' nucleotides (-tail [n]). Alternatively you may want to use the options -less_memory or -even_less_memory.\n\n";
				exit;
				}
			}
		close SMR;

		# clean up SeqMap output (same as for miR)
		$file_id="piR";
		clean_SeqMap_miRNA();

		my%hits_per_piR;
		open(SEQMAP,"$dump_folder/SeqMap_piR.clean-2.temp")||die print"\nERROR! Unable to open $dump_folder/SeqMap_piR.clean-2.temp.\n$!\n\n";
		while(<SEQMAP>)
			{
			$_=~s/\s*$//;
			@seqmap=split("\t",$_);
			$hits_per_piR{$seqmap[4]}++;
			}
		close SEQMAP;

		open(SEQMAP,"$dump_folder/SeqMap_piR.clean-2.temp")||die print"\nERROR! Unable to open $dump_folder/SeqMap_piR.clean-2.temp.\n$!\n\n";
		my%pi_tails;
		my%piRNA_candidates;
		my%piRNA_header;
		while(<SEQMAP>)
			{
			$_=~s/\s*$//;
			@seqmap=split("\t",$_);

			$parsed_loc=$seqmap[0];
			$parsed_loc=~s/ /_/g;
			if($global_annotation_matrix{$seqmap[4]}{$seqmap[3]}!~/piR-cluster:$parsed_loc/){$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="piR-cluster:$parsed_loc\t";}

			# 3' non-template hit to piRNA cluster
			if($seqmap[5]>0)
				{
				foreach$p((length$seqmap[2])-$max_miRtail_length..(length$seqmap[2])-1)
					{
					if(substr($seqmap[2],$p,1) ne substr($seqmap[4],$p,1))
						{
						$tail=substr($seqmap[4],$p);
						$pi_tails{$tail}+=$seqmap[3]/$hits_per_piR{$seqmap[4]};
						last;
						}
					}
				}
			$piRNA_candidates{$seqmap[4]}=$seqmap[3];
			$piRNA_header{$seqmap[4]}.="$seqmap[0]|";
			}
		close SEQMAP;

		# make piRNA candidates tail file
		open(OUT_PITAILS,">$dump_folder/$outfile_prefix.piRcandidates-tails_$species{$species}.txt")||die print"\nERROR! Unable to create output file $dump_folder/$outfile_prefix.piRcandidates-tails_$species{$species}.txt.\n$!\n\n";
		foreach$tail(@combs)
			{
			if(!$pi_tails{$tail})
				{
				$pi_tails{$tail}=0;
				}
			print OUT_PITAILS"$tail\t$pi_tails{$tail}\n";
			}
		close OUT_PITAILS;

		# make piRNA candidates fasta file
		open(PIR_CANDIDATES,">$dump_folder/$outfile_prefix.piRcandidates.fas")||die print"\nERROR! Unable to create output file $dump_folder/$outfile_prefix.piRcandidates.fas.\n$!\n\n";
		$piRc=0;
		foreach$piR(sort{$piRNA_candidates{$b}<=>$piRNA_candidates{$a}}keys%piRNA_candidates)
			{
			$piRc+=$piRNA_candidates{$piR};
			$piRNA_header{$piR}=~s/\|$//;
			print PIR_CANDIDATES">$piRNA_candidates{$piR}:$piRNA_header{$piR}\n$piR\n";
			}
		close PIR_CANDIDATES;
		$ba_in="$dump_folder/$outfile_prefix.piRcandidates.fas";
		$ba_out="$dump_folder/$outfile_prefix.piRcandidates.info";
		basic_analysis();
		print NCRNA_TABLE"   mapped to piRNA producing loci\t$piRc\n";
		}

	# search for phased RNAs
	if(@phasi>0)
		{
		if(!$silent){print"\nSearch for phased RNAs in $input_map:";}
		if($na_for_phasi)
			{
			$info_for_phasi_out="This is a subset of mapped reads without annotation.";
			}
		else
			{
			$info_for_phasi_out="This is a subset of all mapped reads.";
			}
		reformat_input_map();
		sub reformat_input_map
			{
			$lines_in_phasi_map=0;
			# create new input map file (and save reads and hits per sequence) if input map is not ELAND3 from collapsed data
			if($format eq'SAM')
				{
				if(!$silent){print"\n -check input map file...";}
				%lines_in_map=();
				open(INPUT_MAP,$input_map)||die print"\nERROR! Unable to open input map file $input_map.\n$!\n\n";
				while(<INPUT_MAP>)
					{
					next if($_=~/^@/); # skip SAM header lines
					@sam=split("\t",$_);
					next if ($sam_mapped{$sam[1]}==0||$sam[3]==0); # skip unmapped reads

					# reverse complement if sequence was mapped to the minus strand (SAM gives sequence of the locus, not of the mapped sequence)
					if($sam_strand{$sam[1]}eq'-')
						{
						$sam[9]=reverse$sam[9];
						$sam[9]=~tr/ATGC/TACG/;
						}

					#print"\n$sam[9]:$input_map_seq{$sam[9]}";
					$lines_in_map{$sam[2]}{$sam[3]}{$input_map_seq{$sam[9]}}{$sam[9]}=$sam_strand{$sam[1]};
					}
				close INPUT_MAP;
				create_phasi_map();
				}
			elsif($format eq'ELAND3'&&$all_identifiers_are_numeric==0)
				{
				if(!$silent){print"\n -check input map file...";}
				%lines_in_map=();
				open(INPUT_MAP,$input_map)||die print"\nERROR! Unable to open input map file $input_map.\n$!\n\n";
				while(<INPUT_MAP>)
					{
					next if($_=~/^trans_id/||$_=~/^#/); # skip ELAND3 header lines
					$_=~s/\s*$//;
					@eland3=split("\t",$_);
					$lines_in_map{$eland3[0]}{$eland3[1]}{$input_map_seq{$eland3[4]}}{$eland3[4]}=$eland3[6];
					}
				close INPUT_MAP;
				create_phasi_map();
				}
			else
				{
				if(!$silent){print"\n -check input map file...";}
				%hits_per_seq=();
				open(INPUT_MAP,$input_map);
				while(<INPUT_MAP>)
					{
					next if($_=~/^trans_id/);
					@map=split("\t",$_);
					$hits_per_seq{$map[4]}++;
					$lines_in_phasi_map++;
					}
				close INPUT_MAP;
				if(!$silent){print" OK. No reformat required.";}
				}

			sub create_phasi_map
				{
				if(!$silent){print" OK.\n -reformat input map file...";}
				%hits_per_seq=();
				open(REFORMAT_MAP,">$dump_folder/eland3collapsed.map")||die print"\nERROR! Unable to create sorted map file for phasiRNA detection.\n$!\n\n";
				foreach$chr(sort{$a cmp $b}keys%lines_in_map)
					{
					foreach$pos(sort{$a<=>$b}keys%{$lines_in_map{$chr}})
						{
						foreach$reads(keys%{$lines_in_map{$chr}{$pos}})
							{
							foreach$seq(keys%{$lines_in_map{$chr}{$pos}{$reads}})
								{
								$hits_per_seq{$seq}++;
								print REFORMAT_MAP"$chr\t$pos\t-\t$reads\t$seq\t-\t$lines_in_map{$chr}{$pos}{$reads}{$seq}\n";
								$lines_in_phasi_map++;
								}
							}
						}
					}
				close REFORMAT_MAP;
				undef%lines_in_map;
				$input_map="$dump_folder/eland3collapsed.map";
				if(!$silent){print" OK.";}
				}
			}

		if(!$silent){print"\n -read map file with sliding window (sw size=$phasi_sw_size bp).\n
 0%                                  50%                                  100%
 |------------------------------------|------------------------------------|
 ";}
		open(INPUT_MAP,$input_map);
		$phasi_progress_lines=0;
		$progress=0;
		while(<INPUT_MAP>)
			{
			next if($_=~/^trans_id/);
			$_=~s/\s*$//;
			@map=split("\t",$_);

			# give information on progress
			$phasi_progress_lines++;
			if(!$silent&&$phasi_progress_lines>=$lines_in_phasi_map/75)
				{
				if(!$silent){print".";}
				$phasi_progress_lines=0;
				$progress++;
				}

			# consider only reads with correct length for phasiRNA prediction
			if($phasi{length$map[4]}==1)
				{
				if($no_annotation_seqs{$map[4]}||!$na_for_phasi)# optionally consider only reads without ncRNA annotation
					{
					$coordinate_unified=$map[1];
					if($map[6]eq'-')
						{
						$coordinate_unified=$map[1]+2; # combine + and - strand mapped reads
						}
					$pos_offset=int(((($coordinate_unified/(length$map[4]))-(int($coordinate_unified/(length$map[4]))))*length$map[4])+0.5);

					# each locus belongs to two sliding windows
					$phasiRNA_readcount{$map[0]}{length$map[4]}{$pos_offset}{(int($coordinate_unified/$phasi_sw_size))+1}+=$map[3]/$hits_per_seq{$map[4]};
					$phasiRNA_readcount{$map[0]}{length$map[4]}{$pos_offset}{(int(($coordinate_unified+($phasi_sw_size/2))/$phasi_sw_size))+1}+=$map[3]/$hits_per_seq{$map[4]};
					$phasi_positions{$map[0]}{length$map[4]}{$pos_offset}{(int($coordinate_unified/$phasi_sw_size))+1}{$coordinate_unified}+=$map[3]/$hits_per_seq{$map[4]};
					$phasi_positions{$map[0]}{length$map[4]}{$pos_offset}{(int(($coordinate_unified+($phasi_sw_size/2))/$phasi_sw_size))+1}{$coordinate_unified}+=$map[3]/$hits_per_seq{$map[4]};

					# additionally save read counts from one strand only to exclude loci with suspicious strand bias
					if($map[6]eq'+')
						{
						$phasiRNA_readcount_plus{$map[0]}{length$map[4]}{$pos_offset}{(int($coordinate_unified/$phasi_sw_size))+1}+=$map[3]/$hits_per_seq{$map[4]};
						$phasiRNA_readcount_plus{$map[0]}{length$map[4]}{$pos_offset}{(int(($coordinate_unified+($phasi_sw_size/2))/$phasi_sw_size))+1}+=$map[3]/$hits_per_seq{$map[4]};
						}

					# save that for calculation of p with binomialdistriburion
					$total_readcount_phasilength{$map[0]}{length$map[4]}{(int($coordinate_unified/$phasi_sw_size))+1}+=$map[3]/$hits_per_seq{$map[4]};
					$total_readcount_phasilength{$map[0]}{length$map[4]}{(int(($coordinate_unified+($phasi_sw_size/2))/$phasi_sw_size))+1}+=$map[3]/$hits_per_seq{$map[4]};

					# count total number of sliding windows for Bonferroni correction of multiple testing
					$total_sw_count{$map[0]}{(int($coordinate_unified/$phasi_sw_size))+1}=1;
					}
				}
			$total_counts{$map[0]}{(int($coordinate_unified/500))+1}+=$map[3]/$hits_per_seq{$map[4]};
			$total_counts{$map[0]}{(int(($coordinate_unified+250)/500))+1}+=$map[3]/$hits_per_seq{$map[4]};
			}
		if(!$silent)
			{
			foreach($progress..74)
				{
				if(!$silent){print".";}
				}
			if(!$silent){print"\n\n";}
			}
		close INPUT_MAP;

		# create hash with factorials
		use bignum;
		$val=1;
		$fac{0}=1;
		foreach(1..$max_factorials_stored)
		    {
		    $val=$val*$_;
		    $fac{$_}=$val;
		    }

		# calculate Bonferroni-corrected p-value
		$total_sw_count=0;
		foreach$loc(keys%total_sw_count)
			{
			$total_sw_count+=keys%{$total_sw_count{$loc}};
			}
		$bonferroni_p=$phasi_p/$total_sw_count;
		$bonferroni_p_print=(int(($bonferroni_p*(10**15))+0.5))/(10**15);

		if(!$silent){print"\n\n -check for significant phasing signature.\n   -> Initial p set by user: $phasi_p\n   -> After corr. for multiple testing ($total_sw_count windows): $bonferroni_p_print\n
 0%                                  50%                                  100%
 |------------------------------------|------------------------------------|
 ";}
		# go through sliding windows
		my%getphasi=();
		my%sufficient_k=();
		my%insufficient_k=();
		$number_of_tests=0;
		$phasi_progress_windows=0;
		foreach$location(keys%phasiRNA_readcount)
			{
			foreach$phasi_length(@phasi)
				{
				foreach$frame(1..$phasi_length)
					{
					$number_of_tests+=keys%{$phasiRNA_readcount{$location}{$phasi_length}{$frame}};
					}
				}
			}
		$progress=0;
		foreach$location(keys%phasiRNA_readcount)
			{
			foreach$phasi_length(@phasi)
				{
				$pphased=1/$phasi_length;
				$pnotphased=1-$pphased;
				foreach$frame(1..$phasi_length)
					{
					foreach$sw_id(keys%{$phasiRNA_readcount{$location}{$phasi_length}{$frame}})
						{
						# skip windows with suspicious strand bias if they have only few phased loci
						$bad_strand_bias=0;
						if($phasiRNA_readcount_plus{$location}{$phasi_length}{$frame}{$sw_id}/$phasiRNA_readcount{$location}{$phasi_length}{$frame}{$sw_id}>$max_allowed_strandbias||$phasiRNA_readcount_plus{$location}{$phasi_length}{$frame}{$sw_id}/$phasiRNA_readcount{$location}{$phasi_length}{$frame}{$sw_id}<1-$max_allowed_strandbias)
							{
							$bad_strand_bias=1;
							}

						# optionally apply further thresholds: minimum number of loci, minimum fraction of phased reads in sw
						if(keys%{$phasi_positions{$location}{$phasi_length}{$frame}{$sw_id}}>=$min_phasi_loci&&$phasiRNA_readcount{$location}{$phasi_length}{$frame}{$sw_id}>=$total_counts{$location}{$sw_id}*$min_phasi_fraction)
							{
							# check p from binomialdistribution / round phased reads and all reads to nearest integer
							$k_observed=int($phasiRNA_readcount{$location}{$phasi_length}{$frame}{$sw_id}+0.5);
							$n=int($total_readcount_phasilength{$location}{$phasi_length}{$sw_id}+0.5);
							next if($k_observed<$min_phasi_reads);
							if($n>$max_factorials_stored)
								{
								if($calc_big_factorials&&!$fac{$n}) # calculate huge factorial if it was not calculated before
									{
									$fac_huge=$fac{$max_factorials_stored};
									foreach($max_factorials_stored+1..$n)
										{
										$fac_huge=$fac_huge*$_;
										}
									$fac{$n}=$fac_huge;
									}
								else # scale down if n is bigger than the highest factorial available
									{
									$k_observed=int(($k_observed/($n/$max_factorials_stored))+0.5);
									$n=$max_factorials_stored;
									}
								}

							# skip calculation if significant k for n was calculated before AND no need for calculation of loci in line
							if($sufficient_k{$n}&&$sufficient_k{$n}<=$k_observed&&$min_in_line<2&&$bad_strand_bias==0)
								{
								save_phasi_positions();
								}
							# skip calculation if higher k was found to be insufficient for this n before
							elsif(!$insufficient_k{$n}||$insufficient_k{$n}<$k_observed)
								{
								$k=-1;
								$p=0;
								while(1)
									{
									$k++;
									$p+=($fac{$n}/($fac{$k}*$fac{$n-$k}))*($pphased**$k)*($pnotphased**($n-$k));
									if($p>1-$bonferroni_p&&$k<$n) # last, sufficient (significant) k is $k+1
										{
										$sufficient_k{$n}=$k+1; # safe sufficient number of k for n total reads
										$max_in_line=1;
										$current_in_line=0;
										if($min_in_line>1)
											{
											foreach$pos(sort{$a<=>$b}keys%{$phasi_positions{$location}{$phasi_length}{$frame}{$sw_id}})
												{
												if($current_in_line==0||$prev_pos+$phasi_length==$pos)
													{
													$current_in_line++;
													if($current_in_line>$max_in_line)
														{
														$max_in_line=$current_in_line;
														}
													}
												else
													{
													$current_in_line=0;
													}
												$prev_pos=$pos;
												}
											}
										if($max_in_line>=$min_in_line&&$bad_strand_bias==0)
											{
											save_phasi_positions();
											sub save_phasi_positions
												{
												foreach$pos(sort{$a<=>$b}keys%{$phasi_positions{$location}{$phasi_length}{$frame}{$sw_id}})
													{
													$getphasi{$location}{$phasi_length}{$pos}=$frame;
													}
												}
											}
										elsif($bad_strand_bias==1)
											{
											if($min_in_line>=5||$min_phasi_loci>=25)
												{
												save_phasi_positions();
												}
											}
										last;
										}
									elsif($k==$k_observed) # last with non-significant p
										{
										# safe in-sufficient number of k for n total reads
										if(!$insufficient_k{$n}||$insufficient_k{$n}<$k)
											{
											$insufficient_k{$n}=$k;
											}
										$p_out_test=1-((int(($p*(10**10))+0.5))/(10**10));
										$bonferroni_out_test=(int(($bonferroni_p*(10**10))+0.5))/(10**10);
										last;
										}
									}
								}
							}
						$phasi_progress_windows++;
						if($phasi_progress_windows>=$number_of_tests/75)
							{
							if(!$silent){print".";}
							$progress++;
							$phasi_progress_windows=0;
							}
						}
					}
				}
			}
		if(!$silent)
			{
			foreach($progress..74)
				{
				if(!$silent){print".";}
				}
			if(!$silent){print"\n\n";}
			}

		$phasi_cluster_id=0;
		$prev_phasi_location="";
		$prev_phasi_coordinate=0;
		$prev_phasi_seq="";
		$loci_occupied=0;
		$cluster_reads_total=0;
		$cluster_reads_normalized=0;
		if(keys%getphasi>0)
			{
			open(PHASI_SORTED,">$dump_folder/$outfile_prefix.phasiRNA.sorted.fas")||print"\nERROR! Unable to open output file $dump_folder/$outfile_prefix.phasiRNA.sorted.fas.\n$!\n\n";
			open(PHASI_ALL,">$dump_folder/$outfile_prefix.phasiRNA.fas")||print"\nERROR! Unable to open output file $dump_folder/$outfile_prefix.phasiRNA.sorted.fas.\n$!\n\n";
			open(PHASI_ALIGN,">$dump_folder/$outfile_prefix.phasiRNA.align")||print"\nERROR! Unable to open output file $dump_folder/$outfile_prefix.phasiRNA.align.\n$!\n\n";
			print PHASI_ALIGN"CLUSTERS OF PHASED RNAs.\nGenomic sequence is represented by the center line.\nReads above the center line are aligned to the + strand and stated in 5'-3' orientation.\nReads below the center line are aligned to the - strand and stated in 3'-5' orientation.\nInformation on sequence read counts and genomic hits per sequence are given in the following format at the beginning of each sequence line: [sequence read count/genomic hits]\n\n";
			my%phasiRNAs=();
			$phasiRNA_readcount=0;
			if(!$silent){print"\n\n -collect putative phasiRNAs...";}
			$phasi_align_out_plus="";
			$phasi_align_out_minus="";
			open(INPUT_MAP,$input_map);
			while(<INPUT_MAP>)
				{
				$_=~s/\s*$//;
				@map=split("\t",$_);
				if($map[6]eq'+'&&$getphasi{$map[0]}{length$map[4]}{$map[1]})
					{
					report_phasi_cluster();
					$loci_occupied++;
					$cluster_reads_total+=$map[3];
					$cluster_reads_normalized+=$map[3]/$hits_per_seq{$map[4]};
					$read_info_head=substr("                  $map[3]/$hits_per_seq{$map[4]} ",-20);
					$whitespace=" " x ($map[1]-$current_cluster_start);
					$phasi_align_out_plus="${read_info_head}${whitespace}$map[4]\n".$phasi_align_out_plus;
					$print_frame=$getphasi{$map[0]}{length$map[4]}{$map[1]};
					report_phasi_sequence();
					}
				elsif($map[6]eq'-'&&$getphasi{$map[0]}{length$map[4]}{$map[1]+2})
					{
					report_phasi_cluster();
					$loci_occupied++;
					$cluster_reads_total+=$map[3];
					$cluster_reads_normalized+=$map[3]/$hits_per_seq{$map[4]};
					$read_info_head=substr("                  $map[3]/$hits_per_seq{$map[4]} ",-20);
					$seq3to5=reverse$map[4];
					$whitespace=" " x ($map[1]-$current_cluster_start);
					$phasi_align_out_minus.="\n${read_info_head}${whitespace}$seq3to5";
					$print_frame=$getphasi{$map[0]}{length$map[4]}{($map[1])+2};
					report_phasi_sequence();
					}

				# REPORT THE CLUSTER TO OUTFILE
				sub report_phasi_cluster
					{
					if($map[0]ne$prev_phasi_location||$map[1]-$min_distance_between_clusters>=$prev_phasi_coordinate||$print_frame!=$prev_frame) # new cluster if chromosome/scaffold changes, distance > threshold, different phasing frame
						{
						if($phasi_cluster_id>0)
							{
							$current_cluster_end=$prev_phasi_coordinate+(length$prev_phasi_seq)-1;
							$cluster_size=$current_cluster_end-$current_cluster_start+1;
							$center_line="                    ".">" x ($current_cluster_end-$current_cluster_start+1);
							$center_line.="\n                    "."<" x ($current_cluster_end-$current_cluster_start+1);
							print PHASI_ALIGN"cluster_ID:$phasi_cluster_id\tlocation:$current_cluster_location\tstart:$current_cluster_start\tend:$current_cluster_end\tsize:$cluster_size bp\tnon-identical_sequences:$loci_occupied\treads:$cluster_reads_total\treads_normalized:$cluster_reads_normalized\n${phasi_align_out_plus}${center_line}$phasi_align_out_minus\n\n";
							$loci_occupied=0;
							$cluster_reads_total=0;
							$cluster_reads_normalized=0;
							}
						$phasi_align_out_plus="";
						$phasi_align_out_minus="";
						$phasi_cluster_id++;
						$current_cluster_location=$map[0];
						$current_cluster_start=$map[1];
						}
					}

				# REPORT EACH SEQUENCE TO SORTED FASTA FILE
				sub report_phasi_sequence
					{
					$l=length$map[4];
					print PHASI_SORTED">length[nt]:$l, location:$map[0], position:$map[1], cluster_ID:$phasi_cluster_id, strand:$map[6], frame:$print_frame, read_count:$map[3], genomic_hits:$hits_per_seq{$map[4]}\n$map[4]\n";
					$phasiRNAs{$map[4]}=$map[3];
					$prev_phasi_location=$map[0];
					$prev_phasi_coordinate=$map[1];
					$prev_frame=$print_frame;
					$prev_phasi_seq=$map[4];
					}
				}
			close INPUT_MAP;
			foreach$seq(sort{$phasiRNAs{$b}<=>$phasiRNAs{$a} or $a cmp $b} keys%phasiRNAs)
				{
				$phasiRNA_readcount+=$phasiRNAs{$seq};
				print PHASI_ALL">$phasiRNAs{$seq}\n$seq\n";
				$global_annotation_matrix{$seqmap[4]}{$seqmap[3]}.="phasiRNA\t";
				}
			close PHASI_SORTED;
			close PHASI_ALL;
			close PHASI_ALIGN;
			undef%phasiRNAs;
			undef%phasiRNA_readcount;
			undef%getphasi;
			undef%sufficient_k;
			undef%insufficient_k;
			$ba_in="$dump_folder/$outfile_prefix.phasiRNA.fas";
			$ba_out="$dump_folder/$outfile_prefix.phasiRNA.info";
			basic_analysis();
			if($phasiRNA_readcount>0)
				{
				print NCRNA_TABLE"phasiRNAs\t$phasiRNA_readcount\tNOTE: $info_for_phasi_out\n";
				}
			if(!$silent){print" OK.\nFound $phasiRNA_readcount putative phasiRNAs organized in $phasi_cluster_id distinct clusters.\n";}
			}
		else
			{
			if(!$silent){print" no phased reads found.";}
			}
		no bignum;
		}
	undef%no_annotation_seqs;

	open(TARGET_COUNTS,">$dump_folder/$outfile_prefix.hits_per_target.txt")||print"\nError. Unable to create output file $dump_folder/$outfile_prefix.hits_per_target.txt.\n$!\n\n";
	print TARGET_COUNTS"TRANSCRIPT_CLASS\tTRANSCRIPT_NAME\tREAD_COUNT\n";
	foreach$biotype(sort{$a cmp $b}keys%ncRNA_counts_2)
		{
		foreach$id(sort{$ncRNA_counts_2{$biotype}{$b}<=>$ncRNA_counts_2{$biotype}{$a}}keys%{$ncRNA_counts_2{$biotype}})
			{
			print TARGET_COUNTS"$biotype\t$id\t$ncRNA_counts_2{$biotype}{$id}\n";
			}
		}
	close TARGET_COUNTS;
	close NCRNA_TABLE;

	# check ping-pong signature
	if($check_pp_signature)
		{
		if(!$silent){print"\nCheck for ping-pong signature in sequence datasets:";}
		if(!-e"$dump_folder/eland3collapsed.map") # reformat mapfile if that was not done before (phasiRNA prediction)
			{
			reformat_input_map();
			}
		opendir(WIZDIR,$dump_folder);
		%output=();
		while($out_file=readdir(WIZDIR))
			{
			next if($out_file!~/^$outfile_prefix\..+\.fas$/);
			$class=$out_file;
			$class=~s/^$outfile_prefix\.//;
			$class=~s/\.fas$//;
			open(OUTFASTA,"$dump_folder/$out_file")||print"\nERROR! Unable to open output file $out_file.\n$!\n\n";
			while(<OUTFASTA>)
				{
				if($_!~/^>/)
					{
					$_=~s/\s*$//;
					push(@{$output{$_}},$class);
					}
				}
			close OUTFASTA;
			}
		closedir WIZDIR;

		$max_length=0;
		$mapfile_hits=0;
		my%hits_per_seq=();
		open(INPUT_MAP,$input_map);
		while(<INPUT_MAP>)
			{
			next if($_=~/^trans_id/||$_=~/^#/);
			$_=~s/\s*$//;
			@d=split("\t",$_);
			$mapfile_hits++;
			$hits_per_seq{$d[4]}++;
			$reads_per_seq{$d[4]}=$d[3];
			if(length$d[4]>$max_length) # save max. sequence length (-> maximum overlap)
				{
				$max_length=length$d[4];
				}
			}
		close INPUT_MAP;
		if(!$silent){print"

 Scan input map file for 5' overlaps:
 0%                                  50%                                  100%
 |------------------------------------|------------------------------------|
 "};
		@sw=();
		$progress=0;
		$prev_loc="";
		$processed_hits=0;
		%overlap=();
		open(INPUT_MAP,$input_map)||print"\nERROR! Unable to open input map file $input_map.\n$!\n\n";
		while(<INPUT_MAP>)
			{
			next if($_=~/^trans_id/||$_=~/^#/);
			@d=split("\t",$_);
			if($d[0]ne$prev_loc) # empty sliding window when location changes
				{
				@sw=();
				}
			if($d[6]=~/-/) # add hit to sliding window if current hit is on the minus strand
				{
				push(@sw,[$d[1],$d[4],$d[8]]); # sliding window entries comprise coordinate|sequence|allocated reads (if available)
				while(1) # check if hit(s) must be removed from sliding window
					{
					if(@sw>1&&$d[1]>($sw[0][0])+$max_length)
						{
						shift@sw;
						}
					else
						{
						last;
						}
					}
				}
			else # count overlaps in the sliding window if current hit is on the plus strand
				{
				foreach$i(0..@sw-1)
					{
					if($sw[$i][0]+(length$sw[$i][1])>$d[1]&&$sw[$i][0]+(length$sw[$i][1])<$d[1]+length$d[4]) # check whether hits overlap
						{
						# global pp signature
						$overlap{'global'}{$sw[$i][0]+(length$sw[$i][1])-$d[1]}+=(($reads_per_seq{$d[4]}/$hits_per_seq{$d[4]})*($reads_per_seq{$sw[$i][1]}/$hits_per_seq{$sw[$i][1]}));

						# pp signature per RNA class
						foreach$class_seq1(@{$output{$d[4]}})
							{
							foreach$class_seq2(@{$output{$sw[$i][1]}})
								{
								if($class_seq1 eq $class_seq2)
									{
									$overlap{$class_seq1}{$sw[$i][0]+(length$sw[$i][1])-$d[1]}+=(($reads_per_seq{$d[4]}/$hits_per_seq{$d[4]})*($reads_per_seq{$sw[$i][1]}/$hits_per_seq{$sw[$i][1]}));
									}
								}
							}
						}
					}
				}
			$processed_hits++;
			if($processed_hits>=$mapfile_hits/75&&!$silent)
				{
				$progress++;
				$processed_hits=0;
				if(!$silent){print".";}
				}
			$prev_loc=$d[0];
			}
		close INPUT_MAP;
		if(!$silent)
			{
			foreach($progress..74)
				{
				if(!$silent){print".";}
				}
			if(!$silent){print"\n\n";}
			}

		foreach$RNAclass(keys%overlap)
			{
			$pp_results="";
			$pp_results.="Total scores for 5' overlap:\noverlap [nt]\tread pairs\n";
			$average_background=0;
			foreach(1..($max_length-1))
				{
				if($_>=1&&$_<=9)
					{
					$average_background+=$overlap{$RNAclass}{$_};
					}
				elsif($_>=11&&$_<=20)
					{
					$average_background+=$overlap{$RNAclass}{$_};
					}
				$pp_results.="$_\t$overlap{$RNAclass}{$_}\n";
				}
			$average_background=$average_background/19;
			$variance=0;
			foreach(1..($max_length-1))
				{
				if($_>=1&&$_<=9)
					{
					$variance+=($overlap{$RNAclass}{$_}-$average_background)**2;
					}
				elsif($_>=11&&$_<=20)
					{
					$variance+=($overlap{$RNAclass}{$_}-$average_background)**2;
					}
				}
			$variance=$variance/19;
			$stddeviation=sqrt($variance);
			if($stddeviation>0)
				{
				$Zscore=($overlap{$RNAclass}{10}-$average_background)/$stddeviation;
				}
			else
				{
				if($overlap{$RNAclass}{10}>0)
					{
					$Zscore="infinite";
					}
				else
					{
					$Zscore=0;
					}
				}
			$pp_results.="
Z-score calculation:
Average background (overlaps 1-9+11-20): $average_background
Variance background: $variance
Standard deviation: $stddeviation
Ping-Pong Z-Score: $Zscore

Z-score >= 1.6449 (one-tailed hypothesis) -> p < 0.05
Z-score >= 2.3264 (one-tailed hypothesis) -> p < 0.01
";

			open(PP_OUT,">$dump_folder/$outfile_prefix.$RNAclass.pp")||print"\nERROR! Unable to open $dump_folder/$outfile_prefix.$RNAclass.pp.\n$!\n\n";
			print PP_OUT $pp_results;
			close PP_OUT;
			}
		undef%overlap;
		}

	# make HTML files
	if(!$no_html)
		{
		my%other_ncRNA_classes;
		$html_ncRNAcounts="";
		$html_ncRNA_other_counts="";
		$total_reads_in_probe=0;

		$total_reads_in_probe+=$i_miRspecies;
		$total_reads_in_probe+=$i_miRnonspecies;
		$total_reads_in_probe+=$no_annotation;
		$total_reads_in_probe+=$simple_reads;
		foreach$biotype(keys%sorted_sequences)
			{
			$total_reads_in_probe+=$ncRNA_counts_1{$biotype};
			}
		$sorted_sequences{"no annotation"}=1;
		$sorted_sequences{"low complexity reads"}=1;
		$ncRNA_counts_1{"miRNA total"}=$total_miR_reads;
		$ncRNA_counts_1{"miRNA $species"}=$i_miRspecies;
		$ncRNA_counts_1{"miRNA other"}=$i_miRnonspecies;
		$ncRNA_counts_1{"no annotation"}=$no_annotation;
		$ncRNA_counts_1{"low complexity reads"}=$simple_reads;

		# display ncRNA classes above threshold $percentage_threshold
		$percentage_threshold=1; # [%]
		$max_height=300;
		$column_width=60;
		$column_distance=15;
		@font_size=(20,14,10);
		$left_position=-$column_width;
		$other_ncRNA_classes=0;
		$top_value=0;
		@color=("#87ABFF","#FC8989","#ECECEC");

		# miRNAs are not keys in hash %sorted_sequences but are added to the sorted array
		@sorted_ncRNA_classes=keys%sorted_sequences;
		@sorted_ncRNA_classes=sort@sorted_ncRNA_classes;
		unshift(@sorted_ncRNA_classes,"miRNA other");
		unshift(@sorted_ncRNA_classes,"miRNA $species");
		unshift(@sorted_ncRNA_classes,"miRNA total");
		foreach$biotype(@sorted_ncRNA_classes)
			{
			$ncRNA_counts_1{$biotype}=int($ncRNA_counts_1{$biotype}+0.5);
			if($ncRNA_counts_1{$biotype}>=($total_reads_in_probe/100)*$percentage_threshold||$biotype=~/miRNA /)
				{
				$column_height=int(($ncRNA_counts_1{$biotype}/$total_reads_in_probe)*$max_height);
				if($column_height>$top_value)
					{
					$top_value=$column_height;
					}
				$left_position+=($column_width+$column_distance);
				$label_position_x=$column_height+5;
				$label_position_y=$left_position+(($column_width)/2)-($font_size[0]/2);

				$html_ncRNAcounts.="  <div style=\"background-color:$color[0]; width:${column_width}px; height:${column_height}px; position:absolute; bottom:0px; left:${left_position}px;\"></div>\n";
				$html_ncRNAcounts.="  <div style=\"position:absolute; font-size:$font_size[1]px; bottom:${label_position_x}px; left:${label_position_y}px; transform-origin: 0% 0%; moz-transform: rotate(315deg); ms-transform: rotate(315deg); o-transform: rotate(315deg); webkit-transform: rotate(315deg); transform: rotate(315deg);\">$ncRNA_counts_1{$biotype}</div>\n";
				$html_ncRNAcounts.="  <div style=\"position:absolute; font-size:$font_size[0]px; bottom:-20px; left:${label_position_y}px; transform-origin: 0% 100%; moz-transform: rotate(45deg); ms-transform: rotate(45deg); o-transform: rotate(45deg); webkit-transform: rotate(45deg); transform: rotate(45deg);\">$biotype</div>\n";
				}
			else
				{
				$other_ncRNA_classes+=$ncRNA_counts_1{$biotype};
				$other_ncRNA_classes{$biotype}=$ncRNA_counts_1{$biotype};
				}
			}

		# add one column for other classes
		if($other_ncRNA_classes>0)
			{
			$column_height=int(($other_ncRNA_classes/$total_reads_in_probe)*$max_height);
			$left_position+=($column_width+$column_distance);
			$label_position_x=$column_height+20;
			$label_position_y=$left_position+(($column_width)/2)-($font_size[0]/2);

			$html_ncRNAcounts.="  <div style=\"background-color:$color[1]; width:${column_width}px; height:${column_height}px; position:absolute; bottom:0px; left:${left_position}px;\"></div>\n";
			$html_ncRNAcounts.="  <div style=\"position:absolute; font-size:$font_size[1]px; bottom:${label_position_x}px; left:${label_position_y}px; transform-origin: 0% 0%; moz-transform: rotate(315deg); ms-transform: rotate(315deg); o-transform: rotate(315deg); webkit-transform: rotate(315deg); transform: rotate(315deg);\">$other_ncRNA_classes</div>\n";
			$html_ncRNAcounts.="  <div style=\"position:absolute; font-size:$font_size[0]px; bottom:-20px; left:${label_position_y}px; transform-origin: 0% 100%; moz-transform: rotate(45deg); ms-transform: rotate(45deg); o-transform: rotate(45deg); webkit-transform: rotate(45deg); transform: rotate(45deg);\">other</div>\n";

			$arrow_height=$top_value*2;
			$arrow_x=$left_position+($column_width/2)-10;
			$arrow_top=$top_value+75;
			$html_ncRNAcounts.="  <div style=\"background-color:$color[1]; width:2px; height:${arrow_height}px; position:absolute; top:${arrow_top}px; left:${arrow_x}px;\"></div>\n";
			}

		# add frame lines
		$line_width1=$left_position+$column_width+$column_distance+50;
		$line_height1=$top_value+75;
		$html_ncRNAcounts.="  <div style=\"background-color:black; width:${line_width1}px; height:1px; position:absolute; bottom:-1px; left:0px;\"></div>\n";
		$html_ncRNAcounts.="  <div style=\"background-color:black; width:1px; height:${line_height1}px; position:absolute; top:0px; left:0px;\"></div>\n";

		# add second diagram for other ncRNA classes (itemized)
		if($other_ncRNA_classes>0)
			{
			$xposition_for_second_diagram=($line_height1*2)+50;
			$xposition_for_second_label1=$xposition_for_second_diagram-35;
			$xposition_for_second_label2=$xposition_for_second_diagram+115;
			$max_height=300;
			$column_width=40;
			$column_distance=10;
			$top_value=0;
			$left_position=-$column_width;
			foreach$biotype(sort{$other_ncRNA_classes{$b}<=>$other_ncRNA_classes{$a}}keys%other_ncRNA_classes)
				{
				next if($other_ncRNA_classes{$biotype}==0);
				$column_height=int(($other_ncRNA_classes{$biotype}/$other_ncRNA_classes)*$max_height);
				if($column_height>$top_value)
					{
					$top_value=$column_height;
					}
				$left_position+=($column_width+$column_distance);
				$label_position_x=$column_height+5;
				$label_position_y=$left_position+(($column_width)/2)-($font_size[0]/2);

				$html_ncRNA_other_counts.="  <div style=\"background-color:$color[1]; width:${column_width}px; height:${column_height}px; position:absolute; bottom:0px; left:${left_position}px;\"></div>\n";
				$html_ncRNA_other_counts.="  <div style=\"position:absolute; font-size:$font_size[2]px; bottom:${label_position_x}px; left:${label_position_y}px; transform-origin: 0% 0%; moz-transform: rotate(315deg); ms-transform: rotate(315deg); o-transform: rotate(315deg); webkit-transform: rotate(315deg); transform: rotate(315deg);\">$ncRNA_counts_1{$biotype}</div>\n";
				$html_ncRNA_other_counts.="  <div style=\"position:absolute; font-size:$font_size[1]px; bottom:-20px; left:${label_position_y}px; transform-origin: 0% 100%; moz-transform: rotate(45deg); ms-transform: rotate(45deg); o-transform: rotate(45deg); webkit-transform: rotate(45deg); transform: rotate(45deg);\">$biotype</div>\n";
				}

			# add frame lines for second diagram
			$line_width2=$left_position+$column_width+$column_distance+50;
			$line_height2=$top_value+75;
			$html_ncRNA_other_counts.="  <div style=\"background-color:black; width:${line_width2}px; height:1px; position:absolute; bottom:-1px; left:0px;\"></div>\n";
			$html_ncRNA_other_counts.="  <div style=\"background-color:black; width:1px; height:${line_height2}px; position:absolute; top:0px; left:0px;\"></div>\n";
			}

		if($line_width2<$line_width1)
			{
			$line_width2=$line_width1;
			}
		open(NCRNA_HTML,">$dump_folder/ncRNA_counts.html");
		print NCRNA_HTML
"<!DOCTYPE html>
<html>
 <head>
  <meta charset=\"utf-8\">
  <title>small RNA annotation</title>
 </head>
<body>
 <div style=\"position:absolute; font-size:$font_size[0]px; top:20px; left:60px;\">sncRNA annotation (major fractions)</div>
 <div style=\"position:absolute; font-size:$font_size[0]px; top:165px; left:20px; transform-origin: 0% 0%; moz-transform: rotate(270deg); ms-transform: rotate(270deg); o-transform: rotate(270deg); webkit-transform: rotate(270deg); transform: rotate(270deg);\">read counts</div>
 <div style=\"position:absolute; left:50px; top:50px; background-color:$color[2]; width:${line_width1}px; height:${line_height1}px\">\n".$html_ncRNAcounts."</div>

 <div style=\"position:absolute; font-size:$font_size[0]px; top:${xposition_for_second_label1}px; left:60px;\">sncRNA annotation (other fractions)</div>
 <div style=\"position:absolute; font-size:$font_size[0]px; top:${xposition_for_second_label2}px; left:20px; transform-origin: 0% 0%; moz-transform: rotate(270deg); ms-transform: rotate(270deg); o-transform: rotate(270deg); webkit-transform: rotate(270deg); transform: rotate(270deg);\">read counts</div>
 <div style=\"position:absolute; left:50px; top:${xposition_for_second_diagram}px; background-color:$color[2]; width:${line_width2}px; height:${line_height2}px\">\n".$html_ncRNA_other_counts."</div>
 <div style=\"position:absolute; left:50px; top:${xposition_for_second_diagram}px; background-color:$color[1]; width:${line_width2}px; height:2px;\"></div>\n
</body>\n</html>";
		close NCRNA_HTML;
		}

	# remove temporary files from dump folder
	if(!$keep_temp)
		{
		foreach$i(1..4)
			{
			unlink("$dump_folder/SeqMap_report$i.txt");
			}
		unlink("$dump_folder/SeqMap_species.temp");
		unlink("$dump_folder/SeqMap_nonspecies.temp");
		unlink("$dump_folder/SeqMap_ncRNA.temp");
		unlink("$dump_folder/SeqMap_ncRNA.clean.temp");
		unlink("$dump_folder/SeqMap_piR.temp");
		foreach$i(1..2)
			{
			unlink("$dump_folder/SeqMap_species.clean-$i.temp");
			unlink("$dump_folder/SeqMap_nonspecies.clean-$i.temp");
			unlink("$dump_folder/SeqMap_piR.clean-$i.temp");
			unlink("$dump_folder/SeqMap_ncRNA.clean-$i.temp");
			unlink("$dump_folder/SeqMap_input$i.temp");
			}
		unlink("$dump_folder/piRclDB");
		unlink("$dump_folder/miRBase_mature");
		unlink("$dump_folder/miRBase_hairpin_$species{$species}.fas");
		unlink("$dump_folder/miRBase_hairpin_non-$species{$species}.fas");
		unlink("$dump_folder/ncRNA.fas");
		unlink("$dump_folder/cDNA.fas");
		}

	# create global annotation matrix
	open(MATRIX,">$dump_folder/$outfile_prefix.full_annotation_matrix.txt")||print"\nError. Unable to create annotation matrix file.\n$!\n\n";
	print MATRIX"sequence\treads\tannotation(s)";
	foreach$seq(sort{$a cmp $b}keys%global_annotation_matrix)
		{
		print MATRIX"\n$seq";
		foreach$reads(keys%{$global_annotation_matrix{$seq}})
			{
			print MATRIX"\t$reads\t$global_annotation_matrix{$seq}{$reads}";
			}
		}
	close MATRIX;

	if(!$silent){print"\n Finished annotation for file $parsed_input.\n";}
	}

$computation_time=time-$t0;
$days=int($computation_time/86400);
$hours=int(($computation_time-$days*86400)/3600);
$minutes=int((($computation_time-$days*86400)-($hours*3600))/60);
$seconds=$computation_time-($days*86400)-($hours*3600)-($minutes*60);
print"\n\n Computation finished.\n Elapsed time: $days days, $hours hours, $minutes minutes, $seconds seconds.\n\n$update_available


                       ### How to cite unitas ###
 Gebert D, Hewel C, Rosenkranz D. unitas: the universal tool for annotation of
 small RNAs. BMC Genomics 2017 18:644.

";


#################################
#                       SUBROUTINES
#################################

sub clean_SeqMap_miRNA
	{
	# step 1: keep perferct hits or hits with non-template 3' ends
	open(SEQMAP,"$dump_folder/SeqMap_$file_id.temp")||die print"\nERROR! Unable to open temporary SeqMap output file $dump_folder/SeqMap_$file_id.temp.\n$!\n\n";
	open(SEQMAP_CLEAN1,">$dump_folder/SeqMap_$file_id.clean-1.temp")||die print"\nERROR! Unable to create clean SeqMap output file.\n$!\n\n";
	$head=<SEQMAP>;
	%best_hits=();
	while(<SEQMAP>)
		{
		$_=~s/\s*$//;
		@seqmap=split("\t",$_);
		if($seqmap[5]==0)
			{
			print SEQMAP_CLEAN1"$_\t0\n"; # 5th column will refer to tail length, 6th column to total mismatch counts!
			# save best alignment
			$best_hits{$seqmap[4]}=0;
			}

		# check number of internal modifications
		else
			{
			$current_internal_mismatch=0;
			foreach$p(1..(length$seqmap[2])-$max_miRtail_length)
				{
				if(substr($seqmap[2],$p-1,1)ne substr($seqmap[4],$p-1,1))
					{
					$current_internal_mismatch++;
					}
				last if($current_internal_mismatch>$intmod_miR);
				}
			}

		### relaxed tailing defenition = mm in one of the last n positions means: tail starts here ###
		if($current_internal_mismatch<=$intmod_miR)
			{
			$tail_present=0;
			foreach$p((length$seqmap[2])-$max_miRtail_length..(length$seqmap[2])-1)
				{
				if(substr($seqmap[2],$p,1) ne substr($seqmap[4],$p,1))
					{
					# check whether tail-nucleotides represent allowed 3' modification, otherwise count it as internal mismatch
					$tail=substr($seqmap[4],$p);
					@tail=split('',$tail);
					$all_ok=1;
					foreach$nt(@tail)
						{
						if(!$miRtails{$nt})
							{
							$all_ok=0;
							last;
							}
						}
					if($all_ok==0)
						{
						$current_internal_mismatch++;
						last if($current_internal_mismatch>$intmod_miR);
						next;
						}

					$tail_present=1;
					$seqmap[5]=length(substr($seqmap[2],$p)); #5th column will refer to tail length, 6th column to total mismatch counts!
					$total_mm_counts=$seqmap[5]+$current_internal_mismatch;
					print SEQMAP_CLEAN1"$seqmap[0]\t$seqmap[1]\t$seqmap[2]\t$seqmap[3]\t$seqmap[4]\t$seqmap[5]\t$total_mm_counts\n";

					# save best alignment
					if(!$best_hits{$seqmap[4]})
						{
						$best_hits{$seqmap[4]}=$total_mm_counts;
						}
					elsif($seqmap[5]<$best_hits{$seqmap[4]})
						{
						$best_hits{$seqmap[4]}=$total_mm_counts;
						}
					last;
					}
				}
			# no (valid) tail present, only internal modifications, yet not printet to clean seqmap file. 5th column will refer to tail length, 6th column to total mismatch counts!
			if($tail_present==0&&$current_internal_mismatch<=$intmod_miR)
				{
				$best_hits{$seqmap[4]}=$seqmap[5];
				print SEQMAP_CLEAN1"$seqmap[0]\t$seqmap[1]\t$seqmap[2]\t$seqmap[3]\t$seqmap[4]\t0\t$seqmap[5]\n";
				}
			}
		}
	close SEQMAP;
	close SEQMAP_CLEAN1;

	# step 2: keep best hits only, replace '-stem-loop' by '-5p/-3p', check internal modificationss
	open(SEQMAP_CLEAN1,"$dump_folder/SeqMap_$file_id.clean-1.temp")||die print"\nERROR! Unable to open temporary SeqMap output file $dump_folder/SeqMap_$file_id.clean-1.temp.\n$!\n\n";
	open(SEQMAP_CLEAN2,">$dump_folder/SeqMap_$file_id.clean-2.temp")||die print"\nERROR! Unable to create clean SeqMap output file $dump_folder/SeqMap_$file_id.clean-2.temp.\n$!\n\n";
	while(<SEQMAP_CLEAN1>)
		{
		$_=~s/\s*$//;
		@seqmap=split("\t",$_);
		if($best_hits{$seqmap[4]}==$seqmap[6])
			{
			# check -5p or -3p
			if($seqmap[1]+((length$seqmap[4])/2)<=$miR_hairpin_length{$seqmap[0]}/2)
				{
				$_=~s/_stem-loop/-5p/
				}
			else
				{
				$_=~s/_stem-loop/-3p/
				}

			# check for internal modifications
			if($seqmap[6]>$seqmap[5])
				{
				$modification_cigar_string="";
				foreach$p(1..(length$seqmap[4])-$max_miRtail_length)
					{
					if(substr($seqmap[2],$p-1,1)ne substr($seqmap[4],$p-1,1))
						{
						$modification_cigar_string.=$p.substr($seqmap[2],$p-1,1)."->".substr($seqmap[4],$p-1,1)."|";
						}
					}
				if(length$modification_cigar_string>0)
					{
					$modification_cigar_string=~s/\|$//;
					$_=~s/\t/($modification_cigar_string)\t/;
					}
				}
			print SEQMAP_CLEAN2"$_\n";
			}
		}
	close SEQMAP_CLEAN1;
	close SEQMAP_CLEAN2;
	undef%best_hits;
	}

sub clean_SeqMap_ncRNA
	{
	open(SEQMAP,"$dump_folder/SeqMap_ncRNA.temp")||die print"\nERROR! Unable to open temporary SeqMap output file $dump_folder/SeqMap_ncRNA.temp.\n$!\n\n";
	$head=<SEQMAP>;
	%best_hits=();
	while(<SEQMAP>)
		{
		@seqmap=split("\t",$_);
		if(!$best_hits{$seqmap[4]}||$seqmap[5]<$best_hits{$seqmap[4]})
			{
			$best_hits{$seqmap[4]}=$seqmap[5];
			}
		}
	close SEQMAP;
	open(SEQMAP,"$dump_folder/SeqMap_ncRNA.temp")||die print"\nERROR! Unable to open temporary SeqMap output file $dump_folder/SeqMap_ncRNA.temp.\n$!\n\n";
	open(SEQMAP_CLEAN,">$dump_folder/SeqMap_ncRNA.clean.temp")||die print"\nERROR! Unable to create clean SeqMap output file $dump_folder/SeqMap_ncRNA.clean.temp.\n$!\n\n";
	$head=<SEQMAP>;
	while(<SEQMAP>)
		{
		@seqmap=split("\t",$_);
		if($seqmap[5]==$best_hits{$seqmap[4]})
			{
			print SEQMAP_CLEAN$_;
			}
		}
	close SEQMAP;
	close SEQMAP_CLEAN;
	undef%best_hits;
	}

sub basic_analysis
	{
	open(IN,$ba_in)||print"\nERROR! Unable to analyze output file $ba_in.\n$!\n\n";
	open(OUT,">$ba_out")||print"\nERROR! Unable to create output file $ba_out.\n$!\n\n";
	%length=();
	%comp=();
	%nt=();
	while(<IN>)
		{
		$_=~s/\s*$//;
		if($_=~s/^>//)
			{
			$reads=$_;
			}
		else
			{
			$length{length$_}+=$reads;
			foreach$p(1..length$_)
				{
				$comp{$p}{substr($_,$p-1,1)}+=$reads;
				$nt{substr($_,$p-1,1)}=1;
				}
			}
		}
	close IN;

	@size=keys%length;
	@size=sort{$a<=>$b}@size;
	@nt=keys%nt;
	@nt=sort@nt;
	print OUT"LENGTH DISTRIBUTION\nlength\treads";
	foreach$l($size[0]..$size[-1])
		{
		print OUT"\n$l\t$length{$l}";
		}

	print OUT"\n\nPOSITIONAL NUCLEOTIDE COMPOSITION\npos.";
	foreach$nt(@nt)
		{
		print OUT"\t$nt";
		}
	foreach$p(1..$size[-1])
		{
		print OUT"\n$p";
		foreach$nt(@nt)
			{
			if(!$comp{$p}{$nt})
				{
				$comp{$p}{$nt}=0;
				}
			print OUT"\t$comp{$p}{$nt}";
			}
		}
	undef%length;
	undef%comp;
	undef%nt;
	close IN;
	close OUT;
	}

sub load_species_dictionary
	{
	$eval_URL="";
	$eval_URL=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/URLs/species');
	if(length$eval_URL>0)
		{
		eval$eval_URL;
		}
	else
		{
		if(!$silent){print"\nFailed to load current species list from smallRNAgroup-SERVER. Use internal list.";}
### SPECIES DICTONARY START ###
%species=
	(
	'_candida_auris'=>'_candida_auris',
	'_candida_glabrata'=>'_candida_glabrata',
	'_candida_glabrata_gca_001466525'=>'_candida_glabrata_gca_001466525',
	'_candida_glabrata_gca_001466535'=>'_candida_glabrata_gca_001466535',
	'_candida_glabrata_gca_001466565'=>'_candida_glabrata_gca_001466565',
	'_candida_glabrata_gca_001466575'=>'_candida_glabrata_gca_001466575',
	'_candida_glabrata_gca_001466635'=>'_candida_glabrata_gca_001466635',
	'_candida_glabrata_gca_001466685'=>'_candida_glabrata_gca_001466685',
	'_candida_intermedia'=>'_candida_intermedia',
	'_candida_intermedia_gca_900106125'=>'_candida_intermedia_gca_900106125',
	'_candida_tenuis_atcc_10573'=>'_candida_tenuis_atcc_10573',
	'absidia_glauca'=>'Absidia_glauca',
	'acidomyces_richmondensis'=>'Acidomyces_richmondensis',
	'acidomyces_richmondensis_bfw'=>'Acidomyces_richmondensis_bfw',
	'acremonium_chrysogenum_atcc_11550'=>'Acremonium_chrysogenum_atcc_11550',
	'acyrthosiphon_pisum'=>'Acyrthosiphon_pisum',
	'adineta_vaga'=>'Adineta_vaga',
	'aedes_aegypti'=>'Aedes_aegypti',
	'aegilops_tauschii'=>'Aegilops_tauschii',
	'agaricus_bisporus_var_burnettii_jb137_s8'=>'Agaricus_bisporus_var_burnettii_jb137_s8',
	'ailuropoda_melanoleuca'=>'Panda',
	'albugo_laibachii'=>'Albugo_laibachii',
	'allomyces_macrogynus_atcc_38327'=>'Allomyces_macrogynus_atcc_38327',
	'alternaria_alternata'=>'Alternaria_alternata',
	'amanita_muscaria_koide_bx008'=>'Amanita_muscaria_koide_bx008',
	'amborella_trichopoda'=>'Amborella_trichopoda',
	'amphiamblys_sp_wsbs2006'=>'Amphiamblys_sp_wsbs2006',
	'amphimedon_queenslandica'=>'Amphimedon_queenslandica',
	'anas_platyrhynchos'=>'Duck',
	'angomonas_deanei'=>'Angomonas_deanei',
	'anncaliia_algerae_pra109'=>'Anncaliia_algerae_pra109',
	'anncaliia_algerae_pra339'=>'Anncaliia_algerae_pra339',
	'anolis_carolinensis'=>'Anole_lizard',
	'anopheles_darlingi'=>'Anopheles_darlingi',
	'anopheles_gambiae'=>'Anopheles_gambiae',
	'anoplophora_glabripennis'=>'Anoplophora_glabripennis',
	'anthracocystis_flocculosa_pf_1'=>'Anthracocystis_flocculosa_pf_1',
	'aphanomyces_astaci'=>'Aphanomyces_astaci',
	'aphanomyces_invadans'=>'Aphanomyces_invadans',
	'apis_mellifera'=>'Apis_mellifera',
	'arabidopsis_lyrata'=>'Arabidopsis_lyrata',
	'arabidopsis_thaliana'=>'Arabidopsis_thaliana',
	'arthrobotrys_oligospora_atcc_24927'=>'Arthrobotrys_oligospora_atcc_24927',
	'arthroderma_otae_cbs_113480'=>'Arthroderma_otae_cbs_113480',
	'aschersonia_aleyrodis_rcef_2490'=>'Aschersonia_aleyrodis_rcef_2490',
	'ascochyta_rabiei'=>'Ascochyta_rabiei',
	'ascoidea_rubescens_dsm_1968'=>'Ascoidea_rubescens_dsm_1968',
	'ascosphaera_apis_arsef_7405'=>'Ascosphaera_apis_arsef_7405',
	'ashbya_gossypii'=>'Ashbya_gossypii',
	'aspergillus_aculeatus_atcc_16872'=>'Aspergillus_aculeatus_atcc_16872',
	'aspergillus_bombycis'=>'Aspergillus_bombycis',
	'aspergillus_brasiliensis_cbs_101740'=>'Aspergillus_brasiliensis_cbs_101740',
	'aspergillus_calidoustus'=>'Aspergillus_calidoustus',
	'aspergillus_carbonarius_item_5010'=>'Aspergillus_carbonarius_item_5010',
	'aspergillus_clavatus'=>'Aspergillus_clavatus',
	'aspergillus_cristatus'=>'Aspergillus_cristatus',
	'aspergillus_flavus'=>'Aspergillus_flavus',
	'aspergillus_flavus_af70'=>'Aspergillus_flavus_af70',
	'aspergillus_fumigatus'=>'Aspergillus_fumigatus',
	'aspergillus_fumigatus_var_rp_2014'=>'Aspergillus_fumigatus_var_rp_2014',
	'aspergillus_fumigatus_z5'=>'Aspergillus_fumigatus_z5',
	'aspergillus_fumigatusa1163'=>'Aspergillus_fumigatusa1163',
	'aspergillus_glaucus_cbs_516_65'=>'Aspergillus_glaucus_cbs_516_65',
	'aspergillus_lentulus'=>'Aspergillus_lentulus',
	'aspergillus_luchuensis'=>'Aspergillus_luchuensis',
	'aspergillus_luchuensis_cbs_106_47'=>'Aspergillus_luchuensis_cbs_106_47',
	'aspergillus_nidulans'=>'Aspergillus_nidulans',
	'aspergillus_nidulans_fgsc_a4'=>'Aspergillus_nidulans_fgsc_a4',
	'aspergillus_niger'=>'Aspergillus_niger',
	'aspergillus_niger_atcc_1015'=>'Aspergillus_niger_atcc_1015',
	'aspergillus_niger_gca_001515345'=>'Aspergillus_niger_gca_001515345',
	'aspergillus_nomius_nrrl_13137'=>'Aspergillus_nomius_nrrl_13137',
	'aspergillus_ochraceoroseus'=>'Aspergillus_ochraceoroseus',
	'aspergillus_oryzae'=>'Aspergillus_oryzae',
	'aspergillus_oryzae_100_8'=>'Aspergillus_oryzae_100_8',
	'aspergillus_oryzae_3_042'=>'Aspergillus_oryzae_3_042',
	'aspergillus_oryzae_gca_002007945'=>'Aspergillus_oryzae_gca_002007945',
	'aspergillus_parasiticus_su_1'=>'Aspergillus_parasiticus_su_1',
	'aspergillus_rambellii'=>'Aspergillus_rambellii',
	'aspergillus_ruber_cbs_135680'=>'Aspergillus_ruber_cbs_135680',
	'aspergillus_sydowii_cbs_593_65'=>'Aspergillus_sydowii_cbs_593_65',
	'aspergillus_terreus'=>'Aspergillus_terreus',
	'aspergillus_tubingensis_cbs_134_48'=>'Aspergillus_tubingensis_cbs_134_48',
	'aspergillus_udagawae'=>'Aspergillus_udagawae',
	'aspergillus_ustus'=>'Aspergillus_ustus',
	'aspergillus_versicolor_cbs_583_65'=>'Aspergillus_versicolor_cbs_583_65',
	'aspergillus_wentii_dto_134e9'=>'Aspergillus_wentii_dto_134e9',
	'astyanax_mexicanus'=>'Cave_fish',
	'atta_cephalotes'=>'Atta_cephalotes',
	'aureobasidium_melanogenum_cbs_110374'=>'Aureobasidium_melanogenum_cbs_110374',
	'aureobasidium_namibiae_cbs_147_97'=>'Aureobasidium_namibiae_cbs_147_97',
	'aureobasidium_pullulans'=>'Aureobasidium_pullulans',
	'aureobasidium_pullulans_exf_150'=>'Aureobasidium_pullulans_exf_150',
	'aureobasidium_subglaciale_exf_2481'=>'Aureobasidium_subglaciale_exf_2481',
	'babesia_bovis'=>'Babesia_bovis',
	'babesia_microti_strain_ri'=>'Babesia_microti_strain_ri',
	'babjeviella_inositovora_nrrl_y_12698'=>'Babjeviella_inositovora_nrrl_y_12698',
	'batrachochytrium_dendrobatidis_jam81'=>'Batrachochytrium_dendrobatidis_jam81',
	'batrachochytrium_dendrobatidis_jel423'=>'Batrachochytrium_dendrobatidis_jel423',
	'batrachochytrium_salamandrivorans'=>'Batrachochytrium_salamandrivorans',
	'baudoinia_panamericana_uamh_10762'=>'Baudoinia_panamericana_uamh_10762',
	'beauveria_bassiana'=>'Beauveria_bassiana',
	'beauveria_bassiana_arsef_2860'=>'Beauveria_bassiana_arsef_2860',
	'beauveria_bassiana_d1_5'=>'Beauveria_bassiana_d1_5',
	'belgica_antarctica'=>'Belgica_antarctica',
	'beta_vulgaris'=>'Beta_vulgaris',
	'bigelowiella_natans'=>'Bigelowiella_natans',
	'bigelowiella_natans_gca_000002455'=>'Bigelowiella_natans_gca_000002455',
	'bipolaris_maydis_atcc_48331'=>'Bipolaris_maydis_atcc_48331',
	'bipolaris_maydis_c5'=>'Bipolaris_maydis_c5',
	'bipolaris_oryzae_atcc_44560'=>'Bipolaris_oryzae_atcc_44560',
	'bipolaris_sorokiniana_nd90pr'=>'Bipolaris_sorokiniana_nd90pr',
	'bipolaris_victoriae_fi3'=>'Bipolaris_victoriae_fi3',
	'bipolaris_zeicola_26_r_13'=>'Bipolaris_zeicola_26_r_13',
	'blastomyces_dermatitidis_atcc_18188'=>'Blastomyces_dermatitidis_atcc_18188',
	'blastomyces_dermatitidis_atcc_26199'=>'Blastomyces_dermatitidis_atcc_26199',
	'blastomyces_dermatitidis_er_3'=>'Blastomyces_dermatitidis_er_3',
	'blastomyces_gilchristii_slh14081'=>'Blastomyces_gilchristii_slh14081',
	'blastomyces_percursus'=>'Blastomyces_percursus',
	'blumeria_graminis'=>'Blumeria_graminis',
	'blumeria_graminis_f_sp_tritici_96224'=>'Blumeria_graminis_f_sp_tritici_96224',
	'bodo_saltans'=>'Bodo_saltans',
	'bombus_impatiens'=>'Bombus_impatiens',
	'bombyx_mori'=>'Bombyx_mori',
	'bos_taurus'=>'Cow',
	'botryobasidium_botryosum_fd_172_ss1'=>'Botryobasidium_botryosum_fd_172_ss1',
	'botrytis_cinerea'=>'Botrytis_cinerea',
	'botrytis_cinerea_bcdw1'=>'Botrytis_cinerea_bcdw1',
	'botrytis_cinerea_t4'=>'Botrytis_cinerea_t4',
	'brachypodium_distachyon'=>'Brachypodium_distachyon',
	'brassica_napus'=>'Brassica_napus',
	'brassica_oleracea'=>'Brassica_oleracea',
	'brassica_rapa'=>'Brassica_rapa',
	'brettanomyces_bruxellensis_awri1499'=>'Brettanomyces_bruxellensis_awri1499',
	'brugia_malayi'=>'Brugia_malayi',
	'byssochlamys_spectabilis_no_5'=>'Byssochlamys_spectabilis_no_5',
	'caenorhabditis_brenneri'=>'Caenorhabditis_brenneri',
	'caenorhabditis_briggsae'=>'Caenorhabditis_briggsae',
	'caenorhabditis_elegans'=>'Caenorhabditis_elegans',
	'caenorhabditis_japonica'=>'Caenorhabditis_japonica',
	'caenorhabditis_remanei'=>'Caenorhabditis_remanei',
	'callithrix_jacchus'=>'Marmoset',
	'calocera_cornea_hhb12733'=>'Calocera_cornea_hhb12733',
	'calocera_viscosa_tufc12733'=>'Calocera_viscosa_tufc12733',
	'candida_albicans_12c'=>'Candida_albicans_12c',
	'candida_albicans_19f'=>'Candida_albicans_19f',
	'candida_albicans_ca6'=>'Candida_albicans_ca6',
	'candida_albicans_gc75'=>'Candida_albicans_gc75',
	'candida_albicans_l26'=>'Candida_albicans_l26',
	'candida_albicans_p34048'=>'Candida_albicans_p34048',
	'candida_albicans_p37005'=>'Candida_albicans_p37005',
	'candida_albicans_p37037'=>'Candida_albicans_p37037',
	'candida_albicans_p37039'=>'Candida_albicans_p37039',
	'candida_albicans_p57055'=>'Candida_albicans_p57055',
	'candida_albicans_p57072'=>'Candida_albicans_p57072',
	'candida_albicans_p60002'=>'Candida_albicans_p60002',
	'candida_albicans_p75010'=>'Candida_albicans_p75010',
	'candida_albicans_p75016'=>'Candida_albicans_p75016',
	'candida_albicans_p75063'=>'Candida_albicans_p75063',
	'candida_albicans_p76055'=>'Candida_albicans_p76055',
	'candida_albicans_p76067'=>'Candida_albicans_p76067',
	'candida_albicans_p78042'=>'Candida_albicans_p78042',
	'candida_albicans_p78048'=>'Candida_albicans_p78048',
	'candida_albicans_p87'=>'Candida_albicans_p87',
	'candida_albicans_p94015'=>'Candida_albicans_p94015',
	'candida_albicans_sc5314'=>'Candida_albicans_sc5314',
	'candida_albicans_sc5314_gca_000182965'=>'Candida_albicans_sc5314_gca_000182965',
	'candida_albicans_sc5314_gca_000784655'=>'Candida_albicans_sc5314_gca_000784655',
	'candida_albicans_wo_1'=>'Candida_albicans_wo_1',
	'candida_arabinofermentans_nrrl_yb_2248'=>'Candida_arabinofermentans_nrrl_yb_2248',
	'candida_dubliniensis_cd36'=>'Candida_dubliniensis_cd36',
	'candida_maltosa_xu316'=>'Candida_maltosa_xu316',
	'candida_orthopsilosis_co_90_125'=>'Candida_orthopsilosis_co_90_125',
	'candida_parapsilosis_cdc317'=>'Candida_parapsilosis_cdc317',
	'candida_tanzawaensis_nrrl_y_17324'=>'Candida_tanzawaensis_nrrl_y_17324',
	'candida_tropicalis_mya_3404'=>'Candida_tropicalis_mya_3404',
	'canis_familiaris'=>'Dog',
	'capitella_teleta'=>'Capitella_teleta',
	'capronia_coronata_cbs_617_96'=>'Capronia_coronata_cbs_617_96',
	'capronia_epimyces_cbs_606_96'=>'Capronia_epimyces_cbs_606_96',
	'capsaspora_owczarzaki_atcc_30864'=>'Capsaspora_owczarzaki_atcc_30864',
	'carlito_syrichta'=>'Tarsier',
	'cavia_aperea'=>'Brazilian_guinea_pig',
	'cavia_porcellus'=>'Guinea_Pig',
	'ceraceosorus_bombacis'=>'Ceraceosorus_bombacis',
	'ceratocystis_platani'=>'Ceratocystis_platani',
	'chaetomium_globosum_cbs_148_51'=>'Chaetomium_globosum_cbs_148_51',
	'chaetomium_thermophilum_var_thermophilum_dsm_1495'=>'Chaetomium_thermophilum_var_thermophilum_dsm_1495',
	'chinchilla_lanigera'=>'Long-tailed_chinchilla',
	'chlamydomonas_reinhardtii'=>'Chlamydomonas_reinhardtii',
	'chlorocebus_sabaeus'=>'Vervet-AGM',
	'choloepus_hoffmanni'=>'Sloth',
	'chondrus_crispus'=>'Chondrus_crispus',
	'chroomonas_mesostigmatica_ccmp1168'=>'Chroomonas_mesostigmatica_ccmp1168',
	'ciona_intestinalis'=>'C.intestinalis',
	'ciona_savignyi'=>'C.savignyi',
	'cladophialophora_bantiana_cbs_173_52'=>'Cladophialophora_bantiana_cbs_173_52',
	'cladophialophora_carrionii'=>'Cladophialophora_carrionii',
	'cladophialophora_carrionii_cbs_160_54'=>'Cladophialophora_carrionii_cbs_160_54',
	'cladophialophora_immunda'=>'Cladophialophora_immunda',
	'cladophialophora_psammophila_cbs_110553'=>'Cladophialophora_psammophila_cbs_110553',
	'cladophialophora_yegresii_cbs_114405'=>'Cladophialophora_yegresii_cbs_114405',
	'claviceps_purpurea_20_1'=>'Claviceps_purpurea_20_1',
	'clavispora_lusitaniae_atcc_42720'=>'Clavispora_lusitaniae_atcc_42720',
	'coccidioides_immitis_h538_4'=>'Coccidioides_immitis_h538_4',
	'coccidioides_immitis_rmscc_2394'=>'Coccidioides_immitis_rmscc_2394',
	'coccidioides_immitis_rmscc_3703'=>'Coccidioides_immitis_rmscc_3703',
	'coccidioides_immitis_rs'=>'Coccidioides_immitis_rs',
	'coccidioides_posadasii_c735_delta_sowgp'=>'Coccidioides_posadasii_c735_delta_sowgp',
	'coccidioides_posadasii_rmscc_3488'=>'Coccidioides_posadasii_rmscc_3488',
	'coccidioides_posadasii_str_silveira'=>'Coccidioides_posadasii_str_silveira',
	'colletotrichum_chlorophyti'=>'Colletotrichum_chlorophyti',
	'colletotrichum_fioriniae_pj7'=>'Colletotrichum_fioriniae_pj7',
	'colletotrichum_gloeosporioides'=>'Colletotrichum_gloeosporioides',
	'colletotrichum_gloeosporioides_cg_14'=>'Colletotrichum_gloeosporioides_cg_14',
	'colletotrichum_graminicola'=>'Colletotrichum_graminicola',
	'colletotrichum_higginsianum'=>'Colletotrichum_higginsianum',
	'colletotrichum_higginsianum_imi_349063'=>'Colletotrichum_higginsianum_imi_349063',
	'colletotrichum_incanum'=>'Colletotrichum_incanum',
	'colletotrichum_incanum_gca_001855235'=>'Colletotrichum_incanum_gca_001855235',
	'colletotrichum_nymphaeae_sa_01'=>'Colletotrichum_nymphaeae_sa_01',
	'colletotrichum_orbiculare'=>'Colletotrichum_orbiculare',
	'colletotrichum_orchidophilum'=>'Colletotrichum_orchidophilum',
	'colletotrichum_salicis'=>'Colletotrichum_salicis',
	'colletotrichum_simmondsii'=>'Colletotrichum_simmondsii',
	'colletotrichum_sublineola'=>'Colletotrichum_sublineola',
	'colletotrichum_tofieldiae'=>'Colletotrichum_tofieldiae',
	'conidiobolus_coronatus_nrrl_28638'=>'Conidiobolus_coronatus_nrrl_28638',
	'coniochaeta_ligniaria_nrrl_30616'=>'Coniochaeta_ligniaria_nrrl_30616',
	'coniophora_puteana_rwd_64_598_ss2'=>'Coniophora_puteana_rwd_64_598_ss2',
	'coniosporium_apollinis_cbs_100218'=>'Coniosporium_apollinis_cbs_100218',
	'coprinopsis_cinerea_okayama7_130'=>'Coprinopsis_cinerea_okayama7_130',
	'corchorus_capsularis'=>'Corchorus_capsularis',
	'cordyceps_brongniartii_rcef_3172'=>'Cordyceps_brongniartii_rcef_3172',
	'cordyceps_confragosa'=>'Cordyceps_confragosa',
	'cordyceps_confragosa_rcef_1005'=>'Cordyceps_confragosa_rcef_1005',
	'cordyceps_militaris_cm01'=>'Cordyceps_militaris_cm01',
	'crassostrea_gigas'=>'Crassostrea_gigas',
	'cricetulus_griseus_chok1gshd'=>'Chinese_hamster_CHOK1GS',
	'cricetulus_griseus_crigri'=>'Chinese_hamster_CriGri',
	'cryptococcus_amylolentus_cbs_6039'=>'Cryptococcus_amylolentus_cbs_6039',
	'cryptococcus_amylolentus_cbs_6273'=>'Cryptococcus_amylolentus_cbs_6273',
	'cryptococcus_depauperatus_cbs_7841'=>'Cryptococcus_depauperatus_cbs_7841',
	'cryptococcus_depauperatus_cbs_7855'=>'Cryptococcus_depauperatus_cbs_7855',
	'cryptococcus_gattii_ca1280'=>'Cryptococcus_gattii_ca1280',
	'cryptococcus_gattii_ca1873'=>'Cryptococcus_gattii_ca1873',
	'cryptococcus_gattii_e566'=>'Cryptococcus_gattii_e566',
	'cryptococcus_gattii_ejb2'=>'Cryptococcus_gattii_ejb2',
	'cryptococcus_gattii_nt_10'=>'Cryptococcus_gattii_nt_10',
	'cryptococcus_gattii_ru294'=>'Cryptococcus_gattii_ru294',
	'cryptococcus_gattii_vgii_2001_935_1'=>'Cryptococcus_gattii_vgii_2001_935_1',
	'cryptococcus_gattii_vgii_99_473'=>'Cryptococcus_gattii_vgii_99_473',
	'cryptococcus_gattii_vgii_ca1014'=>'Cryptococcus_gattii_vgii_ca1014',
	'cryptococcus_gattii_vgii_cbs_10090'=>'Cryptococcus_gattii_vgii_cbs_10090',
	'cryptococcus_gattii_vgii_la55'=>'Cryptococcus_gattii_vgii_la55',
	'cryptococcus_gattii_vgii_mmrl2647'=>'Cryptococcus_gattii_vgii_mmrl2647',
	'cryptococcus_gattii_vgii_r265'=>'Cryptococcus_gattii_vgii_r265',
	'cryptococcus_gattii_vgii_ram5'=>'Cryptococcus_gattii_vgii_ram5',
	'cryptococcus_gattii_vgiv_ind107'=>'Cryptococcus_gattii_vgiv_ind107',
	'cryptococcus_gattii_wm276'=>'Cryptococcus_gattii_wm276',
	'cryptococcus_neoformans'=>'Cryptococcus_neoformans',
	'cryptococcus_neoformans_var_grubii_h99'=>'Cryptococcus_neoformans_var_grubii_h99',
	'cryptococcus_neoformans_var_neoformans_b_3501a'=>'Cryptococcus_neoformans_var_neoformans_b_3501a',
	'cryptomonas_paramecium'=>'Cryptomonas_paramecium',
	'cryptosporidium_muris_rn66'=>'Cryptosporidium_muris_rn66',
	'cryptosporidium_parvum'=>'Cryptosporidium_parvum',
	'cryptosporidium_parvum_iowa_ii'=>'Cryptosporidium_parvum_iowa_ii',
	'culex_quinquefasciatus'=>'Culex_quinquefasciatus',
	'cutaneotrichosporon_oleaginosus'=>'Cutaneotrichosporon_oleaginosus',
	'cyberlindnera_fabianii'=>'Cyberlindnera_fabianii',
	'cyberlindnera_jadinii'=>'Cyberlindnera_jadinii',
	'cyberlindnera_jadinii_nrrl_y_1542'=>'Cyberlindnera_jadinii_nrrl_y_1542',
	'cyclospora_cayetanensis'=>'Cyclospora_cayetanensis',
	'cylindrobasidium_torrendii_fp15055_ss_10'=>'Cylindrobasidium_torrendii_fp15055_ss_10',
	'cyphellophora_europaea_cbs_101466'=>'Cyphellophora_europaea_cbs_101466',
	'dacryopinax_primogenitus'=>'Dacryopinax_primogenitus',
	'dactylellina_haptotyla_cbs_200_50'=>'Dactylellina_haptotyla_cbs_200_50',
	'daedalea_quercina_l_15889'=>'Daedalea_quercina_l_15889',
	'danaus_plexippus'=>'Danaus_plexippus',
	'danio_rerio'=>'Zebrafish',
	'daphnia_pulex'=>'Daphnia_pulex',
	'dasypus_novemcinctus'=>'Armadillo',
	'debaryomyces_fabryi'=>'Debaryomyces_fabryi',
	'debaryomyces_hansenii_cbs767'=>'Debaryomyces_hansenii_cbs767',
	'dendroctonus_ponderosae'=>'Dendroctonus_ponderosae',
	'diaporthe_ampelina'=>'Diaporthe_ampelina',
	'diaporthe_helianthi'=>'Diaporthe_helianthi',
	'dichomitus_squalens_lyad_421_ss1'=>'Dichomitus_squalens_lyad_421_ss1',
	'dictyostelium_discoideum'=>'Dictyostelium_discoideum',
	'dictyostelium_fasciculatum'=>'Dictyostelium_fasciculatum',
	'dictyostelium_lacteum'=>'Dictyostelium_lacteum',
	'diplodia_corticola'=>'Diplodia_corticola',
	'diplodia_seriata'=>'Diplodia_seriata',
	'diplodia_seriata_gca_001975905'=>'Diplodia_seriata_gca_001975905',
	'dipodomys_ordii'=>'Kangaroo_rat',
	'dothistroma_septosporum'=>'Dothistroma_septosporum',
	'drechmeria_coniospora'=>'Drechmeria_coniospora',
	'drechslerella_stenobrocha_248'=>'Drechslerella_stenobrocha_248',
	'drosophila_ananassae'=>'Drosophila_ananassae',
	'drosophila_erecta'=>'Drosophila_erecta',
	'drosophila_grimshawi'=>'Drosophila_grimshawi',
	'drosophila_melanogaster'=>'Drosophila_melanogaster',
	'drosophila_mojavensis'=>'Drosophila_mojavensis',
	'drosophila_persimilis'=>'Drosophila_persimilis',
	'drosophila_pseudoobscura'=>'Drosophila_pseudoobscura',
	'drosophila_sechellia'=>'Drosophila_sechellia',
	'drosophila_simulans'=>'Drosophila_simulans',
	'drosophila_virilis'=>'Drosophila_virilis',
	'drosophila_willistoni'=>'Drosophila_willistoni',
	'drosophila_yakuba'=>'Drosophila_yakuba',
	'echinops_telfairi'=>'Lesser_hedgehog_tenrec',
	'edhazardia_aedis_usnm_41457'=>'Edhazardia_aedis_usnm_41457',
	'eimeria_brunetti'=>'Eimeria_brunetti',
	'eimeria_maxima'=>'Eimeria_maxima',
	'eimeria_mitis'=>'Eimeria_mitis',
	'eimeria_praecox'=>'Eimeria_praecox',
	'eimeria_tenella'=>'Eimeria_tenella',
	'eimeria_tenella_gca_000499545'=>'Eimeria_tenella_gca_000499545',
	'emergomyces_pasteuriana_ep9510'=>'Emergomyces_pasteuriana_ep9510',
	'emiliania_huxleyi'=>'Emiliania_huxleyi',
	'emmonsia_crescens_uamh_3008'=>'Emmonsia_crescens_uamh_3008',
	'emmonsia_parva_uamh_139'=>'Emmonsia_parva_uamh_139',
	'emmonsia_sp_cac_2015a'=>'Emmonsia_sp_cac_2015a',
	'encephalitozoon_cuniculi_ecuniii_l'=>'Encephalitozoon_cuniculi_ecuniii_l',
	'encephalitozoon_cuniculi_gb_m1'=>'Encephalitozoon_cuniculi_gb_m1',
	'encephalitozoon_hellem_atcc_50504'=>'Encephalitozoon_hellem_atcc_50504',
	'encephalitozoon_intestinalis_atcc_50506'=>'Encephalitozoon_intestinalis_atcc_50506',
	'encephalitozoon_romaleae_sj_2008'=>'Encephalitozoon_romaleae_sj_2008',
	'endocarpon_pusillum_z07020'=>'Endocarpon_pusillum_z07020',
	'entamoeba_histolytica'=>'Entamoeba_histolytica',
	'entamoeba_histolytica_gca_001662325'=>'Entamoeba_histolytica_gca_001662325',
	'entamoeba_histolytica_hm_3_imss'=>'Entamoeba_histolytica_hm_3_imss',
	'entamoeba_histolytica_ku27'=>'Entamoeba_histolytica_ku27',
	'entamoeba_nuttalli_p19'=>'Entamoeba_nuttalli_p19',
	'enterocytozoon_bieneusi_h348'=>'Enterocytozoon_bieneusi_h348',
	'enterocytozoon_hepatopenaei'=>'Enterocytozoon_hepatopenaei',
	'enterospora_canceri'=>'Enterospora_canceri',
	'equus_caballus'=>'Horse',
	'eremothecium_cymbalariae_dbvpg_7215'=>'Eremothecium_cymbalariae_dbvpg_7215',
	'eremothecium_gossypii_fdag1'=>'Eremothecium_gossypii_fdag1',
	'eremothecium_sinecaudum'=>'Eremothecium_sinecaudum',
	'erinaceus_europaeus'=>'Hedgehog',
	'erysiphe_necator'=>'Erysiphe_necator',
	'escovopsis_weberi'=>'Escovopsis_weberi',
	'eutypa_lata_ucrel1'=>'Eutypa_lata_ucrel1',
	'exidia_glandulosa_hhb12029'=>'Exidia_glandulosa_hhb12029',
	'exophiala_aquamarina_cbs_119918'=>'Exophiala_aquamarina_cbs_119918',
	'exophiala_dermatitidis_nih_ut8656'=>'Exophiala_dermatitidis_nih_ut8656',
	'exophiala_mesophila'=>'Exophiala_mesophila',
	'exophiala_oligosperma'=>'Exophiala_oligosperma',
	'exophiala_sideris'=>'Exophiala_sideris',
	'exophiala_spinifera'=>'Exophiala_spinifera',
	'exophiala_xenobiotica'=>'Exophiala_xenobiotica',
	'felis_catus'=>'Cat',
	'fibroporia_radiculosa'=>'Fibroporia_radiculosa',
	'fibulorhizoctonia_sp_cbs_109695'=>'Fibulorhizoctonia_sp_cbs_109695',
	'ficedula_albicollis'=>'Flycatcher',
	'fistulina_hepatica_atcc_64428'=>'Fistulina_hepatica_atcc_64428',
	'fomitiporia_mediterranea_mf3_22'=>'Fomitiporia_mediterranea_mf3_22',
	'fomitopsis_pinicola_fp_58527_ss1'=>'Fomitopsis_pinicola_fp_58527_ss1',
	'fonsecaea_erecta'=>'Fonsecaea_erecta',
	'fonsecaea_monophora'=>'Fonsecaea_monophora',
	'fonsecaea_multimorphosa'=>'Fonsecaea_multimorphosa',
	'fonsecaea_multimorphosa_cbs_102226'=>'Fonsecaea_multimorphosa_cbs_102226',
	'fonsecaea_nubica'=>'Fonsecaea_nubica',
	'fonsecaea_pedrosoi_cbs_271_37'=>'Fonsecaea_pedrosoi_cbs_271_37',
	'fonticula_alba_gca_000388065'=>'Fonticula_alba_gca_000388065',
	'fukomys_damarensis'=>'Damara_mole_rat',
	'fusarium_culmorum'=>'Fusarium_culmorum',
	'fusarium_fujikuroi'=>'Fusarium_fujikuroi',
	'fusarium_fujikuroi_gca_001023035'=>'Fusarium_fujikuroi_gca_001023035',
	'fusarium_fujikuroi_gca_001023045'=>'Fusarium_fujikuroi_gca_001023045',
	'fusarium_fujikuroi_gca_001023065'=>'Fusarium_fujikuroi_gca_001023065',
	'fusarium_graminearum'=>'Fusarium_graminearum',
	'fusarium_graminearum_gca_000599445'=>'Fusarium_graminearum_gca_000599445',
	'fusarium_langsethiae'=>'Fusarium_langsethiae',
	'fusarium_mangiferae'=>'Fusarium_mangiferae',
	'fusarium_oxysporum'=>'Fusarium_oxysporum',
	'fusarium_oxysporum_f_sp_conglutinans_race_2_54008'=>'Fusarium_oxysporum_f_sp_conglutinans_race_2_54008',
	'fusarium_oxysporum_f_sp_cubense_race_1'=>'Fusarium_oxysporum_f_sp_cubense_race_1',
	'fusarium_oxysporum_f_sp_cubense_race_4'=>'Fusarium_oxysporum_f_sp_cubense_race_4',
	'fusarium_oxysporum_f_sp_cubense_tropical_race_4_54006'=>'Fusarium_oxysporum_f_sp_cubense_tropical_race_4_54006',
	'fusarium_oxysporum_f_sp_lycopersici_mn25'=>'Fusarium_oxysporum_f_sp_lycopersici_mn25',
	'fusarium_oxysporum_f_sp_melonis_26406'=>'Fusarium_oxysporum_f_sp_melonis_26406',
	'fusarium_oxysporum_f_sp_pisi_hdv247'=>'Fusarium_oxysporum_f_sp_pisi_hdv247',
	'fusarium_oxysporum_f_sp_radicis_lycopersici_26381'=>'Fusarium_oxysporum_f_sp_radicis_lycopersici_26381',
	'fusarium_oxysporum_f_sp_raphani_54005'=>'Fusarium_oxysporum_f_sp_raphani_54005',
	'fusarium_oxysporum_f_sp_vasinfectum_25433'=>'Fusarium_oxysporum_f_sp_vasinfectum_25433',
	'fusarium_oxysporum_fo47'=>'Fusarium_oxysporum_fo47',
	'fusarium_oxysporum_fosc_3_a'=>'Fusarium_oxysporum_fosc_3_a',
	'fusarium_poae'=>'Fusarium_poae',
	'fusarium_proliferatum'=>'Fusarium_proliferatum',
	'fusarium_proliferatum_et1'=>'Fusarium_proliferatum_et1',
	'fusarium_pseudograminearum'=>'Fusarium_pseudograminearum',
	'fusarium_solani'=>'Fusarium_solani',
	'fusarium_verticillioides'=>'Fusarium_verticillioides',
	'gadus_morhua'=>'Cod',
	'gaeumannomyces_graminis'=>'Gaeumannomyces_graminis',
	'galdieria_sulphuraria'=>'Galdieria_sulphuraria',
	'galerina_marginata_cbs_339_88'=>'Galerina_marginata_cbs_339_88',
	'gallus_gallus'=>'Chicken',
	'gasterosteus_aculeatus'=>'Stickleback',
	'gelatoporia_subvermispora_b'=>'Gelatoporia_subvermispora_b',
	'geotrichum_candidum'=>'Geotrichum_candidum',
	'giardia_intestinalis'=>'Giardia_intestinalis',
	'giardia_intestinalis_assemblage_b'=>'Giardia_intestinalis_assemblage_b',
	'giardia_intestinalis_atcc_50581'=>'Giardia_intestinalis_atcc_50581',
	'giardia_intestinalis_gca_000498715'=>'Giardia_intestinalis_gca_000498715',
	'giardia_lamblia'=>'Giardia_lamblia',
	'giardia_lamblia_p15'=>'Giardia_lamblia_p15',
	'glarea_lozoyensis_74030'=>'Glarea_lozoyensis_74030',
	'glarea_lozoyensis_atcc_20868'=>'Glarea_lozoyensis_atcc_20868',
	'gloeophyllum_trabeum_atcc_11539'=>'Gloeophyllum_trabeum_atcc_11539',
	'glycine_max'=>'Glycine_max',
	'gonapodya_prolifera_jel478'=>'Gonapodya_prolifera_jel478',
	'gorilla_gorilla'=>'Gorilla',
	'gregarina_niphandrodes'=>'Gregarina_niphandrodes',
	'grifola_frondosa'=>'Grifola_frondosa',
	'grosmannia_clavigera_kw1407'=>'Grosmannia_clavigera_kw1407',
	'guillardia_theta'=>'Guillardia_theta',
	'guillardia_theta_gca_000002975'=>'Guillardia_theta_gca_000002975',
	'gymnopus_luxurians_fd_317_m1'=>'Gymnopus_luxurians_fd_317_m1',
	'hammondia_hammondi'=>'Hammondia_hammondi',
	'hanseniaspora_guilliermondii'=>'Hanseniaspora_guilliermondii',
	'hanseniaspora_opuntiae'=>'Hanseniaspora_opuntiae',
	'hanseniaspora_osmophila'=>'Hanseniaspora_osmophila',
	'hanseniaspora_uvarum'=>'Hanseniaspora_uvarum',
	'hanseniaspora_uvarum_dsm_2768'=>'Hanseniaspora_uvarum_dsm_2768',
	'hanseniaspora_valbyensis_nrrl_y_1626'=>'Hanseniaspora_valbyensis_nrrl_y_1626',
	'hebeloma_cylindrosporum_h7'=>'Hebeloma_cylindrosporum_h7',
	'heliconius_melpomene'=>'Heliconius_melpomene',
	'helobdella_robusta'=>'Helobdella_robusta',
	'hepatospora_eriocheir'=>'Hepatospora_eriocheir',
	'hepatospora_eriocheir_gca_002087885'=>'Hepatospora_eriocheir_gca_002087885',
	'heterobasidion_irregulare_tc_32_1'=>'Heterobasidion_irregulare_tc_32_1',
	'heterocephalus_glaber_female'=>'Naked_mole-rat_female',
	'heterocephalus_glaber_male'=>'Naked_mole-rat_male',
	'hirsutella_minnesotensis_3608'=>'Hirsutella_minnesotensis_3608',
	'histoplasma_capsulatum_g186ar'=>'Histoplasma_capsulatum_g186ar',
	'histoplasma_capsulatum_h143'=>'Histoplasma_capsulatum_h143',
	'histoplasma_capsulatum_h88'=>'Histoplasma_capsulatum_h88',
	'histoplasma_capsulatum_nam1'=>'Histoplasma_capsulatum_nam1',
	'homo_sapiens'=>'Human',
	'hordeum_vulgare'=>'Hordeum_vulgare',
	'hyaloperonospora_arabidopsidis'=>'Hyaloperonospora_arabidopsidis',
	'hydnomerulius_pinastri_md_312'=>'Hydnomerulius_pinastri_md_312',
	'hypholoma_sublateritium_fd_334_ss_4'=>'Hypholoma_sublateritium_fd_334_ss_4',
	'hyphopichia_burtonii_nrrl_y_1933'=>'Hyphopichia_burtonii_nrrl_y_1933',
	'hypsizygus_marmoreus'=>'Hypsizygus_marmoreus',
	'ichthyophthirius_multifiliis'=>'Ichthyophthirius_multifiliis',
	'ictidomys_tridecemlineatus'=>'Squirrel',
	'isaria_fumosorosea_arsef_2679'=>'Isaria_fumosorosea_arsef_2679',
	'ixodes_scapularis'=>'Ixodes_scapularis',
	'jaapia_argillacea_mucl_33604'=>'Jaapia_argillacea_mucl_33604',
	'jaculus_jaculus'=>'Lesser_Egyptian_jerboa',
	'kalmanozyma_brasiliensis_ghg001'=>'Kalmanozyma_brasiliensis_ghg001',
	'kazachstania_africana_cbs_2517'=>'Kazachstania_africana_cbs_2517',
	'kazachstania_naganishii_cbs_8797'=>'Kazachstania_naganishii_cbs_8797',
	'kluyveromyces_lactis'=>'Kluyveromyces_lactis',
	'kluyveromyces_marxianus'=>'Kluyveromyces_marxianus',
	'kluyveromyces_marxianus_dmku3_1042'=>'Kluyveromyces_marxianus_dmku3_1042',
	'komagataella_pastoris'=>'Komagataella_pastoris',
	'komagataella_pastoris_gca_001708105'=>'Komagataella_pastoris_gca_001708105',
	'komagataella_phaffii'=>'Komagataella_phaffii',
	'komagataella_phaffii_cbs_7435'=>'Komagataella_phaffii_cbs_7435',
	'komagataella_phaffii_gs115'=>'Komagataella_phaffii_gs115',
	'kuraishia_capsulata_cbs_1993'=>'Kuraishia_capsulata_cbs_1993',
	'kwoniella_bestiolae_cbs_10118'=>'Kwoniella_bestiolae_cbs_10118',
	'kwoniella_dejecticola_cbs_10117'=>'Kwoniella_dejecticola_cbs_10117',
	'kwoniella_heveanensis_bcc8398'=>'Kwoniella_heveanensis_bcc8398',
	'kwoniella_heveanensis_cbs_569'=>'Kwoniella_heveanensis_cbs_569',
	'kwoniella_mangroviensis_cbs_10435'=>'Kwoniella_mangroviensis_cbs_10435',
	'kwoniella_mangroviensis_cbs_8507'=>'Kwoniella_mangroviensis_cbs_8507',
	'kwoniella_mangroviensis_cbs_8886'=>'Kwoniella_mangroviensis_cbs_8886',
	'kwoniella_pini_cbs_10737'=>'Kwoniella_pini_cbs_10737',
	'laccaria_amethystina_laam_08_1'=>'Laccaria_amethystina_laam_08_1',
	'laccaria_bicolor_s238n_h82'=>'Laccaria_bicolor_s238n_h82',
	'lachancea_dasiensis_cbs_10888'=>'Lachancea_dasiensis_cbs_10888',
	'lachancea_fermentati'=>'Lachancea_fermentati',
	'lachancea_lanzarotensis'=>'Lachancea_lanzarotensis',
	'lachancea_meyersii_cbs_8951'=>'Lachancea_meyersii_cbs_8951',
	'lachancea_mirantina'=>'Lachancea_mirantina',
	'lachancea_nothofagi_cbs_11611'=>'Lachancea_nothofagi_cbs_11611',
	'lachancea_sp_cbs_6924'=>'Lachancea_sp_cbs_6924',
	'lachancea_thermotolerans_cbs_6340'=>'Lachancea_thermotolerans_cbs_6340',
	'laetiporus_sulphureus_93_53'=>'Laetiporus_sulphureus_93_53',
	'latimeria_chalumnae'=>'Coelacanth',
	'leersia_perrieri'=>'Leersia_perrieri',
	'leishmania_braziliensis_mhom_br_75_m2904'=>'Leishmania_braziliensis_mhom_br_75_m2904',
	'leishmania_donovani_bpk282a1'=>'Leishmania_donovani_bpk282a1',
	'leishmania_infantum_jpcm5'=>'Leishmania_infantum_jpcm5',
	'leishmania_major'=>'Leishmania_major',
	'leishmania_mexicana_mhom_gt_2001_u1103'=>'Leishmania_mexicana_mhom_gt_2001_u1103',
	'leishmania_panamensis'=>'Leishmania_panamensis',
	'lentinula_edodes'=>'Lentinula_edodes',
	'lepeophtheirus_salmonis'=>'Lepeophtheirus_salmonis',
	'lepisosteus_oculatus'=>'Spotted_gar',
	'leptomonas_pyrrhocoris'=>'Leptomonas_pyrrhocoris',
	'leptomonas_seymouri'=>'Leptomonas_seymouri',
	'leptosphaeria_maculans'=>'Leptosphaeria_maculans',
	'leucoagaricus_sp_symc_cos'=>'Leucoagaricus_sp_symc_cos',
	'lingula_anatina'=>'Lingula_anatina',
	'lipomyces_starkeyi_nrrl_y_11557'=>'Lipomyces_starkeyi_nrrl_y_11557',
	'loa_loa'=>'Loa_loa',
	'lodderomyces_elongisporus_nrrl_yb_4239'=>'Lodderomyces_elongisporus_nrrl_yb_4239',
	'lotharella_oceanica'=>'Lotharella_oceanica',
	'lottia_gigantea'=>'Lottia_gigantea',
	'loxodonta_africana'=>'Elephant',
	'lucilia_cuprina'=>'Lucilia_cuprina',
	'macaca_mulatta'=>'Macaque',
	'macrophomina_phaseolina_ms6'=>'Macrophomina_phaseolina_ms6',
	'madurella_mycetomatis'=>'Madurella_mycetomatis',
	'magnaporthe_oryzae'=>'Magnaporthe_oryzae',
	'magnaporthe_poae'=>'Magnaporthe_poae',
	'malassezia_pachydermatis'=>'Malassezia_pachydermatis',
	'malassezia_sympodialis_atcc_42132'=>'Malassezia_sympodialis_atcc_42132',
	'malassezia_sympodialis_atcc_42132_gca_900149145'=>'Malassezia_sympodialis_atcc_42132_gca_900149145',
	'marssonina_brunnea_f_sp_multigermtubi_mb_m1'=>'Marssonina_brunnea_f_sp_multigermtubi_mb_m1',
	'mayetiola_destructor'=>'Mayetiola_destructor',
	'medicago_truncatula'=>'Medicago_truncatula',
	'megaselia_scalaris'=>'Megaselia_scalaris',
	'melampsora_laricipopulina'=>'Melampsora_laricipopulina',
	'meleagris_gallopavo'=>'Turkey',
	'melitaea_cinxia'=>'Melitaea_cinxia',
	'mesocricetus_auratus'=>'Golden_Hamster',
	'metarhizium_acridum_cqma_102'=>'Metarhizium_acridum_cqma_102',
	'metarhizium_album_arsef_1941'=>'Metarhizium_album_arsef_1941',
	'metarhizium_anisopliae'=>'Metarhizium_anisopliae',
	'metarhizium_anisopliae_arsef_23'=>'Metarhizium_anisopliae_arsef_23',
	'metarhizium_anisopliae_arsef_549'=>'Metarhizium_anisopliae_arsef_549',
	'metarhizium_anisopliae_brip_53284'=>'Metarhizium_anisopliae_brip_53284',
	'metarhizium_anisopliae_brip_53293'=>'Metarhizium_anisopliae_brip_53293',
	'metarhizium_brunneum_arsef_3297'=>'Metarhizium_brunneum_arsef_3297',
	'metarhizium_guizhouense_arsef_977'=>'Metarhizium_guizhouense_arsef_977',
	'metarhizium_majus_arsef_297'=>'Metarhizium_majus_arsef_297',
	'metarhizium_rileyi_rcef_4871'=>'Metarhizium_rileyi_rcef_4871',
	'metarhizium_robertsii'=>'Metarhizium_robertsii',
	'metschnikowia_bicuspidata_var_bicuspidata_nrrl_yb_4993'=>'Metschnikowia_bicuspidata_var_bicuspidata_nrrl_yb_4993',
	'meyerozyma_guilliermondii_atcc_6260'=>'Meyerozyma_guilliermondii_atcc_6260',
	'microbotryum_violaceum'=>'Microbotryum_violaceum',
	'microcebus_murinus'=>'Mouse_Lemur',
	'microdochium_bolleyi'=>'Microdochium_bolleyi',
	'microtus_ochrogaster'=>'Prairie_vole',
	'millerozyma_farinosa_cbs_7064'=>'Millerozyma_farinosa_cbs_7064',
	'mitosporidium_daphniae'=>'Mitosporidium_daphniae',
	'mixia_osmundae_iam_14324'=>'Mixia_osmundae_iam_14324',
	'mixia_osmundae_iam_14324_gca_000708205'=>'Mixia_osmundae_iam_14324_gca_000708205',
	'mnemiopsis_leidyi'=>'Mnemiopsis_leidyi',
	'moesziomyces_antarcticus'=>'Moesziomyces_antarcticus',
	'moesziomyces_aphidis_dsm_70725'=>'Moesziomyces_aphidis_dsm_70725',
	'moniliophthora_perniciosa_fa553'=>'Moniliophthora_perniciosa_fa553',
	'moniliophthora_roreri'=>'Moniliophthora_roreri',
	'moniliophthora_roreri_mca_2997'=>'Moniliophthora_roreri_mca_2997',
	'monodelphis_domestica'=>'Opossum',
	'mortierella_elongata_ag_77'=>'Mortierella_elongata_ag_77',
	'mortierella_verticillata_nrrl_6337'=>'Mortierella_verticillata_nrrl_6337',
	'mucor_ambiguus'=>'Mucor_ambiguus',
	'mucor_circinelloides_f_circinelloides_1006phl'=>'Mucor_circinelloides_f_circinelloides_1006phl',
	'mucor_circinelloides_f_lusitanicus_cbs_277_49'=>'Mucor_circinelloides_f_lusitanicus_cbs_277_49',
	'mus_caroli'=>'Ryukyu_mouse',
	'mus_musculus'=>'Mouse',
	'mus_musculus_129s1svimj'=>'mus_musculus_129s1svimj',
	'mus_musculus_aj'=>'mus_musculus_aj',
	'mus_musculus_akrj'=>'mus_musculus_akrj',
	'mus_musculus_balbcj'=>'mus_musculus_balbcj',
	'mus_musculus_c3hhej'=>'mus_musculus_c3hhej',
	'mus_musculus_c57bl6nj'=>'mus_musculus_c57bl6nj',
	'mus_musculus_casteij'=>'mus_musculus_casteij',
	'mus_musculus_dba2j'=>'mus_musculus_dba2j',
	'mus_musculus_fvbnj'=>'mus_musculus_fvbnj',
	'mus_musculus_lpj'=>'mus_musculus_lpj',
	'mus_musculus_nodshiltj'=>'mus_musculus_nodshiltj',
	'mus_musculus_nzohlltj'=>'mus_musculus_nzohlltj',
	'mus_musculus_pwkphj'=>'mus_musculus_pwkphj',
	'mus_musculus_wsbeij'=>'mus_musculus_wsbeij',
	'mus_pahari'=>'Shrew_mouse',
	'mus_spretus_spreteij'=>'mus_spretus_spreteij',
	'musa_acuminata'=>'Musa_acuminata',
	'mustela_putorius_furo'=>'Ferret',
	'mycosphaerella_eumusae'=>'Mycosphaerella_eumusae',
	'myotis_lucifugus'=>'Microbat',
	'nadsonia_fulvescens_var_elongata_dsm_6958'=>'Nadsonia_fulvescens_var_elongata_dsm_6958',
	'naegleria_gruberi'=>'Naegleria_gruberi',
	'nannizzia_gypsea_cbs_118893'=>'Nannizzia_gypsea_cbs_118893',
	'nannochloropsis_gaditana'=>'Nannochloropsis_gaditana',
	'nannospalax_galili'=>'Upper_Galilee_mountains_blind_mole_rat',
	'nasonia_vitripennis'=>'Nasonia_vitripennis',
	'naumovozyma_castellii_cbs_4309'=>'Naumovozyma_castellii_cbs_4309',
	'naumovozyma_dairenensis_cbs_421'=>'Naumovozyma_dairenensis_cbs_421',
	'nematocida_displodere'=>'Nematocida_displodere',
	'nematocida_parisii_ertm1'=>'Nematocida_parisii_ertm1',
	'nematocida_parisii_ertm3'=>'Nematocida_parisii_ertm3',
	'nematocida_sp_1_ertm2'=>'Nematocida_sp_1_ertm2',
	'nematocida_sp_1_ertm6'=>'Nematocida_sp_1_ertm6',
	'nematocida_sp_ertm5'=>'Nematocida_sp_ertm5',
	'nematostella_vectensis'=>'Nematostella_vectensis',
	'neofusicoccum_parvum_ucrnp2'=>'Neofusicoccum_parvum_ucrnp2',
	'neolecta_irregularis_dah_3'=>'Neolecta_irregularis_dah_3',
	'neolentinus_lepideus_hhb14362_ss_1'=>'Neolentinus_lepideus_hhb14362_ss_1',
	'neonectria_ditissima'=>'Neonectria_ditissima',
	'neosartorya_fischeri'=>'Neosartorya_fischeri',
	'neurospora_crassa'=>'Neurospora_crassa',
	'neurospora_crassa_gca_000786625'=>'Neurospora_crassa_gca_000786625',
	'neurospora_tetrasperma_fgsc_2508'=>'Neurospora_tetrasperma_fgsc_2508',
	'neurospora_tetrasperma_fgsc_2509'=>'Neurospora_tetrasperma_fgsc_2509',
	'nomascus_leucogenys'=>'Gibbon',
	'nosema_apis_brl_01'=>'Nosema_apis_brl_01',
	'nosema_bombycis_cq1'=>'Nosema_bombycis_cq1',
	'nosema_ceranae'=>'Nosema_ceranae',
	'nosema_ceranae_brl01'=>'Nosema_ceranae_brl01',
	'notamacropus_eugenii'=>'Wallaby',
	'ochotona_princeps'=>'Pika',
	'octodon_degus'=>'Degu',
	'octopus_bimaculoides'=>'Octopus_bimaculoides',
	'ogataea_parapolymorpha_dl_1'=>'Ogataea_parapolymorpha_dl_1',
	'ogataea_polymorpha'=>'Ogataea_polymorpha',
	'oidiodendron_maius_zn'=>'Oidiodendron_maius_zn',
	'onchocerca_volvulus'=>'Onchocerca_volvulus',
	'ophiocordyceps_sinensis_co18'=>'Ophiocordyceps_sinensis_co18',
	'ophiocordyceps_unilateralis'=>'Ophiocordyceps_unilateralis',
	'ophiostoma_piceae_uamh_11346'=>'Ophiostoma_piceae_uamh_11346',
	'ordospora_colligata_oc4'=>'Ordospora_colligata_oc4',
	'oreochromis_niloticus'=>'Tilapia',
	'ornithorhynchus_anatinus'=>'Platypus',
	'oryctolagus_cuniculus'=>'Rabbit',
	'oryza_barthii'=>'Oryza_barthii',
	'oryza_brachyantha'=>'Oryza_brachyantha',
	'oryza_glaberrima'=>'Oryza_glaberrima',
	'oryza_glumaepatula'=>'Oryza_glumaepatula',
	'oryza_indica'=>'Oryza_indica',
	'oryza_longistaminata'=>'Oryza_longistaminata',
	'oryza_meridionalis'=>'Oryza_meridionalis',
	'oryza_nivara'=>'Oryza_nivara',
	'oryza_punctata'=>'Oryza_punctata',
	'oryza_rufipogon'=>'Oryza_rufipogon',
	'oryza_sativa'=>'Oryza_sativa',
	'oryzias_latipes'=>'Medaka',
	'ostreococcus_lucimarinus'=>'Ostreococcus_lucimarinus',
	'otolemur_garnettii'=>'Bushbaby',
	'ovis_aries'=>'Sheep',
	'pachysolen_tannophilus_nrrl_y_2460'=>'Pachysolen_tannophilus_nrrl_y_2460',
	'pan_troglodytes'=>'Chimpanzee',
	'papio_anubis'=>'Olive_baboon',
	'paracoccidioides_brasiliensis'=>'Paracoccidioides_brasiliensis',
	'paracoccidioides_brasiliensis_gca_001713695'=>'Paracoccidioides_brasiliensis_gca_001713695',
	'paracoccidioides_brasiliensis_pb03'=>'Paracoccidioides_brasiliensis_pb03',
	'paracoccidioides_brasiliensis_pb18'=>'Paracoccidioides_brasiliensis_pb18',
	'paracoccidioides_sp_lutzii_pb01'=>'Paracoccidioides_sp_lutzii_pb01',
	'paramecium_tetraurelia'=>'Paramecium_tetraurelia',
	'paraphaeosphaeria_sporulosa'=>'Paraphaeosphaeria_sporulosa',
	'parasitella_parasitica'=>'Parasitella_parasitica',
	'paulinella_chromatophora'=>'Paulinella_chromatophora',
	'paxillus_involutus_atcc_200175'=>'Paxillus_involutus_atcc_200175',
	'paxillus_rubicundulus_ve08_2h10'=>'Paxillus_rubicundulus_ve08_2h10',
	'pediculus_humanus'=>'Pediculus_humanus',
	'pelodiscus_sinensis'=>'Chinese_softshell_turtle',
	'penicilliopsis_zonata_cbs_506_65'=>'Penicilliopsis_zonata_cbs_506_65',
	'penicillium_antarcticum'=>'Penicillium_antarcticum',
	'penicillium_arizonense'=>'Penicillium_arizonense',
	'penicillium_brasilianum'=>'Penicillium_brasilianum',
	'penicillium_brasilianum_gca_002016555'=>'Penicillium_brasilianum_gca_002016555',
	'penicillium_camemberti_fm_013'=>'Penicillium_camemberti_fm_013',
	'penicillium_chrysogenum'=>'Penicillium_chrysogenum',
	'penicillium_coprophilum'=>'Penicillium_coprophilum',
	'penicillium_decumbens'=>'Penicillium_decumbens',
	'penicillium_digitatum_pd1'=>'Penicillium_digitatum_pd1',
	'penicillium_digitatum_phi26'=>'Penicillium_digitatum_phi26',
	'penicillium_expansum'=>'Penicillium_expansum',
	'penicillium_expansum_gca_000769735'=>'Penicillium_expansum_gca_000769735',
	'penicillium_expansum_gca_000769745'=>'Penicillium_expansum_gca_000769745',
	'penicillium_flavigenum'=>'Penicillium_flavigenum',
	'penicillium_freii'=>'Penicillium_freii',
	'penicillium_griseofulvum'=>'Penicillium_griseofulvum',
	'penicillium_italicum'=>'Penicillium_italicum',
	'penicillium_nalgiovense'=>'Penicillium_nalgiovense',
	'penicillium_nordicum'=>'Penicillium_nordicum',
	'penicillium_oxalicum_114_2'=>'Penicillium_oxalicum_114_2',
	'penicillium_polonicum'=>'Penicillium_polonicum',
	'penicillium_roqueforti_fm164'=>'Penicillium_roqueforti_fm164',
	'penicillium_rubens_wisconsin_54_1255'=>'Penicillium_rubens_wisconsin_54_1255',
	'penicillium_solitum'=>'Penicillium_solitum',
	'penicillium_steckii'=>'Penicillium_steckii',
	'penicillium_subrubescens'=>'Penicillium_subrubescens',
	'penicillium_vulpinum'=>'Penicillium_vulpinum',
	'peniophora_sp_cont'=>'Peniophora_sp_cont',
	'perkinsus_marinus_atcc_50983'=>'Perkinsus_marinus_atcc_50983',
	'peromyscus_maniculatus_bairdii'=>'Northern_American_deer_mouse',
	'pestalotiopsis_fici_w106_1'=>'Pestalotiopsis_fici_w106_1',
	'petromyzon_marinus'=>'Lamprey',
	'phaeoacremonium_minimum_ucrpa7'=>'Phaeoacremonium_minimum_ucrpa7',
	'phaeodactylum_tricornutum'=>'Phaeodactylum_tricornutum',
	'phaeomoniella_chlamydospora'=>'Phaeomoniella_chlamydospora',
	'phaeosphaeria_nodorum'=>'Phaeosphaeria_nodorum',
	'phanerochaete_carnosa_hhb_10118_sp'=>'Phanerochaete_carnosa_hhb_10118_sp',
	'phialocephala_scopiformis'=>'Phialocephala_scopiformis',
	'phialocephala_subalpina'=>'Phialocephala_subalpina',
	'phialophora_americana'=>'Phialophora_americana',
	'phialophora_attae'=>'Phialophora_attae',
	'phlebia_centrifuga'=>'Phlebia_centrifuga',
	'phlebiopsis_gigantea_11061_1_cr5_6'=>'Phlebiopsis_gigantea_11061_1_cr5_6',
	'phycomyces_blakesleeanus_nrrl_1555_'=>'Phycomyces_blakesleeanus_nrrl_1555_',
	'physcomitrella_patens'=>'Physcomitrella_patens',
	'phytophthora_infestans'=>'Phytophthora_infestans',
	'phytophthora_kernoviae'=>'Phytophthora_kernoviae',
	'phytophthora_lateralis'=>'Phytophthora_lateralis',
	'phytophthora_parasitica'=>'Phytophthora_parasitica',
	'phytophthora_parasitica_cj01a1'=>'Phytophthora_parasitica_cj01a1',
	'phytophthora_parasitica_gca_000509465'=>'Phytophthora_parasitica_gca_000509465',
	'phytophthora_parasitica_gca_000509485'=>'Phytophthora_parasitica_gca_000509485',
	'phytophthora_parasitica_gca_000509505'=>'Phytophthora_parasitica_gca_000509505',
	'phytophthora_parasitica_gca_000509525'=>'Phytophthora_parasitica_gca_000509525',
	'phytophthora_parasitica_inra_310'=>'Phytophthora_parasitica_inra_310',
	'phytophthora_parasitica_p10297'=>'Phytophthora_parasitica_p10297',
	'phytophthora_parasitica_p1976'=>'Phytophthora_parasitica_p1976',
	'phytophthora_ramorum'=>'Phytophthora_ramorum',
	'phytophthora_sojae'=>'Phytophthora_sojae',
	'pichia_kudriavzevii'=>'Pichia_kudriavzevii',
	'pichia_kudriavzevii_gca_001983325'=>'Pichia_kudriavzevii_gca_001983325',
	'pichia_membranifaciens'=>'Pichia_membranifaciens',
	'pichia_membranifaciens_nrrl_y_2026'=>'Pichia_membranifaciens_nrrl_y_2026',
	'piloderma_croceum_f_1598'=>'Piloderma_croceum_f_1598',
	'pisolithus_microcarpus_441'=>'Pisolithus_microcarpus_441',
	'pisolithus_tinctorius_marx_270'=>'Pisolithus_tinctorius_marx_270',
	'plasmodium_berghei'=>'Plasmodium_berghei',
	'plasmodium_berghei_gca_000005395'=>'Plasmodium_berghei_gca_000005395',
	'plasmodium_berghei_gca_900044335'=>'Plasmodium_berghei_gca_900044335',
	'plasmodium_chabaudi'=>'Plasmodium_chabaudi',
	'plasmodium_chabaudi_chabaudi_gca_000003075'=>'Plasmodium_chabaudi_chabaudi_gca_000003075',
	'plasmodium_coatneyi'=>'Plasmodium_coatneyi',
	'plasmodium_cynomolgi_strain_b'=>'Plasmodium_cynomolgi_strain_b',
	'plasmodium_falciparum'=>'Plasmodium_falciparum',
	'plasmodium_falciparum_7g8'=>'Plasmodium_falciparum_7g8',
	'plasmodium_falciparum_camp_malaysia'=>'Plasmodium_falciparum_camp_malaysia',
	'plasmodium_falciparum_dd2'=>'Plasmodium_falciparum_dd2',
	'plasmodium_falciparum_fch_4'=>'Plasmodium_falciparum_fch_4',
	'plasmodium_falciparum_hb3'=>'Plasmodium_falciparum_hb3',
	'plasmodium_falciparum_igh_cr14'=>'Plasmodium_falciparum_igh_cr14',
	'plasmodium_falciparum_malips096_e11'=>'Plasmodium_falciparum_malips096_e11',
	'plasmodium_falciparum_nf135_5_c10'=>'Plasmodium_falciparum_nf135_5_c10',
	'plasmodium_falciparum_nf54'=>'Plasmodium_falciparum_nf54',
	'plasmodium_falciparum_palo_alto_uganda'=>'Plasmodium_falciparum_palo_alto_uganda',
	'plasmodium_falciparum_raj116'=>'Plasmodium_falciparum_raj116',
	'plasmodium_falciparum_santa_lucia'=>'Plasmodium_falciparum_santa_lucia',
	'plasmodium_falciparum_tanzania_2000708_'=>'Plasmodium_falciparum_tanzania_2000708_',
	'plasmodium_falciparum_ugt5_1'=>'Plasmodium_falciparum_ugt5_1',
	'plasmodium_falciparum_vietnam_oak_knoll_fvo_'=>'Plasmodium_falciparum_vietnam_oak_knoll_fvo_',
	'plasmodium_fragile'=>'Plasmodium_fragile',
	'plasmodium_gaboni'=>'Plasmodium_gaboni',
	'plasmodium_inui_san_antonio_1'=>'Plasmodium_inui_san_antonio_1',
	'plasmodium_knowlesi'=>'Plasmodium_knowlesi',
	'plasmodium_knowlesi_strain_h_gca_900004885'=>'Plasmodium_knowlesi_strain_h_gca_900004885',
	'plasmodium_malariae'=>'Plasmodium_malariae',
	'plasmodium_ovale_curtisi'=>'Plasmodium_ovale_curtisi',
	'plasmodium_reichenowi'=>'Plasmodium_reichenowi',
	'plasmodium_reichenowi_gca_001601855'=>'Plasmodium_reichenowi_gca_001601855',
	'plasmodium_vinckei_petteri'=>'Plasmodium_vinckei_petteri',
	'plasmodium_vinckei_vinckei'=>'Plasmodium_vinckei_vinckei',
	'plasmodium_vivax'=>'Plasmodium_vivax',
	'plasmodium_vivax_brazil_i'=>'Plasmodium_vivax_brazil_i',
	'plasmodium_vivax_india_vii'=>'Plasmodium_vivax_india_vii',
	'plasmodium_vivax_mauritania_i'=>'Plasmodium_vivax_mauritania_i',
	'plasmodium_vivax_north_korean'=>'Plasmodium_vivax_north_korean',
	'plasmodium_yoelii'=>'Plasmodium_yoelii',
	'plasmodium_yoelii_17x'=>'Plasmodium_yoelii_17x',
	'plasmodium_yoelii_gca_900002395'=>'Plasmodium_yoelii_gca_900002395',
	'plasmodium_yoelii_yoelii'=>'Plasmodium_yoelii_yoelii',
	'plasmopara_halstedii'=>'Plasmopara_halstedii',
	'pleurotus_ostreatus_pc15'=>'Pleurotus_ostreatus_pc15',
	'plicaturopsis_crispa_fd_325_ss_3'=>'Plicaturopsis_crispa_fd_325_ss_3',
	'pneumocystis_carinii_b80'=>'Pneumocystis_carinii_b80',
	'pneumocystis_jirovecii_ru7'=>'Pneumocystis_jirovecii_ru7',
	'pneumocystis_murina_b123'=>'Pneumocystis_murina_b123',
	'pochonia_chlamydosporia_170'=>'Pochonia_chlamydosporia_170',
	'podospora_anserina_s_mat_'=>'Podospora_anserina_s_mat_',
	'poecilia_formosa'=>'Amazon_molly',
	'polysphondylium_pallidum_pn500'=>'Polysphondylium_pallidum_pn500',
	'pongo_abelii'=>'Orangutan',
	'populus_trichocarpa'=>'Populus_trichocarpa',
	'postia_placenta_mad_698_r'=>'Postia_placenta_mad_698_r',
	'procavia_capensis'=>'Hyrax',
	'prunus_persica'=>'Prunus_persica',
	'pseudocercospora_fijiensis_cirad86'=>'Pseudocercospora_fijiensis_cirad86',
	'pseudocercospora_musae'=>'Pseudocercospora_musae',
	'pseudogymnoascus_destructans'=>'Pseudogymnoascus_destructans',
	'pseudogymnoascus_destructans_20631_21'=>'Pseudogymnoascus_destructans_20631_21',
	'pseudogymnoascus_sp_03vt05'=>'Pseudogymnoascus_sp_03vt05',
	'pseudogymnoascus_sp_05ny08'=>'Pseudogymnoascus_sp_05ny08',
	'pseudogymnoascus_sp_23342_1_i1'=>'Pseudogymnoascus_sp_23342_1_i1',
	'pseudogymnoascus_sp_24mn13'=>'Pseudogymnoascus_sp_24mn13',
	'pseudogymnoascus_sp_vkm_f_103'=>'Pseudogymnoascus_sp_vkm_f_103',
	'pseudogymnoascus_sp_vkm_f_3557'=>'Pseudogymnoascus_sp_vkm_f_3557',
	'pseudogymnoascus_sp_vkm_f_3775'=>'Pseudogymnoascus_sp_vkm_f_3775',
	'pseudogymnoascus_sp_vkm_f_3808'=>'Pseudogymnoascus_sp_vkm_f_3808',
	'pseudogymnoascus_sp_vkm_f_4246'=>'Pseudogymnoascus_sp_vkm_f_4246',
	'pseudogymnoascus_sp_vkm_f_4281_fw_2241_'=>'Pseudogymnoascus_sp_vkm_f_4281_fw_2241_',
	'pseudogymnoascus_sp_vkm_f_4513_fw_928_'=>'Pseudogymnoascus_sp_vkm_f_4513_fw_928_',
	'pseudogymnoascus_sp_vkm_f_4514_fw_929_'=>'Pseudogymnoascus_sp_vkm_f_4514_fw_929_',
	'pseudogymnoascus_sp_vkm_f_4515_fw_2607_'=>'Pseudogymnoascus_sp_vkm_f_4515_fw_2607_',
	'pseudogymnoascus_sp_vkm_f_4516_fw_969_'=>'Pseudogymnoascus_sp_vkm_f_4516_fw_969_',
	'pseudogymnoascus_sp_vkm_f_4517_fw_2822_'=>'Pseudogymnoascus_sp_vkm_f_4517_fw_2822_',
	'pseudogymnoascus_sp_vkm_f_4518_fw_2643_'=>'Pseudogymnoascus_sp_vkm_f_4518_fw_2643_',
	'pseudogymnoascus_sp_vkm_f_4519_fw_2642_'=>'Pseudogymnoascus_sp_vkm_f_4519_fw_2642_',
	'pseudogymnoascus_sp_vkm_f_4520_fw_2644_'=>'Pseudogymnoascus_sp_vkm_f_4520_fw_2644_',
	'pseudogymnoascus_sp_wsf_3629'=>'Pseudogymnoascus_sp_wsf_3629',
	'pseudogymnoascus_verrucosus'=>'Pseudogymnoascus_verrucosus',
	'pseudoloma_neurophilia'=>'Pseudoloma_neurophilia',
	'pseudozyma_hubeiensis_sy62'=>'Pseudozyma_hubeiensis_sy62',
	'pteropus_vampyrus'=>'Megabat',
	'puccinia_graminis'=>'Puccinia_graminis',
	'puccinia_graminisug99'=>'Puccinia_graminisug99',
	'puccinia_sorghi'=>'Puccinia_sorghi',
	'puccinia_striiformis'=>'Puccinia_striiformis',
	'puccinia_striiformis_f_sp_tritici_pst_78'=>'Puccinia_striiformis_f_sp_tritici_pst_78',
	'puccinia_triticina'=>'Puccinia_triticina',
	'punctularia_strigosozonata_hhb_11173_ss5'=>'Punctularia_strigosozonata_hhb_11173_ss5',
	'purpureocillium_lilacinum'=>'Purpureocillium_lilacinum',
	'purpureocillium_lilacinum_gca_001653265'=>'Purpureocillium_lilacinum_gca_001653265',
	'pyrenochaeta_sp_ds3say3a'=>'Pyrenochaeta_sp_ds3say3a',
	'pyrenophora_teres'=>'Pyrenophora_teres',
	'pyrenophora_triticirepentis'=>'Pyrenophora_triticirepentis',
	'pyronema_omphalodes_cbs_100304'=>'Pyronema_omphalodes_cbs_100304',
	'pythium_aphanidermatum'=>'Pythium_aphanidermatum',
	'pythium_arrhenomanes'=>'Pythium_arrhenomanes',
	'pythium_irregulare'=>'Pythium_irregulare',
	'pythium_iwayamai'=>'Pythium_iwayamai',
	'pythium_ultimum'=>'Pythium_ultimum',
	'pythium_vexans'=>'Pythium_vexans',
	'rachicladosporium_antarcticum'=>'Rachicladosporium_antarcticum',
	'rasamsonia_emersonii_cbs_393_64'=>'Rasamsonia_emersonii_cbs_393_64',
	'rattus_norvegicus'=>'Rat',
	'reticulomyxa_filosa'=>'Reticulomyxa_filosa',
	'rhinocladiella_mackenziei_cbs_650_93'=>'Rhinocladiella_mackenziei_cbs_650_93',
	'rhizoctonia_solani'=>'Rhizoctonia_solani',
	'rhizoctonia_solani_123e'=>'Rhizoctonia_solani_123e',
	'rhizoctonia_solani_ag_1_ia'=>'Rhizoctonia_solani_ag_1_ia',
	'rhizoctonia_solani_ag_1_ib'=>'Rhizoctonia_solani_ag_1_ib',
	'rhizoctonia_solani_ag_3_rhs1ap'=>'Rhizoctonia_solani_ag_3_rhs1ap',
	'rhizoctonia_solani_ag_8_wac10335'=>'Rhizoctonia_solani_ag_8_wac10335',
	'rhizophagus_irregularis_daom_181602_gca_000439145'=>'Rhizophagus_irregularis_daom_181602_gca_000439145',
	'rhizopogon_vesiculosus'=>'Rhizopogon_vesiculosus',
	'rhizopogon_vinicolor_am_or11_026'=>'Rhizopogon_vinicolor_am_or11_026',
	'rhizopus_delemar_ra_99_880'=>'Rhizopus_delemar_ra_99_880',
	'rhizopus_microsporus'=>'Rhizopus_microsporus',
	'rhizopus_microsporus_var_microsporus'=>'Rhizopus_microsporus_var_microsporus',
	'rhodnius_prolixus'=>'Rhodnius_prolixus',
	'rhodotorula_graminis_wp1'=>'Rhodotorula_graminis_wp1',
	'rhodotorula_sp_jg_1b'=>'Rhodotorula_sp_jg_1b',
	'rhodotorula_toruloides'=>'Rhodotorula_toruloides',
	'rhodotorula_toruloides_atcc_204091'=>'Rhodotorula_toruloides_atcc_204091',
	'rhodotorula_toruloides_np11'=>'Rhodotorula_toruloides_np11',
	'rhynchosporium_agropyri'=>'Rhynchosporium_agropyri',
	'rhynchosporium_commune'=>'Rhynchosporium_commune',
	'rhynchosporium_secalis'=>'Rhynchosporium_secalis',
	'rozella_allomycis_csf55'=>'Rozella_allomycis_csf55',
	'saccharomyces_arboricola_h_6'=>'Saccharomyces_arboricola_h_6',
	'saccharomyces_cerevisiae'=>'Saccharomyces_cerevisiae',
	'saccharomyces_cerevisiae_awri796'=>'Saccharomyces_cerevisiae_awri796',
	'saccharomyces_cerevisiae_cen_pk113_7d'=>'Saccharomyces_cerevisiae_cen_pk113_7d',
	'saccharomyces_cerevisiae_ec1118'=>'Saccharomyces_cerevisiae_ec1118',
	'saccharomyces_cerevisiae_fostersb'=>'Saccharomyces_cerevisiae_fostersb',
	'saccharomyces_cerevisiae_fosterso'=>'Saccharomyces_cerevisiae_fosterso',
	'saccharomyces_cerevisiae_gca_000091065'=>'Saccharomyces_cerevisiae_gca_000091065',
	'saccharomyces_cerevisiae_gca_001634645'=>'Saccharomyces_cerevisiae_gca_001634645',
	'saccharomyces_cerevisiae_gca_001983315'=>'Saccharomyces_cerevisiae_gca_001983315',
	'saccharomyces_cerevisiae_kyokai_no_7'=>'Saccharomyces_cerevisiae_kyokai_no_7',
	'saccharomyces_cerevisiae_lalvin_qa23'=>'Saccharomyces_cerevisiae_lalvin_qa23',
	'saccharomyces_cerevisiae_p283'=>'Saccharomyces_cerevisiae_p283',
	'saccharomyces_cerevisiae_p301'=>'Saccharomyces_cerevisiae_p301',
	'saccharomyces_cerevisiae_r008'=>'Saccharomyces_cerevisiae_r008',
	'saccharomyces_cerevisiae_r103'=>'Saccharomyces_cerevisiae_r103',
	'saccharomyces_cerevisiae_rm11_1a'=>'Saccharomyces_cerevisiae_rm11_1a',
	'saccharomyces_cerevisiae_vin13'=>'Saccharomyces_cerevisiae_vin13',
	'saccharomyces_cerevisiae_vl3'=>'Saccharomyces_cerevisiae_vl3',
	'saccharomyces_cerevisiae_x_saccharomyces_kudriavzevii_vin7'=>'Saccharomyces_cerevisiae_x_saccharomyces_kudriavzevii_vin7',
	'saccharomyces_cerevisiae_yjm1078'=>'Saccharomyces_cerevisiae_yjm1078',
	'saccharomyces_cerevisiae_yjm1083'=>'Saccharomyces_cerevisiae_yjm1083',
	'saccharomyces_cerevisiae_yjm1129'=>'Saccharomyces_cerevisiae_yjm1129',
	'saccharomyces_cerevisiae_yjm1133'=>'Saccharomyces_cerevisiae_yjm1133',
	'saccharomyces_cerevisiae_yjm1190'=>'Saccharomyces_cerevisiae_yjm1190',
	'saccharomyces_cerevisiae_yjm1199'=>'Saccharomyces_cerevisiae_yjm1199',
	'saccharomyces_cerevisiae_yjm1202'=>'Saccharomyces_cerevisiae_yjm1202',
	'saccharomyces_cerevisiae_yjm1208'=>'Saccharomyces_cerevisiae_yjm1208',
	'saccharomyces_cerevisiae_yjm1242'=>'Saccharomyces_cerevisiae_yjm1242',
	'saccharomyces_cerevisiae_yjm1244'=>'Saccharomyces_cerevisiae_yjm1244',
	'saccharomyces_cerevisiae_yjm1248'=>'Saccharomyces_cerevisiae_yjm1248',
	'saccharomyces_cerevisiae_yjm1250'=>'Saccharomyces_cerevisiae_yjm1250',
	'saccharomyces_cerevisiae_yjm1252'=>'Saccharomyces_cerevisiae_yjm1252',
	'saccharomyces_cerevisiae_yjm1273'=>'Saccharomyces_cerevisiae_yjm1273',
	'saccharomyces_cerevisiae_yjm1304'=>'Saccharomyces_cerevisiae_yjm1304',
	'saccharomyces_cerevisiae_yjm1307'=>'Saccharomyces_cerevisiae_yjm1307',
	'saccharomyces_cerevisiae_yjm1311'=>'Saccharomyces_cerevisiae_yjm1311',
	'saccharomyces_cerevisiae_yjm1326'=>'Saccharomyces_cerevisiae_yjm1326',
	'saccharomyces_cerevisiae_yjm1332'=>'Saccharomyces_cerevisiae_yjm1332',
	'saccharomyces_cerevisiae_yjm1336'=>'Saccharomyces_cerevisiae_yjm1336',
	'saccharomyces_cerevisiae_yjm1338'=>'Saccharomyces_cerevisiae_yjm1338',
	'saccharomyces_cerevisiae_yjm1341'=>'Saccharomyces_cerevisiae_yjm1341',
	'saccharomyces_cerevisiae_yjm1342'=>'Saccharomyces_cerevisiae_yjm1342',
	'saccharomyces_cerevisiae_yjm1355'=>'Saccharomyces_cerevisiae_yjm1355',
	'saccharomyces_cerevisiae_yjm1356'=>'Saccharomyces_cerevisiae_yjm1356',
	'saccharomyces_cerevisiae_yjm1381'=>'Saccharomyces_cerevisiae_yjm1381',
	'saccharomyces_cerevisiae_yjm1383'=>'Saccharomyces_cerevisiae_yjm1383',
	'saccharomyces_cerevisiae_yjm1385'=>'Saccharomyces_cerevisiae_yjm1385',
	'saccharomyces_cerevisiae_yjm1386'=>'Saccharomyces_cerevisiae_yjm1386',
	'saccharomyces_cerevisiae_yjm1387'=>'Saccharomyces_cerevisiae_yjm1387',
	'saccharomyces_cerevisiae_yjm1388'=>'Saccharomyces_cerevisiae_yjm1388',
	'saccharomyces_cerevisiae_yjm1389'=>'Saccharomyces_cerevisiae_yjm1389',
	'saccharomyces_cerevisiae_yjm1399'=>'Saccharomyces_cerevisiae_yjm1399',
	'saccharomyces_cerevisiae_yjm1400'=>'Saccharomyces_cerevisiae_yjm1400',
	'saccharomyces_cerevisiae_yjm1401'=>'Saccharomyces_cerevisiae_yjm1401',
	'saccharomyces_cerevisiae_yjm1402'=>'Saccharomyces_cerevisiae_yjm1402',
	'saccharomyces_cerevisiae_yjm1415'=>'Saccharomyces_cerevisiae_yjm1415',
	'saccharomyces_cerevisiae_yjm1417'=>'Saccharomyces_cerevisiae_yjm1417',
	'saccharomyces_cerevisiae_yjm1418'=>'Saccharomyces_cerevisiae_yjm1418',
	'saccharomyces_cerevisiae_yjm1419'=>'Saccharomyces_cerevisiae_yjm1419',
	'saccharomyces_cerevisiae_yjm1433'=>'Saccharomyces_cerevisiae_yjm1433',
	'saccharomyces_cerevisiae_yjm1434'=>'Saccharomyces_cerevisiae_yjm1434',
	'saccharomyces_cerevisiae_yjm1439'=>'Saccharomyces_cerevisiae_yjm1439',
	'saccharomyces_cerevisiae_yjm1443'=>'Saccharomyces_cerevisiae_yjm1443',
	'saccharomyces_cerevisiae_yjm1444'=>'Saccharomyces_cerevisiae_yjm1444',
	'saccharomyces_cerevisiae_yjm1447'=>'Saccharomyces_cerevisiae_yjm1447',
	'saccharomyces_cerevisiae_yjm1450'=>'Saccharomyces_cerevisiae_yjm1450',
	'saccharomyces_cerevisiae_yjm1460'=>'Saccharomyces_cerevisiae_yjm1460',
	'saccharomyces_cerevisiae_yjm1463'=>'Saccharomyces_cerevisiae_yjm1463',
	'saccharomyces_cerevisiae_yjm1477'=>'Saccharomyces_cerevisiae_yjm1477',
	'saccharomyces_cerevisiae_yjm1478'=>'Saccharomyces_cerevisiae_yjm1478',
	'saccharomyces_cerevisiae_yjm1479'=>'Saccharomyces_cerevisiae_yjm1479',
	'saccharomyces_cerevisiae_yjm1526'=>'Saccharomyces_cerevisiae_yjm1526',
	'saccharomyces_cerevisiae_yjm1527'=>'Saccharomyces_cerevisiae_yjm1527',
	'saccharomyces_cerevisiae_yjm1549'=>'Saccharomyces_cerevisiae_yjm1549',
	'saccharomyces_cerevisiae_yjm1573'=>'Saccharomyces_cerevisiae_yjm1573',
	'saccharomyces_cerevisiae_yjm1574'=>'Saccharomyces_cerevisiae_yjm1574',
	'saccharomyces_cerevisiae_yjm1592'=>'Saccharomyces_cerevisiae_yjm1592',
	'saccharomyces_cerevisiae_yjm1615'=>'Saccharomyces_cerevisiae_yjm1615',
	'saccharomyces_cerevisiae_yjm189'=>'Saccharomyces_cerevisiae_yjm189',
	'saccharomyces_cerevisiae_yjm193'=>'Saccharomyces_cerevisiae_yjm193',
	'saccharomyces_cerevisiae_yjm195'=>'Saccharomyces_cerevisiae_yjm195',
	'saccharomyces_cerevisiae_yjm244'=>'Saccharomyces_cerevisiae_yjm244',
	'saccharomyces_cerevisiae_yjm248'=>'Saccharomyces_cerevisiae_yjm248',
	'saccharomyces_cerevisiae_yjm270'=>'Saccharomyces_cerevisiae_yjm270',
	'saccharomyces_cerevisiae_yjm271'=>'Saccharomyces_cerevisiae_yjm271',
	'saccharomyces_cerevisiae_yjm320'=>'Saccharomyces_cerevisiae_yjm320',
	'saccharomyces_cerevisiae_yjm326'=>'Saccharomyces_cerevisiae_yjm326',
	'saccharomyces_cerevisiae_yjm428'=>'Saccharomyces_cerevisiae_yjm428',
	'saccharomyces_cerevisiae_yjm450'=>'Saccharomyces_cerevisiae_yjm450',
	'saccharomyces_cerevisiae_yjm451'=>'Saccharomyces_cerevisiae_yjm451',
	'saccharomyces_cerevisiae_yjm453'=>'Saccharomyces_cerevisiae_yjm453',
	'saccharomyces_cerevisiae_yjm456'=>'Saccharomyces_cerevisiae_yjm456',
	'saccharomyces_cerevisiae_yjm470'=>'Saccharomyces_cerevisiae_yjm470',
	'saccharomyces_cerevisiae_yjm541'=>'Saccharomyces_cerevisiae_yjm541',
	'saccharomyces_cerevisiae_yjm554'=>'Saccharomyces_cerevisiae_yjm554',
	'saccharomyces_cerevisiae_yjm555'=>'Saccharomyces_cerevisiae_yjm555',
	'saccharomyces_cerevisiae_yjm627'=>'Saccharomyces_cerevisiae_yjm627',
	'saccharomyces_cerevisiae_yjm681'=>'Saccharomyces_cerevisiae_yjm681',
	'saccharomyces_cerevisiae_yjm682'=>'Saccharomyces_cerevisiae_yjm682',
	'saccharomyces_cerevisiae_yjm683'=>'Saccharomyces_cerevisiae_yjm683',
	'saccharomyces_cerevisiae_yjm689'=>'Saccharomyces_cerevisiae_yjm689',
	'saccharomyces_cerevisiae_yjm693'=>'Saccharomyces_cerevisiae_yjm693',
	'saccharomyces_cerevisiae_yjm789'=>'Saccharomyces_cerevisiae_yjm789',
	'saccharomyces_cerevisiae_yjm969'=>'Saccharomyces_cerevisiae_yjm969',
	'saccharomyces_cerevisiae_yjm972'=>'Saccharomyces_cerevisiae_yjm972',
	'saccharomyces_cerevisiae_yjm975'=>'Saccharomyces_cerevisiae_yjm975',
	'saccharomyces_cerevisiae_yjm978'=>'Saccharomyces_cerevisiae_yjm978',
	'saccharomyces_cerevisiae_yjm981'=>'Saccharomyces_cerevisiae_yjm981',
	'saccharomyces_cerevisiae_yjm984'=>'Saccharomyces_cerevisiae_yjm984',
	'saccharomyces_cerevisiae_yjm987'=>'Saccharomyces_cerevisiae_yjm987',
	'saccharomyces_cerevisiae_yjm990'=>'Saccharomyces_cerevisiae_yjm990',
	'saccharomyces_cerevisiae_yjm993'=>'Saccharomyces_cerevisiae_yjm993',
	'saccharomyces_cerevisiae_yjm996'=>'Saccharomyces_cerevisiae_yjm996',
	'saccharomyces_eubayanus'=>'Saccharomyces_eubayanus',
	'saccharomyces_kudriavzevii_ifo_1802'=>'Saccharomyces_kudriavzevii_ifo_1802',
	'saccharomyces_sp_boulardii_'=>'Saccharomyces_sp_boulardii_',
	'saccharomyces_sp_boulardii__gca_001413975'=>'Saccharomyces_sp_boulardii__gca_001413975',
	'saccharomycetaceae_sp_ashbya_aceri_'=>'Saccharomycetaceae_sp_ashbya_aceri_',
	'saitoella_complicata_nrrl_y_17804'=>'Saitoella_complicata_nrrl_y_17804',
	'saitoella_complicata_nrrl_y_17804_gca_001661265'=>'Saitoella_complicata_nrrl_y_17804_gca_001661265',
	'salpingoeca_rosetta'=>'Salpingoeca_rosetta',
	'saprolegnia_diclina_vs20'=>'Saprolegnia_diclina_vs20',
	'saprolegnia_parasitica_cbs_223_65'=>'Saprolegnia_parasitica_cbs_223_65',
	'sarcophilus_harrisii'=>'Tasmanian_devil',
	'sarcoptes_scabiei'=>'Sarcoptes_scabiei',
	'scedosporium_apiospermum'=>'Scedosporium_apiospermum',
	'scheffersomyces_stipitis_cbs_6054'=>'Scheffersomyces_stipitis_cbs_6054',
	'schistosoma_mansoni'=>'Schistosoma_mansoni',
	'schizophyllum_commune_h4_8'=>'Schizophyllum_commune_h4_8',
	'schizopora_paradoxa'=>'Schizopora_paradoxa',
	'schizosaccharomyces_cryophilus'=>'Schizosaccharomyces_cryophilus',
	'schizosaccharomyces_japonicus'=>'Schizosaccharomyces_japonicus',
	'schizosaccharomyces_octosporus'=>'Schizosaccharomyces_octosporus',
	'schizosaccharomyces_pombe'=>'Schizosaccharomyces_pombe',
	'scleroderma_citrinum_foug_a'=>'Scleroderma_citrinum_foug_a',
	'sclerotinia_borealis_f_4128'=>'Sclerotinia_borealis_f_4128',
	'sclerotinia_sclerotiorum'=>'Sclerotinia_sclerotiorum',
	'sclerotinia_sclerotiorum_1980_uf_70'=>'Sclerotinia_sclerotiorum_1980_uf_70',
	'selaginella_moellendorffii'=>'Selaginella_moellendorffii',
	'serendipita_indica_dsm_11827'=>'Serendipita_indica_dsm_11827',
	'serendipita_vermifera_maff_305830'=>'Serendipita_vermifera_maff_305830',
	'serpula_lacrymans_var_lacrymans_s7_3'=>'Serpula_lacrymans_var_lacrymans_s7_3',
	'serpula_lacrymans_var_lacrymans_s7_9'=>'Serpula_lacrymans_var_lacrymans_s7_9',
	'setaria_italica'=>'Setaria_italica',
	'setosphaeria_turcica_et28a'=>'Setosphaeria_turcica_et28a',
	'sistotremastrum_niveocremeum_hhb9708'=>'Sistotremastrum_niveocremeum_hhb9708',
	'sistotremastrum_suecicum_hhb10207_ss_3'=>'Sistotremastrum_suecicum_hhb10207_ss_3',
	'solanum_lycopersicum'=>'Solanum_lycopersicum',
	'solanum_tuberosum'=>'Solanum_tuberosum',
	'solenopsis_invicta'=>'Solenopsis_invicta',
	'sordaria_macrospora'=>'Sordaria_macrospora',
	'sorex_araneus'=>'Shrew',
	'sorghum_bicolor'=>'Sorghum_bicolor',
	'spathaspora_passalidarum_nrrl_y_27907'=>'Spathaspora_passalidarum_nrrl_y_27907',
	'sphaerobolus_stellatus_ss14'=>'Sphaerobolus_stellatus_ss14',
	'sphaeroforma_arctica_jp610'=>'Sphaeroforma_arctica_jp610',
	'sphaerulina_musiva_so2202'=>'Sphaerulina_musiva_so2202',
	'spironucleus_salmonicida'=>'Spironucleus_salmonicida',
	'spizellomyces_punctatus_daom_br117'=>'Spizellomyces_punctatus_daom_br117',
	'sporidiobolus_salmonicolor'=>'Sporidiobolus_salmonicolor',
	'sporisorium_reilianum'=>'Sporisorium_reilianum',
	'sporisorium_scitamineum'=>'Sporisorium_scitamineum',
	'sporothrix_brasiliensis_5110'=>'Sporothrix_brasiliensis_5110',
	'sporothrix_insectorum_rcef_264'=>'Sporothrix_insectorum_rcef_264',
	'sporothrix_schenckii_1099_18'=>'Sporothrix_schenckii_1099_18',
	'sporothrix_schenckii_atcc_58251'=>'Sporothrix_schenckii_atcc_58251',
	'spraguea_lophii_42_110'=>'Spraguea_lophii_42_110',
	'stachybotrys_chartarum_ibt_40288'=>'Stachybotrys_chartarum_ibt_40288',
	'stachybotrys_chartarum_ibt_40293'=>'Stachybotrys_chartarum_ibt_40293',
	'stachybotrys_chartarum_ibt_7711'=>'Stachybotrys_chartarum_ibt_7711',
	'stachybotrys_chlorohalonata_ibt_40285'=>'Stachybotrys_chlorohalonata_ibt_40285',
	'stagonospora_sp_src1lsm3a'=>'Stagonospora_sp_src1lsm3a',
	'stegodyphus_mimosarum'=>'Stegodyphus_mimosarum',
	'stemphylium_lycopersici'=>'Stemphylium_lycopersici',
	'stereum_hirsutum_fp_91666_ss1'=>'Stereum_hirsutum_fp_91666_ss1',
	'strigamia_maritima'=>'Strigamia_maritima',
	'strigomonas_culicis'=>'Strigomonas_culicis',
	'strongylocentrotus_purpuratus'=>'Strongylocentrotus_purpuratus',
	'sugiyamaella_lignohabitans'=>'Sugiyamaella_lignohabitans',
	'suillus_luteus_uh_slu_lm8_n1'=>'Suillus_luteus_uh_slu_lm8_n1',
	'sus_scrofa'=>'Pig',
	'taeniopygia_guttata'=>'Zebra_Finch',
	'takifugu_rubripes'=>'Fugu',
	'talaromyces_cellulolyticus'=>'Talaromyces_cellulolyticus',
	'talaromyces_islandicus'=>'Talaromyces_islandicus',
	'talaromyces_marneffei_atcc_18224'=>'Talaromyces_marneffei_atcc_18224',
	'talaromyces_marneffei_pm1'=>'Talaromyces_marneffei_pm1',
	'talaromyces_stipitatus_atcc_10500'=>'Talaromyces_stipitatus_atcc_10500',
	'termitomyces_sp_j132'=>'Termitomyces_sp_j132',
	'tetrahymena_thermophila'=>'Tetrahymena_thermophila',
	'tetranychus_urticae'=>'Tetranychus_urticae',
	'tetraodon_nigroviridis'=>'Tetraodon',
	'tetrapisispora_blattae_cbs_6284'=>'Tetrapisispora_blattae_cbs_6284',
	'tetrapisispora_phaffii_cbs_4417'=>'Tetrapisispora_phaffii_cbs_4417',
	'thalassiosira_oceanica'=>'Thalassiosira_oceanica',
	'thalassiosira_oceanica_ccmp1005'=>'Thalassiosira_oceanica_ccmp1005',
	'thalassiosira_pseudonana'=>'Thalassiosira_pseudonana',
	'thecamonas_trahens_atcc_50062'=>'Thecamonas_trahens_atcc_50062',
	'theileria_annulata'=>'Theileria_annulata',
	'theileria_equi_strain_wa'=>'Theileria_equi_strain_wa',
	'theileria_orientalis_strain_shintoku'=>'Theileria_orientalis_strain_shintoku',
	'theileria_parva'=>'Theileria_parva',
	'thelohanellus_kitauei'=>'Thelohanellus_kitauei',
	'theobroma_cacao'=>'Theobroma_cacao',
	'thermothelomyces_thermophila_atcc_42464'=>'Thermothelomyces_thermophila_atcc_42464',
	'thielavia_terrestris_nrrl_8126'=>'Thielavia_terrestris_nrrl_8126',
	'thielaviopsis_punctulata'=>'Thielaviopsis_punctulata',
	'tilletia_caries'=>'Tilletia_caries',
	'tilletia_controversa'=>'Tilletia_controversa',
	'tilletia_indica'=>'Tilletia_indica',
	'tilletia_walkeri'=>'Tilletia_walkeri',
	'tilletiaria_anomala_ubc_951'=>'Tilletiaria_anomala_ubc_951',
	'tolypocladium_ophioglossoides_cbs_100239'=>'Tolypocladium_ophioglossoides_cbs_100239',
	'torrubiella_hemipterigena'=>'Torrubiella_hemipterigena',
	'tortispora_caseinolytica_nrrl_y_17796'=>'Tortispora_caseinolytica_nrrl_y_17796',
	'torulaspora_delbrueckii'=>'Torulaspora_delbrueckii',
	'toxoplasma_gondii'=>'Toxoplasma_gondii',
	'toxoplasma_gondii_ari'=>'Toxoplasma_gondii_ari',
	'toxoplasma_gondii_fou'=>'Toxoplasma_gondii_fou',
	'toxoplasma_gondii_gab2_2007_gal_dom2'=>'Toxoplasma_gondii_gab2_2007_gal_dom2',
	'toxoplasma_gondii_gt1'=>'Toxoplasma_gondii_gt1',
	'toxoplasma_gondii_mas'=>'Toxoplasma_gondii_mas',
	'toxoplasma_gondii_p89'=>'Toxoplasma_gondii_p89',
	'toxoplasma_gondii_rub'=>'Toxoplasma_gondii_rub',
	'toxoplasma_gondii_tgcatprc2'=>'Toxoplasma_gondii_tgcatprc2',
	'toxoplasma_gondii_vand'=>'Toxoplasma_gondii_vand',
	'toxoplasma_gondii_veg'=>'Toxoplasma_gondii_veg',
	'trachipleistophora_hominis'=>'Trachipleistophora_hominis',
	'trametes_cinnabarina'=>'Trametes_cinnabarina',
	'trametes_pubescens'=>'Trametes_pubescens',
	'trametes_versicolor_fp_101664_ss1'=>'Trametes_versicolor_fp_101664_ss1',
	'tremella_mesenterica_dsm_1558'=>'Tremella_mesenterica_dsm_1558',
	'tribolium_castaneum'=>'Tribolium_castaneum',
	'trichoderma_atroviride_imi_206040'=>'Trichoderma_atroviride_imi_206040',
	'trichoderma_gamsii'=>'Trichoderma_gamsii',
	'trichoderma_guizhouense'=>'Trichoderma_guizhouense',
	'trichoderma_harzianum'=>'Trichoderma_harzianum',
	'trichoderma_reesei'=>'Trichoderma_reesei',
	'trichoderma_reesei_rut_c_30'=>'Trichoderma_reesei_rut_c_30',
	'trichoderma_virens'=>'Trichoderma_virens',
	'trichomonas_vaginalis_g3'=>'Trichomonas_vaginalis_g3',
	'trichophyton_benhamiae_cbs_112371'=>'Trichophyton_benhamiae_cbs_112371',
	'trichophyton_equinum_cbs_127_97'=>'Trichophyton_equinum_cbs_127_97',
	'trichophyton_interdigitale_h6'=>'Trichophyton_interdigitale_h6',
	'trichophyton_interdigitale_mr816'=>'Trichophyton_interdigitale_mr816',
	'trichophyton_rubrum'=>'Trichophyton_rubrum',
	'trichophyton_rubrum_cbs_100081'=>'Trichophyton_rubrum_cbs_100081',
	'trichophyton_rubrum_cbs_118892'=>'Trichophyton_rubrum_cbs_118892',
	'trichophyton_rubrum_cbs_202_88'=>'Trichophyton_rubrum_cbs_202_88',
	'trichophyton_rubrum_cbs_288_86'=>'Trichophyton_rubrum_cbs_288_86',
	'trichophyton_rubrum_cbs_289_86'=>'Trichophyton_rubrum_cbs_289_86',
	'trichophyton_rubrum_cbs_735_88'=>'Trichophyton_rubrum_cbs_735_88',
	'trichophyton_rubrum_d6'=>'Trichophyton_rubrum_d6',
	'trichophyton_rubrum_mr1448'=>'Trichophyton_rubrum_mr1448',
	'trichophyton_rubrum_mr1459'=>'Trichophyton_rubrum_mr1459',
	'trichophyton_rubrum_mr850'=>'Trichophyton_rubrum_mr850',
	'trichophyton_soudanense_cbs_452_61'=>'Trichophyton_soudanense_cbs_452_61',
	'trichophyton_tonsurans_cbs_112818'=>'Trichophyton_tonsurans_cbs_112818',
	'trichophyton_verrucosum_hki_0517'=>'Trichophyton_verrucosum_hki_0517',
	'trichophyton_violaceum'=>'Trichophyton_violaceum',
	'trichoplax_adhaerens'=>'Trichoplax_adhaerens',
	'trichosporon_asahii_var_asahii_cbs_2479'=>'Trichosporon_asahii_var_asahii_cbs_2479',
	'trichosporon_asahii_var_asahii_cbs_8904'=>'Trichosporon_asahii_var_asahii_cbs_8904',
	'trifolium_pratense'=>'Trifolium_pratense',
	'triticum_aestivum'=>'Triticum_aestivum',
	'triticum_urartu'=>'Triticum_urartu',
	'trypanosoma_brucei'=>'Trypanosoma_brucei',
	'trypanosoma_cruzi'=>'Trypanosoma_cruzi',
	'trypanosoma_cruzi_dm28c'=>'Trypanosoma_cruzi_dm28c',
	'tsuchiyaea_wingfieldii_cbs_7118'=>'Tsuchiyaea_wingfieldii_cbs_7118',
	'tuber_melanosporum'=>'Tuber_melanosporum',
	'tulasnella_calospora_mut_4182'=>'Tulasnella_calospora_mut_4182',
	'tupaia_belangeri'=>'Tree_Shrew',
	'tursiops_truncatus'=>'Dolphin',
	'umbilicaria_pustulata'=>'Umbilicaria_pustulata',
	'uncinocarpus_reesii_1704'=>'Uncinocarpus_reesii_1704',
	'ustilaginoidea_virens'=>'Ustilaginoidea_virens',
	'ustilaginoidea_virens_gca_000965225'=>'Ustilaginoidea_virens_gca_000965225',
	'ustilago_bromivora'=>'Ustilago_bromivora',
	'ustilago_hordei'=>'Ustilago_hordei',
	'ustilago_maydis'=>'Ustilago_maydis',
	'valsa_mali'=>'Valsa_mali',
	'valsa_mali_var_pyri'=>'Valsa_mali_var_pyri',
	'vanderwaltozyma_polyspora_dsm_70294'=>'Vanderwaltozyma_polyspora_dsm_70294',
	'vavraia_culicis_subsp_floridensis'=>'Vavraia_culicis_subsp_floridensis',
	'verruconis_gallopava'=>'Verruconis_gallopava',
	'verticillium_alfalfae_vams_102'=>'Verticillium_alfalfae_vams_102',
	'verticillium_dahliae'=>'Verticillium_dahliae',
	'verticillium_dahliaejr2'=>'Verticillium_dahliaejr2',
	'verticillium_longisporum'=>'Verticillium_longisporum',
	'verticillium_longisporum_gca_001268145'=>'Verticillium_longisporum_gca_001268145',
	'vicugna_pacos'=>'Alpaca',
	'vitis_vinifera'=>'Vitis_vinifera',
	'vitrella_brassicaformis_ccmp3155'=>'Vitrella_brassicaformis_ccmp3155',
	'vittaforma_corneae_atcc_50505'=>'Vittaforma_corneae_atcc_50505',
	'wallemia_ichthyophaga_exf_994'=>'Wallemia_ichthyophaga_exf_994',
	'wallemia_mellicola_cbs_633_66'=>'Wallemia_mellicola_cbs_633_66',
	'wickerhamomyces_anomalus_nrrl_y_366_8'=>'Wickerhamomyces_anomalus_nrrl_y_366_8',
	'wickerhamomyces_ciferrii'=>'Wickerhamomyces_ciferrii',
	'xanthophyllomyces_dendrorhous'=>'Xanthophyllomyces_dendrorhous',
	'xenopus_tropicalis'=>'Xenopus',
	'xiphophorus_maculatus'=>'Platyfish',
	'xylona_heveae_tc161'=>'Xylona_heveae_tc161',
	'yarrowia_lipolytica'=>'Yarrowia_lipolytica',
	'yarrowia_lipolytica_gca_001761485'=>'Yarrowia_lipolytica_gca_001761485',
	'zea_mays'=>'Zea_mays',
	'zootermopsis_nevadensis'=>'Zootermopsis_nevadensis',
	'zygosaccharomyces_bailii_isa1307'=>'Zygosaccharomyces_bailii_isa1307',
	'zygosaccharomyces_parabailii'=>'Zygosaccharomyces_parabailii',
	'zygosaccharomyces_rouxii'=>'Zygosaccharomyces_rouxii',
	'zygosaccharomyces_rouxii_gca_001972345'=>'Zygosaccharomyces_rouxii_gca_001972345',
	'zymoseptoria_brevis'=>'Zymoseptoria_brevis',
	'zymoseptoria_tritici'=>'Zymoseptoria_tritici',
	'other'=>'undefined',
	'x'=>'undefined',
	);### SPECIES DICTONARY END ###
		}
	}

sub load_reference_sequences
	{
	if($download_reference==1&&$species{$species}ne'undefined')
		{
		# download and process Genomic tRNA Database sequences
		$eval_URL="";
		$eval_URL=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/URLs/gtRNAdb');
		if(length$eval_URL>0)
			{
			eval$eval_URL;
			}
		else
			{
			if(!$silent){print"\nFailed to load current gtRNAdb URLs from smallRNAgroup-SERVER. Use internal list.";}
### TRNA URLS START ###
%gtRNAdb_urls=
	(
	'_candida_auris'=>'',
	'_candida_glabrata'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_glab_CBS_138/candGlab_CBS_138-tRNAs.fa',
	'_candida_glabrata_gca_001466525'=>'',
	'_candida_glabrata_gca_001466535'=>'',
	'_candida_glabrata_gca_001466565'=>'',
	'_candida_glabrata_gca_001466575'=>'',
	'_candida_glabrata_gca_001466635'=>'',
	'_candida_glabrata_gca_001466685'=>'',
	'_candida_intermedia'=>'',
	'_candida_intermedia_gca_900106125'=>'',
	'_candida_tenuis_atcc_10573'=>'',
	'absidia_glauca'=>'',
	'acidomyces_richmondensis'=>'',
	'acidomyces_richmondensis_bfw'=>'',
	'acremonium_chrysogenum_atcc_11550'=>'',
	'acyrthosiphon_pisum'=>'',
	'adineta_vaga'=>'',
	'aedes_aegypti'=>'',
	'aegilops_tauschii'=>'',
	'agaricus_bisporus_var_burnettii_jb137_s8'=>'',
	'ailuropoda_melanoleuca'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Amela1/ailMel1-tRNAs.fa',
	'albugo_laibachii'=>'',
	'allomyces_macrogynus_atcc_38327'=>'',
	'alternaria_alternata'=>'',
	'amanita_muscaria_koide_bx008'=>'',
	'amborella_trichopoda'=>'',
	'amphiamblys_sp_wsbs2006'=>'',
	'amphimedon_queenslandica'=>'',
	'anas_platyrhynchos'=>'',
	'angomonas_deanei'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/bacteria/Cand_Kine_crithidii_ex_Angomonas_deanei_ATCC_30255/candKine_CRITHIDII_EX_ANGOMONA-tRNAs.fa',
	'anncaliia_algerae_pra109'=>'',
	'anncaliia_algerae_pra339'=>'',
	'anolis_carolinensis'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Acaro2/anoCar2-tRNAs.fa',
	'anopheles_darlingi'=>'',
	'anopheles_gambiae'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Agamb/Agamb-tRNAs.fa',
	'anoplophora_glabripennis'=>'',
	'anthracocystis_flocculosa_pf_1'=>'',
	'aphanomyces_astaci'=>'',
	'aphanomyces_invadans'=>'',
	'apis_mellifera'=>'',
	'arabidopsis_lyrata'=>'',
	'arabidopsis_thaliana'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Athal10/araTha1-tRNAs.fa',
	'arthrobotrys_oligospora_atcc_24927'=>'',
	'arthroderma_otae_cbs_113480'=>'',
	'aschersonia_aleyrodis_rcef_2490'=>'',
	'ascochyta_rabiei'=>'',
	'ascoidea_rubescens_dsm_1968'=>'',
	'ascosphaera_apis_arsef_7405'=>'',
	'ashbya_gossypii'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Ashb_goss_ATCC_10895/ashbGoss_ATCC10895-tRNAs.fa',
	'aspergillus_aculeatus_atcc_16872'=>'',
	'aspergillus_bombycis'=>'',
	'aspergillus_brasiliensis_cbs_101740'=>'',
	'aspergillus_calidoustus'=>'',
	'aspergillus_carbonarius_item_5010'=>'',
	'aspergillus_clavatus'=>'',
	'aspergillus_cristatus'=>'',
	'aspergillus_flavus'=>'',
	'aspergillus_flavus_af70'=>'',
	'aspergillus_fumigatus'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Aspe_fumi_Af293/aspeFumi_AF293-tRNAs.fa',
	'aspergillus_fumigatus_var_rp_2014'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Aspe_fumi_Af293/aspeFumi_AF293-tRNAs.fa',
	'aspergillus_fumigatus_z5'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Aspe_fumi_Af293/aspeFumi_AF293-tRNAs.fa',
	'aspergillus_fumigatusa1163'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Aspe_fumi_Af293/aspeFumi_AF293-tRNAs.fa',
	'aspergillus_glaucus_cbs_516_65'=>'',
	'aspergillus_lentulus'=>'',
	'aspergillus_luchuensis'=>'',
	'aspergillus_luchuensis_cbs_106_47'=>'',
	'aspergillus_nidulans'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Aspe_nidu_FGSC_A4/aspeNidu_FGSC_A4-tRNAs.fa',
	'aspergillus_nidulans_fgsc_a4'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Aspe_nidu_FGSC_A4/aspeNidu_FGSC_A4-tRNAs.fa',
	'aspergillus_niger'=>'',
	'aspergillus_niger_atcc_1015'=>'',
	'aspergillus_niger_gca_001515345'=>'',
	'aspergillus_nomius_nrrl_13137'=>'',
	'aspergillus_ochraceoroseus'=>'',
	'aspergillus_oryzae'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Aspe_oryz_RIB40/aspeOryz_RIB40-tRNAs.fa',
	'aspergillus_oryzae_100_8'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Aspe_oryz_RIB40/aspeOryz_RIB40-tRNAs.fa',
	'aspergillus_oryzae_3_042'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Aspe_oryz_RIB40/aspeOryz_RIB40-tRNAs.fa',
	'aspergillus_oryzae_gca_002007945'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Aspe_oryz_RIB40/aspeOryz_RIB40-tRNAs.fa',
	'aspergillus_parasiticus_su_1'=>'',
	'aspergillus_rambellii'=>'',
	'aspergillus_ruber_cbs_135680'=>'',
	'aspergillus_sydowii_cbs_593_65'=>'',
	'aspergillus_terreus'=>'',
	'aspergillus_tubingensis_cbs_134_48'=>'',
	'aspergillus_udagawae'=>'',
	'aspergillus_ustus'=>'',
	'aspergillus_versicolor_cbs_583_65'=>'',
	'aspergillus_wentii_dto_134e9'=>'',
	'astyanax_mexicanus'=>'',
	'atta_cephalotes'=>'',
	'aureobasidium_melanogenum_cbs_110374'=>'',
	'aureobasidium_namibiae_cbs_147_97'=>'',
	'aureobasidium_pullulans'=>'',
	'aureobasidium_pullulans_exf_150'=>'',
	'aureobasidium_subglaciale_exf_2481'=>'',
	'babesia_bovis'=>'',
	'babesia_microti_strain_ri'=>'',
	'babjeviella_inositovora_nrrl_y_12698'=>'',
	'batrachochytrium_dendrobatidis_jam81'=>'',
	'batrachochytrium_dendrobatidis_jel423'=>'',
	'batrachochytrium_salamandrivorans'=>'',
	'baudoinia_panamericana_uamh_10762'=>'',
	'beauveria_bassiana'=>'',
	'beauveria_bassiana_arsef_2860'=>'',
	'beauveria_bassiana_d1_5'=>'',
	'belgica_antarctica'=>'',
	'beta_vulgaris'=>'',
	'bigelowiella_natans'=>'',
	'bigelowiella_natans_gca_000002455'=>'',
	'bipolaris_maydis_atcc_48331'=>'',
	'bipolaris_maydis_c5'=>'',
	'bipolaris_oryzae_atcc_44560'=>'',
	'bipolaris_sorokiniana_nd90pr'=>'',
	'bipolaris_victoriae_fi3'=>'',
	'bipolaris_zeicola_26_r_13'=>'',
	'blastomyces_dermatitidis_atcc_18188'=>'',
	'blastomyces_dermatitidis_atcc_26199'=>'',
	'blastomyces_dermatitidis_er_3'=>'',
	'blastomyces_gilchristii_slh14081'=>'',
	'blastomyces_percursus'=>'',
	'blumeria_graminis'=>'',
	'blumeria_graminis_f_sp_tritici_96224'=>'',
	'bodo_saltans'=>'',
	'bombus_impatiens'=>'',
	'bombyx_mori'=>'',
	'bos_taurus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Btaur8/bosTau8-tRNAs.fa',
	'botryobasidium_botryosum_fd_172_ss1'=>'',
	'botrytis_cinerea'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Botr_cine_B05_10/botrCine_B05_10-tRNAs.fa',
	'botrytis_cinerea_bcdw1'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Botr_cine_B05_10/botrCine_B05_10-tRNAs.fa',
	'botrytis_cinerea_t4'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Botr_cine_B05_10/botrCine_B05_10-tRNAs.fa',
	'brachypodium_distachyon'=>'',
	'brassica_napus'=>'',
	'brassica_oleracea'=>'',
	'brassica_rapa'=>'',
	'brettanomyces_bruxellensis_awri1499'=>'',
	'brugia_malayi'=>'',
	'byssochlamys_spectabilis_no_5'=>'',
	'caenorhabditis_brenneri'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cbren2/caePb2-tRNAs.fa',
	'caenorhabditis_briggsae'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cbrig3/cb3-tRNAs.fa',
	'caenorhabditis_elegans'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Celeg_WS220/ce10-tRNAs.fa',
	'caenorhabditis_japonica'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cjapo1/caeJap1-tRNAs.fa',
	'caenorhabditis_remanei'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Crema3/caeRem3-tRNAs.fa',
	'callithrix_jacchus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Cjacc3/calJac3-tRNAs.fa',
	'calocera_cornea_hhb12733'=>'',
	'calocera_viscosa_tufc12733'=>'',
	'candida_albicans_12c'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_19f'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_ca6'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_gc75'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_l26'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p34048'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p37005'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p37037'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p37039'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p57055'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p57072'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p60002'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p75010'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p75016'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p75063'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p76055'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p76067'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p78042'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p78048'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p87'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_p94015'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_sc5314'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_sc5314_gca_000182965'=>'',
	'candida_albicans_sc5314_gca_000784655'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_albicans_wo_1'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_albi_WO_1/candAlbi_WO_1-tRNAs.fa',
	'candida_arabinofermentans_nrrl_yb_2248'=>'',
	'candida_dubliniensis_cd36'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_dubl_CD36/candDubl_CD36-tRNAs.fa',
	'candida_maltosa_xu316'=>'',
	'candida_orthopsilosis_co_90_125'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cand_orth_Co_90_125/candOrth_CO_90_125-tRNAs.fa',
	'candida_parapsilosis_cdc317'=>'',
	'candida_tanzawaensis_nrrl_y_17324'=>'',
	'candida_tropicalis_mya_3404'=>'',
	'canis_familiaris'=>'',
	'capitella_teleta'=>'',
	'capronia_coronata_cbs_617_96'=>'',
	'capronia_epimyces_cbs_606_96'=>'',
	'capsaspora_owczarzaki_atcc_30864'=>'',
	'carlito_syrichta'=>'',
	'cavia_aperea'=>'',
	'cavia_porcellus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Cporc3/cavPor3-tRNAs.fa',
	'ceraceosorus_bombacis'=>'',
	'ceratocystis_platani'=>'',
	'chaetomium_globosum_cbs_148_51'=>'',
	'chaetomium_thermophilum_var_thermophilum_dsm_1495'=>'',
	'chinchilla_lanigera'=>'',
	'chlamydomonas_reinhardtii'=>'',
	'chlorocebus_sabaeus'=>'',
	'choloepus_hoffmanni'=>'',
	'chondrus_crispus'=>'',
	'chroomonas_mesostigmatica_ccmp1168'=>'',
	'ciona_intestinalis'=>'',
	'ciona_savignyi'=>'',
	'cladophialophora_bantiana_cbs_173_52'=>'',
	'cladophialophora_carrionii'=>'',
	'cladophialophora_carrionii_cbs_160_54'=>'',
	'cladophialophora_immunda'=>'',
	'cladophialophora_psammophila_cbs_110553'=>'',
	'cladophialophora_yegresii_cbs_114405'=>'',
	'claviceps_purpurea_20_1'=>'',
	'clavispora_lusitaniae_atcc_42720'=>'',
	'coccidioides_immitis_h538_4'=>'',
	'coccidioides_immitis_rmscc_2394'=>'',
	'coccidioides_immitis_rmscc_3703'=>'',
	'coccidioides_immitis_rs'=>'',
	'coccidioides_posadasii_c735_delta_sowgp'=>'',
	'coccidioides_posadasii_rmscc_3488'=>'',
	'coccidioides_posadasii_str_silveira'=>'',
	'colletotrichum_chlorophyti'=>'',
	'colletotrichum_fioriniae_pj7'=>'',
	'colletotrichum_gloeosporioides'=>'',
	'colletotrichum_gloeosporioides_cg_14'=>'',
	'colletotrichum_graminicola'=>'',
	'colletotrichum_higginsianum'=>'',
	'colletotrichum_higginsianum_imi_349063'=>'',
	'colletotrichum_incanum'=>'',
	'colletotrichum_incanum_gca_001855235'=>'',
	'colletotrichum_nymphaeae_sa_01'=>'',
	'colletotrichum_orbiculare'=>'',
	'colletotrichum_orchidophilum'=>'',
	'colletotrichum_salicis'=>'',
	'colletotrichum_simmondsii'=>'',
	'colletotrichum_sublineola'=>'',
	'colletotrichum_tofieldiae'=>'',
	'conidiobolus_coronatus_nrrl_28638'=>'',
	'coniochaeta_ligniaria_nrrl_30616'=>'',
	'coniophora_puteana_rwd_64_598_ss2'=>'',
	'coniosporium_apollinis_cbs_100218'=>'',
	'coprinopsis_cinerea_okayama7_130'=>'',
	'corchorus_capsularis'=>'',
	'cordyceps_brongniartii_rcef_3172'=>'',
	'cordyceps_confragosa'=>'',
	'cordyceps_confragosa_rcef_1005'=>'',
	'cordyceps_militaris_cm01'=>'',
	'crassostrea_gigas'=>'',
	'cricetulus_griseus_chok1gshd'=>'',
	'cricetulus_griseus_crigri'=>'',
	'cryptococcus_amylolentus_cbs_6039'=>'',
	'cryptococcus_amylolentus_cbs_6273'=>'',
	'cryptococcus_depauperatus_cbs_7841'=>'',
	'cryptococcus_depauperatus_cbs_7855'=>'',
	'cryptococcus_gattii_ca1280'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cryp_gatt_WM276/crypGatt_WM276-tRNAs.fa',
	'cryptococcus_gattii_ca1873'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cryp_gatt_WM276/crypGatt_WM276-tRNAs.fa',
	'cryptococcus_gattii_e566'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cryp_gatt_WM276/crypGatt_WM276-tRNAs.fa',
	'cryptococcus_gattii_ejb2'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cryp_gatt_WM276/crypGatt_WM276-tRNAs.fa',
	'cryptococcus_gattii_nt_10'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cryp_gatt_WM276/crypGatt_WM276-tRNAs.fa',
	'cryptococcus_gattii_ru294'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cryp_gatt_WM276/crypGatt_WM276-tRNAs.fa',
	'cryptococcus_gattii_vgii_2001_935_1'=>'',
	'cryptococcus_gattii_vgii_99_473'=>'',
	'cryptococcus_gattii_vgii_ca1014'=>'',
	'cryptococcus_gattii_vgii_cbs_10090'=>'',
	'cryptococcus_gattii_vgii_la55'=>'',
	'cryptococcus_gattii_vgii_mmrl2647'=>'',
	'cryptococcus_gattii_vgii_r265'=>'',
	'cryptococcus_gattii_vgii_ram5'=>'',
	'cryptococcus_gattii_vgiv_ind107'=>'',
	'cryptococcus_gattii_wm276'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cryp_gatt_WM276/crypGatt_WM276-tRNAs.fa',
	'cryptococcus_neoformans'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cryp_neof_var_grubii_H99/crypNeof_VAR_GRUBII_H99-tRNAs.fa',
	'cryptococcus_neoformans_var_grubii_h99'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cryp_neof_var_grubii_H99/crypNeof_VAR_GRUBII_H99-tRNAs.fa',
	'cryptococcus_neoformans_var_neoformans_b_3501a'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cryp_neof_var_neoformans_B_3501A/crypNeof_VAR_NEOFORMANS_B_3501-tRNAs.fa',
	'cryptomonas_paramecium'=>'',
	'cryptosporidium_muris_rn66'=>'',
	'cryptosporidium_parvum'=>'',
	'cryptosporidium_parvum_iowa_ii'=>'',
	'culex_quinquefasciatus'=>'',
	'cutaneotrichosporon_oleaginosus'=>'',
	'cyberlindnera_fabianii'=>'',
	'cyberlindnera_jadinii'=>'',
	'cyberlindnera_jadinii_nrrl_y_1542'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Cybe_jadi_NBRC_0988_NBRC0988/cybeJadi_NBRC_0988_NBRC0988-tRNAs.fa',
	'cyclospora_cayetanensis'=>'',
	'cylindrobasidium_torrendii_fp15055_ss_10'=>'',
	'cyphellophora_europaea_cbs_101466'=>'',
	'dacryopinax_primogenitus'=>'',
	'dactylellina_haptotyla_cbs_200_50'=>'',
	'daedalea_quercina_l_15889'=>'',
	'danaus_plexippus'=>'',
	'danio_rerio'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Dreri_v8/danRer6-tRNAs.fa',
	'daphnia_pulex'=>'',
	'dasypus_novemcinctus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Dnove3/dasNov3-tRNAs.fa',
	'debaryomyces_fabryi'=>'',
	'debaryomyces_hansenii_cbs767'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Deba_hans_CBS767/debaHans_CBS767-tRNAs.fa',
	'dendroctonus_ponderosae'=>'',
	'diaporthe_ampelina'=>'',
	'diaporthe_helianthi'=>'',
	'dichomitus_squalens_lyad_421_ss1'=>'',
	'dictyostelium_discoideum'=>'',
	'dictyostelium_fasciculatum'=>'',
	'dictyostelium_lacteum'=>'',
	'diplodia_corticola'=>'',
	'diplodia_seriata'=>'',
	'diplodia_seriata_gca_001975905'=>'',
	'dipodomys_ordii'=>'',
	'dothistroma_septosporum'=>'',
	'drechmeria_coniospora'=>'',
	'drechslerella_stenobrocha_248'=>'',
	'drosophila_ananassae'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Danan3/droAna3-tRNAs.fa',
	'drosophila_erecta'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Derec2/droEre2-tRNAs.fa',
	'drosophila_grimshawi'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Dgrim2/droGri2-tRNAs.fa',
	'drosophila_melanogaster'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Dmela6/dm6-tRNAs.fa',
	'drosophila_mojavensis'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Dmoja3/droMoj3-tRNAs.fa',
	'drosophila_persimilis'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Dpers1/droPer1-tRNAs.fa',
	'drosophila_pseudoobscura'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Dpseu4/dp4-tRNAs.fa',
	'drosophila_sechellia'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Dsech1/droSec1-tRNAs.fa',
	'drosophila_simulans'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Dsimu1/droSim1-tRNAs.fa',
	'drosophila_virilis'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Dviri3/droVir3-tRNAs.fa',
	'drosophila_willistoni'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Dwill1/droWil1-tRNAs.fa',
	'drosophila_yakuba'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Dyaku2/droYak2-tRNAs.fa',
	'echinops_telfairi'=>'',
	'edhazardia_aedis_usnm_41457'=>'',
	'eimeria_brunetti'=>'',
	'eimeria_maxima'=>'',
	'eimeria_mitis'=>'',
	'eimeria_praecox'=>'',
	'eimeria_tenella'=>'',
	'eimeria_tenella_gca_000499545'=>'',
	'emergomyces_pasteuriana_ep9510'=>'',
	'emiliania_huxleyi'=>'',
	'emmonsia_crescens_uamh_3008'=>'',
	'emmonsia_parva_uamh_139'=>'',
	'emmonsia_sp_cac_2015a'=>'',
	'encephalitozoon_cuniculi_ecuniii_l'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Ence_cuni_GB_M1/enceCuni_GB_M1-tRNAs.fa',
	'encephalitozoon_cuniculi_gb_m1'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Ence_cuni_GB_M1/enceCuni_GB_M1-tRNAs.fa',
	'encephalitozoon_hellem_atcc_50504'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Ence_hell_ATCC_50504/enceHell_ATCC50504-tRNAs.fa',
	'encephalitozoon_intestinalis_atcc_50506'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Ence_inte_ATCC_50506/enceInte_ATCC50506-tRNAs.fa',
	'encephalitozoon_romaleae_sj_2008'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Ence_roma_SJ_2008/',
	'endocarpon_pusillum_z07020'=>'',
	'entamoeba_histolytica'=>'',
	'entamoeba_histolytica_gca_001662325'=>'',
	'entamoeba_histolytica_hm_3_imss'=>'',
	'entamoeba_histolytica_ku27'=>'',
	'entamoeba_nuttalli_p19'=>'',
	'enterocytozoon_bieneusi_h348'=>'',
	'enterocytozoon_hepatopenaei'=>'',
	'enterospora_canceri'=>'',
	'equus_caballus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Ecaba2/equCab2-tRNAs.fa',
	'eremothecium_cymbalariae_dbvpg_7215'=>'',
	'eremothecium_gossypii_fdag1'=>'',
	'eremothecium_sinecaudum'=>'',
	'erinaceus_europaeus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Eeuro2/eriEur2-tRNAs.fa',
	'erysiphe_necator'=>'',
	'escovopsis_weberi'=>'',
	'eutypa_lata_ucrel1'=>'',
	'exidia_glandulosa_hhb12029'=>'',
	'exophiala_aquamarina_cbs_119918'=>'',
	'exophiala_dermatitidis_nih_ut8656'=>'',
	'exophiala_mesophila'=>'',
	'exophiala_oligosperma'=>'',
	'exophiala_sideris'=>'',
	'exophiala_spinifera'=>'',
	'exophiala_xenobiotica'=>'',
	'felis_catus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Fcatu5/felCat5-tRNAs.fa',
	'fibroporia_radiculosa'=>'',
	'fibulorhizoctonia_sp_cbs_109695'=>'',
	'ficedula_albicollis'=>'',
	'fistulina_hepatica_atcc_64428'=>'',
	'fomitiporia_mediterranea_mf3_22'=>'',
	'fomitopsis_pinicola_fp_58527_ss1'=>'',
	'fonsecaea_erecta'=>'',
	'fonsecaea_monophora'=>'',
	'fonsecaea_multimorphosa'=>'',
	'fonsecaea_multimorphosa_cbs_102226'=>'',
	'fonsecaea_nubica'=>'',
	'fonsecaea_pedrosoi_cbs_271_37'=>'',
	'fonticula_alba_gca_000388065'=>'',
	'fukomys_damarensis'=>'',
	'fusarium_culmorum'=>'',
	'fusarium_fujikuroi'=>'',
	'fusarium_fujikuroi_gca_001023035'=>'',
	'fusarium_fujikuroi_gca_001023045'=>'',
	'fusarium_fujikuroi_gca_001023065'=>'',
	'fusarium_graminearum'=>'',
	'fusarium_graminearum_gca_000599445'=>'',
	'fusarium_langsethiae'=>'',
	'fusarium_mangiferae'=>'',
	'fusarium_oxysporum'=>'',
	'fusarium_oxysporum_f_sp_conglutinans_race_2_54008'=>'',
	'fusarium_oxysporum_f_sp_cubense_race_1'=>'',
	'fusarium_oxysporum_f_sp_cubense_race_4'=>'',
	'fusarium_oxysporum_f_sp_cubense_tropical_race_4_54006'=>'',
	'fusarium_oxysporum_f_sp_lycopersici_mn25'=>'',
	'fusarium_oxysporum_f_sp_melonis_26406'=>'',
	'fusarium_oxysporum_f_sp_pisi_hdv247'=>'',
	'fusarium_oxysporum_f_sp_radicis_lycopersici_26381'=>'',
	'fusarium_oxysporum_f_sp_raphani_54005'=>'',
	'fusarium_oxysporum_f_sp_vasinfectum_25433'=>'',
	'fusarium_oxysporum_fo47'=>'',
	'fusarium_oxysporum_fosc_3_a'=>'',
	'fusarium_poae'=>'',
	'fusarium_proliferatum'=>'',
	'fusarium_proliferatum_et1'=>'',
	'fusarium_pseudograminearum'=>'',
	'fusarium_solani'=>'',
	'fusarium_verticillioides'=>'',
	'gadus_morhua'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Gmorh1/gadMor1-tRNAs.fa',
	'gaeumannomyces_graminis'=>'',
	'galdieria_sulphuraria'=>'',
	'galerina_marginata_cbs_339_88'=>'',
	'gallus_gallus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Ggall4/galGal4-tRNAs.fa',
	'gasterosteus_aculeatus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Gacul1/gasAcu1-tRNAs.fa',
	'gelatoporia_subvermispora_b'=>'',
	'geotrichum_candidum'=>'',
	'giardia_intestinalis'=>'',
	'giardia_intestinalis_assemblage_b'=>'',
	'giardia_intestinalis_atcc_50581'=>'',
	'giardia_intestinalis_gca_000498715'=>'',
	'giardia_lamblia'=>'',
	'giardia_lamblia_p15'=>'',
	'glarea_lozoyensis_74030'=>'',
	'glarea_lozoyensis_atcc_20868'=>'',
	'gloeophyllum_trabeum_atcc_11539'=>'',
	'glycine_max'=>'',
	'gonapodya_prolifera_jel478'=>'',
	'gorilla_gorilla'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Ggori3/gorGor3-tRNAs.fa',
	'gregarina_niphandrodes'=>'',
	'grifola_frondosa'=>'',
	'grosmannia_clavigera_kw1407'=>'',
	'guillardia_theta'=>'',
	'guillardia_theta_gca_000002975'=>'',
	'gymnopus_luxurians_fd_317_m1'=>'',
	'hammondia_hammondi'=>'',
	'hanseniaspora_guilliermondii'=>'',
	'hanseniaspora_opuntiae'=>'',
	'hanseniaspora_osmophila'=>'',
	'hanseniaspora_uvarum'=>'',
	'hanseniaspora_uvarum_dsm_2768'=>'',
	'hanseniaspora_valbyensis_nrrl_y_1626'=>'',
	'hebeloma_cylindrosporum_h7'=>'',
	'heliconius_melpomene'=>'',
	'helobdella_robusta'=>'',
	'hepatospora_eriocheir'=>'',
	'hepatospora_eriocheir_gca_002087885'=>'',
	'heterobasidion_irregulare_tc_32_1'=>'',
	'heterocephalus_glaber_female'=>'',
	'heterocephalus_glaber_male'=>'',
	'hirsutella_minnesotensis_3608'=>'',
	'histoplasma_capsulatum_g186ar'=>'',
	'histoplasma_capsulatum_h143'=>'',
	'histoplasma_capsulatum_h88'=>'',
	'histoplasma_capsulatum_nam1'=>'',
	'homo_sapiens'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Hsapi19/hg19-tRNAs.fa',
	'hordeum_vulgare'=>'',
	'hyaloperonospora_arabidopsidis'=>'',
	'hydnomerulius_pinastri_md_312'=>'',
	'hypholoma_sublateritium_fd_334_ss_4'=>'',
	'hyphopichia_burtonii_nrrl_y_1933'=>'',
	'hypsizygus_marmoreus'=>'',
	'ichthyophthirius_multifiliis'=>'',
	'ictidomys_tridecemlineatus'=>'',
	'isaria_fumosorosea_arsef_2679'=>'',
	'ixodes_scapularis'=>'',
	'jaapia_argillacea_mucl_33604'=>'',
	'jaculus_jaculus'=>'',
	'kalmanozyma_brasiliensis_ghg001'=>'',
	'kazachstania_africana_cbs_2517'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Kaza_afri_CBS_2517/kazaAfri_CBS_2517-tRNAs.fa',
	'kazachstania_naganishii_cbs_8797'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Kaza_naga_CBS_8797/kazaNaga_CBS_8797-tRNAs.fa',
	'kluyveromyces_lactis'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Kluy_lact_NRRL_Y_1140/kluyLact_NRRL_Y_1140-tRNAs.fa',
	'kluyveromyces_marxianus'=>'',
	'kluyveromyces_marxianus_dmku3_1042'=>'',
	'komagataella_pastoris'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Koma_past_CBS_7435/komaPast_CBS_7435-tRNAs.fa',
	'komagataella_pastoris_gca_001708105'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Koma_past_CBS_7435/komaPast_CBS_7435-tRNAs.fa',
	'komagataella_phaffii'=>'',
	'komagataella_phaffii_cbs_7435'=>'',
	'komagataella_phaffii_gs115'=>'',
	'kuraishia_capsulata_cbs_1993'=>'',
	'kwoniella_bestiolae_cbs_10118'=>'',
	'kwoniella_dejecticola_cbs_10117'=>'',
	'kwoniella_heveanensis_bcc8398'=>'',
	'kwoniella_heveanensis_cbs_569'=>'',
	'kwoniella_mangroviensis_cbs_10435'=>'',
	'kwoniella_mangroviensis_cbs_8507'=>'',
	'kwoniella_mangroviensis_cbs_8886'=>'',
	'kwoniella_pini_cbs_10737'=>'',
	'laccaria_amethystina_laam_08_1'=>'',
	'laccaria_bicolor_s238n_h82'=>'',
	'lachancea_dasiensis_cbs_10888'=>'',
	'lachancea_fermentati'=>'',
	'lachancea_lanzarotensis'=>'',
	'lachancea_meyersii_cbs_8951'=>'',
	'lachancea_mirantina'=>'',
	'lachancea_nothofagi_cbs_11611'=>'',
	'lachancea_sp_cbs_6924'=>'',
	'lachancea_thermotolerans_cbs_6340'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Lach_ther_CBS_6340/lachTher_CBS_6340-tRNAs.fa',
	'laetiporus_sulphureus_93_53'=>'',
	'latimeria_chalumnae'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Lchal1/latCha1-tRNAs.fa',
	'leersia_perrieri'=>'',
	'leishmania_braziliensis_mhom_br_75_m2904'=>'',
	'leishmania_donovani_bpk282a1'=>'',
	'leishmania_infantum_jpcm5'=>'',
	'leishmania_major'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Lmajo/Lmajo-tRNAs.fa',
	'leishmania_mexicana_mhom_gt_2001_u1103'=>'',
	'leishmania_panamensis'=>'',
	'lentinula_edodes'=>'',
	'lepeophtheirus_salmonis'=>'',
	'lepisosteus_oculatus'=>'',
	'leptomonas_pyrrhocoris'=>'',
	'leptomonas_seymouri'=>'',
	'leptosphaeria_maculans'=>'',
	'leucoagaricus_sp_symc_cos'=>'',
	'lingula_anatina'=>'',
	'lipomyces_starkeyi_nrrl_y_11557'=>'',
	'loa_loa'=>'',
	'lodderomyces_elongisporus_nrrl_yb_4239'=>'',
	'lotharella_oceanica'=>'',
	'lottia_gigantea'=>'',
	'loxodonta_africana'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Lafri3/loxAfr3-tRNAs.fa',
	'lucilia_cuprina'=>'',
	'macaca_mulatta'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmula3/rheMac3-tRNAs.fa',
	'macrophomina_phaseolina_ms6'=>'',
	'madurella_mycetomatis'=>'',
	'magnaporthe_oryzae'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Magn_oryz_70_15/magnOryz_70_15-tRNAs.fa',
	'magnaporthe_poae'=>'',
	'malassezia_pachydermatis'=>'',
	'malassezia_sympodialis_atcc_42132'=>'',
	'malassezia_sympodialis_atcc_42132_gca_900149145'=>'',
	'marssonina_brunnea_f_sp_multigermtubi_mb_m1'=>'',
	'mayetiola_destructor'=>'',
	'medicago_truncatula'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Mtrun/mt3-tRNAs.fa',
	'megaselia_scalaris'=>'',
	'melampsora_laricipopulina'=>'',
	'meleagris_gallopavo'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mgall1/melGal1-tRNAs.fa',
	'melitaea_cinxia'=>'',
	'mesocricetus_auratus'=>'',
	'metarhizium_acridum_cqma_102'=>'',
	'metarhizium_album_arsef_1941'=>'',
	'metarhizium_anisopliae'=>'',
	'metarhizium_anisopliae_arsef_23'=>'',
	'metarhizium_anisopliae_arsef_549'=>'',
	'metarhizium_anisopliae_brip_53284'=>'',
	'metarhizium_anisopliae_brip_53293'=>'',
	'metarhizium_brunneum_arsef_3297'=>'',
	'metarhizium_guizhouense_arsef_977'=>'',
	'metarhizium_majus_arsef_297'=>'',
	'metarhizium_rileyi_rcef_4871'=>'',
	'metarhizium_robertsii'=>'',
	'metschnikowia_bicuspidata_var_bicuspidata_nrrl_yb_4993'=>'',
	'meyerozyma_guilliermondii_atcc_6260'=>'',
	'microbotryum_violaceum'=>'',
	'microcebus_murinus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmuri1/micMur1-tRNAs.fa',
	'microdochium_bolleyi'=>'',
	'microtus_ochrogaster'=>'',
	'millerozyma_farinosa_cbs_7064'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Mill_fari_CBS_7064/millFari_CBS_7064-tRNAs.fa',
	'mitosporidium_daphniae'=>'',
	'mixia_osmundae_iam_14324'=>'',
	'mixia_osmundae_iam_14324_gca_000708205'=>'',
	'mnemiopsis_leidyi'=>'',
	'moesziomyces_antarcticus'=>'',
	'moesziomyces_aphidis_dsm_70725'=>'',
	'moniliophthora_perniciosa_fa553'=>'',
	'moniliophthora_roreri'=>'',
	'moniliophthora_roreri_mca_2997'=>'',
	'monodelphis_domestica'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mdome5/monDom5-tRNAs.fa',
	'mortierella_elongata_ag_77'=>'',
	'mortierella_verticillata_nrrl_6337'=>'',
	'mucor_ambiguus'=>'',
	'mucor_circinelloides_f_circinelloides_1006phl'=>'',
	'mucor_circinelloides_f_lusitanicus_cbs_277_49'=>'',
	'mus_caroli'=>'',
	'mus_musculus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_129s1svimj'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_aj'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_akrj'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_balbcj'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_c3hhej'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_c57bl6nj'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_casteij'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_dba2j'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_fvbnj'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_lpj'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_nodshiltj'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_nzohlltj'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_pwkphj'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_musculus_wsbeij'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mmusc10/mm10-tRNAs.fa',
	'mus_pahari'=>'',
	'mus_spretus_spreteij'=>'',
	'musa_acuminata'=>'',
	'mustela_putorius_furo'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mputo1/musFur1-tRNAs.fa',
	'mycosphaerella_eumusae'=>'',
	'myotis_lucifugus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Mluci2/myoLuc2-tRNAs.fa',
	'nadsonia_fulvescens_var_elongata_dsm_6958'=>'',
	'naegleria_gruberi'=>'',
	'nannizzia_gypsea_cbs_118893'=>'',
	'nannochloropsis_gaditana'=>'',
	'nannospalax_galili'=>'',
	'nasonia_vitripennis'=>'',
	'naumovozyma_castellii_cbs_4309'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Naum_cast_CBS_4309/naumCast_CBS_4309-tRNAs.fa',
	'naumovozyma_dairenensis_cbs_421'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Naum_dair_CBS_421/naumDair_CBS_421-tRNAs.fa',
	'nematocida_displodere'=>'',
	'nematocida_parisii_ertm1'=>'',
	'nematocida_parisii_ertm3'=>'',
	'nematocida_sp_1_ertm2'=>'',
	'nematocida_sp_1_ertm6'=>'',
	'nematocida_sp_ertm5'=>'',
	'nematostella_vectensis'=>'',
	'neofusicoccum_parvum_ucrnp2'=>'',
	'neolecta_irregularis_dah_3'=>'',
	'neolentinus_lepideus_hhb14362_ss_1'=>'',
	'neonectria_ditissima'=>'',
	'neosartorya_fischeri'=>'',
	'neurospora_crassa'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Neur_cras_OR74A/neurCras_OR74A-tRNAs.fa',
	'neurospora_crassa_gca_000786625'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Neur_cras_OR74A/neurCras_OR74A-tRNAs.fa',
	'neurospora_tetrasperma_fgsc_2508'=>'',
	'neurospora_tetrasperma_fgsc_2509'=>'',
	'nomascus_leucogenys'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Nleuc3/nomLeu3-tRNAs.fa',
	'nosema_apis_brl_01'=>'',
	'nosema_bombycis_cq1'=>'',
	'nosema_ceranae'=>'',
	'nosema_ceranae_brl01'=>'',
	'notamacropus_eugenii'=>'',
	'ochotona_princeps'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Oprin3/ochPri3-tRNAs.fa',
	'octodon_degus'=>'',
	'octopus_bimaculoides'=>'',
	'ogataea_parapolymorpha_dl_1'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Ogat_para_DL_1/ogatPara_DL_1-tRNAs.fa',
	'ogataea_polymorpha'=>'',
	'oidiodendron_maius_zn'=>'',
	'onchocerca_volvulus'=>'',
	'ophiocordyceps_sinensis_co18'=>'',
	'ophiocordyceps_unilateralis'=>'',
	'ophiostoma_piceae_uamh_11346'=>'',
	'ordospora_colligata_oc4'=>'',
	'oreochromis_niloticus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Onilo2/oreNil2-tRNAs.fa',
	'ornithorhynchus_anatinus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Oanat1/ornAna1-tRNAs.fa',
	'oryctolagus_cuniculus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Ocuni2/oryCun2-tRNAs.fa',
	'oryza_barthii'=>'',
	'oryza_brachyantha'=>'',
	'oryza_glaberrima'=>'',
	'oryza_glumaepatula'=>'',
	'oryza_indica'=>'',
	'oryza_longistaminata'=>'',
	'oryza_meridionalis'=>'',
	'oryza_nivara'=>'',
	'oryza_punctata'=>'',
	'oryza_rufipogon'=>'',
	'oryza_sativa'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Osati/Osati-tRNAs.fa',
	'oryzias_latipes'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Olati2/',
	'ostreococcus_lucimarinus'=>'',
	'otolemur_garnettii'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Ogarn3/otoGar3-tRNAs.fa',
	'ovis_aries'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Oarie1/oviAri1-tRNAs.fa',
	'pachysolen_tannophilus_nrrl_y_2460'=>'',
	'pan_troglodytes'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Ptrog4/panTro4-tRNAs.fa',
	'papio_anubis'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Panub2/papAnu2-tRNAs.fa',
	'paracoccidioides_brasiliensis'=>'',
	'paracoccidioides_brasiliensis_gca_001713695'=>'',
	'paracoccidioides_brasiliensis_pb03'=>'',
	'paracoccidioides_brasiliensis_pb18'=>'',
	'paracoccidioides_sp_lutzii_pb01'=>'',
	'paramecium_tetraurelia'=>'',
	'paraphaeosphaeria_sporulosa'=>'',
	'parasitella_parasitica'=>'',
	'paulinella_chromatophora'=>'',
	'paxillus_involutus_atcc_200175'=>'',
	'paxillus_rubicundulus_ve08_2h10'=>'',
	'pediculus_humanus'=>'',
	'pelodiscus_sinensis'=>'',
	'penicilliopsis_zonata_cbs_506_65'=>'',
	'penicillium_antarcticum'=>'',
	'penicillium_arizonense'=>'',
	'penicillium_brasilianum'=>'',
	'penicillium_brasilianum_gca_002016555'=>'',
	'penicillium_camemberti_fm_013'=>'',
	'penicillium_chrysogenum'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Peni_chry_P2niaD18/peniChry_P2NIAD18-tRNAs.fa',
	'penicillium_coprophilum'=>'',
	'penicillium_decumbens'=>'',
	'penicillium_digitatum_pd1'=>'',
	'penicillium_digitatum_phi26'=>'',
	'penicillium_expansum'=>'',
	'penicillium_expansum_gca_000769735'=>'',
	'penicillium_expansum_gca_000769745'=>'',
	'penicillium_flavigenum'=>'',
	'penicillium_freii'=>'',
	'penicillium_griseofulvum'=>'',
	'penicillium_italicum'=>'',
	'penicillium_nalgiovense'=>'',
	'penicillium_nordicum'=>'',
	'penicillium_oxalicum_114_2'=>'',
	'penicillium_polonicum'=>'',
	'penicillium_roqueforti_fm164'=>'',
	'penicillium_rubens_wisconsin_54_1255'=>'',
	'penicillium_solitum'=>'',
	'penicillium_steckii'=>'',
	'penicillium_subrubescens'=>'',
	'penicillium_vulpinum'=>'',
	'peniophora_sp_cont'=>'',
	'perkinsus_marinus_atcc_50983'=>'',
	'peromyscus_maniculatus_bairdii'=>'',
	'pestalotiopsis_fici_w106_1'=>'',
	'petromyzon_marinus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Pmari2/petMar2-tRNAs.fa',
	'phaeoacremonium_minimum_ucrpa7'=>'',
	'phaeodactylum_tricornutum'=>'',
	'phaeomoniella_chlamydospora'=>'',
	'phaeosphaeria_nodorum'=>'',
	'phanerochaete_carnosa_hhb_10118_sp'=>'',
	'phialocephala_scopiformis'=>'',
	'phialocephala_subalpina'=>'',
	'phialophora_americana'=>'',
	'phialophora_attae'=>'',
	'phlebia_centrifuga'=>'',
	'phlebiopsis_gigantea_11061_1_cr5_6'=>'',
	'phycomyces_blakesleeanus_nrrl_1555_'=>'',
	'physcomitrella_patens'=>'',
	'phytophthora_infestans'=>'',
	'phytophthora_kernoviae'=>'',
	'phytophthora_lateralis'=>'',
	'phytophthora_parasitica'=>'',
	'phytophthora_parasitica_cj01a1'=>'',
	'phytophthora_parasitica_gca_000509465'=>'',
	'phytophthora_parasitica_gca_000509485'=>'',
	'phytophthora_parasitica_gca_000509505'=>'',
	'phytophthora_parasitica_gca_000509525'=>'',
	'phytophthora_parasitica_inra_310'=>'',
	'phytophthora_parasitica_p10297'=>'',
	'phytophthora_parasitica_p1976'=>'',
	'phytophthora_ramorum'=>'',
	'phytophthora_sojae'=>'',
	'pichia_kudriavzevii'=>'',
	'pichia_kudriavzevii_gca_001983325'=>'',
	'pichia_membranifaciens'=>'',
	'pichia_membranifaciens_nrrl_y_2026'=>'',
	'piloderma_croceum_f_1598'=>'',
	'pisolithus_microcarpus_441'=>'',
	'pisolithus_tinctorius_marx_270'=>'',
	'plasmodium_berghei'=>'',
	'plasmodium_berghei_gca_000005395'=>'',
	'plasmodium_berghei_gca_900044335'=>'',
	'plasmodium_chabaudi'=>'',
	'plasmodium_chabaudi_chabaudi_gca_000003075'=>'',
	'plasmodium_coatneyi'=>'',
	'plasmodium_cynomolgi_strain_b'=>'',
	'plasmodium_falciparum'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_7g8'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_camp_malaysia'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_dd2'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_fch_4'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_hb3'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_igh_cr14'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_malips096_e11'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_nf135_5_c10'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_nf54'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_palo_alto_uganda'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_raj116'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_santa_lucia'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_tanzania_2000708_'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_ugt5_1'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_falciparum_vietnam_oak_knoll_fvo_'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Pfalc/plasFalc1-tRNAs.fa',
	'plasmodium_fragile'=>'',
	'plasmodium_gaboni'=>'',
	'plasmodium_inui_san_antonio_1'=>'',
	'plasmodium_knowlesi'=>'',
	'plasmodium_knowlesi_strain_h_gca_900004885'=>'',
	'plasmodium_malariae'=>'',
	'plasmodium_ovale_curtisi'=>'',
	'plasmodium_reichenowi'=>'',
	'plasmodium_reichenowi_gca_001601855'=>'',
	'plasmodium_vinckei_petteri'=>'',
	'plasmodium_vinckei_vinckei'=>'',
	'plasmodium_vivax'=>'',
	'plasmodium_vivax_brazil_i'=>'',
	'plasmodium_vivax_india_vii'=>'',
	'plasmodium_vivax_mauritania_i'=>'',
	'plasmodium_vivax_north_korean'=>'',
	'plasmodium_yoelii'=>'',
	'plasmodium_yoelii_17x'=>'',
	'plasmodium_yoelii_gca_900002395'=>'',
	'plasmodium_yoelii_yoelii'=>'',
	'plasmopara_halstedii'=>'',
	'pleurotus_ostreatus_pc15'=>'',
	'plicaturopsis_crispa_fd_325_ss_3'=>'',
	'pneumocystis_carinii_b80'=>'',
	'pneumocystis_jirovecii_ru7'=>'',
	'pneumocystis_murina_b123'=>'',
	'pochonia_chlamydosporia_170'=>'',
	'podospora_anserina_s_mat_'=>'',
	'poecilia_formosa'=>'',
	'polysphondylium_pallidum_pn500'=>'',
	'pongo_abelii'=>'',
	'populus_trichocarpa'=>'',
	'postia_placenta_mad_698_r'=>'',
	'procavia_capensis'=>'',
	'prunus_persica'=>'',
	'pseudocercospora_fijiensis_cirad86'=>'',
	'pseudocercospora_musae'=>'',
	'pseudogymnoascus_destructans'=>'',
	'pseudogymnoascus_destructans_20631_21'=>'',
	'pseudogymnoascus_sp_03vt05'=>'',
	'pseudogymnoascus_sp_05ny08'=>'',
	'pseudogymnoascus_sp_23342_1_i1'=>'',
	'pseudogymnoascus_sp_24mn13'=>'',
	'pseudogymnoascus_sp_vkm_f_103'=>'',
	'pseudogymnoascus_sp_vkm_f_3557'=>'',
	'pseudogymnoascus_sp_vkm_f_3775'=>'',
	'pseudogymnoascus_sp_vkm_f_3808'=>'',
	'pseudogymnoascus_sp_vkm_f_4246'=>'',
	'pseudogymnoascus_sp_vkm_f_4281_fw_2241_'=>'',
	'pseudogymnoascus_sp_vkm_f_4513_fw_928_'=>'',
	'pseudogymnoascus_sp_vkm_f_4514_fw_929_'=>'',
	'pseudogymnoascus_sp_vkm_f_4515_fw_2607_'=>'',
	'pseudogymnoascus_sp_vkm_f_4516_fw_969_'=>'',
	'pseudogymnoascus_sp_vkm_f_4517_fw_2822_'=>'',
	'pseudogymnoascus_sp_vkm_f_4518_fw_2643_'=>'',
	'pseudogymnoascus_sp_vkm_f_4519_fw_2642_'=>'',
	'pseudogymnoascus_sp_vkm_f_4520_fw_2644_'=>'',
	'pseudogymnoascus_sp_wsf_3629'=>'',
	'pseudogymnoascus_verrucosus'=>'',
	'pseudoloma_neurophilia'=>'',
	'pseudozyma_hubeiensis_sy62'=>'',
	'pteropus_vampyrus'=>'',
	'puccinia_graminis'=>'',
	'puccinia_graminisug99'=>'',
	'puccinia_sorghi'=>'',
	'puccinia_striiformis'=>'',
	'puccinia_striiformis_f_sp_tritici_pst_78'=>'',
	'puccinia_triticina'=>'',
	'punctularia_strigosozonata_hhb_11173_ss5'=>'',
	'purpureocillium_lilacinum'=>'',
	'purpureocillium_lilacinum_gca_001653265'=>'',
	'pyrenochaeta_sp_ds3say3a'=>'',
	'pyrenophora_teres'=>'',
	'pyrenophora_triticirepentis'=>'',
	'pyronema_omphalodes_cbs_100304'=>'',
	'pythium_aphanidermatum'=>'',
	'pythium_arrhenomanes'=>'',
	'pythium_irregulare'=>'',
	'pythium_iwayamai'=>'',
	'pythium_ultimum'=>'',
	'pythium_vexans'=>'',
	'rachicladosporium_antarcticum'=>'',
	'rasamsonia_emersonii_cbs_393_64'=>'',
	'rattus_norvegicus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Rnorv5/rn5-tRNAs.fa',
	'reticulomyxa_filosa'=>'',
	'rhinocladiella_mackenziei_cbs_650_93'=>'',
	'rhizoctonia_solani'=>'',
	'rhizoctonia_solani_123e'=>'',
	'rhizoctonia_solani_ag_1_ia'=>'',
	'rhizoctonia_solani_ag_1_ib'=>'',
	'rhizoctonia_solani_ag_3_rhs1ap'=>'',
	'rhizoctonia_solani_ag_8_wac10335'=>'',
	'rhizophagus_irregularis_daom_181602_gca_000439145'=>'',
	'rhizopogon_vesiculosus'=>'',
	'rhizopogon_vinicolor_am_or11_026'=>'',
	'rhizopus_delemar_ra_99_880'=>'',
	'rhizopus_microsporus'=>'',
	'rhizopus_microsporus_var_microsporus'=>'',
	'rhodnius_prolixus'=>'',
	'rhodotorula_graminis_wp1'=>'',
	'rhodotorula_sp_jg_1b'=>'',
	'rhodotorula_toruloides'=>'',
	'rhodotorula_toruloides_atcc_204091'=>'',
	'rhodotorula_toruloides_np11'=>'',
	'rhynchosporium_agropyri'=>'',
	'rhynchosporium_commune'=>'',
	'rhynchosporium_secalis'=>'',
	'rozella_allomycis_csf55'=>'',
	'saccharomyces_arboricola_h_6'=>'',
	'saccharomyces_cerevisiae'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_awri796'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_cen_pk113_7d'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_ec1118'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_fostersb'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_fosterso'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_gca_000091065'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_gca_001634645'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_gca_001983315'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_kyokai_no_7'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_lalvin_qa23'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_p283'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_p301'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_r008'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_r103'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_rm11_1a'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_vin13'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_vl3'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_x_saccharomyces_kudriavzevii_vin7'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1078'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1083'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1129'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1133'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1190'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1199'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1202'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1208'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1242'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1244'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1248'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1250'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1252'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1273'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1304'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1307'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1311'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1326'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1332'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1336'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1338'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1341'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1342'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1355'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1356'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1381'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1383'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1385'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1386'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1387'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1388'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1389'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1399'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1400'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1401'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1402'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1415'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1417'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1418'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1419'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1433'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1434'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1439'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1443'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1444'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1447'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1450'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1460'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1463'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1477'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1478'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1479'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1526'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1527'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1549'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1573'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1574'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1592'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm1615'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm189'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm193'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm195'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm244'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm248'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm270'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm271'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm320'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm326'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm428'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm450'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm451'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm453'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm456'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm470'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm541'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm554'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm555'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm627'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm681'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm682'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm683'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm689'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm693'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm789'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm969'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm972'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm975'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm978'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm981'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm984'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm987'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm990'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm993'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_cerevisiae_yjm996'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Scere3/sacCer3-tRNAs.fa',
	'saccharomyces_eubayanus'=>'',
	'saccharomyces_kudriavzevii_ifo_1802'=>'',
	'saccharomyces_sp_boulardii_'=>'',
	'saccharomyces_sp_boulardii__gca_001413975'=>'',
	'saccharomycetaceae_sp_ashbya_aceri_'=>'',
	'saitoella_complicata_nrrl_y_17804'=>'',
	'saitoella_complicata_nrrl_y_17804_gca_001661265'=>'',
	'salpingoeca_rosetta'=>'',
	'saprolegnia_diclina_vs20'=>'',
	'saprolegnia_parasitica_cbs_223_65'=>'',
	'sarcophilus_harrisii'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Sharr1/sarHar1-tRNAs.fa',
	'sarcoptes_scabiei'=>'',
	'scedosporium_apiospermum'=>'',
	'scheffersomyces_stipitis_cbs_6054'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Sche_stip_CBS_6054/scheStip_CBS_6054-tRNAs.fa',
	'schistosoma_mansoni'=>'',
	'schizophyllum_commune_h4_8'=>'',
	'schizopora_paradoxa'=>'',
	'schizosaccharomyces_cryophilus'=>'',
	'schizosaccharomyces_japonicus'=>'',
	'schizosaccharomyces_octosporus'=>'',
	'schizosaccharomyces_pombe'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Schi_pomb_972h/schiPomb_972H-tRNAs.fa',
	'scleroderma_citrinum_foug_a'=>'',
	'sclerotinia_borealis_f_4128'=>'',
	'sclerotinia_sclerotiorum'=>'',
	'sclerotinia_sclerotiorum_1980_uf_70'=>'',
	'selaginella_moellendorffii'=>'',
	'serendipita_indica_dsm_11827'=>'',
	'serendipita_vermifera_maff_305830'=>'',
	'serpula_lacrymans_var_lacrymans_s7_3'=>'',
	'serpula_lacrymans_var_lacrymans_s7_9'=>'',
	'setaria_italica'=>'',
	'setosphaeria_turcica_et28a'=>'',
	'sistotremastrum_niveocremeum_hhb9708'=>'',
	'sistotremastrum_suecicum_hhb10207_ss_3'=>'',
	'solanum_lycopersicum'=>'',
	'solanum_tuberosum'=>'',
	'solenopsis_invicta'=>'',
	'sordaria_macrospora'=>'',
	'sorex_araneus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Saran2/sorAra2-tRNAs.fa',
	'sorghum_bicolor'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Sbico/Sbico-tRNAs.fa',
	'spathaspora_passalidarum_nrrl_y_27907'=>'',
	'sphaerobolus_stellatus_ss14'=>'',
	'sphaeroforma_arctica_jp610'=>'',
	'sphaerulina_musiva_so2202'=>'',
	'spironucleus_salmonicida'=>'',
	'spizellomyces_punctatus_daom_br117'=>'',
	'sporidiobolus_salmonicolor'=>'',
	'sporisorium_reilianum'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Spor_reil_SRZ2/sporReil_SRZ2-tRNAs.fa',
	'sporisorium_scitamineum'=>'',
	'sporothrix_brasiliensis_5110'=>'',
	'sporothrix_insectorum_rcef_264'=>'',
	'sporothrix_schenckii_1099_18'=>'',
	'sporothrix_schenckii_atcc_58251'=>'',
	'spraguea_lophii_42_110'=>'',
	'stachybotrys_chartarum_ibt_40288'=>'',
	'stachybotrys_chartarum_ibt_40293'=>'',
	'stachybotrys_chartarum_ibt_7711'=>'',
	'stachybotrys_chlorohalonata_ibt_40285'=>'',
	'stagonospora_sp_src1lsm3a'=>'',
	'stegodyphus_mimosarum'=>'',
	'stemphylium_lycopersici'=>'',
	'stereum_hirsutum_fp_91666_ss1'=>'',
	'strigamia_maritima'=>'',
	'strigomonas_culicis'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/bacteria/Cand_Kine_blastocrithidii_ex_Strigomonas_culicis/candKine_BLASTOCRITHIDII_EX_ST-tRNAs.fa',
	'strongylocentrotus_purpuratus'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Spurp/Spurp-tRNAs.fa',
	'sugiyamaella_lignohabitans'=>'',
	'suillus_luteus_uh_slu_lm8_n1'=>'',
	'sus_scrofa'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Sscro3/susScr3-tRNAs.fa',
	'taeniopygia_guttata'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Tgutt2/taeGut2-tRNAs.fa',
	'takifugu_rubripes'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Trubr3/fr3-tRNAs.fa',
	'talaromyces_cellulolyticus'=>'',
	'talaromyces_islandicus'=>'',
	'talaromyces_marneffei_atcc_18224'=>'',
	'talaromyces_marneffei_pm1'=>'',
	'talaromyces_stipitatus_atcc_10500'=>'',
	'termitomyces_sp_j132'=>'',
	'tetrahymena_thermophila'=>'',
	'tetranychus_urticae'=>'',
	'tetraodon_nigroviridis'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Tnigr2/tetNig2-tRNAs.fa',
	'tetrapisispora_blattae_cbs_6284'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Tetr_blat_CBS_6284/tetrBlat_CBS_6284-tRNAs.fa',
	'tetrapisispora_phaffii_cbs_4417'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Tetr_phaf_CBS_4417/tetrPhaf_CBS_4417-tRNAs.fa',
	'thalassiosira_oceanica'=>'',
	'thalassiosira_oceanica_ccmp1005'=>'',
	'thalassiosira_pseudonana'=>'',
	'thecamonas_trahens_atcc_50062'=>'',
	'theileria_annulata'=>'',
	'theileria_equi_strain_wa'=>'',
	'theileria_orientalis_strain_shintoku'=>'',
	'theileria_parva'=>'',
	'thelohanellus_kitauei'=>'',
	'theobroma_cacao'=>'',
	'thermothelomyces_thermophila_atcc_42464'=>'',
	'thielavia_terrestris_nrrl_8126'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Thie_terr_NRRL_8126/thieTerr_NRRL_8126-tRNAs.fa',
	'thielaviopsis_punctulata'=>'',
	'tilletia_caries'=>'',
	'tilletia_controversa'=>'',
	'tilletia_indica'=>'',
	'tilletia_walkeri'=>'',
	'tilletiaria_anomala_ubc_951'=>'',
	'tolypocladium_ophioglossoides_cbs_100239'=>'',
	'torrubiella_hemipterigena'=>'',
	'tortispora_caseinolytica_nrrl_y_17796'=>'',
	'torulaspora_delbrueckii'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Toru_delb_CBS_1146/toruDelb_CBS_1146-tRNAs.fa',
	'toxoplasma_gondii'=>'',
	'toxoplasma_gondii_ari'=>'',
	'toxoplasma_gondii_fou'=>'',
	'toxoplasma_gondii_gab2_2007_gal_dom2'=>'',
	'toxoplasma_gondii_gt1'=>'',
	'toxoplasma_gondii_mas'=>'',
	'toxoplasma_gondii_p89'=>'',
	'toxoplasma_gondii_rub'=>'',
	'toxoplasma_gondii_tgcatprc2'=>'',
	'toxoplasma_gondii_vand'=>'',
	'toxoplasma_gondii_veg'=>'',
	'trachipleistophora_hominis'=>'',
	'trametes_cinnabarina'=>'',
	'trametes_pubescens'=>'',
	'trametes_versicolor_fp_101664_ss1'=>'',
	'tremella_mesenterica_dsm_1558'=>'',
	'tribolium_castaneum'=>'',
	'trichoderma_atroviride_imi_206040'=>'',
	'trichoderma_gamsii'=>'',
	'trichoderma_guizhouense'=>'',
	'trichoderma_harzianum'=>'',
	'trichoderma_reesei'=>'',
	'trichoderma_reesei_rut_c_30'=>'',
	'trichoderma_virens'=>'',
	'trichomonas_vaginalis_g3'=>'',
	'trichophyton_benhamiae_cbs_112371'=>'',
	'trichophyton_equinum_cbs_127_97'=>'',
	'trichophyton_interdigitale_h6'=>'',
	'trichophyton_interdigitale_mr816'=>'',
	'trichophyton_rubrum'=>'',
	'trichophyton_rubrum_cbs_100081'=>'',
	'trichophyton_rubrum_cbs_118892'=>'',
	'trichophyton_rubrum_cbs_202_88'=>'',
	'trichophyton_rubrum_cbs_288_86'=>'',
	'trichophyton_rubrum_cbs_289_86'=>'',
	'trichophyton_rubrum_cbs_735_88'=>'',
	'trichophyton_rubrum_d6'=>'',
	'trichophyton_rubrum_mr1448'=>'',
	'trichophyton_rubrum_mr1459'=>'',
	'trichophyton_rubrum_mr850'=>'',
	'trichophyton_soudanense_cbs_452_61'=>'',
	'trichophyton_tonsurans_cbs_112818'=>'',
	'trichophyton_verrucosum_hki_0517'=>'',
	'trichophyton_violaceum'=>'',
	'trichoplax_adhaerens'=>'',
	'trichosporon_asahii_var_asahii_cbs_2479'=>'',
	'trichosporon_asahii_var_asahii_cbs_8904'=>'',
	'trifolium_pratense'=>'',
	'triticum_aestivum'=>'',
	'triticum_urartu'=>'',
	'trypanosoma_brucei'=>'',
	'trypanosoma_cruzi'=>'',
	'trypanosoma_cruzi_dm28c'=>'',
	'tsuchiyaea_wingfieldii_cbs_7118'=>'',
	'tuber_melanosporum'=>'',
	'tulasnella_calospora_mut_4182'=>'',
	'tupaia_belangeri'=>'',
	'tursiops_truncatus'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Ttrun2/turTru2-tRNAs.fa',
	'umbilicaria_pustulata'=>'',
	'uncinocarpus_reesii_1704'=>'',
	'ustilaginoidea_virens'=>'',
	'ustilaginoidea_virens_gca_000965225'=>'',
	'ustilago_bromivora'=>'',
	'ustilago_hordei'=>'',
	'ustilago_maydis'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Usti_mayd_521/ustiMayd_521-tRNAs.fa',
	'valsa_mali'=>'',
	'valsa_mali_var_pyri'=>'',
	'vanderwaltozyma_polyspora_dsm_70294'=>'',
	'vavraia_culicis_subsp_floridensis'=>'',
	'verruconis_gallopava'=>'',
	'verticillium_alfalfae_vams_102'=>'',
	'verticillium_dahliae'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Vert_dahl_VdLs_17/vertDahl_VDLS_17-tRNAs.fa',
	'verticillium_dahliaejr2'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Vert_dahl_JR2/vertDahl_JR2-tRNAs.fa',
	'verticillium_longisporum'=>'',
	'verticillium_longisporum_gca_001268145'=>'',
	'vicugna_pacos'=>'',
	'vitis_vinifera'=>'',
	'vitrella_brassicaformis_ccmp3155'=>'',
	'vittaforma_corneae_atcc_50505'=>'',
	'wallemia_ichthyophaga_exf_994'=>'',
	'wallemia_mellicola_cbs_633_66'=>'',
	'wickerhamomyces_anomalus_nrrl_y_366_8'=>'',
	'wickerhamomyces_ciferrii'=>'',
	'xanthophyllomyces_dendrorhous'=>'',
	'xenopus_tropicalis'=>'http://gtrnadb.ucsc.edu/genomes/eukaryota/Xtrop3/xenTro3-tRNAs.fa',
	'xiphophorus_maculatus'=>'',
	'xylona_heveae_tc161'=>'',
	'yarrowia_lipolytica'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Yarr_lipo_CLIB122/yarrLipo_CLIB122-tRNAs.fa',
	'yarrowia_lipolytica_gca_001761485'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Yarr_lipo_CLIB122/yarrLipo_CLIB122-tRNAs.fa',
	'zea_mays'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Zmays5/zeaMay5-tRNAs.fa',
	'zootermopsis_nevadensis'=>'',
	'zygosaccharomyces_bailii_isa1307'=>'',
	'zygosaccharomyces_parabailii'=>'',
	'zygosaccharomyces_rouxii'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Zygo_roux_CBS_732/zygoRoux_CBS_732-tRNAs.fa',
	'zygosaccharomyces_rouxii_gca_001972345'=>'http://gtrnadb.ucsc.edu/GtRNAdb2/genomes/eukaryota/Zygo_roux_CBS_732/zygoRoux_CBS_732-tRNAs.fa',
	'zymoseptoria_brevis'=>'',
	'zymoseptoria_tritici'=>'',
	);### TRNA URLS END ###
			}

		if(length$gtRNAdb_urls{$species}>0)
			{
			if(!$silent){print"\nDownload tRNA data for $species{$species} from Genomic tRNA database...";}
			$status=getstore("$gtRNAdb_urls{$species}","UNITAS_refdump_$species/gtRNAdb");
			if(is_success($status))
				{
				if(!$silent){print" OK. Database date: $mday.$mon.$year (dd.mm.yyyy)";}
				$db_versions_info.="Genomic tRNA database version/date: ....... $mday.$mon.$year (dd.mm.yyyy)\n";
				}
			else
				{
				if(!$silent){print" FAILED! $status. Download data from smallRNAgroup-SERVER...";}
				$status=getstore("http://www.smallrnagroup.uni-mainz.de/data/UNITAS/gtRNAdb/gtRNAdb_$species.fasta","UNITAS_refdump_$species/gtRNAdb");
				$version=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/gtRNAdb/release');
				$db_versions_info.="Genomic tRNA database version/date: ....... $version (dd.mm.yyyy)\n";
				if(is_success($status))
					{
					if(!$silent){print" OK.";}
					}
				else
					{
					if(!$silent){print" FAILED! $status.\n\n";}
					}
				}
			if(!$silent){print"\nProcess data from gtRNAdb...";}
			open(GTRNADB,"UNITAS_refdump_$species/gtRNAdb")||die print"\nERROR! Unable to read UNITAS_refdump_$species/gtRNAdb.\n$!\n\n";
			%gtRNAdb=();
			$i=0;
			while(<GTRNADB>)
				{
				$_=~s/\s*$//;
				if($_=~/^>/)
					{
					$_=~s/tRNA[^ ]+//i;
					$id=$&;
					$i++;
					}
				else
					{
					$gtRNAdb{$id}.=$_;
					}
				}
			close GTRNADB;
			if(!$silent){print" OK ($i sequences loaded).";}
			}
		else
			{
			if(!$silent){print"\nNo tRNA data for $species{$species} at Genomic tRNA database -> SKIP.";}
			$version=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/gtRNAdb/release');
			$db_versions_info.="Genomic tRNA database version/date: ....... $version (dd.mm.yyyy)\n";
			}

		# download piRNA cluster sequences from piRNA cluster database (value may contain more than one URL, separated by whitespace)
		if(!$skip_piR)
			{
			$eval_URL="";
			$eval_URL=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/URLs/piRclDB');
			if(length$eval_URL>0)
				{
				eval$eval_URL;
				}
			else
				{
				if(!$silent){print"\nFailed to load current piRNA cluster database URLs from smallRNAgroup-SERVER. Use internal list.";}
### PIRCLDB URLS START ###
%piRclDB_urls=
	(
	'_candida_auris'=>'',
	'_candida_glabrata'=>'',
	'_candida_glabrata_gca_001466525'=>'',
	'_candida_glabrata_gca_001466535'=>'',
	'_candida_glabrata_gca_001466565'=>'',
	'_candida_glabrata_gca_001466575'=>'',
	'_candida_glabrata_gca_001466635'=>'',
	'_candida_glabrata_gca_001466685'=>'',
	'_candida_intermedia'=>'',
	'_candida_intermedia_gca_900106125'=>'',
	'_candida_tenuis_atcc_10573'=>'',
	'absidia_glauca'=>'',
	'acidomyces_richmondensis'=>'',
	'acidomyces_richmondensis_bfw'=>'',
	'acremonium_chrysogenum_atcc_11550'=>'',
	'acyrthosiphon_pisum'=>'',
	'adineta_vaga'=>'',
	'aedes_aegypti'=>'',
	'aegilops_tauschii'=>'',
	'agaricus_bisporus_var_burnettii_jb137_s8'=>'',
	'ailuropoda_melanoleuca'=>'',
	'albugo_laibachii'=>'',
	'allomyces_macrogynus_atcc_38327'=>'',
	'alternaria_alternata'=>'',
	'amanita_muscaria_koide_bx008'=>'',
	'amborella_trichopoda'=>'',
	'amphiamblys_sp_wsbs2006'=>'',
	'amphimedon_queenslandica'=>'',
	'anas_platyrhynchos'=>'',
	'angomonas_deanei'=>'',
	'anncaliia_algerae_pra109'=>'',
	'anncaliia_algerae_pra339'=>'',
	'anolis_carolinensis'=>'',
	'anopheles_darlingi'=>'',
	'anopheles_gambiae'=>'',
	'anoplophora_glabripennis'=>'',
	'anthracocystis_flocculosa_pf_1'=>'',
	'aphanomyces_astaci'=>'',
	'aphanomyces_invadans'=>'',
	'apis_mellifera'=>'',
	'arabidopsis_lyrata'=>'',
	'arabidopsis_thaliana'=>'',
	'arthrobotrys_oligospora_atcc_24927'=>'',
	'arthroderma_otae_cbs_113480'=>'',
	'aschersonia_aleyrodis_rcef_2490'=>'',
	'ascochyta_rabiei'=>'',
	'ascoidea_rubescens_dsm_1968'=>'',
	'ascosphaera_apis_arsef_7405'=>'',
	'ashbya_gossypii'=>'',
	'aspergillus_aculeatus_atcc_16872'=>'',
	'aspergillus_bombycis'=>'',
	'aspergillus_brasiliensis_cbs_101740'=>'',
	'aspergillus_calidoustus'=>'',
	'aspergillus_carbonarius_item_5010'=>'',
	'aspergillus_clavatus'=>'',
	'aspergillus_cristatus'=>'',
	'aspergillus_flavus'=>'',
	'aspergillus_flavus_af70'=>'',
	'aspergillus_fumigatus'=>'',
	'aspergillus_fumigatus_var_rp_2014'=>'',
	'aspergillus_fumigatus_z5'=>'',
	'aspergillus_fumigatusa1163'=>'',
	'aspergillus_glaucus_cbs_516_65'=>'',
	'aspergillus_lentulus'=>'',
	'aspergillus_luchuensis'=>'',
	'aspergillus_luchuensis_cbs_106_47'=>'',
	'aspergillus_nidulans'=>'',
	'aspergillus_nidulans_fgsc_a4'=>'',
	'aspergillus_niger'=>'',
	'aspergillus_niger_atcc_1015'=>'',
	'aspergillus_niger_gca_001515345'=>'',
	'aspergillus_nomius_nrrl_13137'=>'',
	'aspergillus_ochraceoroseus'=>'',
	'aspergillus_oryzae'=>'',
	'aspergillus_oryzae_100_8'=>'',
	'aspergillus_oryzae_3_042'=>'',
	'aspergillus_oryzae_gca_002007945'=>'',
	'aspergillus_parasiticus_su_1'=>'',
	'aspergillus_rambellii'=>'',
	'aspergillus_ruber_cbs_135680'=>'',
	'aspergillus_sydowii_cbs_593_65'=>'',
	'aspergillus_terreus'=>'',
	'aspergillus_tubingensis_cbs_134_48'=>'',
	'aspergillus_udagawae'=>'',
	'aspergillus_ustus'=>'',
	'aspergillus_versicolor_cbs_583_65'=>'',
	'aspergillus_wentii_dto_134e9'=>'',
	'astyanax_mexicanus'=>'',
	'atta_cephalotes'=>'',
	'aureobasidium_melanogenum_cbs_110374'=>'',
	'aureobasidium_namibiae_cbs_147_97'=>'',
	'aureobasidium_pullulans'=>'',
	'aureobasidium_pullulans_exf_150'=>'',
	'aureobasidium_subglaciale_exf_2481'=>'',
	'babesia_bovis'=>'',
	'babesia_microti_strain_ri'=>'',
	'babjeviella_inositovora_nrrl_y_12698'=>'',
	'batrachochytrium_dendrobatidis_jam81'=>'',
	'batrachochytrium_dendrobatidis_jel423'=>'',
	'batrachochytrium_salamandrivorans'=>'',
	'baudoinia_panamericana_uamh_10762'=>'',
	'beauveria_bassiana'=>'',
	'beauveria_bassiana_arsef_2860'=>'',
	'beauveria_bassiana_d1_5'=>'',
	'belgica_antarctica'=>'',
	'beta_vulgaris'=>'',
	'bigelowiella_natans'=>'',
	'bigelowiella_natans_gca_000002455'=>'',
	'bipolaris_maydis_atcc_48331'=>'',
	'bipolaris_maydis_c5'=>'',
	'bipolaris_oryzae_atcc_44560'=>'',
	'bipolaris_sorokiniana_nd90pr'=>'',
	'bipolaris_victoriae_fi3'=>'',
	'bipolaris_zeicola_26_r_13'=>'',
	'blastomyces_dermatitidis_atcc_18188'=>'',
	'blastomyces_dermatitidis_atcc_26199'=>'',
	'blastomyces_dermatitidis_er_3'=>'',
	'blastomyces_gilchristii_slh14081'=>'',
	'blastomyces_percursus'=>'',
	'blumeria_graminis'=>'',
	'blumeria_graminis_f_sp_tritici_96224'=>'',
	'bodo_saltans'=>'',
	'bombus_impatiens'=>'',
	'bombyx_mori'=>'',
	'bos_taurus'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/bos_taurus/proTRAC_IVF_embryo_generic/clusters.fasta http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/bos_taurus/proTRAC_normal_testis_generic/clusters.fasta http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/bos_taurus/proTRAC_oocytes_generic/clusters.fasta',
	'botryobasidium_botryosum_fd_172_ss1'=>'',
	'botrytis_cinerea'=>'',
	'botrytis_cinerea_bcdw1'=>'',
	'botrytis_cinerea_t4'=>'',
	'brachypodium_distachyon'=>'',
	'brassica_napus'=>'',
	'brassica_oleracea'=>'',
	'brassica_rapa'=>'',
	'brettanomyces_bruxellensis_awri1499'=>'',
	'brugia_malayi'=>'',
	'byssochlamys_spectabilis_no_5'=>'',
	'caenorhabditis_brenneri'=>'',
	'caenorhabditis_briggsae'=>'',
	'caenorhabditis_elegans'=>'',
	'caenorhabditis_japonica'=>'',
	'caenorhabditis_remanei'=>'',
	'callithrix_jacchus'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/callithrix_jacchus/proTRAC_normal_testis_generic/clusters.fasta',
	'calocera_cornea_hhb12733'=>'',
	'calocera_viscosa_tufc12733'=>'',
	'candida_albicans_12c'=>'',
	'candida_albicans_19f'=>'',
	'candida_albicans_ca6'=>'',
	'candida_albicans_gc75'=>'',
	'candida_albicans_l26'=>'',
	'candida_albicans_p34048'=>'',
	'candida_albicans_p37005'=>'',
	'candida_albicans_p37037'=>'',
	'candida_albicans_p37039'=>'',
	'candida_albicans_p57055'=>'',
	'candida_albicans_p57072'=>'',
	'candida_albicans_p60002'=>'',
	'candida_albicans_p75010'=>'',
	'candida_albicans_p75016'=>'',
	'candida_albicans_p75063'=>'',
	'candida_albicans_p76055'=>'',
	'candida_albicans_p76067'=>'',
	'candida_albicans_p78042'=>'',
	'candida_albicans_p78048'=>'',
	'candida_albicans_p87'=>'',
	'candida_albicans_p94015'=>'',
	'candida_albicans_sc5314'=>'',
	'candida_albicans_sc5314_gca_000182965'=>'',
	'candida_albicans_sc5314_gca_000784655'=>'',
	'candida_albicans_wo_1'=>'',
	'candida_arabinofermentans_nrrl_yb_2248'=>'',
	'candida_dubliniensis_cd36'=>'',
	'candida_maltosa_xu316'=>'',
	'candida_orthopsilosis_co_90_125'=>'',
	'candida_parapsilosis_cdc317'=>'',
	'candida_tanzawaensis_nrrl_y_17324'=>'',
	'candida_tropicalis_mya_3404'=>'',
	'canis_familiaris'=>'',
	'capitella_teleta'=>'',
	'capronia_coronata_cbs_617_96'=>'',
	'capronia_epimyces_cbs_606_96'=>'',
	'capsaspora_owczarzaki_atcc_30864'=>'',
	'carlito_syrichta'=>'',
	'cavia_aperea'=>'',
	'cavia_porcellus'=>'',
	'ceraceosorus_bombacis'=>'',
	'ceratocystis_platani'=>'',
	'chaetomium_globosum_cbs_148_51'=>'',
	'chaetomium_thermophilum_var_thermophilum_dsm_1495'=>'',
	'chinchilla_lanigera'=>'',
	'chlamydomonas_reinhardtii'=>'',
	'chlorocebus_sabaeus'=>'',
	'choloepus_hoffmanni'=>'',
	'chondrus_crispus'=>'',
	'chroomonas_mesostigmatica_ccmp1168'=>'',
	'ciona_intestinalis'=>'',
	'ciona_savignyi'=>'',
	'cladophialophora_bantiana_cbs_173_52'=>'',
	'cladophialophora_carrionii'=>'',
	'cladophialophora_carrionii_cbs_160_54'=>'',
	'cladophialophora_immunda'=>'',
	'cladophialophora_psammophila_cbs_110553'=>'',
	'cladophialophora_yegresii_cbs_114405'=>'',
	'claviceps_purpurea_20_1'=>'',
	'clavispora_lusitaniae_atcc_42720'=>'',
	'coccidioides_immitis_h538_4'=>'',
	'coccidioides_immitis_rmscc_2394'=>'',
	'coccidioides_immitis_rmscc_3703'=>'',
	'coccidioides_immitis_rs'=>'',
	'coccidioides_posadasii_c735_delta_sowgp'=>'',
	'coccidioides_posadasii_rmscc_3488'=>'',
	'coccidioides_posadasii_str_silveira'=>'',
	'colletotrichum_chlorophyti'=>'',
	'colletotrichum_fioriniae_pj7'=>'',
	'colletotrichum_gloeosporioides'=>'',
	'colletotrichum_gloeosporioides_cg_14'=>'',
	'colletotrichum_graminicola'=>'',
	'colletotrichum_higginsianum'=>'',
	'colletotrichum_higginsianum_imi_349063'=>'',
	'colletotrichum_incanum'=>'',
	'colletotrichum_incanum_gca_001855235'=>'',
	'colletotrichum_nymphaeae_sa_01'=>'',
	'colletotrichum_orbiculare'=>'',
	'colletotrichum_orchidophilum'=>'',
	'colletotrichum_salicis'=>'',
	'colletotrichum_simmondsii'=>'',
	'colletotrichum_sublineola'=>'',
	'colletotrichum_tofieldiae'=>'',
	'conidiobolus_coronatus_nrrl_28638'=>'',
	'coniochaeta_ligniaria_nrrl_30616'=>'',
	'coniophora_puteana_rwd_64_598_ss2'=>'',
	'coniosporium_apollinis_cbs_100218'=>'',
	'coprinopsis_cinerea_okayama7_130'=>'',
	'corchorus_capsularis'=>'',
	'cordyceps_brongniartii_rcef_3172'=>'',
	'cordyceps_confragosa'=>'',
	'cordyceps_confragosa_rcef_1005'=>'',
	'cordyceps_militaris_cm01'=>'',
	'crassostrea_gigas'=>'',
	'cricetulus_griseus_chok1gshd'=>'',
	'cricetulus_griseus_crigri'=>'',
	'cryptococcus_amylolentus_cbs_6039'=>'',
	'cryptococcus_amylolentus_cbs_6273'=>'',
	'cryptococcus_depauperatus_cbs_7841'=>'',
	'cryptococcus_depauperatus_cbs_7855'=>'',
	'cryptococcus_gattii_ca1280'=>'',
	'cryptococcus_gattii_ca1873'=>'',
	'cryptococcus_gattii_e566'=>'',
	'cryptococcus_gattii_ejb2'=>'',
	'cryptococcus_gattii_nt_10'=>'',
	'cryptococcus_gattii_ru294'=>'',
	'cryptococcus_gattii_vgii_2001_935_1'=>'',
	'cryptococcus_gattii_vgii_99_473'=>'',
	'cryptococcus_gattii_vgii_ca1014'=>'',
	'cryptococcus_gattii_vgii_cbs_10090'=>'',
	'cryptococcus_gattii_vgii_la55'=>'',
	'cryptococcus_gattii_vgii_mmrl2647'=>'',
	'cryptococcus_gattii_vgii_r265'=>'',
	'cryptococcus_gattii_vgii_ram5'=>'',
	'cryptococcus_gattii_vgiv_ind107'=>'',
	'cryptococcus_gattii_wm276'=>'',
	'cryptococcus_neoformans'=>'',
	'cryptococcus_neoformans_var_grubii_h99'=>'',
	'cryptococcus_neoformans_var_neoformans_b_3501a'=>'',
	'cryptomonas_paramecium'=>'',
	'cryptosporidium_muris_rn66'=>'',
	'cryptosporidium_parvum'=>'',
	'cryptosporidium_parvum_iowa_ii'=>'',
	'culex_quinquefasciatus'=>'',
	'cutaneotrichosporon_oleaginosus'=>'',
	'cyberlindnera_fabianii'=>'',
	'cyberlindnera_jadinii'=>'',
	'cyberlindnera_jadinii_nrrl_y_1542'=>'',
	'cyclospora_cayetanensis'=>'',
	'cylindrobasidium_torrendii_fp15055_ss_10'=>'',
	'cyphellophora_europaea_cbs_101466'=>'',
	'dacryopinax_primogenitus'=>'',
	'dactylellina_haptotyla_cbs_200_50'=>'',
	'daedalea_quercina_l_15889'=>'',
	'danaus_plexippus'=>'',
	'danio_rerio'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/danio_rerio/proTRAC_normal_testis_generic/clusters.fasta http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/danio_rerio/proTRAC_normal_ovary_generic/clusters.fasta',
	'daphnia_pulex'=>'',
	'dasypus_novemcinctus'=>'',
	'debaryomyces_fabryi'=>'',
	'debaryomyces_hansenii_cbs767'=>'',
	'dendroctonus_ponderosae'=>'',
	'diaporthe_ampelina'=>'',
	'diaporthe_helianthi'=>'',
	'dichomitus_squalens_lyad_421_ss1'=>'',
	'dictyostelium_discoideum'=>'',
	'dictyostelium_fasciculatum'=>'',
	'dictyostelium_lacteum'=>'',
	'diplodia_corticola'=>'',
	'diplodia_seriata'=>'',
	'diplodia_seriata_gca_001975905'=>'',
	'dipodomys_ordii'=>'',
	'dothistroma_septosporum'=>'',
	'drechmeria_coniospora'=>'',
	'drechslerella_stenobrocha_248'=>'',
	'drosophila_ananassae'=>'',
	'drosophila_erecta'=>'',
	'drosophila_grimshawi'=>'',
	'drosophila_melanogaster'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/drosophila_melanogaster/proTRAC_normal_ovary_generic/clusters_rDNAremoved.fasta',
	'drosophila_mojavensis'=>'',
	'drosophila_persimilis'=>'',
	'drosophila_pseudoobscura'=>'',
	'drosophila_sechellia'=>'',
	'drosophila_simulans'=>'',
	'drosophila_virilis'=>'',
	'drosophila_willistoni'=>'',
	'drosophila_yakuba'=>'',
	'echinops_telfairi'=>'',
	'edhazardia_aedis_usnm_41457'=>'',
	'eimeria_brunetti'=>'',
	'eimeria_maxima'=>'',
	'eimeria_mitis'=>'',
	'eimeria_praecox'=>'',
	'eimeria_tenella'=>'',
	'eimeria_tenella_gca_000499545'=>'',
	'emergomyces_pasteuriana_ep9510'=>'',
	'emiliania_huxleyi'=>'',
	'emmonsia_crescens_uamh_3008'=>'',
	'emmonsia_parva_uamh_139'=>'',
	'emmonsia_sp_cac_2015a'=>'',
	'encephalitozoon_cuniculi_ecuniii_l'=>'',
	'encephalitozoon_cuniculi_gb_m1'=>'',
	'encephalitozoon_hellem_atcc_50504'=>'',
	'encephalitozoon_intestinalis_atcc_50506'=>'',
	'encephalitozoon_romaleae_sj_2008'=>'',
	'endocarpon_pusillum_z07020'=>'',
	'entamoeba_histolytica'=>'',
	'entamoeba_histolytica_gca_001662325'=>'',
	'entamoeba_histolytica_hm_3_imss'=>'',
	'entamoeba_histolytica_ku27'=>'',
	'entamoeba_nuttalli_p19'=>'',
	'enterocytozoon_bieneusi_h348'=>'',
	'enterocytozoon_hepatopenaei'=>'',
	'enterospora_canceri'=>'',
	'equus_caballus'=>'',
	'eremothecium_cymbalariae_dbvpg_7215'=>'',
	'eremothecium_gossypii_fdag1'=>'',
	'eremothecium_sinecaudum'=>'',
	'erinaceus_europaeus'=>'',
	'erysiphe_necator'=>'',
	'escovopsis_weberi'=>'',
	'eutypa_lata_ucrel1'=>'',
	'exidia_glandulosa_hhb12029'=>'',
	'exophiala_aquamarina_cbs_119918'=>'',
	'exophiala_dermatitidis_nih_ut8656'=>'',
	'exophiala_mesophila'=>'',
	'exophiala_oligosperma'=>'',
	'exophiala_sideris'=>'',
	'exophiala_spinifera'=>'',
	'exophiala_xenobiotica'=>'',
	'felis_catus'=>'',
	'fibroporia_radiculosa'=>'',
	'fibulorhizoctonia_sp_cbs_109695'=>'',
	'ficedula_albicollis'=>'',
	'fistulina_hepatica_atcc_64428'=>'',
	'fomitiporia_mediterranea_mf3_22'=>'',
	'fomitopsis_pinicola_fp_58527_ss1'=>'',
	'fonsecaea_erecta'=>'',
	'fonsecaea_monophora'=>'',
	'fonsecaea_multimorphosa'=>'',
	'fonsecaea_multimorphosa_cbs_102226'=>'',
	'fonsecaea_nubica'=>'',
	'fonsecaea_pedrosoi_cbs_271_37'=>'',
	'fonticula_alba_gca_000388065'=>'',
	'fukomys_damarensis'=>'',
	'fusarium_culmorum'=>'',
	'fusarium_fujikuroi'=>'',
	'fusarium_fujikuroi_gca_001023035'=>'',
	'fusarium_fujikuroi_gca_001023045'=>'',
	'fusarium_fujikuroi_gca_001023065'=>'',
	'fusarium_graminearum'=>'',
	'fusarium_graminearum_gca_000599445'=>'',
	'fusarium_langsethiae'=>'',
	'fusarium_mangiferae'=>'',
	'fusarium_oxysporum'=>'',
	'fusarium_oxysporum_f_sp_conglutinans_race_2_54008'=>'',
	'fusarium_oxysporum_f_sp_cubense_race_1'=>'',
	'fusarium_oxysporum_f_sp_cubense_race_4'=>'',
	'fusarium_oxysporum_f_sp_cubense_tropical_race_4_54006'=>'',
	'fusarium_oxysporum_f_sp_lycopersici_mn25'=>'',
	'fusarium_oxysporum_f_sp_melonis_26406'=>'',
	'fusarium_oxysporum_f_sp_pisi_hdv247'=>'',
	'fusarium_oxysporum_f_sp_radicis_lycopersici_26381'=>'',
	'fusarium_oxysporum_f_sp_raphani_54005'=>'',
	'fusarium_oxysporum_f_sp_vasinfectum_25433'=>'',
	'fusarium_oxysporum_fo47'=>'',
	'fusarium_oxysporum_fosc_3_a'=>'',
	'fusarium_poae'=>'',
	'fusarium_proliferatum'=>'',
	'fusarium_proliferatum_et1'=>'',
	'fusarium_pseudograminearum'=>'',
	'fusarium_solani'=>'',
	'fusarium_verticillioides'=>'',
	'gadus_morhua'=>'',
	'gaeumannomyces_graminis'=>'',
	'galdieria_sulphuraria'=>'',
	'galerina_marginata_cbs_339_88'=>'',
	'gallus_gallus'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/gallus_gallus/proTRAC_SRR772069/clusters.fasta',
	'gasterosteus_aculeatus'=>'',
	'gelatoporia_subvermispora_b'=>'',
	'geotrichum_candidum'=>'',
	'giardia_intestinalis'=>'',
	'giardia_intestinalis_assemblage_b'=>'',
	'giardia_intestinalis_atcc_50581'=>'',
	'giardia_intestinalis_gca_000498715'=>'',
	'giardia_lamblia'=>'',
	'giardia_lamblia_p15'=>'',
	'glarea_lozoyensis_74030'=>'',
	'glarea_lozoyensis_atcc_20868'=>'',
	'gloeophyllum_trabeum_atcc_11539'=>'',
	'glycine_max'=>'',
	'gonapodya_prolifera_jel478'=>'',
	'gorilla_gorilla'=>'',
	'gregarina_niphandrodes'=>'',
	'grifola_frondosa'=>'',
	'grosmannia_clavigera_kw1407'=>'',
	'guillardia_theta'=>'',
	'guillardia_theta_gca_000002975'=>'',
	'gymnopus_luxurians_fd_317_m1'=>'',
	'hammondia_hammondi'=>'',
	'hanseniaspora_guilliermondii'=>'',
	'hanseniaspora_opuntiae'=>'',
	'hanseniaspora_osmophila'=>'',
	'hanseniaspora_uvarum'=>'',
	'hanseniaspora_uvarum_dsm_2768'=>'',
	'hanseniaspora_valbyensis_nrrl_y_1626'=>'',
	'hebeloma_cylindrosporum_h7'=>'',
	'heliconius_melpomene'=>'',
	'helobdella_robusta'=>'',
	'hepatospora_eriocheir'=>'',
	'hepatospora_eriocheir_gca_002087885'=>'',
	'heterobasidion_irregulare_tc_32_1'=>'',
	'heterocephalus_glaber_female'=>'',
	'heterocephalus_glaber_male'=>'',
	'hirsutella_minnesotensis_3608'=>'',
	'histoplasma_capsulatum_g186ar'=>'',
	'histoplasma_capsulatum_h143'=>'',
	'histoplasma_capsulatum_h88'=>'',
	'histoplasma_capsulatum_nam1'=>'',
	'homo_sapiens'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/homo_sapiens/proTRAC_normal_testis_generic/clusters.fasta http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/homo_sapiens/proTRAC_SRR1755255/clusters.fasta',
	'hordeum_vulgare'=>'',
	'hyaloperonospora_arabidopsidis'=>'',
	'hydnomerulius_pinastri_md_312'=>'',
	'hypholoma_sublateritium_fd_334_ss_4'=>'',
	'hyphopichia_burtonii_nrrl_y_1933'=>'',
	'hypsizygus_marmoreus'=>'',
	'ichthyophthirius_multifiliis'=>'',
	'ictidomys_tridecemlineatus'=>'',
	'isaria_fumosorosea_arsef_2679'=>'',
	'ixodes_scapularis'=>'',
	'jaapia_argillacea_mucl_33604'=>'',
	'jaculus_jaculus'=>'',
	'kalmanozyma_brasiliensis_ghg001'=>'',
	'kazachstania_africana_cbs_2517'=>'',
	'kazachstania_naganishii_cbs_8797'=>'',
	'kluyveromyces_lactis'=>'',
	'kluyveromyces_marxianus'=>'',
	'kluyveromyces_marxianus_dmku3_1042'=>'',
	'komagataella_pastoris'=>'',
	'komagataella_pastoris_gca_001708105'=>'',
	'komagataella_phaffii'=>'',
	'komagataella_phaffii_cbs_7435'=>'',
	'komagataella_phaffii_gs115'=>'',
	'kuraishia_capsulata_cbs_1993'=>'',
	'kwoniella_bestiolae_cbs_10118'=>'',
	'kwoniella_dejecticola_cbs_10117'=>'',
	'kwoniella_heveanensis_bcc8398'=>'',
	'kwoniella_heveanensis_cbs_569'=>'',
	'kwoniella_mangroviensis_cbs_10435'=>'',
	'kwoniella_mangroviensis_cbs_8507'=>'',
	'kwoniella_mangroviensis_cbs_8886'=>'',
	'kwoniella_pini_cbs_10737'=>'',
	'laccaria_amethystina_laam_08_1'=>'',
	'laccaria_bicolor_s238n_h82'=>'',
	'lachancea_dasiensis_cbs_10888'=>'',
	'lachancea_fermentati'=>'',
	'lachancea_lanzarotensis'=>'',
	'lachancea_meyersii_cbs_8951'=>'',
	'lachancea_mirantina'=>'',
	'lachancea_nothofagi_cbs_11611'=>'',
	'lachancea_sp_cbs_6924'=>'',
	'lachancea_thermotolerans_cbs_6340'=>'',
	'laetiporus_sulphureus_93_53'=>'',
	'latimeria_chalumnae'=>'',
	'leersia_perrieri'=>'',
	'leishmania_braziliensis_mhom_br_75_m2904'=>'',
	'leishmania_donovani_bpk282a1'=>'',
	'leishmania_infantum_jpcm5'=>'',
	'leishmania_major'=>'',
	'leishmania_mexicana_mhom_gt_2001_u1103'=>'',
	'leishmania_panamensis'=>'',
	'lentinula_edodes'=>'',
	'lepeophtheirus_salmonis'=>'',
	'lepisosteus_oculatus'=>'',
	'leptomonas_pyrrhocoris'=>'',
	'leptomonas_seymouri'=>'',
	'leptosphaeria_maculans'=>'',
	'leucoagaricus_sp_symc_cos'=>'',
	'lingula_anatina'=>'',
	'lipomyces_starkeyi_nrrl_y_11557'=>'',
	'loa_loa'=>'',
	'lodderomyces_elongisporus_nrrl_yb_4239'=>'',
	'lotharella_oceanica'=>'',
	'lottia_gigantea'=>'',
	'loxodonta_africana'=>'',
	'lucilia_cuprina'=>'',
	'macaca_mulatta'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/macaca_mulatta/proTRAC_normal_testis_generic/clusters.fasta',
	'macrophomina_phaseolina_ms6'=>'',
	'madurella_mycetomatis'=>'',
	'magnaporthe_oryzae'=>'',
	'magnaporthe_poae'=>'',
	'malassezia_pachydermatis'=>'',
	'malassezia_sympodialis_atcc_42132'=>'',
	'malassezia_sympodialis_atcc_42132_gca_900149145'=>'',
	'marssonina_brunnea_f_sp_multigermtubi_mb_m1'=>'',
	'mayetiola_destructor'=>'',
	'medicago_truncatula'=>'',
	'megaselia_scalaris'=>'',
	'melampsora_laricipopulina'=>'',
	'meleagris_gallopavo'=>'',
	'melitaea_cinxia'=>'',
	'mesocricetus_auratus'=>'',
	'metarhizium_acridum_cqma_102'=>'',
	'metarhizium_album_arsef_1941'=>'',
	'metarhizium_anisopliae'=>'',
	'metarhizium_anisopliae_arsef_23'=>'',
	'metarhizium_anisopliae_arsef_549'=>'',
	'metarhizium_anisopliae_brip_53284'=>'',
	'metarhizium_anisopliae_brip_53293'=>'',
	'metarhizium_brunneum_arsef_3297'=>'',
	'metarhizium_guizhouense_arsef_977'=>'',
	'metarhizium_majus_arsef_297'=>'',
	'metarhizium_rileyi_rcef_4871'=>'',
	'metarhizium_robertsii'=>'',
	'metschnikowia_bicuspidata_var_bicuspidata_nrrl_yb_4993'=>'',
	'meyerozyma_guilliermondii_atcc_6260'=>'',
	'microbotryum_violaceum'=>'',
	'microcebus_murinus'=>'',
	'microdochium_bolleyi'=>'',
	'microtus_ochrogaster'=>'',
	'millerozyma_farinosa_cbs_7064'=>'',
	'mitosporidium_daphniae'=>'',
	'mixia_osmundae_iam_14324'=>'',
	'mixia_osmundae_iam_14324_gca_000708205'=>'',
	'mnemiopsis_leidyi'=>'',
	'moesziomyces_antarcticus'=>'',
	'moesziomyces_aphidis_dsm_70725'=>'',
	'moniliophthora_perniciosa_fa553'=>'',
	'moniliophthora_roreri'=>'',
	'moniliophthora_roreri_mca_2997'=>'',
	'monodelphis_domestica'=>'',
	'mortierella_elongata_ag_77'=>'',
	'mortierella_verticillata_nrrl_6337'=>'',
	'mucor_ambiguus'=>'',
	'mucor_circinelloides_f_circinelloides_1006phl'=>'',
	'mucor_circinelloides_f_lusitanicus_cbs_277_49'=>'',
	'mus_caroli'=>'',
	'mus_musculus'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_129s1svimj'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_aj'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_akrj'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_balbcj'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_c3hhej'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_c57bl6nj'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_casteij'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_dba2j'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_fvbnj'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_lpj'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_nodshiltj'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_nzohlltj'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_pwkphj'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_musculus_wsbeij'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/mus_musculus/proTRAC_normal_testis_generic/clusters.fasta',
	'mus_pahari'=>'',
	'mus_spretus_spreteij'=>'',
	'musa_acuminata'=>'',
	'mustela_putorius_furo'=>'',
	'mycosphaerella_eumusae'=>'',
	'myotis_lucifugus'=>'',
	'nadsonia_fulvescens_var_elongata_dsm_6958'=>'',
	'naegleria_gruberi'=>'',
	'nannizzia_gypsea_cbs_118893'=>'',
	'nannochloropsis_gaditana'=>'',
	'nannospalax_galili'=>'',
	'nasonia_vitripennis'=>'',
	'naumovozyma_castellii_cbs_4309'=>'',
	'naumovozyma_dairenensis_cbs_421'=>'',
	'nematocida_displodere'=>'',
	'nematocida_parisii_ertm1'=>'',
	'nematocida_parisii_ertm3'=>'',
	'nematocida_sp_1_ertm2'=>'',
	'nematocida_sp_1_ertm6'=>'',
	'nematocida_sp_ertm5'=>'',
	'nematostella_vectensis'=>'',
	'neofusicoccum_parvum_ucrnp2'=>'',
	'neolecta_irregularis_dah_3'=>'',
	'neolentinus_lepideus_hhb14362_ss_1'=>'',
	'neonectria_ditissima'=>'',
	'neosartorya_fischeri'=>'',
	'neurospora_crassa'=>'',
	'neurospora_crassa_gca_000786625'=>'',
	'neurospora_tetrasperma_fgsc_2508'=>'',
	'neurospora_tetrasperma_fgsc_2509'=>'',
	'nomascus_leucogenys'=>'',
	'nosema_apis_brl_01'=>'',
	'nosema_bombycis_cq1'=>'',
	'nosema_ceranae'=>'',
	'nosema_ceranae_brl01'=>'',
	'notamacropus_eugenii'=>'',
	'ochotona_princeps'=>'',
	'octodon_degus'=>'',
	'octopus_bimaculoides'=>'',
	'ogataea_parapolymorpha_dl_1'=>'',
	'ogataea_polymorpha'=>'',
	'oidiodendron_maius_zn'=>'',
	'onchocerca_volvulus'=>'',
	'ophiocordyceps_sinensis_co18'=>'',
	'ophiocordyceps_unilateralis'=>'',
	'ophiostoma_piceae_uamh_11346'=>'',
	'ordospora_colligata_oc4'=>'',
	'oreochromis_niloticus'=>'',
	'ornithorhynchus_anatinus'=>'',
	'oryctolagus_cuniculus'=>'',
	'oryza_barthii'=>'',
	'oryza_brachyantha'=>'',
	'oryza_glaberrima'=>'',
	'oryza_glumaepatula'=>'',
	'oryza_indica'=>'',
	'oryza_longistaminata'=>'',
	'oryza_meridionalis'=>'',
	'oryza_nivara'=>'',
	'oryza_punctata'=>'',
	'oryza_rufipogon'=>'',
	'oryza_sativa'=>'',
	'oryzias_latipes'=>'',
	'ostreococcus_lucimarinus'=>'',
	'otolemur_garnettii'=>'',
	'ovis_aries'=>'',
	'pachysolen_tannophilus_nrrl_y_2460'=>'',
	'pan_troglodytes'=>'',
	'papio_anubis'=>'',
	'paracoccidioides_brasiliensis'=>'',
	'paracoccidioides_brasiliensis_gca_001713695'=>'',
	'paracoccidioides_brasiliensis_pb03'=>'',
	'paracoccidioides_brasiliensis_pb18'=>'',
	'paracoccidioides_sp_lutzii_pb01'=>'',
	'paramecium_tetraurelia'=>'',
	'paraphaeosphaeria_sporulosa'=>'',
	'parasitella_parasitica'=>'',
	'paulinella_chromatophora'=>'',
	'paxillus_involutus_atcc_200175'=>'',
	'paxillus_rubicundulus_ve08_2h10'=>'',
	'pediculus_humanus'=>'',
	'pelodiscus_sinensis'=>'',
	'penicilliopsis_zonata_cbs_506_65'=>'',
	'penicillium_antarcticum'=>'',
	'penicillium_arizonense'=>'',
	'penicillium_brasilianum'=>'',
	'penicillium_brasilianum_gca_002016555'=>'',
	'penicillium_camemberti_fm_013'=>'',
	'penicillium_chrysogenum'=>'',
	'penicillium_coprophilum'=>'',
	'penicillium_decumbens'=>'',
	'penicillium_digitatum_pd1'=>'',
	'penicillium_digitatum_phi26'=>'',
	'penicillium_expansum'=>'',
	'penicillium_expansum_gca_000769735'=>'',
	'penicillium_expansum_gca_000769745'=>'',
	'penicillium_flavigenum'=>'',
	'penicillium_freii'=>'',
	'penicillium_griseofulvum'=>'',
	'penicillium_italicum'=>'',
	'penicillium_nalgiovense'=>'',
	'penicillium_nordicum'=>'',
	'penicillium_oxalicum_114_2'=>'',
	'penicillium_polonicum'=>'',
	'penicillium_roqueforti_fm164'=>'',
	'penicillium_rubens_wisconsin_54_1255'=>'',
	'penicillium_solitum'=>'',
	'penicillium_steckii'=>'',
	'penicillium_subrubescens'=>'',
	'penicillium_vulpinum'=>'',
	'peniophora_sp_cont'=>'',
	'perkinsus_marinus_atcc_50983'=>'',
	'peromyscus_maniculatus_bairdii'=>'',
	'pestalotiopsis_fici_w106_1'=>'',
	'petromyzon_marinus'=>'',
	'phaeoacremonium_minimum_ucrpa7'=>'',
	'phaeodactylum_tricornutum'=>'',
	'phaeomoniella_chlamydospora'=>'',
	'phaeosphaeria_nodorum'=>'',
	'phanerochaete_carnosa_hhb_10118_sp'=>'',
	'phialocephala_scopiformis'=>'',
	'phialocephala_subalpina'=>'',
	'phialophora_americana'=>'',
	'phialophora_attae'=>'',
	'phlebia_centrifuga'=>'',
	'phlebiopsis_gigantea_11061_1_cr5_6'=>'',
	'phycomyces_blakesleeanus_nrrl_1555_'=>'',
	'physcomitrella_patens'=>'',
	'phytophthora_infestans'=>'',
	'phytophthora_kernoviae'=>'',
	'phytophthora_lateralis'=>'',
	'phytophthora_parasitica'=>'',
	'phytophthora_parasitica_cj01a1'=>'',
	'phytophthora_parasitica_gca_000509465'=>'',
	'phytophthora_parasitica_gca_000509485'=>'',
	'phytophthora_parasitica_gca_000509505'=>'',
	'phytophthora_parasitica_gca_000509525'=>'',
	'phytophthora_parasitica_inra_310'=>'',
	'phytophthora_parasitica_p10297'=>'',
	'phytophthora_parasitica_p1976'=>'',
	'phytophthora_ramorum'=>'',
	'phytophthora_sojae'=>'',
	'pichia_kudriavzevii'=>'',
	'pichia_kudriavzevii_gca_001983325'=>'',
	'pichia_membranifaciens'=>'',
	'pichia_membranifaciens_nrrl_y_2026'=>'',
	'piloderma_croceum_f_1598'=>'',
	'pisolithus_microcarpus_441'=>'',
	'pisolithus_tinctorius_marx_270'=>'',
	'plasmodium_berghei'=>'',
	'plasmodium_berghei_gca_000005395'=>'',
	'plasmodium_berghei_gca_900044335'=>'',
	'plasmodium_chabaudi'=>'',
	'plasmodium_chabaudi_chabaudi_gca_000003075'=>'',
	'plasmodium_coatneyi'=>'',
	'plasmodium_cynomolgi_strain_b'=>'',
	'plasmodium_falciparum'=>'',
	'plasmodium_falciparum_7g8'=>'',
	'plasmodium_falciparum_camp_malaysia'=>'',
	'plasmodium_falciparum_dd2'=>'',
	'plasmodium_falciparum_fch_4'=>'',
	'plasmodium_falciparum_hb3'=>'',
	'plasmodium_falciparum_igh_cr14'=>'',
	'plasmodium_falciparum_malips096_e11'=>'',
	'plasmodium_falciparum_nf135_5_c10'=>'',
	'plasmodium_falciparum_nf54'=>'',
	'plasmodium_falciparum_palo_alto_uganda'=>'',
	'plasmodium_falciparum_raj116'=>'',
	'plasmodium_falciparum_santa_lucia'=>'',
	'plasmodium_falciparum_tanzania_2000708_'=>'',
	'plasmodium_falciparum_ugt5_1'=>'',
	'plasmodium_falciparum_vietnam_oak_knoll_fvo_'=>'',
	'plasmodium_fragile'=>'',
	'plasmodium_gaboni'=>'',
	'plasmodium_inui_san_antonio_1'=>'',
	'plasmodium_knowlesi'=>'',
	'plasmodium_knowlesi_strain_h_gca_900004885'=>'',
	'plasmodium_malariae'=>'',
	'plasmodium_ovale_curtisi'=>'',
	'plasmodium_reichenowi'=>'',
	'plasmodium_reichenowi_gca_001601855'=>'',
	'plasmodium_vinckei_petteri'=>'',
	'plasmodium_vinckei_vinckei'=>'',
	'plasmodium_vivax'=>'',
	'plasmodium_vivax_brazil_i'=>'',
	'plasmodium_vivax_india_vii'=>'',
	'plasmodium_vivax_mauritania_i'=>'',
	'plasmodium_vivax_north_korean'=>'',
	'plasmodium_yoelii'=>'',
	'plasmodium_yoelii_17x'=>'',
	'plasmodium_yoelii_gca_900002395'=>'',
	'plasmodium_yoelii_yoelii'=>'',
	'plasmopara_halstedii'=>'',
	'pleurotus_ostreatus_pc15'=>'',
	'plicaturopsis_crispa_fd_325_ss_3'=>'',
	'pneumocystis_carinii_b80'=>'',
	'pneumocystis_jirovecii_ru7'=>'',
	'pneumocystis_murina_b123'=>'',
	'pochonia_chlamydosporia_170'=>'',
	'podospora_anserina_s_mat_'=>'',
	'poecilia_formosa'=>'',
	'polysphondylium_pallidum_pn500'=>'',
	'pongo_abelii'=>'',
	'populus_trichocarpa'=>'',
	'postia_placenta_mad_698_r'=>'',
	'procavia_capensis'=>'',
	'prunus_persica'=>'',
	'pseudocercospora_fijiensis_cirad86'=>'',
	'pseudocercospora_musae'=>'',
	'pseudogymnoascus_destructans'=>'',
	'pseudogymnoascus_destructans_20631_21'=>'',
	'pseudogymnoascus_sp_03vt05'=>'',
	'pseudogymnoascus_sp_05ny08'=>'',
	'pseudogymnoascus_sp_23342_1_i1'=>'',
	'pseudogymnoascus_sp_24mn13'=>'',
	'pseudogymnoascus_sp_vkm_f_103'=>'',
	'pseudogymnoascus_sp_vkm_f_3557'=>'',
	'pseudogymnoascus_sp_vkm_f_3775'=>'',
	'pseudogymnoascus_sp_vkm_f_3808'=>'',
	'pseudogymnoascus_sp_vkm_f_4246'=>'',
	'pseudogymnoascus_sp_vkm_f_4281_fw_2241_'=>'',
	'pseudogymnoascus_sp_vkm_f_4513_fw_928_'=>'',
	'pseudogymnoascus_sp_vkm_f_4514_fw_929_'=>'',
	'pseudogymnoascus_sp_vkm_f_4515_fw_2607_'=>'',
	'pseudogymnoascus_sp_vkm_f_4516_fw_969_'=>'',
	'pseudogymnoascus_sp_vkm_f_4517_fw_2822_'=>'',
	'pseudogymnoascus_sp_vkm_f_4518_fw_2643_'=>'',
	'pseudogymnoascus_sp_vkm_f_4519_fw_2642_'=>'',
	'pseudogymnoascus_sp_vkm_f_4520_fw_2644_'=>'',
	'pseudogymnoascus_sp_wsf_3629'=>'',
	'pseudogymnoascus_verrucosus'=>'',
	'pseudoloma_neurophilia'=>'',
	'pseudozyma_hubeiensis_sy62'=>'',
	'pteropus_vampyrus'=>'',
	'puccinia_graminis'=>'',
	'puccinia_graminisug99'=>'',
	'puccinia_sorghi'=>'',
	'puccinia_striiformis'=>'',
	'puccinia_striiformis_f_sp_tritici_pst_78'=>'',
	'puccinia_triticina'=>'',
	'punctularia_strigosozonata_hhb_11173_ss5'=>'',
	'purpureocillium_lilacinum'=>'',
	'purpureocillium_lilacinum_gca_001653265'=>'',
	'pyrenochaeta_sp_ds3say3a'=>'',
	'pyrenophora_teres'=>'',
	'pyrenophora_triticirepentis'=>'',
	'pyronema_omphalodes_cbs_100304'=>'',
	'pythium_aphanidermatum'=>'',
	'pythium_arrhenomanes'=>'',
	'pythium_irregulare'=>'',
	'pythium_iwayamai'=>'',
	'pythium_ultimum'=>'',
	'pythium_vexans'=>'',
	'rachicladosporium_antarcticum'=>'',
	'rasamsonia_emersonii_cbs_393_64'=>'',
	'rattus_norvegicus'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/rattus_norvegicus/proTRAC_SRR035657/clusters.fasta http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/rattus_norvegicus/proTRAC_SRR035663/clusters.fasta',
	'reticulomyxa_filosa'=>'',
	'rhinocladiella_mackenziei_cbs_650_93'=>'',
	'rhizoctonia_solani'=>'',
	'rhizoctonia_solani_123e'=>'',
	'rhizoctonia_solani_ag_1_ia'=>'',
	'rhizoctonia_solani_ag_1_ib'=>'',
	'rhizoctonia_solani_ag_3_rhs1ap'=>'',
	'rhizoctonia_solani_ag_8_wac10335'=>'',
	'rhizophagus_irregularis_daom_181602_gca_000439145'=>'',
	'rhizopogon_vesiculosus'=>'',
	'rhizopogon_vinicolor_am_or11_026'=>'',
	'rhizopus_delemar_ra_99_880'=>'',
	'rhizopus_microsporus'=>'',
	'rhizopus_microsporus_var_microsporus'=>'',
	'rhodnius_prolixus'=>'',
	'rhodotorula_graminis_wp1'=>'',
	'rhodotorula_sp_jg_1b'=>'',
	'rhodotorula_toruloides'=>'',
	'rhodotorula_toruloides_atcc_204091'=>'',
	'rhodotorula_toruloides_np11'=>'',
	'rhynchosporium_agropyri'=>'',
	'rhynchosporium_commune'=>'',
	'rhynchosporium_secalis'=>'',
	'rozella_allomycis_csf55'=>'',
	'saccharomyces_arboricola_h_6'=>'',
	'saccharomyces_cerevisiae'=>'',
	'saccharomyces_cerevisiae_awri796'=>'',
	'saccharomyces_cerevisiae_cen_pk113_7d'=>'',
	'saccharomyces_cerevisiae_ec1118'=>'',
	'saccharomyces_cerevisiae_fostersb'=>'',
	'saccharomyces_cerevisiae_fosterso'=>'',
	'saccharomyces_cerevisiae_gca_000091065'=>'',
	'saccharomyces_cerevisiae_gca_001634645'=>'',
	'saccharomyces_cerevisiae_gca_001983315'=>'',
	'saccharomyces_cerevisiae_kyokai_no_7'=>'',
	'saccharomyces_cerevisiae_lalvin_qa23'=>'',
	'saccharomyces_cerevisiae_p283'=>'',
	'saccharomyces_cerevisiae_p301'=>'',
	'saccharomyces_cerevisiae_r008'=>'',
	'saccharomyces_cerevisiae_r103'=>'',
	'saccharomyces_cerevisiae_rm11_1a'=>'',
	'saccharomyces_cerevisiae_vin13'=>'',
	'saccharomyces_cerevisiae_vl3'=>'',
	'saccharomyces_cerevisiae_x_saccharomyces_kudriavzevii_vin7'=>'',
	'saccharomyces_cerevisiae_yjm1078'=>'',
	'saccharomyces_cerevisiae_yjm1083'=>'',
	'saccharomyces_cerevisiae_yjm1129'=>'',
	'saccharomyces_cerevisiae_yjm1133'=>'',
	'saccharomyces_cerevisiae_yjm1190'=>'',
	'saccharomyces_cerevisiae_yjm1199'=>'',
	'saccharomyces_cerevisiae_yjm1202'=>'',
	'saccharomyces_cerevisiae_yjm1208'=>'',
	'saccharomyces_cerevisiae_yjm1242'=>'',
	'saccharomyces_cerevisiae_yjm1244'=>'',
	'saccharomyces_cerevisiae_yjm1248'=>'',
	'saccharomyces_cerevisiae_yjm1250'=>'',
	'saccharomyces_cerevisiae_yjm1252'=>'',
	'saccharomyces_cerevisiae_yjm1273'=>'',
	'saccharomyces_cerevisiae_yjm1304'=>'',
	'saccharomyces_cerevisiae_yjm1307'=>'',
	'saccharomyces_cerevisiae_yjm1311'=>'',
	'saccharomyces_cerevisiae_yjm1326'=>'',
	'saccharomyces_cerevisiae_yjm1332'=>'',
	'saccharomyces_cerevisiae_yjm1336'=>'',
	'saccharomyces_cerevisiae_yjm1338'=>'',
	'saccharomyces_cerevisiae_yjm1341'=>'',
	'saccharomyces_cerevisiae_yjm1342'=>'',
	'saccharomyces_cerevisiae_yjm1355'=>'',
	'saccharomyces_cerevisiae_yjm1356'=>'',
	'saccharomyces_cerevisiae_yjm1381'=>'',
	'saccharomyces_cerevisiae_yjm1383'=>'',
	'saccharomyces_cerevisiae_yjm1385'=>'',
	'saccharomyces_cerevisiae_yjm1386'=>'',
	'saccharomyces_cerevisiae_yjm1387'=>'',
	'saccharomyces_cerevisiae_yjm1388'=>'',
	'saccharomyces_cerevisiae_yjm1389'=>'',
	'saccharomyces_cerevisiae_yjm1399'=>'',
	'saccharomyces_cerevisiae_yjm1400'=>'',
	'saccharomyces_cerevisiae_yjm1401'=>'',
	'saccharomyces_cerevisiae_yjm1402'=>'',
	'saccharomyces_cerevisiae_yjm1415'=>'',
	'saccharomyces_cerevisiae_yjm1417'=>'',
	'saccharomyces_cerevisiae_yjm1418'=>'',
	'saccharomyces_cerevisiae_yjm1419'=>'',
	'saccharomyces_cerevisiae_yjm1433'=>'',
	'saccharomyces_cerevisiae_yjm1434'=>'',
	'saccharomyces_cerevisiae_yjm1439'=>'',
	'saccharomyces_cerevisiae_yjm1443'=>'',
	'saccharomyces_cerevisiae_yjm1444'=>'',
	'saccharomyces_cerevisiae_yjm1447'=>'',
	'saccharomyces_cerevisiae_yjm1450'=>'',
	'saccharomyces_cerevisiae_yjm1460'=>'',
	'saccharomyces_cerevisiae_yjm1463'=>'',
	'saccharomyces_cerevisiae_yjm1477'=>'',
	'saccharomyces_cerevisiae_yjm1478'=>'',
	'saccharomyces_cerevisiae_yjm1479'=>'',
	'saccharomyces_cerevisiae_yjm1526'=>'',
	'saccharomyces_cerevisiae_yjm1527'=>'',
	'saccharomyces_cerevisiae_yjm1549'=>'',
	'saccharomyces_cerevisiae_yjm1573'=>'',
	'saccharomyces_cerevisiae_yjm1574'=>'',
	'saccharomyces_cerevisiae_yjm1592'=>'',
	'saccharomyces_cerevisiae_yjm1615'=>'',
	'saccharomyces_cerevisiae_yjm189'=>'',
	'saccharomyces_cerevisiae_yjm193'=>'',
	'saccharomyces_cerevisiae_yjm195'=>'',
	'saccharomyces_cerevisiae_yjm244'=>'',
	'saccharomyces_cerevisiae_yjm248'=>'',
	'saccharomyces_cerevisiae_yjm270'=>'',
	'saccharomyces_cerevisiae_yjm271'=>'',
	'saccharomyces_cerevisiae_yjm320'=>'',
	'saccharomyces_cerevisiae_yjm326'=>'',
	'saccharomyces_cerevisiae_yjm428'=>'',
	'saccharomyces_cerevisiae_yjm450'=>'',
	'saccharomyces_cerevisiae_yjm451'=>'',
	'saccharomyces_cerevisiae_yjm453'=>'',
	'saccharomyces_cerevisiae_yjm456'=>'',
	'saccharomyces_cerevisiae_yjm470'=>'',
	'saccharomyces_cerevisiae_yjm541'=>'',
	'saccharomyces_cerevisiae_yjm554'=>'',
	'saccharomyces_cerevisiae_yjm555'=>'',
	'saccharomyces_cerevisiae_yjm627'=>'',
	'saccharomyces_cerevisiae_yjm681'=>'',
	'saccharomyces_cerevisiae_yjm682'=>'',
	'saccharomyces_cerevisiae_yjm683'=>'',
	'saccharomyces_cerevisiae_yjm689'=>'',
	'saccharomyces_cerevisiae_yjm693'=>'',
	'saccharomyces_cerevisiae_yjm789'=>'',
	'saccharomyces_cerevisiae_yjm969'=>'',
	'saccharomyces_cerevisiae_yjm972'=>'',
	'saccharomyces_cerevisiae_yjm975'=>'',
	'saccharomyces_cerevisiae_yjm978'=>'',
	'saccharomyces_cerevisiae_yjm981'=>'',
	'saccharomyces_cerevisiae_yjm984'=>'',
	'saccharomyces_cerevisiae_yjm987'=>'',
	'saccharomyces_cerevisiae_yjm990'=>'',
	'saccharomyces_cerevisiae_yjm993'=>'',
	'saccharomyces_cerevisiae_yjm996'=>'',
	'saccharomyces_eubayanus'=>'',
	'saccharomyces_kudriavzevii_ifo_1802'=>'',
	'saccharomyces_sp_boulardii_'=>'',
	'saccharomyces_sp_boulardii__gca_001413975'=>'',
	'saccharomycetaceae_sp_ashbya_aceri_'=>'',
	'saitoella_complicata_nrrl_y_17804'=>'',
	'saitoella_complicata_nrrl_y_17804_gca_001661265'=>'',
	'salpingoeca_rosetta'=>'',
	'saprolegnia_diclina_vs20'=>'',
	'saprolegnia_parasitica_cbs_223_65'=>'',
	'sarcophilus_harrisii'=>'',
	'sarcoptes_scabiei'=>'',
	'scedosporium_apiospermum'=>'',
	'scheffersomyces_stipitis_cbs_6054'=>'',
	'schistosoma_mansoni'=>'',
	'schizophyllum_commune_h4_8'=>'',
	'schizopora_paradoxa'=>'',
	'schizosaccharomyces_cryophilus'=>'',
	'schizosaccharomyces_japonicus'=>'',
	'schizosaccharomyces_octosporus'=>'',
	'schizosaccharomyces_pombe'=>'',
	'scleroderma_citrinum_foug_a'=>'',
	'sclerotinia_borealis_f_4128'=>'',
	'sclerotinia_sclerotiorum'=>'',
	'sclerotinia_sclerotiorum_1980_uf_70'=>'',
	'selaginella_moellendorffii'=>'',
	'serendipita_indica_dsm_11827'=>'',
	'serendipita_vermifera_maff_305830'=>'',
	'serpula_lacrymans_var_lacrymans_s7_3'=>'',
	'serpula_lacrymans_var_lacrymans_s7_9'=>'',
	'setaria_italica'=>'',
	'setosphaeria_turcica_et28a'=>'',
	'sistotremastrum_niveocremeum_hhb9708'=>'',
	'sistotremastrum_suecicum_hhb10207_ss_3'=>'',
	'solanum_lycopersicum'=>'',
	'solanum_tuberosum'=>'',
	'solenopsis_invicta'=>'',
	'sordaria_macrospora'=>'',
	'sorex_araneus'=>'',
	'sorghum_bicolor'=>'',
	'spathaspora_passalidarum_nrrl_y_27907'=>'',
	'sphaerobolus_stellatus_ss14'=>'',
	'sphaeroforma_arctica_jp610'=>'',
	'sphaerulina_musiva_so2202'=>'',
	'spironucleus_salmonicida'=>'',
	'spizellomyces_punctatus_daom_br117'=>'',
	'sporidiobolus_salmonicolor'=>'',
	'sporisorium_reilianum'=>'',
	'sporisorium_scitamineum'=>'',
	'sporothrix_brasiliensis_5110'=>'',
	'sporothrix_insectorum_rcef_264'=>'',
	'sporothrix_schenckii_1099_18'=>'',
	'sporothrix_schenckii_atcc_58251'=>'',
	'spraguea_lophii_42_110'=>'',
	'stachybotrys_chartarum_ibt_40288'=>'',
	'stachybotrys_chartarum_ibt_40293'=>'',
	'stachybotrys_chartarum_ibt_7711'=>'',
	'stachybotrys_chlorohalonata_ibt_40285'=>'',
	'stagonospora_sp_src1lsm3a'=>'',
	'stegodyphus_mimosarum'=>'',
	'stemphylium_lycopersici'=>'',
	'stereum_hirsutum_fp_91666_ss1'=>'',
	'strigamia_maritima'=>'',
	'strigomonas_culicis'=>'',
	'strongylocentrotus_purpuratus'=>'',
	'sugiyamaella_lignohabitans'=>'',
	'suillus_luteus_uh_slu_lm8_n1'=>'',
	'sus_scrofa'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/sus_scrofa/proTRAC_normal_testis_generic/clusters.fasta http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/sus_scrofa/proTRAC_normal_ovary_generic/clusters.fasta',
	'taeniopygia_guttata'=>'',
	'takifugu_rubripes'=>'',
	'talaromyces_cellulolyticus'=>'',
	'talaromyces_islandicus'=>'',
	'talaromyces_marneffei_atcc_18224'=>'',
	'talaromyces_marneffei_pm1'=>'',
	'talaromyces_stipitatus_atcc_10500'=>'',
	'termitomyces_sp_j132'=>'',
	'tetrahymena_thermophila'=>'',
	'tetranychus_urticae'=>'',
	'tetraodon_nigroviridis'=>'',
	'tetrapisispora_blattae_cbs_6284'=>'',
	'tetrapisispora_phaffii_cbs_4417'=>'',
	'thalassiosira_oceanica'=>'',
	'thalassiosira_oceanica_ccmp1005'=>'',
	'thalassiosira_pseudonana'=>'',
	'thecamonas_trahens_atcc_50062'=>'',
	'theileria_annulata'=>'',
	'theileria_equi_strain_wa'=>'',
	'theileria_orientalis_strain_shintoku'=>'',
	'theileria_parva'=>'',
	'thelohanellus_kitauei'=>'',
	'theobroma_cacao'=>'',
	'thermothelomyces_thermophila_atcc_42464'=>'',
	'thielavia_terrestris_nrrl_8126'=>'',
	'thielaviopsis_punctulata'=>'',
	'tilletia_caries'=>'',
	'tilletia_controversa'=>'',
	'tilletia_indica'=>'',
	'tilletia_walkeri'=>'',
	'tilletiaria_anomala_ubc_951'=>'',
	'tolypocladium_ophioglossoides_cbs_100239'=>'',
	'torrubiella_hemipterigena'=>'',
	'tortispora_caseinolytica_nrrl_y_17796'=>'',
	'torulaspora_delbrueckii'=>'',
	'toxoplasma_gondii'=>'',
	'toxoplasma_gondii_ari'=>'',
	'toxoplasma_gondii_fou'=>'',
	'toxoplasma_gondii_gab2_2007_gal_dom2'=>'',
	'toxoplasma_gondii_gt1'=>'',
	'toxoplasma_gondii_mas'=>'',
	'toxoplasma_gondii_p89'=>'',
	'toxoplasma_gondii_rub'=>'',
	'toxoplasma_gondii_tgcatprc2'=>'',
	'toxoplasma_gondii_vand'=>'',
	'toxoplasma_gondii_veg'=>'',
	'trachipleistophora_hominis'=>'',
	'trametes_cinnabarina'=>'',
	'trametes_pubescens'=>'',
	'trametes_versicolor_fp_101664_ss1'=>'',
	'tremella_mesenterica_dsm_1558'=>'',
	'tribolium_castaneum'=>'',
	'trichoderma_atroviride_imi_206040'=>'',
	'trichoderma_gamsii'=>'',
	'trichoderma_guizhouense'=>'',
	'trichoderma_harzianum'=>'',
	'trichoderma_reesei'=>'',
	'trichoderma_reesei_rut_c_30'=>'',
	'trichoderma_virens'=>'',
	'trichomonas_vaginalis_g3'=>'',
	'trichophyton_benhamiae_cbs_112371'=>'',
	'trichophyton_equinum_cbs_127_97'=>'',
	'trichophyton_interdigitale_h6'=>'',
	'trichophyton_interdigitale_mr816'=>'',
	'trichophyton_rubrum'=>'',
	'trichophyton_rubrum_cbs_100081'=>'',
	'trichophyton_rubrum_cbs_118892'=>'',
	'trichophyton_rubrum_cbs_202_88'=>'',
	'trichophyton_rubrum_cbs_288_86'=>'',
	'trichophyton_rubrum_cbs_289_86'=>'',
	'trichophyton_rubrum_cbs_735_88'=>'',
	'trichophyton_rubrum_d6'=>'',
	'trichophyton_rubrum_mr1448'=>'',
	'trichophyton_rubrum_mr1459'=>'',
	'trichophyton_rubrum_mr850'=>'',
	'trichophyton_soudanense_cbs_452_61'=>'',
	'trichophyton_tonsurans_cbs_112818'=>'',
	'trichophyton_verrucosum_hki_0517'=>'',
	'trichophyton_violaceum'=>'',
	'trichoplax_adhaerens'=>'',
	'trichosporon_asahii_var_asahii_cbs_2479'=>'',
	'trichosporon_asahii_var_asahii_cbs_8904'=>'',
	'trifolium_pratense'=>'',
	'triticum_aestivum'=>'',
	'triticum_urartu'=>'',
	'trypanosoma_brucei'=>'',
	'trypanosoma_cruzi'=>'',
	'trypanosoma_cruzi_dm28c'=>'',
	'tsuchiyaea_wingfieldii_cbs_7118'=>'',
	'tuber_melanosporum'=>'',
	'tulasnella_calospora_mut_4182'=>'',
	'tupaia_belangeri'=>'http://www.smallrnagroup.uni-mainz.de/piRNAclusterDB/tupaia_belangeri/proTRAC_SRR1184429/clusters.fasta',
	'tursiops_truncatus'=>'',
	'umbilicaria_pustulata'=>'',
	'uncinocarpus_reesii_1704'=>'',
	'ustilaginoidea_virens'=>'',
	'ustilaginoidea_virens_gca_000965225'=>'',
	'ustilago_bromivora'=>'',
	'ustilago_hordei'=>'',
	'ustilago_maydis'=>'',
	'valsa_mali'=>'',
	'valsa_mali_var_pyri'=>'',
	'vanderwaltozyma_polyspora_dsm_70294'=>'',
	'vavraia_culicis_subsp_floridensis'=>'',
	'verruconis_gallopava'=>'',
	'verticillium_alfalfae_vams_102'=>'',
	'verticillium_dahliae'=>'',
	'verticillium_dahliaejr2'=>'',
	'verticillium_longisporum'=>'',
	'verticillium_longisporum_gca_001268145'=>'',
	'vicugna_pacos'=>'',
	'vitis_vinifera'=>'',
	'vitrella_brassicaformis_ccmp3155'=>'',
	'vittaforma_corneae_atcc_50505'=>'',
	'wallemia_ichthyophaga_exf_994'=>'',
	'wallemia_mellicola_cbs_633_66'=>'',
	'wickerhamomyces_anomalus_nrrl_y_366_8'=>'',
	'wickerhamomyces_ciferrii'=>'',
	'xanthophyllomyces_dendrorhous'=>'',
	'xenopus_tropicalis'=>'',
	'xiphophorus_maculatus'=>'',
	'xylona_heveae_tc161'=>'',
	'yarrowia_lipolytica'=>'',
	'yarrowia_lipolytica_gca_001761485'=>'',
	'zea_mays'=>'',
	'zootermopsis_nevadensis'=>'',
	'zygosaccharomyces_bailii_isa1307'=>'',
	'zygosaccharomyces_parabailii'=>'',
	'zygosaccharomyces_rouxii'=>'',
	'zygosaccharomyces_rouxii_gca_001972345'=>'',
	'zymoseptoria_brevis'=>'',
	'zymoseptoria_tritici'=>'',
	);### PIRCLDB URLS END ###
				}
			if(length$piRclDB_urls{$species}>0)
				{
				if(!$silent){print"\nDownload piRNA cluster data for $species{$species} from piRNA cluster database...";}

				@piURLs=split(' ',$piRclDB_urls{$species});
				$i=0;
				$success=0;
				foreach$piURL(@piURLs)
					{
					$i++;
					$status=getstore("$piURL","UNITAS_refdump_$species/piRclDB_$i");
					if(is_success($status))
						{
						$success++;
						}
					else
						{
						if(!$silent){print" FAILED: $status!";}
						}
					}
				if($success==$i&&!$silent)
					{
					print" $success/$i OK. Database date: $mday.$mon.$year (dd.mm.yyyy)";
					}
				elsif(!$silent)
					{
					print" Warning: Downloaded $success/$i files!\n\n";
					}
				$db_versions_info.="piRNA cluster database version/date: ...... $mday.$mon.$year (dd.mm.yyyy)\n";

				if(!$silent){print"\nProcess data from piRNA cluster database...";}
				open(PIRCLDB_ALL,">UNITAS_refdump_$species/piRclDB")||die print"\nERROR! Unable to create piRNA cluster sequence file UNITAS_refdump_$species/piRclDB.\n$!\n\n";
				$i_cl=0;
				foreach$id(1..$i)
					{
					open(PIRCLDB,"UNITAS_refdump_$species/piRclDB_$id")||print"\nERROR! Unable to read UNITAS_refdump_$species/piRclDB_$id.\n$!\n\n";
					while(<PIRCLDB>)
						{
						$_=~s/\s*$//;
						if($_=~/^>/)
							{
							$i_cl++;
							$_=~s/ \(.*$//;
							print PIRCLDB_ALL"$_\n";
							}
						else
							{
							$piRcl_seq="";
							while(1)
								{
								$_=~s/.{1,60}//;
								$piRcl_seq.="$&\n";
								last if(length$_==0);
								}
							print PIRCLDB_ALL$piRcl_seq;
							}
						}
					close PIRCLDB;
					unlink("UNITAS_refdump_$species/piRclDB_$id");
					}
				close PIRCLDB_ALL;
				if(!$silent){print" OK ($i_cl piRNA cluster sequences collected).";}
				}
			else
				{
				if(!$silent){print"\nNo piRNA cluster data for $species{$species} at piRNA cluster database -> SKIP.";}
				$db_versions_info.="piRNA cluster database version/date: ...... $mday.$mon.$year (dd.mm.yyyy)\n";
				}
			}

		# download and process ensembl ncRNA data
		if(!$silent){print"\nCheck latest Ensembl database release...";}
		$ensembl_home="";
		$ensembl_home=get("http://www.ensembl.org");
		if(length$ensembl_home>0)
			{
			$ensembl_home=~s/Ensembl genome browser \d+//;
			$ensembl_title=$&;
			$ensembl_title=~s/\d+//;
			$ensembl_release=$&;
			if($ensembl_release!~/^\d+$/)
				{
				if(!$silent){print" FAILED!\nServer error? Assuming release 88 to be the latest.\n\n";}
				$ensembl_release=88;
				}
			elsif(!$silent){print" $ensembl_release.";}
			}
		else
			{
			if(!$silent){print" FAILED!\nServer error? Assuming release 88 to be the latest.\n\n";}
			$ensembl_release=88;
			}

		if(!$silent){print"\nCheck latest EnsemblGenomes database release...";}
		$ensemblgenomes_home="";
		$ensemblgenomes_home=get("http://ensemblgenomes.org/");
		if(length$ensemblgenomes_home>0)
			{
			$ensemblgenomes_home=~s/<option value="\d+">Release \d+ \(//;
			$ensemblgenomes_title=$&;
			$ensemblgenomes_title=~s/\d+//;
			$ensemblgenomes_release=$&;
			if($ensemblgenomes_release!~/^\d+$/)
				{
				if(!$silent){print" FAILED!\nServer error? Assuming release 35 to be the latest.\n\n";}
				$ensemblgenomes_release=35;
				}
			elsif(!$silent){print" $ensemblgenomes_release.";}
			}
		else
			{
			if(!$silent){print" FAILED!\nServer error? Assuming release 35 to be the latest.\n\n";}
			$ensemblgenomes_release=35;
			}


		$eval_URL="";
		$eval_URL=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/URLs/Ensembl_ncRNA');
		if(length$eval_URL>0)
			{
			eval$eval_URL;
			}
		else
			{
			if(!$silent){print"\nFailed to load current Ensembl URLs for ncRNA data from smallRNAgroup-SERVER. Use internal list.";}
### NCRNA URLS START ###
%ensembl_ncRNA=
	(
	'_candida_auris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_auris/ncrna/_candida_auris.ASM118947v1.ncrna.fa.gz',
	'_candida_glabrata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/_candida_glabrata/ncrna/_candida_glabrata.ASM254v2.ncrna.fa.gz',
	'_candida_glabrata_gca_001466525'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466525/ncrna/_candida_glabrata_gca_001466525.ASM146652v1.ncrna.fa.gz',
	'_candida_glabrata_gca_001466535'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466535/ncrna/_candida_glabrata_gca_001466535.ASM146653v1.ncrna.fa.gz',
	'_candida_glabrata_gca_001466565'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466565/ncrna/_candida_glabrata_gca_001466565.ASM146656v1.ncrna.fa.gz',
	'_candida_glabrata_gca_001466575'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466575/ncrna/_candida_glabrata_gca_001466575.ASM146657v1.ncrna.fa.gz',
	'_candida_glabrata_gca_001466635'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466635/ncrna/_candida_glabrata_gca_001466635.ASM146663v1.ncrna.fa.gz',
	'_candida_glabrata_gca_001466685'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466685/ncrna/_candida_glabrata_gca_001466685.ASM146668v1.ncrna.fa.gz',
	'_candida_intermedia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_intermedia/ncrna/_candida_intermedia.CBS_141442_assembly.ncrna.fa.gz',
	'_candida_intermedia_gca_900106125'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_intermedia_gca_900106125/ncrna/_candida_intermedia_gca_900106125.PYCC_4715_assembly.ncrna.fa.gz',
	'_candida_tenuis_atcc_10573'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/_candida_tenuis_atcc_10573/ncrna/_candida_tenuis_atcc_10573.Candida_tenuis_v1.0.ncrna.fa.gz',
	'absidia_glauca'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/absidia_glauca/ncrna/Absidia_glauca.AG_v1.ncrna.fa.gz',
	'acidomyces_richmondensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/acidomyces_richmondensis/ncrna/Acidomyces_richmondensis.ASM157207v1.ncrna.fa.gz',
	'acidomyces_richmondensis_bfw'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/acidomyces_richmondensis_bfw/ncrna/Acidomyces_richmondensis_bfw.Acidomyces_richmondensis_BFW_v1.0.ncrna.fa.gz',
	'acremonium_chrysogenum_atcc_11550'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/acremonium_chrysogenum_atcc_11550/ncrna/Acremonium_chrysogenum_atcc_11550.ASM76926v1.ncrna.fa.gz',
	'acyrthosiphon_pisum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/acyrthosiphon_pisum/ncrna/Acyrthosiphon_pisum.Acyr_2.0.ncrna.fa.gz',
	'adineta_vaga'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/adineta_vaga/ncrna/Adineta_vaga.AMS_PRJEB1171_v1.ncrna.fa.gz',
	'aedes_aegypti'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/aedes_aegypti/ncrna/Aedes_aegypti.AaegL3.ncrna.fa.gz',
	'aegilops_tauschii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/aegilops_tauschii/ncrna/Aegilops_tauschii.ASM34733v1.ncrna.fa.gz',
	'agaricus_bisporus_var_burnettii_jb137_s8'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/agaricus_bisporus_var_burnettii_jb137_s8/ncrna/Agaricus_bisporus_var_burnettii_jb137_s8.Agabi_varbur_1.ncrna.fa.gz',
	'ailuropoda_melanoleuca'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ailuropoda_melanoleuca/ncrna/Ailuropoda_melanoleuca.ailMel1.ncrna.fa.gz',
	'albugo_laibachii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/albugo_laibachii/ncrna/Albugo_laibachii.ENA1.ncrna.fa.gz',
	'allomyces_macrogynus_atcc_38327'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_blastocladiomycota1_collection/allomyces_macrogynus_atcc_38327/ncrna/Allomyces_macrogynus_atcc_38327.A_macrogynus_V3.ncrna.fa.gz',
	'alternaria_alternata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/alternaria_alternata/ncrna/Alternaria_alternata.Altal1.ncrna.fa.gz',
	'amanita_muscaria_koide_bx008'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/amanita_muscaria_koide_bx008/ncrna/Amanita_muscaria_koide_bx008.Amanita_muscaria_Koide_BX008_v1.0.ncrna.fa.gz',
	'amborella_trichopoda'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/amborella_trichopoda/ncrna/Amborella_trichopoda.AMTR1.0.ncrna.fa.gz',
	'amphiamblys_sp_wsbs2006'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/amphiamblys_sp_wsbs2006/ncrna/Amphiamblys_sp_wsbs2006.ASM187567v1.ncrna.fa.gz',
	'amphimedon_queenslandica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/amphimedon_queenslandica/ncrna/Amphimedon_queenslandica.Aqu1.ncrna.fa.gz',
	'anas_platyrhynchos'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/anas_platyrhynchos/ncrna/Anas_platyrhynchos.BGI_duck_1.0.ncrna.fa.gz',
	'angomonas_deanei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/angomonas_deanei/ncrna/Angomonas_deanei.Angomonas_deanei_Genome.ncrna.fa.gz',
	'anncaliia_algerae_pra109'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/anncaliia_algerae_pra109/ncrna/Anncaliia_algerae_pra109.Annc_alge_PRA109_V4.ncrna.fa.gz',
	'anncaliia_algerae_pra339'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/anncaliia_algerae_pra339/ncrna/Anncaliia_algerae_pra339.Annc_alge_insect_USDA_JJB_V2.ncrna.fa.gz',
	'anolis_carolinensis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/anolis_carolinensis/ncrna/Anolis_carolinensis.AnoCar2.0.ncrna.fa.gz',
	'anopheles_darlingi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/anopheles_darlingi/ncrna/Anopheles_darlingi.AdarC3.ncrna.fa.gz',
	'anopheles_gambiae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/anopheles_gambiae/ncrna/Anopheles_gambiae.AgamP4.ncrna.fa.gz',
	'anoplophora_glabripennis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/anoplophora_glabripennis/ncrna/Anoplophora_glabripennis.Agla_1.0.ncrna.fa.gz',
	'anthracocystis_flocculosa_pf_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/anthracocystis_flocculosa_pf_1/ncrna/Anthracocystis_flocculosa_pf_1.Pflocc_1.0.ncrna.fa.gz',
	'aphanomyces_astaci'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/aphanomyces_astaci/ncrna/Aphanomyces_astaci.Apha_asta_APO3_V1.ncrna.fa.gz',
	'aphanomyces_invadans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/aphanomyces_invadans/ncrna/Aphanomyces_invadans.Apha_inva_NJM9701_V1.ncrna.fa.gz',
	'apis_mellifera'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/apis_mellifera/ncrna/Apis_mellifera.Amel_4.5.ncrna.fa.gz',
	'arabidopsis_lyrata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/arabidopsis_lyrata/ncrna/Arabidopsis_lyrata.v.1.0.ncrna.fa.gz',
	'arabidopsis_thaliana'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/arabidopsis_thaliana/ncrna/Arabidopsis_thaliana.TAIR10.ncrna.fa.gz',
	'arthrobotrys_oligospora_atcc_24927'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/arthrobotrys_oligospora_atcc_24927/ncrna/Arthrobotrys_oligospora_atcc_24927.AOL24927_1.0.ncrna.fa.gz',
	'arthroderma_otae_cbs_113480'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/arthroderma_otae_cbs_113480/ncrna/Arthroderma_otae_cbs_113480.ASM15114v1.ncrna.fa.gz',
	'aschersonia_aleyrodis_rcef_2490'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aschersonia_aleyrodis_rcef_2490/ncrna/Aschersonia_aleyrodis_rcef_2490.AAL_1.0.ncrna.fa.gz',
	'ascochyta_rabiei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ascochyta_rabiei/ncrna/Ascochyta_rabiei.AscRab1.0.ncrna.fa.gz',
	'ascoidea_rubescens_dsm_1968'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ascoidea_rubescens_dsm_1968/ncrna/Ascoidea_rubescens_dsm_1968.Ascru1.ncrna.fa.gz',
	'ascosphaera_apis_arsef_7405'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ascosphaera_apis_arsef_7405/ncrna/Ascosphaera_apis_arsef_7405.AAP_1.0.ncrna.fa.gz',
	'ashbya_gossypii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/ashbya_gossypii/ncrna/Ashbya_gossypii.ASM9102v1.ncrna.fa.gz',
	'aspergillus_aculeatus_atcc_16872'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_aculeatus_atcc_16872/ncrna/Aspergillus_aculeatus_atcc_16872.Aspac1.ncrna.fa.gz',
	'aspergillus_bombycis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_bombycis/ncrna/Aspergillus_bombycis.ASM179269v1.ncrna.fa.gz',
	'aspergillus_brasiliensis_cbs_101740'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_brasiliensis_cbs_101740/ncrna/Aspergillus_brasiliensis_cbs_101740.Aspbr1.ncrna.fa.gz',
	'aspergillus_calidoustus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_calidoustus/ncrna/Aspergillus_calidoustus.Acal_Allpaths_LG.ncrna.fa.gz',
	'aspergillus_carbonarius_item_5010'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_carbonarius_item_5010/ncrna/Aspergillus_carbonarius_item_5010.Aspca3.ncrna.fa.gz',
	'aspergillus_clavatus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_clavatus/ncrna/Aspergillus_clavatus.CADRE.ncrna.fa.gz',
	'aspergillus_cristatus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_cristatus/ncrna/Aspergillus_cristatus.ASM171748v1.ncrna.fa.gz',
	'aspergillus_flavus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_flavus/ncrna/Aspergillus_flavus.JCVI-afl1-v2.0.ncrna.fa.gz',
	'aspergillus_flavus_af70'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/aspergillus_flavus_af70/ncrna/Aspergillus_flavus_af70.ASM95283v1.ncrna.fa.gz',
	'aspergillus_fumigatus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_fumigatus/ncrna/Aspergillus_fumigatus.CADRE.ncrna.fa.gz',
	'aspergillus_fumigatus_var_rp_2014'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aspergillus_fumigatus_var_rp_2014/ncrna/Aspergillus_fumigatus_var_rp_2014.AspFumNiv1.0.ncrna.fa.gz',
	'aspergillus_fumigatus_z5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_fumigatus_z5/ncrna/Aspergillus_fumigatus_z5.ASM102932v1.ncrna.fa.gz',
	'aspergillus_fumigatusa1163'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_fumigatusa1163/ncrna/Aspergillus_fumigatusa1163.CADRE.ncrna.fa.gz',
	'aspergillus_glaucus_cbs_516_65'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_glaucus_cbs_516_65/ncrna/Aspergillus_glaucus_cbs_516_65.Aspgl1.ncrna.fa.gz',
	'aspergillus_lentulus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_lentulus/ncrna/Aspergillus_lentulus.Alt_assembly01.ncrna.fa.gz',
	'aspergillus_luchuensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_luchuensis/ncrna/Aspergillus_luchuensis.AspL_2604.ncrna.fa.gz',
	'aspergillus_luchuensis_cbs_106_47'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_luchuensis_cbs_106_47/ncrna/Aspergillus_luchuensis_cbs_106_47.Aspfo1.ncrna.fa.gz',
	'aspergillus_nidulans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_nidulans/ncrna/Aspergillus_nidulans.ASM1142v1.ncrna.fa.gz',
	'aspergillus_nidulans_fgsc_a4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/aspergillus_nidulans_fgsc_a4/ncrna/Aspergillus_nidulans_fgsc_a4.ASM14920v2.ncrna.fa.gz',
	'aspergillus_niger'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_niger/ncrna/Aspergillus_niger.ASM285v2.ncrna.fa.gz',
	'aspergillus_niger_atcc_1015'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aspergillus_niger_atcc_1015/ncrna/Aspergillus_niger_atcc_1015.ASPNI_v3.0.ncrna.fa.gz',
	'aspergillus_niger_gca_001515345'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_niger_gca_001515345/ncrna/Aspergillus_niger_gca_001515345.ASM151534v1.ncrna.fa.gz',
	'aspergillus_nomius_nrrl_13137'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_nomius_nrrl_13137/ncrna/Aspergillus_nomius_nrrl_13137.ASM120477v1.ncrna.fa.gz',
	'aspergillus_ochraceoroseus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/aspergillus_ochraceoroseus/ncrna/Aspergillus_ochraceoroseus.ASM98666v1.ncrna.fa.gz',
	'aspergillus_oryzae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_oryzae/ncrna/Aspergillus_oryzae.ASM18445v3.ncrna.fa.gz',
	'aspergillus_oryzae_100_8'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aspergillus_oryzae_100_8/ncrna/Aspergillus_oryzae_100_8.Aspergillus_oryzae_100-8.ncrna.fa.gz',
	'aspergillus_oryzae_3_042'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aspergillus_oryzae_3_042/ncrna/Aspergillus_oryzae_3_042.AspOry3042.ncrna.fa.gz',
	'aspergillus_oryzae_gca_002007945'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_oryzae_gca_002007945/ncrna/Aspergillus_oryzae_gca_002007945.ASM200794v1.ncrna.fa.gz',
	'aspergillus_parasiticus_su_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_parasiticus_su_1/ncrna/Aspergillus_parasiticus_su_1.ASM95608v1.ncrna.fa.gz',
	'aspergillus_rambellii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/aspergillus_rambellii/ncrna/Aspergillus_rambellii.ASM98664v1.ncrna.fa.gz',
	'aspergillus_ruber_cbs_135680'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aspergillus_ruber_cbs_135680/ncrna/Aspergillus_ruber_cbs_135680.Eurhe1.ncrna.fa.gz',
	'aspergillus_sydowii_cbs_593_65'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_sydowii_cbs_593_65/ncrna/Aspergillus_sydowii_cbs_593_65.Aspsy1.ncrna.fa.gz',
	'aspergillus_terreus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_terreus/ncrna/Aspergillus_terreus.CADRE.ncrna.fa.gz',
	'aspergillus_tubingensis_cbs_134_48'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_tubingensis_cbs_134_48/ncrna/Aspergillus_tubingensis_cbs_134_48.Asptu1.ncrna.fa.gz',
	'aspergillus_udagawae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_udagawae/ncrna/Aspergillus_udagawae.Aud_assembly01.ncrna.fa.gz',
	'aspergillus_ustus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/aspergillus_ustus/ncrna/Aspergillus_ustus.Austus1.0.ncrna.fa.gz',
	'aspergillus_versicolor_cbs_583_65'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_versicolor_cbs_583_65/ncrna/Aspergillus_versicolor_cbs_583_65.Aspve1.ncrna.fa.gz',
	'aspergillus_wentii_dto_134e9'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_wentii_dto_134e9/ncrna/Aspergillus_wentii_dto_134e9.Aspwe1.ncrna.fa.gz',
	'astyanax_mexicanus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/astyanax_mexicanus/ncrna/Astyanax_mexicanus.AstMex102.ncrna.fa.gz',
	'atta_cephalotes'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/atta_cephalotes/ncrna/Atta_cephalotes.Attacep1.0.ncrna.fa.gz',
	'aureobasidium_melanogenum_cbs_110374'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aureobasidium_melanogenum_cbs_110374/ncrna/Aureobasidium_melanogenum_cbs_110374.Aureobasidium_pullulans_var._melanogenum_CBS_110374_v1.0.ncrna.fa.gz',
	'aureobasidium_namibiae_cbs_147_97'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aureobasidium_namibiae_cbs_147_97/ncrna/Aureobasidium_namibiae_cbs_147_97.Aureobasidium_pullulans_var._namibiae_CBS_147.97_v1.0.ncrna.fa.gz',
	'aureobasidium_pullulans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aureobasidium_pullulans/ncrna/Aureobasidium_pullulans.ASM167811v1.ncrna.fa.gz',
	'aureobasidium_pullulans_exf_150'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aureobasidium_pullulans_exf_150/ncrna/Aureobasidium_pullulans_exf_150.Aureobasidium_pullulans_var._pullulans_EXF-150_assembly_version_1.0.ncrna.fa.gz',
	'aureobasidium_subglaciale_exf_2481'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aureobasidium_subglaciale_exf_2481/ncrna/Aureobasidium_subglaciale_exf_2481.Aureobasidium_pullulans_var._subglaciale_EXF-2481_v1.0.ncrna.fa.gz',
	'babesia_bovis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/babesia_bovis/ncrna/Babesia_bovis.ASM16539v1.ncrna.fa.gz',
	'babesia_microti_strain_ri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/babesia_microti_strain_ri/ncrna/Babesia_microti_strain_ri.ASM69194v1.ncrna.fa.gz',
	'babjeviella_inositovora_nrrl_y_12698'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/babjeviella_inositovora_nrrl_y_12698/ncrna/Babjeviella_inositovora_nrrl_y_12698.Babin1.ncrna.fa.gz',
	'batrachochytrium_dendrobatidis_jam81'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_chytridiomycota1_collection/batrachochytrium_dendrobatidis_jam81/ncrna/Batrachochytrium_dendrobatidis_jam81.v1.0.ncrna.fa.gz',
	'batrachochytrium_dendrobatidis_jel423'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_chytridiomycota1_collection/batrachochytrium_dendrobatidis_jel423/ncrna/Batrachochytrium_dendrobatidis_jel423.BD_JEL423.ncrna.fa.gz',
	'batrachochytrium_salamandrivorans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_chytridiomycota1_collection/batrachochytrium_salamandrivorans/ncrna/Batrachochytrium_salamandrivorans.Batr_sala_BS_V1.ncrna.fa.gz',
	'baudoinia_panamericana_uamh_10762'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/baudoinia_panamericana_uamh_10762/ncrna/Baudoinia_panamericana_uamh_10762.Bauco1.ncrna.fa.gz',
	'beauveria_bassiana'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/beauveria_bassiana/ncrna/Beauveria_bassiana.ASM168263v1.ncrna.fa.gz',
	'beauveria_bassiana_arsef_2860'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/beauveria_bassiana_arsef_2860/ncrna/Beauveria_bassiana_arsef_2860.ASM28067v1.ncrna.fa.gz',
	'beauveria_bassiana_d1_5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/beauveria_bassiana_d1_5/ncrna/Beauveria_bassiana_d1_5.BBA1.0.ncrna.fa.gz',
	'belgica_antarctica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/belgica_antarctica/ncrna/Belgica_antarctica.ASM77530v1.ncrna.fa.gz',
	'beta_vulgaris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/beta_vulgaris/ncrna/Beta_vulgaris.RefBeet-1.2.2.ncrna.fa.gz',
	'bigelowiella_natans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/bigelowiella_natans/ncrna/Bigelowiella_natans.Bigna1.ncrna.fa.gz',
	'bigelowiella_natans_gca_000002455'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_rhizaria1_collection/bigelowiella_natans_gca_000002455/ncrna/Bigelowiella_natans_gca_000002455.ASM245v1.ncrna.fa.gz',
	'bipolaris_maydis_atcc_48331'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_maydis_atcc_48331/ncrna/Bipolaris_maydis_atcc_48331.CocheC4_1.ncrna.fa.gz',
	'bipolaris_maydis_c5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_maydis_c5/ncrna/Bipolaris_maydis_c5.CocheC5_3.ncrna.fa.gz',
	'bipolaris_oryzae_atcc_44560'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_oryzae_atcc_44560/ncrna/Bipolaris_oryzae_atcc_44560.Cochliobolus_miyabeanus_v1.0.ncrna.fa.gz',
	'bipolaris_sorokiniana_nd90pr'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_sorokiniana_nd90pr/ncrna/Bipolaris_sorokiniana_nd90pr.Cocsa1.ncrna.fa.gz',
	'bipolaris_victoriae_fi3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_victoriae_fi3/ncrna/Bipolaris_victoriae_fi3.Cochliobolus_victoriae_v1.0.ncrna.fa.gz',
	'bipolaris_zeicola_26_r_13'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_zeicola_26_r_13/ncrna/Bipolaris_zeicola_26_r_13.Cochliobolus_carbonum_v1.0.ncrna.fa.gz',
	'blastomyces_dermatitidis_atcc_18188'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/blastomyces_dermatitidis_atcc_18188/ncrna/Blastomyces_dermatitidis_atcc_18188.BD_ATCC18188_V1.ncrna.fa.gz',
	'blastomyces_dermatitidis_atcc_26199'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/blastomyces_dermatitidis_atcc_26199/ncrna/Blastomyces_dermatitidis_atcc_26199.BD_ATCC26199_V2.ncrna.fa.gz',
	'blastomyces_dermatitidis_er_3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/blastomyces_dermatitidis_er_3/ncrna/Blastomyces_dermatitidis_er_3.BD_ER3_V1.ncrna.fa.gz',
	'blastomyces_gilchristii_slh14081'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/blastomyces_gilchristii_slh14081/ncrna/Blastomyces_gilchristii_slh14081.BD_SLH14081_V1.ncrna.fa.gz',
	'blastomyces_percursus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/blastomyces_percursus/ncrna/Blastomyces_percursus.Blas_perc_EI222_V1.ncrna.fa.gz',
	'blumeria_graminis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/blumeria_graminis/ncrna/Blumeria_graminis.EF1.ncrna.fa.gz',
	'blumeria_graminis_f_sp_tritici_96224'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/blumeria_graminis_f_sp_tritici_96224/ncrna/Blumeria_graminis_f_sp_tritici_96224.Bgt_454_newbler_assembly.ncrna.fa.gz',
	'bodo_saltans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/bodo_saltans/ncrna/Bodo_saltans.BSAL.ncrna.fa.gz',
	'bombus_impatiens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/bombus_impatiens/ncrna/Bombus_impatiens.BIMP_2.0.ncrna.fa.gz',
	'bombyx_mori'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/bombyx_mori/ncrna/Bombyx_mori.ASM15162v1.ncrna.fa.gz',
	'bos_taurus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/bos_taurus/ncrna/Bos_taurus.UMD3.1.ncrna.fa.gz',
	'botryobasidium_botryosum_fd_172_ss1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/botryobasidium_botryosum_fd_172_ss1/ncrna/Botryobasidium_botryosum_fd_172_ss1.Botbo1.ncrna.fa.gz',
	'botrytis_cinerea'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/botrytis_cinerea/ncrna/Botrytis_cinerea.ASM83294v1.ncrna.fa.gz',
	'botrytis_cinerea_bcdw1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/botrytis_cinerea_bcdw1/ncrna/Botrytis_cinerea_bcdw1.BcDW1.ncrna.fa.gz',
	'botrytis_cinerea_t4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/botrytis_cinerea_t4/ncrna/Botrytis_cinerea_t4.BotFuc_Mar2011.ncrna.fa.gz',
	'brachypodium_distachyon'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/brachypodium_distachyon/ncrna/Brachypodium_distachyon.v1.0.ncrna.fa.gz',
	'brassica_napus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/brassica_napus/ncrna/Brassica_napus.AST_PRJEB5043_v1.ncrna.fa.gz',
	'brassica_oleracea'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/brassica_oleracea/ncrna/Brassica_oleracea.v2.1.ncrna.fa.gz',
	'brassica_rapa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/brassica_rapa/ncrna/Brassica_rapa.IVFCAASv1.ncrna.fa.gz',
	'brettanomyces_bruxellensis_awri1499'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/brettanomyces_bruxellensis_awri1499/ncrna/Brettanomyces_bruxellensis_awri1499.AWRI1499_v1.0.ncrna.fa.gz',
	'brugia_malayi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/brugia_malayi/ncrna/Brugia_malayi.B_malayi-3.1.ncrna.fa.gz',
	'byssochlamys_spectabilis_no_5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/byssochlamys_spectabilis_no_5/ncrna/Byssochlamys_spectabilis_no_5.PVAR5_assembly01.ncrna.fa.gz',
	'caenorhabditis_brenneri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/caenorhabditis_brenneri/ncrna/Caenorhabditis_brenneri.C_brenneri-6.0.1b.ncrna.fa.gz',
	'caenorhabditis_briggsae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/caenorhabditis_briggsae/ncrna/Caenorhabditis_briggsae.CB4.ncrna.fa.gz',
	'caenorhabditis_elegans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/caenorhabditis_elegans/ncrna/Caenorhabditis_elegans.WBcel235.ncrna.fa.gz',
	'caenorhabditis_japonica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/caenorhabditis_japonica/ncrna/Caenorhabditis_japonica.C_japonica-7.0.1.ncrna.fa.gz',
	'caenorhabditis_remanei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/caenorhabditis_remanei/ncrna/Caenorhabditis_remanei.C_remanei-15.0.1.ncrna.fa.gz',
	'callithrix_jacchus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/callithrix_jacchus/ncrna/Callithrix_jacchus.C_jacchus3.2.1.ncrna.fa.gz',
	'calocera_cornea_hhb12733'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/calocera_cornea_hhb12733/ncrna/Calocera_cornea_hhb12733.Calco1.ncrna.fa.gz',
	'calocera_viscosa_tufc12733'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/calocera_viscosa_tufc12733/ncrna/Calocera_viscosa_tufc12733.Calvi1.ncrna.fa.gz',
	'candida_albicans_12c'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_12c/ncrna/Candida_albicans_12c.Cand_albi_12C_V2.ncrna.fa.gz',
	'candida_albicans_19f'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_19f/ncrna/Candida_albicans_19f.Cand_albi_19F_V2.ncrna.fa.gz',
	'candida_albicans_ca6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_ca6/ncrna/Candida_albicans_ca6.Cand_albi_Ca6_V2.ncrna.fa.gz',
	'candida_albicans_gc75'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_gc75/ncrna/Candida_albicans_gc75.Cand_albi_GC75_V1.ncrna.fa.gz',
	'candida_albicans_l26'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_l26/ncrna/Candida_albicans_l26.Cand_albi_L26_V2.ncrna.fa.gz',
	'candida_albicans_p34048'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p34048/ncrna/Candida_albicans_p34048.Cand_albi_P34048_V1.ncrna.fa.gz',
	'candida_albicans_p37005'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_p37005/ncrna/Candida_albicans_p37005.Cand_albi_P37005_V2.ncrna.fa.gz',
	'candida_albicans_p37037'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_p37037/ncrna/Candida_albicans_p37037.Cand_albi_P37037_V1.ncrna.fa.gz',
	'candida_albicans_p37039'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p37039/ncrna/Candida_albicans_p37039.Cand_albi_P37039_V1.ncrna.fa.gz',
	'candida_albicans_p57055'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p57055/ncrna/Candida_albicans_p57055.Cand_albi_P57055_V1.ncrna.fa.gz',
	'candida_albicans_p57072'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_p57072/ncrna/Candida_albicans_p57072.Cand_albi_P57072_V1.ncrna.fa.gz',
	'candida_albicans_p60002'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p60002/ncrna/Candida_albicans_p60002.Cand_albi_P60002_V1.ncrna.fa.gz',
	'candida_albicans_p75010'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p75010/ncrna/Candida_albicans_p75010.Cand_albi_P75010_V1.ncrna.fa.gz',
	'candida_albicans_p75016'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p75016/ncrna/Candida_albicans_p75016.Cand_albi_P75016_V1.ncrna.fa.gz',
	'candida_albicans_p75063'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p75063/ncrna/Candida_albicans_p75063.Cand_albi_P75063_V1.ncrna.fa.gz',
	'candida_albicans_p76055'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p76055/ncrna/Candida_albicans_p76055.Cand_albi_P76055_V1.ncrna.fa.gz',
	'candida_albicans_p76067'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p76067/ncrna/Candida_albicans_p76067.Cand_albi_P76067_V1.ncrna.fa.gz',
	'candida_albicans_p78042'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p78042/ncrna/Candida_albicans_p78042.Cand_albi_P78042_V1.ncrna.fa.gz',
	'candida_albicans_p78048'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_p78048/ncrna/Candida_albicans_p78048.Cand_albi_P78048_V1.ncrna.fa.gz',
	'candida_albicans_p87'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p87/ncrna/Candida_albicans_p87.Cand_albi_P87_V2.ncrna.fa.gz',
	'candida_albicans_p94015'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p94015/ncrna/Candida_albicans_p94015.Cand_albi_P94015_V1.ncrna.fa.gz',
	'candida_albicans_sc5314'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_sc5314/ncrna/Candida_albicans_sc5314.Cand_albi_SC5314_V4.ncrna.fa.gz',
	'candida_albicans_sc5314_gca_000182965'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/candida_albicans_sc5314_gca_000182965/ncrna/Candida_albicans_sc5314_gca_000182965.ASM18296v3.ncrna.fa.gz',
	'candida_albicans_sc5314_gca_000784655'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_sc5314_gca_000784655/ncrna/Candida_albicans_sc5314_gca_000784655.Cand_albi_SC5314_V3.ncrna.fa.gz',
	'candida_albicans_wo_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_wo_1/ncrna/Candida_albicans_wo_1.ASM14944v2.ncrna.fa.gz',
	'candida_arabinofermentans_nrrl_yb_2248'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/candida_arabinofermentans_nrrl_yb_2248/ncrna/Candida_arabinofermentans_nrrl_yb_2248.Canar1.ncrna.fa.gz',
	'candida_dubliniensis_cd36'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_dubliniensis_cd36/ncrna/Candida_dubliniensis_cd36.ASM2694v1.ncrna.fa.gz',
	'candida_maltosa_xu316'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_maltosa_xu316/ncrna/Candida_maltosa_xu316.Cmaltosa_v01.ncrna.fa.gz',
	'candida_orthopsilosis_co_90_125'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_orthopsilosis_co_90_125/ncrna/Candida_orthopsilosis_co_90_125.ASM31587v1.ncrna.fa.gz',
	'candida_parapsilosis_cdc317'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/candida_parapsilosis_cdc317/ncrna/Candida_parapsilosis_cdc317.ASM18276v2.ncrna.fa.gz',
	'candida_tanzawaensis_nrrl_y_17324'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/candida_tanzawaensis_nrrl_y_17324/ncrna/Candida_tanzawaensis_nrrl_y_17324.Canta1.ncrna.fa.gz',
	'candida_tropicalis_mya_3404'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_tropicalis_mya_3404/ncrna/Candida_tropicalis_mya_3404.ASM633v2.ncrna.fa.gz',
	'canis_familiaris'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/canis_familiaris/ncrna/Canis_familiaris.CanFam3.1.ncrna.fa.gz',
	'capitella_teleta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/capitella_teleta/ncrna/Capitella_teleta.Capitella_teleta_v1.0.ncrna.fa.gz',
	'capronia_coronata_cbs_617_96'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/capronia_coronata_cbs_617_96/ncrna/Capronia_coronata_cbs_617_96.Capr_coro_CBS_617_96_V1.ncrna.fa.gz',
	'capronia_epimyces_cbs_606_96'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/capronia_epimyces_cbs_606_96/ncrna/Capronia_epimyces_cbs_606_96.Capr_epim_CBS_606_96_V1.ncrna.fa.gz',
	'capsaspora_owczarzaki_atcc_30864'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_ichthyosporea1_collection/capsaspora_owczarzaki_atcc_30864/ncrna/Capsaspora_owczarzaki_atcc_30864.C_owczarzaki_V2.ncrna.fa.gz',
	'carlito_syrichta'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/carlito_syrichta/ncrna/Carlito_syrichta.tarSyr1.ncrna.fa.gz',
	'cavia_aperea'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/cavia_aperea/ncrna/Cavia_aperea.CavAp1.0.ncrna.fa.gz',
	'cavia_porcellus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/cavia_porcellus/ncrna/Cavia_porcellus.Cavpor3.0.ncrna.fa.gz',
	'ceraceosorus_bombacis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/ceraceosorus_bombacis/ncrna/Ceraceosorus_bombacis.Ceraceosorus_bombacis.ncrna.fa.gz',
	'ceratocystis_platani'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/ceratocystis_platani/ncrna/Ceratocystis_platani.ASM97888v1.ncrna.fa.gz',
	'chaetomium_globosum_cbs_148_51'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/chaetomium_globosum_cbs_148_51/ncrna/Chaetomium_globosum_cbs_148_51.ASM14336v1.ncrna.fa.gz',
	'chaetomium_thermophilum_var_thermophilum_dsm_1495'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/chaetomium_thermophilum_var_thermophilum_dsm_1495/ncrna/Chaetomium_thermophilum_var_thermophilum_dsm_1495.CTHT_3.0.ncrna.fa.gz',
	'chinchilla_lanigera'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/chinchilla_lanigera/ncrna/Chinchilla_lanigera.ChiLan1.0.ncrna.fa.gz',
	'chlamydomonas_reinhardtii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/chlamydomonas_reinhardtii/ncrna/Chlamydomonas_reinhardtii.v3.1.ncrna.fa.gz',
	'chlorocebus_sabaeus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/chlorocebus_sabaeus/ncrna/Chlorocebus_sabaeus.ChlSab1.1.ncrna.fa.gz',
	'choloepus_hoffmanni'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/choloepus_hoffmanni/ncrna/Choloepus_hoffmanni.choHof1.ncrna.fa.gz',
	'chondrus_crispus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/chondrus_crispus/ncrna/Chondrus_crispus.ASM35022v2.ncrna.fa.gz',
	'chroomonas_mesostigmatica_ccmp1168'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_cryptophyta1_collection/chroomonas_mesostigmatica_ccmp1168/ncrna/Chroomonas_mesostigmatica_ccmp1168.ASM28609v1.ncrna.fa.gz',
	'ciona_intestinalis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ciona_intestinalis/ncrna/Ciona_intestinalis.KH.ncrna.fa.gz',
	'ciona_savignyi'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ciona_savignyi/ncrna/Ciona_savignyi.CSAV2.0.ncrna.fa.gz',
	'cladophialophora_bantiana_cbs_173_52'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/cladophialophora_bantiana_cbs_173_52/ncrna/Cladophialophora_bantiana_cbs_173_52.Clad_bant_CBS_173_52_V1.ncrna.fa.gz',
	'cladophialophora_carrionii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cladophialophora_carrionii/ncrna/Cladophialophora_carrionii.ASM170077v1.ncrna.fa.gz',
	'cladophialophora_carrionii_cbs_160_54'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/cladophialophora_carrionii_cbs_160_54/ncrna/Cladophialophora_carrionii_cbs_160_54.Clad_carr_CBS_160_54_V1.ncrna.fa.gz',
	'cladophialophora_immunda'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/cladophialophora_immunda/ncrna/Cladophialophora_immunda.Clad_immu_CBS83496_V1.ncrna.fa.gz',
	'cladophialophora_psammophila_cbs_110553'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/cladophialophora_psammophila_cbs_110553/ncrna/Cladophialophora_psammophila_cbs_110553.Clad_psam_CBS_110553_V1.ncrna.fa.gz',
	'cladophialophora_yegresii_cbs_114405'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/cladophialophora_yegresii_cbs_114405/ncrna/Cladophialophora_yegresii_cbs_114405.Clad_yegr_CBS_114405_V1.ncrna.fa.gz',
	'claviceps_purpurea_20_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/claviceps_purpurea_20_1/ncrna/Claviceps_purpurea_20_1.ASM34735v1.ncrna.fa.gz',
	'clavispora_lusitaniae_atcc_42720'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/clavispora_lusitaniae_atcc_42720/ncrna/Clavispora_lusitaniae_atcc_42720.ASM383v1.ncrna.fa.gz',
	'coccidioides_immitis_h538_4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/coccidioides_immitis_h538_4/ncrna/Coccidioides_immitis_h538_4.ASM14981v1.ncrna.fa.gz',
	'coccidioides_immitis_rmscc_2394'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/coccidioides_immitis_rmscc_2394/ncrna/Coccidioides_immitis_rmscc_2394.ASM14989v1.ncrna.fa.gz',
	'coccidioides_immitis_rmscc_3703'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/coccidioides_immitis_rmscc_3703/ncrna/Coccidioides_immitis_rmscc_3703.ASM15008v1.ncrna.fa.gz',
	'coccidioides_immitis_rs'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/coccidioides_immitis_rs/ncrna/Coccidioides_immitis_rs.ASM14933v2.ncrna.fa.gz',
	'coccidioides_posadasii_c735_delta_sowgp'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/coccidioides_posadasii_c735_delta_sowgp/ncrna/Coccidioides_posadasii_c735_delta_sowgp.JCVI-cpa1-1.0.ncrna.fa.gz',
	'coccidioides_posadasii_rmscc_3488'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/coccidioides_posadasii_rmscc_3488/ncrna/Coccidioides_posadasii_rmscc_3488.ASM15005v1.ncrna.fa.gz',
	'coccidioides_posadasii_str_silveira'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/coccidioides_posadasii_str_silveira/ncrna/Coccidioides_posadasii_str_silveira.CPS2.ncrna.fa.gz',
	'colletotrichum_chlorophyti'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_chlorophyti/ncrna/Colletotrichum_chlorophyti.ASM193710v1.ncrna.fa.gz',
	'colletotrichum_fioriniae_pj7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/colletotrichum_fioriniae_pj7/ncrna/Colletotrichum_fioriniae_pj7.CFIO01.ncrna.fa.gz',
	'colletotrichum_gloeosporioides'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/colletotrichum_gloeosporioides/ncrna/Colletotrichum_gloeosporioides.GCA_000319635.1.ncrna.fa.gz',
	'colletotrichum_gloeosporioides_cg_14'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/colletotrichum_gloeosporioides_cg_14/ncrna/Colletotrichum_gloeosporioides_cg_14.Colletotrichum_gloeosporioides1.ncrna.fa.gz',
	'colletotrichum_graminicola'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/colletotrichum_graminicola/ncrna/Colletotrichum_graminicola.C_graminicola_M1_001_V1.ncrna.fa.gz',
	'colletotrichum_higginsianum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/colletotrichum_higginsianum/ncrna/Colletotrichum_higginsianum.GCA_000313795.2.ncrna.fa.gz',
	'colletotrichum_higginsianum_imi_349063'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_higginsianum_imi_349063/ncrna/Colletotrichum_higginsianum_imi_349063.ASM167251v1.ncrna.fa.gz',
	'colletotrichum_incanum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_incanum/ncrna/Colletotrichum_incanum.Ci238704v1.ncrna.fa.gz',
	'colletotrichum_incanum_gca_001855235'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_incanum_gca_001855235/ncrna/Colletotrichum_incanum_gca_001855235.ASM185523v1.ncrna.fa.gz',
	'colletotrichum_nymphaeae_sa_01'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_nymphaeae_sa_01/ncrna/Colletotrichum_nymphaeae_sa_01.CNYM01.ncrna.fa.gz',
	'colletotrichum_orbiculare'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/colletotrichum_orbiculare/ncrna/Colletotrichum_orbiculare.GCA_000350065.1.ncrna.fa.gz',
	'colletotrichum_orchidophilum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_orchidophilum/ncrna/Colletotrichum_orchidophilum.CORC01.ncrna.fa.gz',
	'colletotrichum_salicis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_salicis/ncrna/Colletotrichum_salicis.CSAL01.ncrna.fa.gz',
	'colletotrichum_simmondsii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_simmondsii/ncrna/Colletotrichum_simmondsii.CSIM01.ncrna.fa.gz',
	'colletotrichum_sublineola'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/colletotrichum_sublineola/ncrna/Colletotrichum_sublineola.ASM69613v1.ncrna.fa.gz',
	'colletotrichum_tofieldiae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_tofieldiae/ncrna/Colletotrichum_tofieldiae.Ct0861v1.ncrna.fa.gz',
	'conidiobolus_coronatus_nrrl_28638'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_entomophthoromycota1_collection/conidiobolus_coronatus_nrrl_28638/ncrna/Conidiobolus_coronatus_nrrl_28638.Conidiobolus_coronatus_NRRL28638.ncrna.fa.gz',
	'coniochaeta_ligniaria_nrrl_30616'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/coniochaeta_ligniaria_nrrl_30616/ncrna/Coniochaeta_ligniaria_nrrl_30616.Conlig_v1.0.ncrna.fa.gz',
	'coniophora_puteana_rwd_64_598_ss2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/coniophora_puteana_rwd_64_598_ss2/ncrna/Coniophora_puteana_rwd_64_598_ss2.Conpu1.ncrna.fa.gz',
	'coniosporium_apollinis_cbs_100218'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/coniosporium_apollinis_cbs_100218/ncrna/Coniosporium_apollinis_cbs_100218.Coni_apol_CBS100218_V1.ncrna.fa.gz',
	'coprinopsis_cinerea_okayama7_130'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/coprinopsis_cinerea_okayama7_130/ncrna/Coprinopsis_cinerea_okayama7_130.CC3.ncrna.fa.gz',
	'corchorus_capsularis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/corchorus_capsularis/ncrna/Corchorus_capsularis.CCACVL1_1.0.ncrna.fa.gz',
	'cordyceps_brongniartii_rcef_3172'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cordyceps_brongniartii_rcef_3172/ncrna/Cordyceps_brongniartii_rcef_3172.BBO_1.0.ncrna.fa.gz',
	'cordyceps_confragosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cordyceps_confragosa/ncrna/Cordyceps_confragosa.ASM165321v1.ncrna.fa.gz',
	'cordyceps_confragosa_rcef_1005'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cordyceps_confragosa_rcef_1005/ncrna/Cordyceps_confragosa_rcef_1005.LEL_1.0.ncrna.fa.gz',
	'cordyceps_militaris_cm01'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/cordyceps_militaris_cm01/ncrna/Cordyceps_militaris_cm01.CmilitarisCM01_v01.ncrna.fa.gz',
	'crassostrea_gigas'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/crassostrea_gigas/ncrna/Crassostrea_gigas.oyster_v9.ncrna.fa.gz',
	'cricetulus_griseus_chok1gshd'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/cricetulus_griseus_chok1gshd/ncrna/Cricetulus_griseus_chok1gshd.CHOK1GS_HDv1.ncrna.fa.gz',
	'cricetulus_griseus_crigri'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/cricetulus_griseus_crigri/ncrna/Cricetulus_griseus_crigri.CriGri_1.0.ncrna.fa.gz',
	'cryptococcus_amylolentus_cbs_6039'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_amylolentus_cbs_6039/ncrna/Cryptococcus_amylolentus_cbs_6039.Cryp_amyl_CBS6039_V3.ncrna.fa.gz',
	'cryptococcus_amylolentus_cbs_6273'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_amylolentus_cbs_6273/ncrna/Cryptococcus_amylolentus_cbs_6273.Cryp_amyl_CBS6273_V2.ncrna.fa.gz',
	'cryptococcus_depauperatus_cbs_7841'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_depauperatus_cbs_7841/ncrna/Cryptococcus_depauperatus_cbs_7841.Filo_depa_CBS7841_V1.ncrna.fa.gz',
	'cryptococcus_depauperatus_cbs_7855'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_depauperatus_cbs_7855/ncrna/Cryptococcus_depauperatus_cbs_7855.Filo_depa_CBS7855_V2.ncrna.fa.gz',
	'cryptococcus_gattii_ca1280'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_ca1280/ncrna/Cryptococcus_gattii_ca1280.Cryp_gatt_CA1280_V1.ncrna.fa.gz',
	'cryptococcus_gattii_ca1873'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_ca1873/ncrna/Cryptococcus_gattii_ca1873.Cryp_gatt_CA1873_V1.ncrna.fa.gz',
	'cryptococcus_gattii_e566'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_e566/ncrna/Cryptococcus_gattii_e566.Cryp_gatt_E566_V1.ncrna.fa.gz',
	'cryptococcus_gattii_ejb2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_ejb2/ncrna/Cryptococcus_gattii_ejb2.Cryp_gatt_EJB2_V1.ncrna.fa.gz',
	'cryptococcus_gattii_nt_10'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_nt_10/ncrna/Cryptococcus_gattii_nt_10.Cryp_gatt_NT-10_V1.ncrna.fa.gz',
	'cryptococcus_gattii_ru294'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_ru294/ncrna/Cryptococcus_gattii_ru294.Cryp_gatt_Ru294_V1.ncrna.fa.gz',
	'cryptococcus_gattii_vgii_2001_935_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_2001_935_1/ncrna/Cryptococcus_gattii_vgii_2001_935_1.Cryp_gatt_2001_935-1_V1.ncrna.fa.gz',
	'cryptococcus_gattii_vgii_99_473'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_99_473/ncrna/Cryptococcus_gattii_vgii_99_473.Cryp_gatt_99_473_V1.ncrna.fa.gz',
	'cryptococcus_gattii_vgii_ca1014'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_ca1014/ncrna/Cryptococcus_gattii_vgii_ca1014.Cryp_gatt_CA1014_V1.ncrna.fa.gz',
	'cryptococcus_gattii_vgii_cbs_10090'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_cbs_10090/ncrna/Cryptococcus_gattii_vgii_cbs_10090.Cryp_gatt_CBS10090_V1.ncrna.fa.gz',
	'cryptococcus_gattii_vgii_la55'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_la55/ncrna/Cryptococcus_gattii_vgii_la55.Cryp_gatt_LA55_V1.ncrna.fa.gz',
	'cryptococcus_gattii_vgii_mmrl2647'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_mmrl2647/ncrna/Cryptococcus_gattii_vgii_mmrl2647.Cryp_gatt_MMRL2647_V2.ncrna.fa.gz',
	'cryptococcus_gattii_vgii_r265'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_r265/ncrna/Cryptococcus_gattii_vgii_r265.CNB2.ncrna.fa.gz',
	'cryptococcus_gattii_vgii_ram5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_ram5/ncrna/Cryptococcus_gattii_vgii_ram5.Cryp_gatt_Ram5_V1.ncrna.fa.gz',
	'cryptococcus_gattii_vgiv_ind107'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgiv_ind107/ncrna/Cryptococcus_gattii_vgiv_ind107.Cryp_gatt_IND107_V2.ncrna.fa.gz',
	'cryptococcus_gattii_wm276'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_wm276/ncrna/Cryptococcus_gattii_wm276.ASM18594v1.ncrna.fa.gz',
	'cryptococcus_neoformans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/cryptococcus_neoformans/ncrna/Cryptococcus_neoformans.GCA_000091045.1.ncrna.fa.gz',
	'cryptococcus_neoformans_var_grubii_h99'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_neoformans_var_grubii_h99/ncrna/Cryptococcus_neoformans_var_grubii_h99.CNA3.ncrna.fa.gz',
	'cryptococcus_neoformans_var_neoformans_b_3501a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_neoformans_var_neoformans_b_3501a/ncrna/Cryptococcus_neoformans_var_neoformans_b_3501a.ASM14938v1.ncrna.fa.gz',
	'cryptomonas_paramecium'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_cryptophyta1_collection/cryptomonas_paramecium/ncrna/Cryptomonas_paramecium.ASM19445v1.ncrna.fa.gz',
	'cryptosporidium_muris_rn66'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/cryptosporidium_muris_rn66/ncrna/Cryptosporidium_muris_rn66.JCVI-cmg-v1.0.ncrna.fa.gz',
	'cryptosporidium_parvum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/cryptosporidium_parvum/ncrna/Cryptosporidium_parvum.ASM20969v1.ncrna.fa.gz',
	'cryptosporidium_parvum_iowa_ii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/cryptosporidium_parvum_iowa_ii/ncrna/Cryptosporidium_parvum_iowa_ii.ASM16534v1.ncrna.fa.gz',
	'culex_quinquefasciatus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/culex_quinquefasciatus/ncrna/Culex_quinquefasciatus.CpipJ2.ncrna.fa.gz',
	'cutaneotrichosporon_oleaginosus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cutaneotrichosporon_oleaginosus/ncrna/Cutaneotrichosporon_oleaginosus.Triol1.ncrna.fa.gz',
	'cyberlindnera_fabianii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cyberlindnera_fabianii/ncrna/Cyberlindnera_fabianii.ASM198330v1.ncrna.fa.gz',
	'cyberlindnera_jadinii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cyberlindnera_jadinii/ncrna/Cyberlindnera_jadinii.cj1.ncrna.fa.gz',
	'cyberlindnera_jadinii_nrrl_y_1542'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cyberlindnera_jadinii_nrrl_y_1542/ncrna/Cyberlindnera_jadinii_nrrl_y_1542.Cybja1.ncrna.fa.gz',
	'cyclospora_cayetanensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/cyclospora_cayetanensis/ncrna/Cyclospora_cayetanensis.ASM76915v2.ncrna.fa.gz',
	'cylindrobasidium_torrendii_fp15055_ss_10'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cylindrobasidium_torrendii_fp15055_ss_10/ncrna/Cylindrobasidium_torrendii_fp15055_ss_10.Cylto1.ncrna.fa.gz',
	'cyphellophora_europaea_cbs_101466'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/cyphellophora_europaea_cbs_101466/ncrna/Cyphellophora_europaea_cbs_101466.Phia_euro_CBS_101466_V1.ncrna.fa.gz',
	'dacryopinax_primogenitus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/dacryopinax_primogenitus/ncrna/Dacryopinax_primogenitus.Dacryopinax_sp._DJM_731_SSP1_v1.0.ncrna.fa.gz',
	'dactylellina_haptotyla_cbs_200_50'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/dactylellina_haptotyla_cbs_200_50/ncrna/Dactylellina_haptotyla_cbs_200_50.MHA_v2.ncrna.fa.gz',
	'daedalea_quercina_l_15889'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/daedalea_quercina_l_15889/ncrna/Daedalea_quercina_l_15889.Daequ1.ncrna.fa.gz',
	'danaus_plexippus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/danaus_plexippus/ncrna/Danaus_plexippus.DanPle_1.0.ncrna.fa.gz',
	'danio_rerio'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/danio_rerio/ncrna/Danio_rerio.GRCz10.ncrna.fa.gz',
	'daphnia_pulex'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/daphnia_pulex/ncrna/Daphnia_pulex.V1.0.ncrna.fa.gz',
	'dasypus_novemcinctus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/dasypus_novemcinctus/ncrna/Dasypus_novemcinctus.Dasnov3.0.ncrna.fa.gz',
	'debaryomyces_fabryi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/debaryomyces_fabryi/ncrna/Debaryomyces_fabryi.debFab1.0.ncrna.fa.gz',
	'debaryomyces_hansenii_cbs767'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/debaryomyces_hansenii_cbs767/ncrna/Debaryomyces_hansenii_cbs767.ASM644v2.ncrna.fa.gz',
	'dendroctonus_ponderosae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/dendroctonus_ponderosae/ncrna/Dendroctonus_ponderosae.DendPond_male_1.0.ncrna.fa.gz',
	'diaporthe_ampelina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/diaporthe_ampelina/ncrna/Diaporthe_ampelina.UCDDA912v1.0.ncrna.fa.gz',
	'diaporthe_helianthi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/diaporthe_helianthi/ncrna/Diaporthe_helianthi.ASM170239v1.ncrna.fa.gz',
	'dichomitus_squalens_lyad_421_ss1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/dichomitus_squalens_lyad_421_ss1/ncrna/Dichomitus_squalens_lyad_421_ss1.Dichomitus_squalens_v1.0.ncrna.fa.gz',
	'dictyostelium_discoideum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/dictyostelium_discoideum/ncrna/Dictyostelium_discoideum.dicty_2.7.ncrna.fa.gz',
	'dictyostelium_fasciculatum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/dictyostelium_fasciculatum/ncrna/Dictyostelium_fasciculatum.DFas_2.0.ncrna.fa.gz',
	'dictyostelium_lacteum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/dictyostelium_lacteum/ncrna/Dictyostelium_lacteum.ASM160615v1.ncrna.fa.gz',
	'diplodia_corticola'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/diplodia_corticola/ncrna/Diplodia_corticola.ASM188384v1.ncrna.fa.gz',
	'diplodia_seriata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/diplodia_seriata/ncrna/Diplodia_seriata.UCDDS831v0.1.ncrna.fa.gz',
	'diplodia_seriata_gca_001975905'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/diplodia_seriata_gca_001975905/ncrna/Diplodia_seriata_gca_001975905.Dipser_v1.ncrna.fa.gz',
	'dipodomys_ordii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/dipodomys_ordii/ncrna/Dipodomys_ordii.Dord_2.0.ncrna.fa.gz',
	'dothistroma_septosporum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/dothistroma_septosporum/ncrna/Dothistroma_septosporum.GCA_000340195.1.ncrna.fa.gz',
	'drechmeria_coniospora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/drechmeria_coniospora/ncrna/Drechmeria_coniospora.ASM162519v1.ncrna.fa.gz',
	'drechslerella_stenobrocha_248'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/drechslerella_stenobrocha_248/ncrna/Drechslerella_stenobrocha_248.DREv1.ncrna.fa.gz',
	'drosophila_ananassae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_ananassae/ncrna/Drosophila_ananassae.dana_caf1.ncrna.fa.gz',
	'drosophila_erecta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_erecta/ncrna/Drosophila_erecta.dere_caf1.ncrna.fa.gz',
	'drosophila_grimshawi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_grimshawi/ncrna/Drosophila_grimshawi.dgri_caf1.ncrna.fa.gz',
	'drosophila_melanogaster'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_melanogaster/ncrna/Drosophila_melanogaster.BDGP6.ncrna.fa.gz',
	'drosophila_mojavensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_mojavensis/ncrna/Drosophila_mojavensis.dmoj_caf1.ncrna.fa.gz',
	'drosophila_persimilis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_persimilis/ncrna/Drosophila_persimilis.dper_caf1.ncrna.fa.gz',
	'drosophila_pseudoobscura'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_pseudoobscura/ncrna/Drosophila_pseudoobscura.Dpse_3.0.ncrna.fa.gz',
	'drosophila_sechellia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_sechellia/ncrna/Drosophila_sechellia.dsec_caf1.ncrna.fa.gz',
	'drosophila_simulans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_simulans/ncrna/Drosophila_simulans.dsim_caf1.ncrna.fa.gz',
	'drosophila_virilis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_virilis/ncrna/Drosophila_virilis.dvir_caf1.ncrna.fa.gz',
	'drosophila_willistoni'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_willistoni/ncrna/Drosophila_willistoni.dwil_caf1.ncrna.fa.gz',
	'drosophila_yakuba'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_yakuba/ncrna/Drosophila_yakuba.dyak_caf1.ncrna.fa.gz',
	'echinops_telfairi'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/echinops_telfairi/ncrna/Echinops_telfairi.TENREC.ncrna.fa.gz',
	'edhazardia_aedis_usnm_41457'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/edhazardia_aedis_usnm_41457/ncrna/Edhazardia_aedis_usnm_41457.Edha_aedis_V4b.ncrna.fa.gz',
	'eimeria_brunetti'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_brunetti/ncrna/Eimeria_brunetti.EBH001.ncrna.fa.gz',
	'eimeria_maxima'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_maxima/ncrna/Eimeria_maxima.EMW001.ncrna.fa.gz',
	'eimeria_mitis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_mitis/ncrna/Eimeria_mitis.EMH001.ncrna.fa.gz',
	'eimeria_praecox'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_praecox/ncrna/Eimeria_praecox.EPH001.ncrna.fa.gz',
	'eimeria_tenella'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_tenella/ncrna/Eimeria_tenella.ASM283v1.ncrna.fa.gz',
	'eimeria_tenella_gca_000499545'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_tenella_gca_000499545/ncrna/Eimeria_tenella_gca_000499545.ETH001.ncrna.fa.gz',
	'emergomyces_pasteuriana_ep9510'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/emergomyces_pasteuriana_ep9510/ncrna/Emergomyces_pasteuriana_ep9510.Emmo_past_UAMH9510_V1.ncrna.fa.gz',
	'emiliania_huxleyi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/emiliania_huxleyi/ncrna/Emiliania_huxleyi.Emiliana_huxleyi_CCMP1516_main_genome_assembly_v1.0.ncrna.fa.gz',
	'emmonsia_crescens_uamh_3008'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/emmonsia_crescens_uamh_3008/ncrna/Emmonsia_crescens_uamh_3008.ASM100828v1.ncrna.fa.gz',
	'emmonsia_parva_uamh_139'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/emmonsia_parva_uamh_139/ncrna/Emmonsia_parva_uamh_139.ASM101475v1.ncrna.fa.gz',
	'emmonsia_sp_cac_2015a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/emmonsia_sp_cac_2015a/ncrna/Emmonsia_sp_cac_2015a.Emmo_afri_EA111.ncrna.fa.gz',
	'encephalitozoon_cuniculi_ecuniii_l'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/encephalitozoon_cuniculi_ecuniii_l/ncrna/Encephalitozoon_cuniculi_ecuniii_l.ECIIIL.ncrna.fa.gz',
	'encephalitozoon_cuniculi_gb_m1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/encephalitozoon_cuniculi_gb_m1/ncrna/Encephalitozoon_cuniculi_gb_m1.ASM9122v1.ncrna.fa.gz',
	'encephalitozoon_hellem_atcc_50504'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/encephalitozoon_hellem_atcc_50504/ncrna/Encephalitozoon_hellem_atcc_50504.ASM27781v3.ncrna.fa.gz',
	'encephalitozoon_intestinalis_atcc_50506'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/encephalitozoon_intestinalis_atcc_50506/ncrna/Encephalitozoon_intestinalis_atcc_50506.ASM14646v1.ncrna.fa.gz',
	'encephalitozoon_romaleae_sj_2008'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/encephalitozoon_romaleae_sj_2008/ncrna/Encephalitozoon_romaleae_sj_2008.ASM28003v2.ncrna.fa.gz',
	'endocarpon_pusillum_z07020'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/endocarpon_pusillum_z07020/ncrna/Endocarpon_pusillum_z07020.EPUS.ncrna.fa.gz',
	'entamoeba_histolytica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/entamoeba_histolytica/ncrna/Entamoeba_histolytica.JCVI-ESG2-1.0.ncrna.fa.gz',
	'entamoeba_histolytica_gca_001662325'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/entamoeba_histolytica_gca_001662325/ncrna/Entamoeba_histolytica_gca_001662325.Ehistolytica_2016.ncrna.fa.gz',
	'entamoeba_histolytica_hm_3_imss'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/entamoeba_histolytica_hm_3_imss/ncrna/Entamoeba_histolytica_hm_3_imss.EHA.strHM3_v1.ncrna.fa.gz',
	'entamoeba_histolytica_ku27'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/entamoeba_histolytica_ku27/ncrna/Entamoeba_histolytica_ku27.EHA_ku27_v1.ncrna.fa.gz',
	'entamoeba_nuttalli_p19'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/entamoeba_nuttalli_p19/ncrna/Entamoeba_nuttalli_p19.ENU1_v1.ncrna.fa.gz',
	'enterocytozoon_bieneusi_h348'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/enterocytozoon_bieneusi_h348/ncrna/Enterocytozoon_bieneusi_h348.ASM20948v1.ncrna.fa.gz',
	'enterocytozoon_hepatopenaei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/enterocytozoon_hepatopenaei/ncrna/Enterocytozoon_hepatopenaei.ASM208167v1.ncrna.fa.gz',
	'enterospora_canceri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/enterospora_canceri/ncrna/Enterospora_canceri.ASM208791v1.ncrna.fa.gz',
	'equus_caballus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/equus_caballus/ncrna/Equus_caballus.EquCab2.ncrna.fa.gz',
	'eremothecium_cymbalariae_dbvpg_7215'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/eremothecium_cymbalariae_dbvpg_7215/ncrna/Eremothecium_cymbalariae_dbvpg_7215.ASM23536v1.ncrna.fa.gz',
	'eremothecium_gossypii_fdag1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/eremothecium_gossypii_fdag1/ncrna/Eremothecium_gossypii_fdag1.ASM96883v1.ncrna.fa.gz',
	'eremothecium_sinecaudum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/eremothecium_sinecaudum/ncrna/Eremothecium_sinecaudum.ASM154855v1.ncrna.fa.gz',
	'erinaceus_europaeus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/erinaceus_europaeus/ncrna/Erinaceus_europaeus.HEDGEHOG.ncrna.fa.gz',
	'erysiphe_necator'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/erysiphe_necator/ncrna/Erysiphe_necator.ASM79871v1.ncrna.fa.gz',
	'escovopsis_weberi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/escovopsis_weberi/ncrna/Escovopsis_weberi.ASM127849v1.ncrna.fa.gz',
	'eutypa_lata_ucrel1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/eutypa_lata_ucrel1/ncrna/Eutypa_lata_ucrel1.UCREL1V03.ncrna.fa.gz',
	'exidia_glandulosa_hhb12029'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/exidia_glandulosa_hhb12029/ncrna/Exidia_glandulosa_hhb12029.Exigl1.ncrna.fa.gz',
	'exophiala_aquamarina_cbs_119918'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/exophiala_aquamarina_cbs_119918/ncrna/Exophiala_aquamarina_cbs_119918.Exop_aqua_CBS_119918_V1.ncrna.fa.gz',
	'exophiala_dermatitidis_nih_ut8656'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/exophiala_dermatitidis_nih_ut8656/ncrna/Exophiala_dermatitidis_nih_ut8656.Exop_derm_V1.ncrna.fa.gz',
	'exophiala_mesophila'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/exophiala_mesophila/ncrna/Exophiala_mesophila.Exop_meso_CBS40295_V1.ncrna.fa.gz',
	'exophiala_oligosperma'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/exophiala_oligosperma/ncrna/Exophiala_oligosperma.Exop_olig_CBS72588_V1.ncrna.fa.gz',
	'exophiala_sideris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/exophiala_sideris/ncrna/Exophiala_sideris.Exop_side_CBS121828_V1.ncrna.fa.gz',
	'exophiala_spinifera'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/exophiala_spinifera/ncrna/Exophiala_spinifera.Exop_spin_CBS89968_V1.ncrna.fa.gz',
	'exophiala_xenobiotica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/exophiala_xenobiotica/ncrna/Exophiala_xenobiotica.Exop_xeno_CBS118157_V1.ncrna.fa.gz',
	'felis_catus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/felis_catus/ncrna/Felis_catus.Felis_catus_6.2.ncrna.fa.gz',
	'fibroporia_radiculosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/fibroporia_radiculosa/ncrna/Fibroporia_radiculosa.ASM31352v1.ncrna.fa.gz',
	'fibulorhizoctonia_sp_cbs_109695'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/fibulorhizoctonia_sp_cbs_109695/ncrna/Fibulorhizoctonia_sp_cbs_109695.Fibsp1.ncrna.fa.gz',
	'ficedula_albicollis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ficedula_albicollis/ncrna/Ficedula_albicollis.FicAlb_1.4.ncrna.fa.gz',
	'fistulina_hepatica_atcc_64428'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/fistulina_hepatica_atcc_64428/ncrna/Fistulina_hepatica_atcc_64428.Fishe1.ncrna.fa.gz',
	'fomitiporia_mediterranea_mf3_22'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/fomitiporia_mediterranea_mf3_22/ncrna/Fomitiporia_mediterranea_mf3_22.Fomme1.ncrna.fa.gz',
	'fomitopsis_pinicola_fp_58527_ss1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/fomitopsis_pinicola_fp_58527_ss1/ncrna/Fomitopsis_pinicola_fp_58527_ss1.Fompi3.ncrna.fa.gz',
	'fonsecaea_erecta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fonsecaea_erecta/ncrna/Fonsecaea_erecta.ASM165198v1.ncrna.fa.gz',
	'fonsecaea_monophora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fonsecaea_monophora/ncrna/Fonsecaea_monophora.ASM164247v1.ncrna.fa.gz',
	'fonsecaea_multimorphosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fonsecaea_multimorphosa/ncrna/Fonsecaea_multimorphosa.ASM164698v1.ncrna.fa.gz',
	'fonsecaea_multimorphosa_cbs_102226'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/fonsecaea_multimorphosa_cbs_102226/ncrna/Fonsecaea_multimorphosa_cbs_102226.Fons_mult_CBS_102226_V1.ncrna.fa.gz',
	'fonsecaea_nubica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fonsecaea_nubica/ncrna/Fonsecaea_nubica.ASM164696v1.ncrna.fa.gz',
	'fonsecaea_pedrosoi_cbs_271_37'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/fonsecaea_pedrosoi_cbs_271_37/ncrna/Fonsecaea_pedrosoi_cbs_271_37.Fons_pedr_CBS_271_37_V1.ncrna.fa.gz',
	'fonticula_alba_gca_000388065'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_nucleariidaeandfonticulagroup1_collection/fonticula_alba_gca_000388065/ncrna/Fonticula_alba_gca_000388065.Font_alba_ATCC_38817_V2.ncrna.fa.gz',
	'fukomys_damarensis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/fukomys_damarensis/ncrna/Fukomys_damarensis.DMR_v1.0.ncrna.fa.gz',
	'fusarium_culmorum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_culmorum/ncrna/Fusarium_culmorum.EF1.ncrna.fa.gz',
	'fusarium_fujikuroi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_fujikuroi/ncrna/Fusarium_fujikuroi.EF1.ncrna.fa.gz',
	'fusarium_fujikuroi_gca_001023035'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/fusarium_fujikuroi_gca_001023035/ncrna/Fusarium_fujikuroi_gca_001023035.ASM102303v1.ncrna.fa.gz',
	'fusarium_fujikuroi_gca_001023045'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_fujikuroi_gca_001023045/ncrna/Fusarium_fujikuroi_gca_001023045.ASM102304v1.ncrna.fa.gz',
	'fusarium_fujikuroi_gca_001023065'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/fusarium_fujikuroi_gca_001023065/ncrna/Fusarium_fujikuroi_gca_001023065.ASM102306v1.ncrna.fa.gz',
	'fusarium_graminearum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_graminearum/ncrna/Fusarium_graminearum.RR1.ncrna.fa.gz',
	'fusarium_graminearum_gca_000599445'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_graminearum_gca_000599445/ncrna/Fusarium_graminearum_gca_000599445.CS3005v1.ncrna.fa.gz',
	'fusarium_langsethiae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_langsethiae/ncrna/Fusarium_langsethiae.ASM129263v1.ncrna.fa.gz',
	'fusarium_mangiferae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_mangiferae/ncrna/Fusarium_mangiferae.Genome_assembly_version_1.ncrna.fa.gz',
	'fusarium_oxysporum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_oxysporum/ncrna/Fusarium_oxysporum.FO2.ncrna.fa.gz',
	'fusarium_oxysporum_f_sp_conglutinans_race_2_54008'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_conglutinans_race_2_54008/ncrna/Fusarium_oxysporum_f_sp_conglutinans_race_2_54008.FO_PHW808_V1.ncrna.fa.gz',
	'fusarium_oxysporum_f_sp_cubense_race_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_cubense_race_1/ncrna/Fusarium_oxysporum_f_sp_cubense_race_1.Foc1_1.0.ncrna.fa.gz',
	'fusarium_oxysporum_f_sp_cubense_race_4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_cubense_race_4/ncrna/Fusarium_oxysporum_f_sp_cubense_race_4.Foc4_1.0.ncrna.fa.gz',
	'fusarium_oxysporum_f_sp_cubense_tropical_race_4_54006'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_cubense_tropical_race_4_54006/ncrna/Fusarium_oxysporum_f_sp_cubense_tropical_race_4_54006.FO_II5_V1.ncrna.fa.gz',
	'fusarium_oxysporum_f_sp_lycopersici_mn25'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_lycopersici_mn25/ncrna/Fusarium_oxysporum_f_sp_lycopersici_mn25.FO_MN25_V1.ncrna.fa.gz',
	'fusarium_oxysporum_f_sp_melonis_26406'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_melonis_26406/ncrna/Fusarium_oxysporum_f_sp_melonis_26406.FO_melonis_V1.ncrna.fa.gz',
	'fusarium_oxysporum_f_sp_pisi_hdv247'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_pisi_hdv247/ncrna/Fusarium_oxysporum_f_sp_pisi_hdv247.FO_HDV247_V1.ncrna.fa.gz',
	'fusarium_oxysporum_f_sp_radicis_lycopersici_26381'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_radicis_lycopersici_26381/ncrna/Fusarium_oxysporum_f_sp_radicis_lycopersici_26381.FO_CL57_V1.ncrna.fa.gz',
	'fusarium_oxysporum_f_sp_raphani_54005'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_raphani_54005/ncrna/Fusarium_oxysporum_f_sp_raphani_54005.FO_PHW815_V1.ncrna.fa.gz',
	'fusarium_oxysporum_f_sp_vasinfectum_25433'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_vasinfectum_25433/ncrna/Fusarium_oxysporum_f_sp_vasinfectum_25433.FO_Cotton_V1.ncrna.fa.gz',
	'fusarium_oxysporum_fo47'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_fo47/ncrna/Fusarium_oxysporum_fo47.FO_Fo47_V1.ncrna.fa.gz',
	'fusarium_oxysporum_fosc_3_a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_fosc_3_a/ncrna/Fusarium_oxysporum_fosc_3_a.FO_FOSC_3_a_V1.ncrna.fa.gz',
	'fusarium_poae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_poae/ncrna/Fusarium_poae.FPOA1.0.ncrna.fa.gz',
	'fusarium_proliferatum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_proliferatum/ncrna/Fusarium_proliferatum.F._proliferatum_NRRL62905_version_1.ncrna.fa.gz',
	'fusarium_proliferatum_et1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_proliferatum_et1/ncrna/Fusarium_proliferatum_et1.F._proliferatum_ET1_version_1.ncrna.fa.gz',
	'fusarium_pseudograminearum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_pseudograminearum/ncrna/Fusarium_pseudograminearum.GCA_000303195.1.ncrna.fa.gz',
	'fusarium_solani'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_solani/ncrna/Fusarium_solani.v2.0.ncrna.fa.gz',
	'fusarium_verticillioides'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_verticillioides/ncrna/Fusarium_verticillioides.ASM14955v1.ncrna.fa.gz',
	'gadus_morhua'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/gadus_morhua/ncrna/Gadus_morhua.gadMor1.ncrna.fa.gz',
	'gaeumannomyces_graminis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/gaeumannomyces_graminis/ncrna/Gaeumannomyces_graminis.Gae_graminis_V2.ncrna.fa.gz',
	'galdieria_sulphuraria'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/galdieria_sulphuraria/ncrna/Galdieria_sulphuraria.ASM34128v1.ncrna.fa.gz',
	'galerina_marginata_cbs_339_88'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/galerina_marginata_cbs_339_88/ncrna/Galerina_marginata_cbs_339_88.Galma1.ncrna.fa.gz',
	'gallus_gallus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/gallus_gallus/ncrna/Gallus_gallus.Gallus_gallus-5.0.ncrna.fa.gz',
	'gasterosteus_aculeatus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/gasterosteus_aculeatus/ncrna/Gasterosteus_aculeatus.BROADS1.ncrna.fa.gz',
	'gelatoporia_subvermispora_b'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/gelatoporia_subvermispora_b/ncrna/Gelatoporia_subvermispora_b.Ceriporiopsis_subvermispora_B_v1.0.ncrna.fa.gz',
	'geotrichum_candidum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/geotrichum_candidum/ncrna/Geotrichum_candidum.New2.3_08062011.ncrna.fa.gz',
	'giardia_intestinalis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/giardia_intestinalis/ncrna/Giardia_intestinalis.ASM49873v1.ncrna.fa.gz',
	'giardia_intestinalis_assemblage_b'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/giardia_intestinalis_assemblage_b/ncrna/Giardia_intestinalis_assemblage_b.G_duodenalis_AssB_BAH15c1.ncrna.fa.gz',
	'giardia_intestinalis_atcc_50581'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/giardia_intestinalis_atcc_50581/ncrna/Giardia_intestinalis_atcc_50581.ASM18240v1.ncrna.fa.gz',
	'giardia_intestinalis_gca_000498715'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/giardia_intestinalis_gca_000498715/ncrna/Giardia_intestinalis_gca_000498715.ASM49871v1.ncrna.fa.gz',
	'giardia_lamblia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/giardia_lamblia/ncrna/Giardia_lamblia.GL2.ncrna.fa.gz',
	'giardia_lamblia_p15'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/giardia_lamblia_p15/ncrna/Giardia_lamblia_p15.ASM18266v1.ncrna.fa.gz',
	'glarea_lozoyensis_74030'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/glarea_lozoyensis_74030/ncrna/Glarea_lozoyensis_74030.LBAGla_1.0.ncrna.fa.gz',
	'glarea_lozoyensis_atcc_20868'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/glarea_lozoyensis_atcc_20868/ncrna/Glarea_lozoyensis_atcc_20868.GLAREA.ncrna.fa.gz',
	'gloeophyllum_trabeum_atcc_11539'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/gloeophyllum_trabeum_atcc_11539/ncrna/Gloeophyllum_trabeum_atcc_11539.Glotr1_1.ncrna.fa.gz',
	'glycine_max'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/glycine_max/ncrna/Glycine_max.V1.0.ncrna.fa.gz',
	'gonapodya_prolifera_jel478'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_chytridiomycota1_collection/gonapodya_prolifera_jel478/ncrna/Gonapodya_prolifera_jel478.Ganpr1.ncrna.fa.gz',
	'gorilla_gorilla'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/gorilla_gorilla/ncrna/Gorilla_gorilla.gorGor3.1.ncrna.fa.gz',
	'gregarina_niphandrodes'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/gregarina_niphandrodes/ncrna/Gregarina_niphandrodes.GNI3.ncrna.fa.gz',
	'grifola_frondosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/grifola_frondosa/ncrna/Grifola_frondosa.ASM168373v1.ncrna.fa.gz',
	'grosmannia_clavigera_kw1407'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/grosmannia_clavigera_kw1407/ncrna/Grosmannia_clavigera_kw1407.Sanger-454-IlluminaPA_2.0.ncrna.fa.gz',
	'guillardia_theta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/guillardia_theta/ncrna/Guillardia_theta.Guith1.ncrna.fa.gz',
	'guillardia_theta_gca_000002975'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_cryptophyta1_collection/guillardia_theta_gca_000002975/ncrna/Guillardia_theta_gca_000002975.ASM297v1.ncrna.fa.gz',
	'gymnopus_luxurians_fd_317_m1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/gymnopus_luxurians_fd_317_m1/ncrna/Gymnopus_luxurians_fd_317_m1.Gymlu1.ncrna.fa.gz',
	'hammondia_hammondi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/hammondia_hammondi/ncrna/Hammondia_hammondi.HHA1_v02.ncrna.fa.gz',
	'hanseniaspora_guilliermondii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hanseniaspora_guilliermondii/ncrna/Hanseniaspora_guilliermondii.version_1.ncrna.fa.gz',
	'hanseniaspora_opuntiae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hanseniaspora_opuntiae/ncrna/Hanseniaspora_opuntiae.ASM174979v1.ncrna.fa.gz',
	'hanseniaspora_osmophila'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hanseniaspora_osmophila/ncrna/Hanseniaspora_osmophila.ASM174704v1.ncrna.fa.gz',
	'hanseniaspora_uvarum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hanseniaspora_uvarum/ncrna/Hanseniaspora_uvarum.ASM174705v1.ncrna.fa.gz',
	'hanseniaspora_uvarum_dsm_2768'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/hanseniaspora_uvarum_dsm_2768/ncrna/Hanseniaspora_uvarum_dsm_2768.Huva2.0.ncrna.fa.gz',
	'hanseniaspora_valbyensis_nrrl_y_1626'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hanseniaspora_valbyensis_nrrl_y_1626/ncrna/Hanseniaspora_valbyensis_nrrl_y_1626.Hanva1_1.ncrna.fa.gz',
	'hebeloma_cylindrosporum_h7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/hebeloma_cylindrosporum_h7/ncrna/Hebeloma_cylindrosporum_h7.Hebeloma_cylindrosporum_h7_v2.0.ncrna.fa.gz',
	'heliconius_melpomene'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/heliconius_melpomene/ncrna/Heliconius_melpomene.Hmel1.ncrna.fa.gz',
	'helobdella_robusta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/helobdella_robusta/ncrna/Helobdella_robusta.Helro1.ncrna.fa.gz',
	'hepatospora_eriocheir'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/hepatospora_eriocheir/ncrna/Hepatospora_eriocheir.ASM208787v1.ncrna.fa.gz',
	'hepatospora_eriocheir_gca_002087885'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/hepatospora_eriocheir_gca_002087885/ncrna/Hepatospora_eriocheir_gca_002087885.ASM208788v1.ncrna.fa.gz',
	'heterobasidion_irregulare_tc_32_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/heterobasidion_irregulare_tc_32_1/ncrna/Heterobasidion_irregulare_tc_32_1.Heterobasidion_irregulare_v2.0.ncrna.fa.gz',
	'heterocephalus_glaber_female'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/heterocephalus_glaber_female/ncrna/Heterocephalus_glaber_female.HetGla_female_1.0.ncrna.fa.gz',
	'heterocephalus_glaber_male'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/heterocephalus_glaber_male/ncrna/Heterocephalus_glaber_male.HetGla_1.0.ncrna.fa.gz',
	'hirsutella_minnesotensis_3608'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/hirsutella_minnesotensis_3608/ncrna/Hirsutella_minnesotensis_3608.ASM95604v1.ncrna.fa.gz',
	'histoplasma_capsulatum_g186ar'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/histoplasma_capsulatum_g186ar/ncrna/Histoplasma_capsulatum_g186ar.ASM15011v1.ncrna.fa.gz',
	'histoplasma_capsulatum_h143'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/histoplasma_capsulatum_h143/ncrna/Histoplasma_capsulatum_h143.ASM15103v1.ncrna.fa.gz',
	'histoplasma_capsulatum_h88'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/histoplasma_capsulatum_h88/ncrna/Histoplasma_capsulatum_h88.ASM15100v2.ncrna.fa.gz',
	'histoplasma_capsulatum_nam1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/histoplasma_capsulatum_nam1/ncrna/Histoplasma_capsulatum_nam1.ASM14958v1.ncrna.fa.gz',
	'homo_sapiens'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/homo_sapiens/ncrna/Homo_sapiens.GRCh38.ncrna.fa.gz',
	'hordeum_vulgare'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/hordeum_vulgare/ncrna/Hordeum_vulgare.Hv_IBSC_PGSB_v2.ncrna.fa.gz',
	'hyaloperonospora_arabidopsidis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/hyaloperonospora_arabidopsidis/ncrna/Hyaloperonospora_arabidopsidis.HyaAraEmoy2_2.0.ncrna.fa.gz',
	'hydnomerulius_pinastri_md_312'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/hydnomerulius_pinastri_md_312/ncrna/Hydnomerulius_pinastri_md_312.Hydpi2.ncrna.fa.gz',
	'hypholoma_sublateritium_fd_334_ss_4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/hypholoma_sublateritium_fd_334_ss_4/ncrna/Hypholoma_sublateritium_fd_334_ss_4.Hypsu1.ncrna.fa.gz',
	'hyphopichia_burtonii_nrrl_y_1933'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hyphopichia_burtonii_nrrl_y_1933/ncrna/Hyphopichia_burtonii_nrrl_y_1933.Hypbu1.ncrna.fa.gz',
	'hypsizygus_marmoreus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/hypsizygus_marmoreus/ncrna/Hypsizygus_marmoreus.ASM160531v1.ncrna.fa.gz',
	'ichthyophthirius_multifiliis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/ichthyophthirius_multifiliis/ncrna/Ichthyophthirius_multifiliis.JCVI-IMG1-V.1.ncrna.fa.gz',
	'ictidomys_tridecemlineatus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ictidomys_tridecemlineatus/ncrna/Ictidomys_tridecemlineatus.SpeTri2.0.ncrna.fa.gz',
	'isaria_fumosorosea_arsef_2679'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/isaria_fumosorosea_arsef_2679/ncrna/Isaria_fumosorosea_arsef_2679.ISF_1.0.ncrna.fa.gz',
	'ixodes_scapularis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/ixodes_scapularis/ncrna/Ixodes_scapularis.IscaW1.ncrna.fa.gz',
	'jaapia_argillacea_mucl_33604'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/jaapia_argillacea_mucl_33604/ncrna/Jaapia_argillacea_mucl_33604.Jaaar1.ncrna.fa.gz',
	'jaculus_jaculus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/jaculus_jaculus/ncrna/Jaculus_jaculus.JacJac1.0.ncrna.fa.gz',
	'kalmanozyma_brasiliensis_ghg001'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kalmanozyma_brasiliensis_ghg001/ncrna/Kalmanozyma_brasiliensis_ghg001.PSEUBRA1.ncrna.fa.gz',
	'kazachstania_africana_cbs_2517'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/kazachstania_africana_cbs_2517/ncrna/Kazachstania_africana_cbs_2517.Ka_CBS2517.ncrna.fa.gz',
	'kazachstania_naganishii_cbs_8797'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/kazachstania_naganishii_cbs_8797/ncrna/Kazachstania_naganishii_cbs_8797.ASM34898v1.ncrna.fa.gz',
	'kluyveromyces_lactis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/kluyveromyces_lactis/ncrna/Kluyveromyces_lactis.ASM251v1.ncrna.fa.gz',
	'kluyveromyces_marxianus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/kluyveromyces_marxianus/ncrna/Kluyveromyces_marxianus.KM1777_03.ncrna.fa.gz',
	'kluyveromyces_marxianus_dmku3_1042'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/kluyveromyces_marxianus_dmku3_1042/ncrna/Kluyveromyces_marxianus_dmku3_1042.Kmar_1.0.ncrna.fa.gz',
	'komagataella_pastoris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/komagataella_pastoris/ncrna/Komagataella_pastoris.GCA_000027005.1.ncrna.fa.gz',
	'komagataella_pastoris_gca_001708105'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/komagataella_pastoris_gca_001708105/ncrna/Komagataella_pastoris_gca_001708105.ASM170810v1.ncrna.fa.gz',
	'komagataella_phaffii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/komagataella_phaffii/ncrna/Komagataella_phaffii.ASM170808v1.ncrna.fa.gz',
	'komagataella_phaffii_cbs_7435'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/komagataella_phaffii_cbs_7435/ncrna/Komagataella_phaffii_cbs_7435.PicPas_Mar2011.ncrna.fa.gz',
	'komagataella_phaffii_gs115'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/komagataella_phaffii_gs115/ncrna/Komagataella_phaffii_gs115.ASM174695v1.ncrna.fa.gz',
	'kuraishia_capsulata_cbs_1993'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/kuraishia_capsulata_cbs_1993/ncrna/Kuraishia_capsulata_cbs_1993.AUH_PRJEB4427_v1.ncrna.fa.gz',
	'kwoniella_bestiolae_cbs_10118'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_bestiolae_cbs_10118/ncrna/Kwoniella_bestiolae_cbs_10118.Cryp_best_CBS10118_V1.ncrna.fa.gz',
	'kwoniella_dejecticola_cbs_10117'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_dejecticola_cbs_10117/ncrna/Kwoniella_dejecticola_cbs_10117.Cryp_deje_CBS10117_V1.ncrna.fa.gz',
	'kwoniella_heveanensis_bcc8398'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_heveanensis_bcc8398/ncrna/Kwoniella_heveanensis_bcc8398.Cryp_heve_BCC8398_V1.ncrna.fa.gz',
	'kwoniella_heveanensis_cbs_569'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_heveanensis_cbs_569/ncrna/Kwoniella_heveanensis_cbs_569.Cryp_heve_CBS569_V2.ncrna.fa.gz',
	'kwoniella_mangroviensis_cbs_10435'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_mangroviensis_cbs_10435/ncrna/Kwoniella_mangroviensis_cbs_10435.Kwon_mang_CBS10435_V2.ncrna.fa.gz',
	'kwoniella_mangroviensis_cbs_8507'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_mangroviensis_cbs_8507/ncrna/Kwoniella_mangroviensis_cbs_8507.Kwon_mang_CBS8507_V2.ncrna.fa.gz',
	'kwoniella_mangroviensis_cbs_8886'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_mangroviensis_cbs_8886/ncrna/Kwoniella_mangroviensis_cbs_8886.Kwon_mang_CBS8886_V1.ncrna.fa.gz',
	'kwoniella_pini_cbs_10737'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_pini_cbs_10737/ncrna/Kwoniella_pini_cbs_10737.Cryp_pinu_CBS10737_V1.ncrna.fa.gz',
	'laccaria_amethystina_laam_08_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/laccaria_amethystina_laam_08_1/ncrna/Laccaria_amethystina_laam_08_1.Laccaria_amethystina_LaAM-08-1_v1.0.ncrna.fa.gz',
	'laccaria_bicolor_s238n_h82'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/laccaria_bicolor_s238n_h82/ncrna/Laccaria_bicolor_s238n_h82.V1.0.ncrna.fa.gz',
	'lachancea_dasiensis_cbs_10888'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_dasiensis_cbs_10888/ncrna/Lachancea_dasiensis_cbs_10888.LADA0.ncrna.fa.gz',
	'lachancea_fermentati'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_fermentati/ncrna/Lachancea_fermentati.LAFE0.ncrna.fa.gz',
	'lachancea_lanzarotensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/lachancea_lanzarotensis/ncrna/Lachancea_lanzarotensis.LALA0.ncrna.fa.gz',
	'lachancea_meyersii_cbs_8951'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_meyersii_cbs_8951/ncrna/Lachancea_meyersii_cbs_8951.LAME0.ncrna.fa.gz',
	'lachancea_mirantina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_mirantina/ncrna/Lachancea_mirantina.LAMI0.ncrna.fa.gz',
	'lachancea_nothofagi_cbs_11611'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_nothofagi_cbs_11611/ncrna/Lachancea_nothofagi_cbs_11611.LANO0.ncrna.fa.gz',
	'lachancea_sp_cbs_6924'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_sp_cbs_6924/ncrna/Lachancea_sp_cbs_6924.LAFA0.ncrna.fa.gz',
	'lachancea_thermotolerans_cbs_6340'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/lachancea_thermotolerans_cbs_6340/ncrna/Lachancea_thermotolerans_cbs_6340.ASM14280v1.ncrna.fa.gz',
	'laetiporus_sulphureus_93_53'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/laetiporus_sulphureus_93_53/ncrna/Laetiporus_sulphureus_93_53.Laesu1.ncrna.fa.gz',
	'latimeria_chalumnae'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/latimeria_chalumnae/ncrna/Latimeria_chalumnae.LatCha1.ncrna.fa.gz',
	'leersia_perrieri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/leersia_perrieri/ncrna/Leersia_perrieri.Lperr_V1.4.ncrna.fa.gz',
	'leishmania_braziliensis_mhom_br_75_m2904'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leishmania_braziliensis_mhom_br_75_m2904/ncrna/Leishmania_braziliensis_mhom_br_75_m2904.ASM284v2.ncrna.fa.gz',
	'leishmania_donovani_bpk282a1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leishmania_donovani_bpk282a1/ncrna/Leishmania_donovani_bpk282a1.ASM22713v2.ncrna.fa.gz',
	'leishmania_infantum_jpcm5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leishmania_infantum_jpcm5/ncrna/Leishmania_infantum_jpcm5.ASM287v2.ncrna.fa.gz',
	'leishmania_major'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/leishmania_major/ncrna/Leishmania_major.ASM272v2.ncrna.fa.gz',
	'leishmania_mexicana_mhom_gt_2001_u1103'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leishmania_mexicana_mhom_gt_2001_u1103/ncrna/Leishmania_mexicana_mhom_gt_2001_u1103.ASM23466v4.ncrna.fa.gz',
	'leishmania_panamensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leishmania_panamensis/ncrna/Leishmania_panamensis.ASM75516v1.ncrna.fa.gz',
	'lentinula_edodes'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/lentinula_edodes/ncrna/Lentinula_edodes.Lened_assembly01.ncrna.fa.gz',
	'lepeophtheirus_salmonis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/lepeophtheirus_salmonis/ncrna/Lepeophtheirus_salmonis.LSalAtl2s.ncrna.fa.gz',
	'lepisosteus_oculatus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/lepisosteus_oculatus/ncrna/Lepisosteus_oculatus.LepOcu1.ncrna.fa.gz',
	'leptomonas_pyrrhocoris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leptomonas_pyrrhocoris/ncrna/Leptomonas_pyrrhocoris.ASM129339v1.ncrna.fa.gz',
	'leptomonas_seymouri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leptomonas_seymouri/ncrna/Leptomonas_seymouri.ASM129953v1.ncrna.fa.gz',
	'leptosphaeria_maculans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/leptosphaeria_maculans/ncrna/Leptosphaeria_maculans.ASM23037v1.ncrna.fa.gz',
	'leucoagaricus_sp_symc_cos'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/leucoagaricus_sp_symc_cos/ncrna/Leucoagaricus_sp_symc_cos.ASM156373v1.ncrna.fa.gz',
	'lingula_anatina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/lingula_anatina/ncrna/Lingula_anatina.LinAna1.0.ncrna.fa.gz',
	'lipomyces_starkeyi_nrrl_y_11557'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lipomyces_starkeyi_nrrl_y_11557/ncrna/Lipomyces_starkeyi_nrrl_y_11557.Lipst1_1.ncrna.fa.gz',
	'loa_loa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/loa_loa/ncrna/Loa_loa.Loa_loa_V3.ncrna.fa.gz',
	'lodderomyces_elongisporus_nrrl_yb_4239'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/lodderomyces_elongisporus_nrrl_yb_4239/ncrna/Lodderomyces_elongisporus_nrrl_yb_4239.ASM14968v1.ncrna.fa.gz',
	'lotharella_oceanica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_rhizaria1_collection/lotharella_oceanica/ncrna/Lotharella_oceanica.ASM69843v2.ncrna.fa.gz',
	'lottia_gigantea'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/lottia_gigantea/ncrna/Lottia_gigantea.Lotgi1.ncrna.fa.gz',
	'loxodonta_africana'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/loxodonta_africana/ncrna/Loxodonta_africana.loxAfr3.ncrna.fa.gz',
	'lucilia_cuprina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/lucilia_cuprina/ncrna/Lucilia_cuprina.ASM118794v1.ncrna.fa.gz',
	'macaca_mulatta'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/macaca_mulatta/ncrna/Macaca_mulatta.Mmul_8.0.1.ncrna.fa.gz',
	'macrophomina_phaseolina_ms6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/macrophomina_phaseolina_ms6/ncrna/Macrophomina_phaseolina_ms6.MphMS6_1.0.ncrna.fa.gz',
	'madurella_mycetomatis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/madurella_mycetomatis/ncrna/Madurella_mycetomatis.ASM127576v2.ncrna.fa.gz',
	'magnaporthe_oryzae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/magnaporthe_oryzae/ncrna/Magnaporthe_oryzae.MG8.ncrna.fa.gz',
	'magnaporthe_poae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/magnaporthe_poae/ncrna/Magnaporthe_poae.Mag_poae_ATCC_64411_V1.ncrna.fa.gz',
	'malassezia_pachydermatis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/malassezia_pachydermatis/ncrna/Malassezia_pachydermatis.MalaPachy.ncrna.fa.gz',
	'malassezia_sympodialis_atcc_42132'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/malassezia_sympodialis_atcc_42132/ncrna/Malassezia_sympodialis_atcc_42132.ASM34930v2.ncrna.fa.gz',
	'malassezia_sympodialis_atcc_42132_gca_900149145'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/malassezia_sympodialis_atcc_42132_gca_900149145/ncrna/Malassezia_sympodialis_atcc_42132_gca_900149145.Msy_ATCC_42132_Feb2016.ncrna.fa.gz',
	'marssonina_brunnea_f_sp_multigermtubi_mb_m1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/marssonina_brunnea_f_sp_multigermtubi_mb_m1/ncrna/Marssonina_brunnea_f_sp_multigermtubi_mb_m1.ASM29877v1.ncrna.fa.gz',
	'mayetiola_destructor'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/mayetiola_destructor/ncrna/Mayetiola_destructor.Mdes_1.0.ncrna.fa.gz',
	'medicago_truncatula'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/medicago_truncatula/ncrna/Medicago_truncatula.MedtrA17_4.0.ncrna.fa.gz',
	'megaselia_scalaris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/megaselia_scalaris/ncrna/Megaselia_scalaris.Msca1.ncrna.fa.gz',
	'melampsora_laricipopulina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/melampsora_laricipopulina/ncrna/Melampsora_laricipopulina.GCA_000204055.1.ncrna.fa.gz',
	'meleagris_gallopavo'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/meleagris_gallopavo/ncrna/Meleagris_gallopavo.UMD2.ncrna.fa.gz',
	'melitaea_cinxia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/melitaea_cinxia/ncrna/Melitaea_cinxia.MelCinx1.0.ncrna.fa.gz',
	'mesocricetus_auratus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mesocricetus_auratus/ncrna/Mesocricetus_auratus.MesAur1.0.ncrna.fa.gz',
	'metarhizium_acridum_cqma_102'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/metarhizium_acridum_cqma_102/ncrna/Metarhizium_acridum_cqma_102.MetAcr_May2010.ncrna.fa.gz',
	'metarhizium_album_arsef_1941'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_album_arsef_1941/ncrna/Metarhizium_album_arsef_1941.MAM_1.0_for_version_1_of_the_Metarhizium_album_genome.ncrna.fa.gz',
	'metarhizium_anisopliae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/metarhizium_anisopliae/ncrna/Metarhizium_anisopliae.Metarhizium_anisopliae.ncrna.fa.gz',
	'metarhizium_anisopliae_arsef_23'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/metarhizium_anisopliae_arsef_23/ncrna/Metarhizium_anisopliae_arsef_23.MAA_2.0.ncrna.fa.gz',
	'metarhizium_anisopliae_arsef_549'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_anisopliae_arsef_549/ncrna/Metarhizium_anisopliae_arsef_549.MAN_1.0.ncrna.fa.gz',
	'metarhizium_anisopliae_brip_53284'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_anisopliae_brip_53284/ncrna/Metarhizium_anisopliae_brip_53284.ASM42698v1.ncrna.fa.gz',
	'metarhizium_anisopliae_brip_53293'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_anisopliae_brip_53293/ncrna/Metarhizium_anisopliae_brip_53293.ASM42696v1.ncrna.fa.gz',
	'metarhizium_brunneum_arsef_3297'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_brunneum_arsef_3297/ncrna/Metarhizium_brunneum_arsef_3297.MBR_1.0.ncrna.fa.gz',
	'metarhizium_guizhouense_arsef_977'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_guizhouense_arsef_977/ncrna/Metarhizium_guizhouense_arsef_977.MGU_1.0.ncrna.fa.gz',
	'metarhizium_majus_arsef_297'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_majus_arsef_297/ncrna/Metarhizium_majus_arsef_297.MAJ_1.0.ncrna.fa.gz',
	'metarhizium_rileyi_rcef_4871'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/metarhizium_rileyi_rcef_4871/ncrna/Metarhizium_rileyi_rcef_4871.NOR_1.0.ncrna.fa.gz',
	'metarhizium_robertsii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/metarhizium_robertsii/ncrna/Metarhizium_robertsii.MR2010_11_27.ncrna.fa.gz',
	'metschnikowia_bicuspidata_var_bicuspidata_nrrl_yb_4993'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/metschnikowia_bicuspidata_var_bicuspidata_nrrl_yb_4993/ncrna/Metschnikowia_bicuspidata_var_bicuspidata_nrrl_yb_4993.Metbi1.ncrna.fa.gz',
	'meyerozyma_guilliermondii_atcc_6260'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/meyerozyma_guilliermondii_atcc_6260/ncrna/Meyerozyma_guilliermondii_atcc_6260.ASM14942v1.ncrna.fa.gz',
	'microbotryum_violaceum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/microbotryum_violaceum/ncrna/Microbotryum_violaceum.GCA_000166175.1.ncrna.fa.gz',
	'microcebus_murinus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/microcebus_murinus/ncrna/Microcebus_murinus.Mmur_2.0.ncrna.fa.gz',
	'microdochium_bolleyi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/microdochium_bolleyi/ncrna/Microdochium_bolleyi.Microdochium_bolleyi_v1.0.ncrna.fa.gz',
	'microtus_ochrogaster'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/microtus_ochrogaster/ncrna/Microtus_ochrogaster.MicOch1.0.ncrna.fa.gz',
	'millerozyma_farinosa_cbs_7064'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/millerozyma_farinosa_cbs_7064/ncrna/Millerozyma_farinosa_cbs_7064.ASM31589v1.ncrna.fa.gz',
	'mitosporidium_daphniae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/mitosporidium_daphniae/ncrna/Mitosporidium_daphniae.UGP1.0.ncrna.fa.gz',
	'mixia_osmundae_iam_14324'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/mixia_osmundae_iam_14324/ncrna/Mixia_osmundae_iam_14324.Mosmundae_2.0.ncrna.fa.gz',
	'mixia_osmundae_iam_14324_gca_000708205'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/mixia_osmundae_iam_14324_gca_000708205/ncrna/Mixia_osmundae_iam_14324_gca_000708205.Mixia_osmundae_v1.0.ncrna.fa.gz',
	'mnemiopsis_leidyi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/mnemiopsis_leidyi/ncrna/Mnemiopsis_leidyi.MneLei_Aug2011.ncrna.fa.gz',
	'moesziomyces_antarcticus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/moesziomyces_antarcticus/ncrna/Moesziomyces_antarcticus.ASM74776v1.ncrna.fa.gz',
	'moesziomyces_aphidis_dsm_70725'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/moesziomyces_aphidis_dsm_70725/ncrna/Moesziomyces_aphidis_dsm_70725.PseuAph1.0.ncrna.fa.gz',
	'moniliophthora_perniciosa_fa553'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/moniliophthora_perniciosa_fa553/ncrna/Moniliophthora_perniciosa_fa553.ASM18302v1.ncrna.fa.gz',
	'moniliophthora_roreri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/moniliophthora_roreri/ncrna/Moniliophthora_roreri.ASM146670v1.ncrna.fa.gz',
	'moniliophthora_roreri_mca_2997'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/moniliophthora_roreri_mca_2997/ncrna/Moniliophthora_roreri_mca_2997.M_roreri_MCA_2997_v1.ncrna.fa.gz',
	'monodelphis_domestica'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/monodelphis_domestica/ncrna/Monodelphis_domestica.BROADO5.ncrna.fa.gz',
	'mortierella_elongata_ag_77'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/mortierella_elongata_ag_77/ncrna/Mortierella_elongata_ag_77.Mortierella_elongata_AG-77_v2.0.ncrna.fa.gz',
	'mortierella_verticillata_nrrl_6337'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/mortierella_verticillata_nrrl_6337/ncrna/Mortierella_verticillata_nrrl_6337.Mort_vert_NRRL_6337_V1.ncrna.fa.gz',
	'mucor_ambiguus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/mucor_ambiguus/ncrna/Mucor_ambiguus.ASM95059v1.ncrna.fa.gz',
	'mucor_circinelloides_f_circinelloides_1006phl'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/mucor_circinelloides_f_circinelloides_1006phl/ncrna/Mucor_circinelloides_f_circinelloides_1006phl.Muco_sp_1006Ph_V1.ncrna.fa.gz',
	'mucor_circinelloides_f_lusitanicus_cbs_277_49'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/mucor_circinelloides_f_lusitanicus_cbs_277_49/ncrna/Mucor_circinelloides_f_lusitanicus_cbs_277_49.Mucci2.ncrna.fa.gz',
	'mus_caroli'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_caroli/ncrna/Mus_caroli.CAROLI_EIJ_v1.1.ncrna.fa.gz',
	'mus_musculus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus/ncrna/Mus_musculus.GRCm38.ncrna.fa.gz',
	'mus_musculus_129s1svimj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_129s1svimj/ncrna/Mus_musculus_129s1svimj.129S1_SvImJ_v1.ncrna.fa.gz',
	'mus_musculus_aj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_aj/ncrna/Mus_musculus_aj.A_J_v1.ncrna.fa.gz',
	'mus_musculus_akrj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_akrj/ncrna/Mus_musculus_akrj.AKR_J_v1.ncrna.fa.gz',
	'mus_musculus_balbcj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_balbcj/ncrna/Mus_musculus_balbcj.BALB_cJ_v1.ncrna.fa.gz',
	'mus_musculus_c3hhej'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_c3hhej/ncrna/Mus_musculus_c3hhej.C3H_HeJ_v1.ncrna.fa.gz',
	'mus_musculus_c57bl6nj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_c57bl6nj/ncrna/Mus_musculus_c57bl6nj.C57BL_6NJ_v1.ncrna.fa.gz',
	'mus_musculus_casteij'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_casteij/ncrna/Mus_musculus_casteij.CAST_EiJ_v1.ncrna.fa.gz',
	'mus_musculus_dba2j'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_dba2j/ncrna/Mus_musculus_dba2j.DBA_2J_v1.ncrna.fa.gz',
	'mus_musculus_fvbnj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_fvbnj/ncrna/Mus_musculus_fvbnj.FVB_NJ_v1.ncrna.fa.gz',
	'mus_musculus_lpj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_lpj/ncrna/Mus_musculus_lpj.LP_J_v1.ncrna.fa.gz',
	'mus_musculus_nodshiltj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_nodshiltj/ncrna/Mus_musculus_nodshiltj.NOD_ShiLtJ_v1.ncrna.fa.gz',
	'mus_musculus_nzohlltj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_nzohlltj/ncrna/Mus_musculus_nzohlltj.NZO_HlLtJ_v1.ncrna.fa.gz',
	'mus_musculus_pwkphj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_pwkphj/ncrna/Mus_musculus_pwkphj.PWK_PhJ_v1.ncrna.fa.gz',
	'mus_musculus_wsbeij'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_wsbeij/ncrna/Mus_musculus_wsbeij.WSB_EiJ_v1.ncrna.fa.gz',
	'mus_pahari'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_pahari/ncrna/Mus_pahari.PAHARI_EIJ_v1.1.ncrna.fa.gz',
	'mus_spretus_spreteij'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_spretus_spreteij/ncrna/Mus_spretus_spreteij.SPRET_EiJ_v1.ncrna.fa.gz',
	'musa_acuminata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/musa_acuminata/ncrna/Musa_acuminata.MA1.ncrna.fa.gz',
	'mustela_putorius_furo'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mustela_putorius_furo/ncrna/Mustela_putorius_furo.MusPutFur1.0.ncrna.fa.gz',
	'mycosphaerella_eumusae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/mycosphaerella_eumusae/ncrna/Mycosphaerella_eumusae.ASM157823v1.ncrna.fa.gz',
	'myotis_lucifugus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/myotis_lucifugus/ncrna/Myotis_lucifugus.Myoluc2.0.ncrna.fa.gz',
	'nadsonia_fulvescens_var_elongata_dsm_6958'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/nadsonia_fulvescens_var_elongata_dsm_6958/ncrna/Nadsonia_fulvescens_var_elongata_dsm_6958.Nadfu1.ncrna.fa.gz',
	'naegleria_gruberi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_heterolobosea1_collection/naegleria_gruberi/ncrna/Naegleria_gruberi.V1.0.ncrna.fa.gz',
	'nannizzia_gypsea_cbs_118893'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/nannizzia_gypsea_cbs_118893/ncrna/Nannizzia_gypsea_cbs_118893.MS_CBS118893.ncrna.fa.gz',
	'nannochloropsis_gaditana'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/nannochloropsis_gaditana/ncrna/Nannochloropsis_gaditana.NagaB31_1.0.ncrna.fa.gz',
	'nannospalax_galili'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/nannospalax_galili/ncrna/Nannospalax_galili.S.galili_v1.0.ncrna.fa.gz',
	'nasonia_vitripennis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/nasonia_vitripennis/ncrna/Nasonia_vitripennis.Nvit_2.1.ncrna.fa.gz',
	'naumovozyma_castellii_cbs_4309'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/naumovozyma_castellii_cbs_4309/ncrna/Naumovozyma_castellii_cbs_4309.ASM23734v1.ncrna.fa.gz',
	'naumovozyma_dairenensis_cbs_421'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/naumovozyma_dairenensis_cbs_421/ncrna/Naumovozyma_dairenensis_cbs_421.ASM22711v2.ncrna.fa.gz',
	'nematocida_displodere'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_displodere/ncrna/Nematocida_displodere.ASM164239v1.ncrna.fa.gz',
	'nematocida_parisii_ertm1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_parisii_ertm1/ncrna/Nematocida_parisii_ertm1.Nema_parisii_ERTm1_V3.ncrna.fa.gz',
	'nematocida_parisii_ertm3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_parisii_ertm3/ncrna/Nematocida_parisii_ertm3.Nema_parisii_ERTm3_V1.ncrna.fa.gz',
	'nematocida_sp_1_ertm2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_sp_1_ertm2/ncrna/Nematocida_sp_1_ertm2.Nema_parisii_ERTm2_V1.ncrna.fa.gz',
	'nematocida_sp_1_ertm6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_sp_1_ertm6/ncrna/Nematocida_sp_1_ertm6.Nema_sp_1_ERTm6_V2.ncrna.fa.gz',
	'nematocida_sp_ertm5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_sp_ertm5/ncrna/Nematocida_sp_ertm5.ASM164241v1.ncrna.fa.gz',
	'nematostella_vectensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/nematostella_vectensis/ncrna/Nematostella_vectensis.ASM20922v1.ncrna.fa.gz',
	'neofusicoccum_parvum_ucrnp2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/neofusicoccum_parvum_ucrnp2/ncrna/Neofusicoccum_parvum_ucrnp2.UCRNP2V3.ncrna.fa.gz',
	'neolecta_irregularis_dah_3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/neolecta_irregularis_dah_3/ncrna/Neolecta_irregularis_dah_3.NeoIirr1.0.ncrna.fa.gz',
	'neolentinus_lepideus_hhb14362_ss_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/neolentinus_lepideus_hhb14362_ss_1/ncrna/Neolentinus_lepideus_hhb14362_ss_1.Neole1.ncrna.fa.gz',
	'neonectria_ditissima'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/neonectria_ditissima/ncrna/Neonectria_ditissima.R0905_v2.0.ncrna.fa.gz',
	'neosartorya_fischeri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/neosartorya_fischeri/ncrna/Neosartorya_fischeri.CADRE.ncrna.fa.gz',
	'neurospora_crassa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/neurospora_crassa/ncrna/Neurospora_crassa.NC12.ncrna.fa.gz',
	'neurospora_crassa_gca_000786625'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/neurospora_crassa_gca_000786625/ncrna/Neurospora_crassa_gca_000786625.Neucr_trp3_1.ncrna.fa.gz',
	'neurospora_tetrasperma_fgsc_2508'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/neurospora_tetrasperma_fgsc_2508/ncrna/Neurospora_tetrasperma_fgsc_2508.v2.0.ncrna.fa.gz',
	'neurospora_tetrasperma_fgsc_2509'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/neurospora_tetrasperma_fgsc_2509/ncrna/Neurospora_tetrasperma_fgsc_2509.v1.0.ncrna.fa.gz',
	'nomascus_leucogenys'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/nomascus_leucogenys/ncrna/Nomascus_leucogenys.Nleu1.0.ncrna.fa.gz',
	'nosema_apis_brl_01'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nosema_apis_brl_01/ncrna/Nosema_apis_brl_01.NapisBRLv01.ncrna.fa.gz',
	'nosema_bombycis_cq1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nosema_bombycis_cq1/ncrna/Nosema_bombycis_cq1.NosBomCQ1_v1.0.ncrna.fa.gz',
	'nosema_ceranae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nosema_ceranae/ncrna/Nosema_ceranae.ASM98816v1.ncrna.fa.gz',
	'nosema_ceranae_brl01'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nosema_ceranae_brl01/ncrna/Nosema_ceranae_brl01.ASM18298v1.ncrna.fa.gz',
	'notamacropus_eugenii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/notamacropus_eugenii/ncrna/Notamacropus_eugenii.Meug_1.0.ncrna.fa.gz',
	'ochotona_princeps'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ochotona_princeps/ncrna/Ochotona_princeps.OchPri2.0-Ens.ncrna.fa.gz',
	'octodon_degus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/octodon_degus/ncrna/Octodon_degus.OctDeg1.0.ncrna.fa.gz',
	'octopus_bimaculoides'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/octopus_bimaculoides/ncrna/Octopus_bimaculoides.PRJNA270931.ncrna.fa.gz',
	'ogataea_parapolymorpha_dl_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/ogataea_parapolymorpha_dl_1/ncrna/Ogataea_parapolymorpha_dl_1.Hansenula_2.ncrna.fa.gz',
	'ogataea_polymorpha'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ogataea_polymorpha/ncrna/Ogataea_polymorpha.Hanpo2.ncrna.fa.gz',
	'oidiodendron_maius_zn'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/oidiodendron_maius_zn/ncrna/Oidiodendron_maius_zn.Oidiodendron_maius_Zn_v1.0.ncrna.fa.gz',
	'onchocerca_volvulus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/onchocerca_volvulus/ncrna/Onchocerca_volvulus.O_volvulus_Cameroon_v3.ncrna.fa.gz',
	'ophiocordyceps_sinensis_co18'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/ophiocordyceps_sinensis_co18/ncrna/Ophiocordyceps_sinensis_co18.ASM44836v1.ncrna.fa.gz',
	'ophiocordyceps_unilateralis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ophiocordyceps_unilateralis/ncrna/Ophiocordyceps_unilateralis.ASM127257v1.ncrna.fa.gz',
	'ophiostoma_piceae_uamh_11346'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/ophiostoma_piceae_uamh_11346/ncrna/Ophiostoma_piceae_uamh_11346.Opiceae_UAMHv01.ncrna.fa.gz',
	'ordospora_colligata_oc4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/ordospora_colligata_oc4/ncrna/Ordospora_colligata_oc4.ASM80326v1.ncrna.fa.gz',
	'oreochromis_niloticus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/oreochromis_niloticus/ncrna/Oreochromis_niloticus.Orenil1.0.ncrna.fa.gz',
	'ornithorhynchus_anatinus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ornithorhynchus_anatinus/ncrna/Ornithorhynchus_anatinus.OANA5.ncrna.fa.gz',
	'oryctolagus_cuniculus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/oryctolagus_cuniculus/ncrna/Oryctolagus_cuniculus.OryCun2.0.ncrna.fa.gz',
	'oryza_barthii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_barthii/ncrna/Oryza_barthii.O.barthii_v1.ncrna.fa.gz',
	'oryza_brachyantha'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_brachyantha/ncrna/Oryza_brachyantha.Oryza_brachyantha.v1.4b.ncrna.fa.gz',
	'oryza_glaberrima'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_glaberrima/ncrna/Oryza_glaberrima.AGI1.1.ncrna.fa.gz',
	'oryza_glumaepatula'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_glumaepatula/ncrna/Oryza_glumaepatula.ALNU02000000.ncrna.fa.gz',
	'oryza_indica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_indica/ncrna/Oryza_indica.ASM465v1.ncrna.fa.gz',
	'oryza_longistaminata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_longistaminata/ncrna/Oryza_longistaminata.O_longistaminata_v1.0.ncrna.fa.gz',
	'oryza_meridionalis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_meridionalis/ncrna/Oryza_meridionalis.Oryza_meridionalis_v1.3.ncrna.fa.gz',
	'oryza_nivara'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_nivara/ncrna/Oryza_nivara.AWHD00000000.ncrna.fa.gz',
	'oryza_punctata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_punctata/ncrna/Oryza_punctata.AVCL00000000.ncrna.fa.gz',
	'oryza_rufipogon'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_rufipogon/ncrna/Oryza_rufipogon.OR_W1943.ncrna.fa.gz',
	'oryza_sativa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_sativa/ncrna/Oryza_sativa.IRGSP-1.0.ncrna.fa.gz',
	'oryzias_latipes'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/oryzias_latipes/ncrna/Oryzias_latipes.MEDAKA1.ncrna.fa.gz',
	'ostreococcus_lucimarinus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/ostreococcus_lucimarinus/ncrna/Ostreococcus_lucimarinus.ASM9206v1.ncrna.fa.gz',
	'otolemur_garnettii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/otolemur_garnettii/ncrna/Otolemur_garnettii.OtoGar3.ncrna.fa.gz',
	'ovis_aries'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ovis_aries/ncrna/Ovis_aries.Oar_v3.1.ncrna.fa.gz',
	'pachysolen_tannophilus_nrrl_y_2460'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pachysolen_tannophilus_nrrl_y_2460/ncrna/Pachysolen_tannophilus_nrrl_y_2460.Pacta1_2.ncrna.fa.gz',
	'pan_troglodytes'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/pan_troglodytes/ncrna/Pan_troglodytes.CHIMP2.1.4.ncrna.fa.gz',
	'papio_anubis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/papio_anubis/ncrna/Papio_anubis.PapAnu2.0.ncrna.fa.gz',
	'paracoccidioides_brasiliensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/paracoccidioides_brasiliensis/ncrna/Paracoccidioides_brasiliensis.ASM171364v1.ncrna.fa.gz',
	'paracoccidioides_brasiliensis_gca_001713695'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/paracoccidioides_brasiliensis_gca_001713695/ncrna/Paracoccidioides_brasiliensis_gca_001713695.Paracocci_br_PbCNH.ncrna.fa.gz',
	'paracoccidioides_brasiliensis_pb03'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/paracoccidioides_brasiliensis_pb03/ncrna/Paracoccidioides_brasiliensis_pb03.Paracocci_br_Pb03_V2.ncrna.fa.gz',
	'paracoccidioides_brasiliensis_pb18'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/paracoccidioides_brasiliensis_pb18/ncrna/Paracoccidioides_brasiliensis_pb18.Paracocci_br_Pb18_V2.ncrna.fa.gz',
	'paracoccidioides_sp_lutzii_pb01'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/paracoccidioides_sp_lutzii_pb01/ncrna/Paracoccidioides_sp_lutzii_pb01.Paracocci_br_Pb01_V2.ncrna.fa.gz',
	'paramecium_tetraurelia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/paramecium_tetraurelia/ncrna/Paramecium_tetraurelia.ASM16542v1.ncrna.fa.gz',
	'paraphaeosphaeria_sporulosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/paraphaeosphaeria_sporulosa/ncrna/Paraphaeosphaeria_sporulosa.Parsp1.ncrna.fa.gz',
	'parasitella_parasitica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/parasitella_parasitica/ncrna/Parasitella_parasitica.PP.v1.ncrna.fa.gz',
	'paulinella_chromatophora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_rhizaria1_collection/paulinella_chromatophora/ncrna/Paulinella_chromatophora.ASM1792v1.ncrna.fa.gz',
	'paxillus_involutus_atcc_200175'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/paxillus_involutus_atcc_200175/ncrna/Paxillus_involutus_atcc_200175.Paxillus_involutus_ATCC_200175_v1.0.ncrna.fa.gz',
	'paxillus_rubicundulus_ve08_2h10'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/paxillus_rubicundulus_ve08_2h10/ncrna/Paxillus_rubicundulus_ve08_2h10.Paxillus_rubicundulus_Ve08.2h10_v1.0.ncrna.fa.gz',
	'pediculus_humanus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/pediculus_humanus/ncrna/Pediculus_humanus.PhumU2.ncrna.fa.gz',
	'pelodiscus_sinensis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/pelodiscus_sinensis/ncrna/Pelodiscus_sinensis.PelSin_1.0.ncrna.fa.gz',
	'penicilliopsis_zonata_cbs_506_65'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicilliopsis_zonata_cbs_506_65/ncrna/Penicilliopsis_zonata_cbs_506_65.Aspzo1.ncrna.fa.gz',
	'penicillium_antarcticum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_antarcticum/ncrna/Penicillium_antarcticum.ASM207234v1.ncrna.fa.gz',
	'penicillium_arizonense'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_arizonense/ncrna/Penicillium_arizonense.ASM177332v1.ncrna.fa.gz',
	'penicillium_brasilianum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/penicillium_brasilianum/ncrna/Penicillium_brasilianum.Pbras_Allpaths-LG.ncrna.fa.gz',
	'penicillium_brasilianum_gca_002016555'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_brasilianum_gca_002016555/ncrna/Penicillium_brasilianum_gca_002016555.ASM201655v1.ncrna.fa.gz',
	'penicillium_camemberti_fm_013'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/penicillium_camemberti_fm_013/ncrna/Penicillium_camemberti_fm_013.PCAMFM013_20131106.ncrna.fa.gz',
	'penicillium_chrysogenum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_chrysogenum/ncrna/Penicillium_chrysogenum.ASM71027v1.ncrna.fa.gz',
	'penicillium_coprophilum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_coprophilum/ncrna/Penicillium_coprophilum.ASM207240v1.ncrna.fa.gz',
	'penicillium_decumbens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_decumbens/ncrna/Penicillium_decumbens.ASM207224v1.ncrna.fa.gz',
	'penicillium_digitatum_pd1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_digitatum_pd1/ncrna/Penicillium_digitatum_pd1.PdigPd1_v1.ncrna.fa.gz',
	'penicillium_digitatum_phi26'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_digitatum_phi26/ncrna/Penicillium_digitatum_phi26.PdigPHI26_v1.ncrna.fa.gz',
	'penicillium_expansum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_expansum/ncrna/Penicillium_expansum.PEX1.ncrna.fa.gz',
	'penicillium_expansum_gca_000769735'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_expansum_gca_000769735/ncrna/Penicillium_expansum_gca_000769735.ASM76973v1.ncrna.fa.gz',
	'penicillium_expansum_gca_000769745'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_expansum_gca_000769745/ncrna/Penicillium_expansum_gca_000769745.ASM76974v1.ncrna.fa.gz',
	'penicillium_flavigenum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_flavigenum/ncrna/Penicillium_flavigenum.ASM207236v1.ncrna.fa.gz',
	'penicillium_freii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_freii/ncrna/Penicillium_freii.ASM151392v1.ncrna.fa.gz',
	'penicillium_griseofulvum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_griseofulvum/ncrna/Penicillium_griseofulvum.ASM156193v1.ncrna.fa.gz',
	'penicillium_italicum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_italicum/ncrna/Penicillium_italicum.ASM76976v1.ncrna.fa.gz',
	'penicillium_nalgiovense'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_nalgiovense/ncrna/Penicillium_nalgiovense.ASM207242v1.ncrna.fa.gz',
	'penicillium_nordicum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_nordicum/ncrna/Penicillium_nordicum.ASM127859v1.ncrna.fa.gz',
	'penicillium_oxalicum_114_2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_oxalicum_114_2/ncrna/Penicillium_oxalicum_114_2.pde_v1.0.ncrna.fa.gz',
	'penicillium_polonicum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_polonicum/ncrna/Penicillium_polonicum.ASM207226v1.ncrna.fa.gz',
	'penicillium_roqueforti_fm164'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_roqueforti_fm164/ncrna/Penicillium_roqueforti_fm164.PROQFM164_20130607.ncrna.fa.gz',
	'penicillium_rubens_wisconsin_54_1255'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_rubens_wisconsin_54_1255/ncrna/Penicillium_rubens_wisconsin_54_1255.PenChr_Nov2007.ncrna.fa.gz',
	'penicillium_solitum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_solitum/ncrna/Penicillium_solitum.ASM207223v1.ncrna.fa.gz',
	'penicillium_steckii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_steckii/ncrna/Penicillium_steckii.ASM207237v1.ncrna.fa.gz',
	'penicillium_subrubescens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_subrubescens/ncrna/Penicillium_subrubescens.ASM190812v1.ncrna.fa.gz',
	'penicillium_vulpinum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_vulpinum/ncrna/Penicillium_vulpinum.ASM207225v1.ncrna.fa.gz',
	'peniophora_sp_cont'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/peniophora_sp_cont/ncrna/Peniophora_sp_cont.Ricme1.ncrna.fa.gz',
	'perkinsus_marinus_atcc_50983'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/perkinsus_marinus_atcc_50983/ncrna/Perkinsus_marinus_atcc_50983.JCVI_PMG_1.0.ncrna.fa.gz',
	'peromyscus_maniculatus_bairdii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/peromyscus_maniculatus_bairdii/ncrna/Peromyscus_maniculatus_bairdii.Pman_1.0.ncrna.fa.gz',
	'pestalotiopsis_fici_w106_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pestalotiopsis_fici_w106_1/ncrna/Pestalotiopsis_fici_w106_1.PFICI.ncrna.fa.gz',
	'petromyzon_marinus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/petromyzon_marinus/ncrna/Petromyzon_marinus.Pmarinus_7.0.ncrna.fa.gz',
	'phaeoacremonium_minimum_ucrpa7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/phaeoacremonium_minimum_ucrpa7/ncrna/Phaeoacremonium_minimum_ucrpa7.UCRPA7V03.ncrna.fa.gz',
	'phaeodactylum_tricornutum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phaeodactylum_tricornutum/ncrna/Phaeodactylum_tricornutum.ASM15095v2.ncrna.fa.gz',
	'phaeomoniella_chlamydospora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/phaeomoniella_chlamydospora/ncrna/Phaeomoniella_chlamydospora.UCRPA7V1.0.ncrna.fa.gz',
	'phaeosphaeria_nodorum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/phaeosphaeria_nodorum/ncrna/Phaeosphaeria_nodorum.ASM14691v1.ncrna.fa.gz',
	'phanerochaete_carnosa_hhb_10118_sp'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/phanerochaete_carnosa_hhb_10118_sp/ncrna/Phanerochaete_carnosa_hhb_10118_sp.Phanerochaete_carnosa_HHB-10118-Sp_v1.0.ncrna.fa.gz',
	'phialocephala_scopiformis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/phialocephala_scopiformis/ncrna/Phialocephala_scopiformis.Phisc1.ncrna.fa.gz',
	'phialocephala_subalpina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/phialocephala_subalpina/ncrna/Phialocephala_subalpina.PAC_version_1.ncrna.fa.gz',
	'phialophora_americana'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/phialophora_americana/ncrna/Phialophora_americana.Capr_semi_CBS27337_V1.ncrna.fa.gz',
	'phialophora_attae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/phialophora_attae/ncrna/Phialophora_attae.ASM129925v1.ncrna.fa.gz',
	'phlebia_centrifuga'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/phlebia_centrifuga/ncrna/Phlebia_centrifuga.ASM191385v1.ncrna.fa.gz',
	'phlebiopsis_gigantea_11061_1_cr5_6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/phlebiopsis_gigantea_11061_1_cr5_6/ncrna/Phlebiopsis_gigantea_11061_1_cr5_6.Phlgi1.ncrna.fa.gz',
	'phycomyces_blakesleeanus_nrrl_1555_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/phycomyces_blakesleeanus_nrrl_1555_/ncrna/Phycomyces_blakesleeanus_nrrl_1555_.Phybl2.ncrna.fa.gz',
	'physcomitrella_patens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/physcomitrella_patens/ncrna/Physcomitrella_patens.ASM242v1.ncrna.fa.gz',
	'phytophthora_infestans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_infestans/ncrna/Phytophthora_infestans.ASM14294v1.ncrna.fa.gz',
	'phytophthora_kernoviae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_kernoviae/ncrna/Phytophthora_kernoviae.PhyKer238_432v1.ncrna.fa.gz',
	'phytophthora_lateralis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_lateralis/ncrna/Phytophthora_lateralis.MPF4_v1.0.ncrna.fa.gz',
	'phytophthora_parasitica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_parasitica/ncrna/Phytophthora_parasitica.Phyt_para_P1569_V1.ncrna.fa.gz',
	'phytophthora_parasitica_cj01a1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_cj01a1/ncrna/Phytophthora_parasitica_cj01a1.Phyt_para_CJ01A1_V1.ncrna.fa.gz',
	'phytophthora_parasitica_gca_000509465'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_gca_000509465/ncrna/Phytophthora_parasitica_gca_000509465.Phyt_para_CJ02B3_V1.ncrna.fa.gz',
	'phytophthora_parasitica_gca_000509485'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_gca_000509485/ncrna/Phytophthora_parasitica_gca_000509485.Phyt_para_CJ05E6_V1.ncrna.fa.gz',
	'phytophthora_parasitica_gca_000509505'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_gca_000509505/ncrna/Phytophthora_parasitica_gca_000509505.Phyt_para_CHvinca01_V1.ncrna.fa.gz',
	'phytophthora_parasitica_gca_000509525'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_gca_000509525/ncrna/Phytophthora_parasitica_gca_000509525.Phyt_para_IAC_01_95_V1.ncrna.fa.gz',
	'phytophthora_parasitica_inra_310'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_inra_310/ncrna/Phytophthora_parasitica_inra_310.PP_INRA-310_V2.ncrna.fa.gz',
	'phytophthora_parasitica_p10297'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_p10297/ncrna/Phytophthora_parasitica_p10297.Phyt_para_P10297_V1.ncrna.fa.gz',
	'phytophthora_parasitica_p1976'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_p1976/ncrna/Phytophthora_parasitica_p1976.Phyt_para_P1976_V1.ncrna.fa.gz',
	'phytophthora_ramorum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_ramorum/ncrna/Phytophthora_ramorum.ASM14973v1.ncrna.fa.gz',
	'phytophthora_sojae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_sojae/ncrna/Phytophthora_sojae.P_sojae_V3_0.ncrna.fa.gz',
	'pichia_kudriavzevii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pichia_kudriavzevii/ncrna/Pichia_kudriavzevii.ASM76445v1.ncrna.fa.gz',
	'pichia_kudriavzevii_gca_001983325'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pichia_kudriavzevii_gca_001983325/ncrna/Pichia_kudriavzevii_gca_001983325.ASM198332v1.ncrna.fa.gz',
	'pichia_membranifaciens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pichia_membranifaciens/ncrna/Pichia_membranifaciens.P_membrenifaciens-1.0.ncrna.fa.gz',
	'pichia_membranifaciens_nrrl_y_2026'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pichia_membranifaciens_nrrl_y_2026/ncrna/Pichia_membranifaciens_nrrl_y_2026.Picme2.ncrna.fa.gz',
	'piloderma_croceum_f_1598'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/piloderma_croceum_f_1598/ncrna/Piloderma_croceum_f_1598.Piloderma_croceum_F_1598_v1.0.ncrna.fa.gz',
	'pisolithus_microcarpus_441'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/pisolithus_microcarpus_441/ncrna/Pisolithus_microcarpus_441.Pisolithus_microcarpus_441_v1.0.ncrna.fa.gz',
	'pisolithus_tinctorius_marx_270'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/pisolithus_tinctorius_marx_270/ncrna/Pisolithus_tinctorius_marx_270.Pisolithus_tinctorius_Marx_270_v1.0.ncrna.fa.gz',
	'plasmodium_berghei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/plasmodium_berghei/ncrna/Plasmodium_berghei.PBANKA01.ncrna.fa.gz',
	'plasmodium_berghei_gca_000005395'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_berghei_gca_000005395/ncrna/Plasmodium_berghei_gca_000005395.ASM539v1.ncrna.fa.gz',
	'plasmodium_berghei_gca_900044335'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_berghei_gca_900044335/ncrna/Plasmodium_berghei_gca_900044335.PbK173.ncrna.fa.gz',
	'plasmodium_chabaudi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/plasmodium_chabaudi/ncrna/Plasmodium_chabaudi.PCHAS01.ncrna.fa.gz',
	'plasmodium_chabaudi_chabaudi_gca_000003075'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_chabaudi_chabaudi_gca_000003075/ncrna/Plasmodium_chabaudi_chabaudi_gca_000003075.ASM307v1.ncrna.fa.gz',
	'plasmodium_coatneyi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_coatneyi/ncrna/Plasmodium_coatneyi.ASM168000v1.ncrna.fa.gz',
	'plasmodium_cynomolgi_strain_b'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_cynomolgi_strain_b/ncrna/Plasmodium_cynomolgi_strain_b.PcynB_1.0.ncrna.fa.gz',
	'plasmodium_falciparum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/plasmodium_falciparum/ncrna/Plasmodium_falciparum.EPr1.ncrna.fa.gz',
	'plasmodium_falciparum_7g8'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_7g8/ncrna/Plasmodium_falciparum_7g8.Plas_falc_7G8_V1.ncrna.fa.gz',
	'plasmodium_falciparum_camp_malaysia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_camp_malaysia/ncrna/Plasmodium_falciparum_camp_malaysia.Plas_falc_Malayan_Camp_V1.ncrna.fa.gz',
	'plasmodium_falciparum_dd2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_dd2/ncrna/Plasmodium_falciparum_dd2.ASM14979v1.ncrna.fa.gz',
	'plasmodium_falciparum_fch_4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_fch_4/ncrna/Plasmodium_falciparum_fch_4.Plas_falc_FCH_4_V2.ncrna.fa.gz',
	'plasmodium_falciparum_hb3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_hb3/ncrna/Plasmodium_falciparum_hb3.ASM14966v2.ncrna.fa.gz',
	'plasmodium_falciparum_igh_cr14'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_igh_cr14/ncrna/Plasmodium_falciparum_igh_cr14.ASM18605v2.ncrna.fa.gz',
	'plasmodium_falciparum_malips096_e11'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_malips096_e11/ncrna/Plasmodium_falciparum_malips096_e11.Plas_falc_MaliPS096_E11_V1.ncrna.fa.gz',
	'plasmodium_falciparum_nf135_5_c10'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_nf135_5_c10/ncrna/Plasmodium_falciparum_nf135_5_c10.Plas_falc_NF135_5_C10_V1.ncrna.fa.gz',
	'plasmodium_falciparum_nf54'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_nf54/ncrna/Plasmodium_falciparum_nf54.Plas_falc_NF4_V1.ncrna.fa.gz',
	'plasmodium_falciparum_palo_alto_uganda'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_palo_alto_uganda/ncrna/Plasmodium_falciparum_palo_alto_uganda.Plas_falc_Uganda_Palo-Alto_FUP_H_V1.ncrna.fa.gz',
	'plasmodium_falciparum_raj116'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_raj116/ncrna/Plasmodium_falciparum_raj116.ASM18602v2.ncrna.fa.gz',
	'plasmodium_falciparum_santa_lucia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_santa_lucia/ncrna/Plasmodium_falciparum_santa_lucia.Plas_falc_Santa_Lucia_Salvador_I_V1.ncrna.fa.gz',
	'plasmodium_falciparum_tanzania_2000708_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_tanzania_2000708_/ncrna/Plasmodium_falciparum_tanzania_2000708_.Plas_falc_02000708_V1.ncrna.fa.gz',
	'plasmodium_falciparum_ugt5_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_ugt5_1/ncrna/Plasmodium_falciparum_ugt5_1.Plas_falc_5_1_V1.ncrna.fa.gz',
	'plasmodium_falciparum_vietnam_oak_knoll_fvo_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_vietnam_oak_knoll_fvo_/ncrna/Plasmodium_falciparum_vietnam_oak_knoll_fvo_.Plas_falc_Vietnam_Oak-Knoll_FVO_V1.ncrna.fa.gz',
	'plasmodium_fragile'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_fragile/ncrna/Plasmodium_fragile.Plas_frag_nilgiri_V1.ncrna.fa.gz',
	'plasmodium_gaboni'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_gaboni/ncrna/Plasmodium_gaboni.ASM160202v1.ncrna.fa.gz',
	'plasmodium_inui_san_antonio_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_inui_san_antonio_1/ncrna/Plasmodium_inui_san_antonio_1.Plas_inui_San_Antonio_1_V1.ncrna.fa.gz',
	'plasmodium_knowlesi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/plasmodium_knowlesi/ncrna/Plasmodium_knowlesi.ASM635v1.ncrna.fa.gz',
	'plasmodium_knowlesi_strain_h_gca_900004885'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_knowlesi_strain_h_gca_900004885/ncrna/Plasmodium_knowlesi_strain_h_gca_900004885.PKNA1-C.2.ncrna.fa.gz',
	'plasmodium_malariae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_malariae/ncrna/Plasmodium_malariae.Pmal.ncrna.fa.gz',
	'plasmodium_ovale_curtisi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_ovale_curtisi/ncrna/Plasmodium_ovale_curtisi.Poc1.ncrna.fa.gz',
	'plasmodium_reichenowi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_reichenowi/ncrna/Plasmodium_reichenowi.PREICH001.ncrna.fa.gz',
	'plasmodium_reichenowi_gca_001601855'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_reichenowi_gca_001601855/ncrna/Plasmodium_reichenowi_gca_001601855.ASM160185v1.ncrna.fa.gz',
	'plasmodium_vinckei_petteri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vinckei_petteri/ncrna/Plasmodium_vinckei_petteri.Plas_vinc_pett_CR_V1.ncrna.fa.gz',
	'plasmodium_vinckei_vinckei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vinckei_vinckei/ncrna/Plasmodium_vinckei_vinckei.Plas_vinc_vinckei_V1.ncrna.fa.gz',
	'plasmodium_vivax'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/plasmodium_vivax/ncrna/Plasmodium_vivax.ASM241v2.ncrna.fa.gz',
	'plasmodium_vivax_brazil_i'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vivax_brazil_i/ncrna/Plasmodium_vivax_brazil_i.PV_Brazil_I_V1.ncrna.fa.gz',
	'plasmodium_vivax_india_vii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vivax_india_vii/ncrna/Plasmodium_vivax_india_vii.PV_India_VII_V2.ncrna.fa.gz',
	'plasmodium_vivax_mauritania_i'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vivax_mauritania_i/ncrna/Plasmodium_vivax_mauritania_i.PV_Mauritania_I_V1.ncrna.fa.gz',
	'plasmodium_vivax_north_korean'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vivax_north_korean/ncrna/Plasmodium_vivax_north_korean.PV_N_Korean_V1.ncrna.fa.gz',
	'plasmodium_yoelii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_yoelii/ncrna/Plasmodium_yoelii.PY17X01.ncrna.fa.gz',
	'plasmodium_yoelii_17x'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_yoelii_17x/ncrna/Plasmodium_yoelii_17x.Plas_yoel_17X_V2.ncrna.fa.gz',
	'plasmodium_yoelii_gca_900002395'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_yoelii_gca_900002395/ncrna/Plasmodium_yoelii_gca_900002395.PYYM01.ncrna.fa.gz',
	'plasmodium_yoelii_yoelii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_yoelii_yoelii/ncrna/Plasmodium_yoelii_yoelii.ASM308v2.ncrna.fa.gz',
	'plasmopara_halstedii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/plasmopara_halstedii/ncrna/Plasmopara_halstedii.Plasmopara_halstedii_genome.ncrna.fa.gz',
	'pleurotus_ostreatus_pc15'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/pleurotus_ostreatus_pc15/ncrna/Pleurotus_ostreatus_pc15.PleosPC15_2.ncrna.fa.gz',
	'plicaturopsis_crispa_fd_325_ss_3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/plicaturopsis_crispa_fd_325_ss_3/ncrna/Plicaturopsis_crispa_fd_325_ss_3.Plicr1.ncrna.fa.gz',
	'pneumocystis_carinii_b80'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pneumocystis_carinii_b80/ncrna/Pneumocystis_carinii_b80.Pneu_cari_B80_V3.ncrna.fa.gz',
	'pneumocystis_jirovecii_ru7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pneumocystis_jirovecii_ru7/ncrna/Pneumocystis_jirovecii_ru7.Pneu_jiro_RU7_V2.ncrna.fa.gz',
	'pneumocystis_murina_b123'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pneumocystis_murina_b123/ncrna/Pneumocystis_murina_b123.Pneumo_murina_B123_V4.ncrna.fa.gz',
	'pochonia_chlamydosporia_170'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pochonia_chlamydosporia_170/ncrna/Pochonia_chlamydosporia_170.ASM165323v1.ncrna.fa.gz',
	'podospora_anserina_s_mat_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/podospora_anserina_s_mat_/ncrna/Podospora_anserina_s_mat_.ASM22654v1.ncrna.fa.gz',
	'poecilia_formosa'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/poecilia_formosa/ncrna/Poecilia_formosa.PoeFor_5.1.2.ncrna.fa.gz',
	'polysphondylium_pallidum_pn500'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/polysphondylium_pallidum_pn500/ncrna/Polysphondylium_pallidum_pn500.PolPal_Dec2009.ncrna.fa.gz',
	'pongo_abelii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/pongo_abelii/ncrna/Pongo_abelii.PPYG2.ncrna.fa.gz',
	'populus_trichocarpa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/populus_trichocarpa/ncrna/Populus_trichocarpa.JGI2.0.ncrna.fa.gz',
	'postia_placenta_mad_698_r'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/postia_placenta_mad_698_r/ncrna/Postia_placenta_mad_698_r.Postia_placenta_V1.0.ncrna.fa.gz',
	'procavia_capensis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/procavia_capensis/ncrna/Procavia_capensis.proCap1.ncrna.fa.gz',
	'prunus_persica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/prunus_persica/ncrna/Prunus_persica.Prupe1_0.ncrna.fa.gz',
	'pseudocercospora_fijiensis_cirad86'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pseudocercospora_fijiensis_cirad86/ncrna/Pseudocercospora_fijiensis_cirad86.Mycfi2.ncrna.fa.gz',
	'pseudocercospora_musae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudocercospora_musae/ncrna/Pseudocercospora_musae.ASM157822v1.ncrna.fa.gz',
	'pseudogymnoascus_destructans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_destructans/ncrna/Pseudogymnoascus_destructans.ASM164126v1.ncrna.fa.gz',
	'pseudogymnoascus_destructans_20631_21'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pseudogymnoascus_destructans_20631_21/ncrna/Pseudogymnoascus_destructans_20631_21.Geom_destructans_V1.ncrna.fa.gz',
	'pseudogymnoascus_sp_03vt05'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_sp_03vt05/ncrna/Pseudogymnoascus_sp_03vt05.ASM166264v1.ncrna.fa.gz',
	'pseudogymnoascus_sp_05ny08'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_sp_05ny08/ncrna/Pseudogymnoascus_sp_05ny08.ASM166260v1.ncrna.fa.gz',
	'pseudogymnoascus_sp_23342_1_i1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_sp_23342_1_i1/ncrna/Pseudogymnoascus_sp_23342_1_i1.ASM166257v1.ncrna.fa.gz',
	'pseudogymnoascus_sp_24mn13'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_sp_24mn13/ncrna/Pseudogymnoascus_sp_24mn13.ASM166259v1.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_103'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_103/ncrna/Pseudogymnoascus_sp_vkm_f_103.DG30.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_3557'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pseudogymnoascus_sp_vkm_f_3557/ncrna/Pseudogymnoascus_sp_vkm_f_3557.DG3.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_3775'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_3775/ncrna/Pseudogymnoascus_sp_vkm_f_3775.DG4.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_3808'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pseudogymnoascus_sp_vkm_f_3808/ncrna/Pseudogymnoascus_sp_vkm_f_3808.DG1.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4246'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4246/ncrna/Pseudogymnoascus_sp_vkm_f_4246.DG5.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4281_fw_2241_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4281_fw_2241_/ncrna/Pseudogymnoascus_sp_vkm_f_4281_fw_2241_.DG6.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4513_fw_928_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4513_fw_928_/ncrna/Pseudogymnoascus_sp_vkm_f_4513_fw_928_.DG7.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4514_fw_929_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4514_fw_929_/ncrna/Pseudogymnoascus_sp_vkm_f_4514_fw_929_.DG8.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4515_fw_2607_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4515_fw_2607_/ncrna/Pseudogymnoascus_sp_vkm_f_4515_fw_2607_.DG10.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4516_fw_969_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4516_fw_969_/ncrna/Pseudogymnoascus_sp_vkm_f_4516_fw_969_.DG11.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4517_fw_2822_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4517_fw_2822_/ncrna/Pseudogymnoascus_sp_vkm_f_4517_fw_2822_.DG13.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4518_fw_2643_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4518_fw_2643_/ncrna/Pseudogymnoascus_sp_vkm_f_4518_fw_2643_.DG36.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4519_fw_2642_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4519_fw_2642_/ncrna/Pseudogymnoascus_sp_vkm_f_4519_fw_2642_.DG38.ncrna.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4520_fw_2644_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4520_fw_2644_/ncrna/Pseudogymnoascus_sp_vkm_f_4520_fw_2644_.DG39.ncrna.fa.gz',
	'pseudogymnoascus_sp_wsf_3629'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_sp_wsf_3629/ncrna/Pseudogymnoascus_sp_wsf_3629.ASM166258v1.ncrna.fa.gz',
	'pseudogymnoascus_verrucosus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_verrucosus/ncrna/Pseudogymnoascus_verrucosus.ASM166265v1.ncrna.fa.gz',
	'pseudoloma_neurophilia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/pseudoloma_neurophilia/ncrna/Pseudoloma_neurophilia.ASM143216v1.ncrna.fa.gz',
	'pseudozyma_hubeiensis_sy62'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/pseudozyma_hubeiensis_sy62/ncrna/Pseudozyma_hubeiensis_sy62.ASM40351v1.ncrna.fa.gz',
	'pteropus_vampyrus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/pteropus_vampyrus/ncrna/Pteropus_vampyrus.pteVam1.ncrna.fa.gz',
	'puccinia_graminis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/puccinia_graminis/ncrna/Puccinia_graminis.ASM14992v1.ncrna.fa.gz',
	'puccinia_graminisug99'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/puccinia_graminisug99/ncrna/Puccinia_graminisug99.v1.ncrna.fa.gz',
	'puccinia_sorghi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/puccinia_sorghi/ncrna/Puccinia_sorghi.ASM126337v1.ncrna.fa.gz',
	'puccinia_striiformis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/puccinia_striiformis/ncrna/Puccinia_striiformis.PST-130_1.0.ncrna.fa.gz',
	'puccinia_striiformis_f_sp_tritici_pst_78'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/puccinia_striiformis_f_sp_tritici_pst_78/ncrna/Puccinia_striiformis_f_sp_tritici_pst_78.P_striiformis_V1.ncrna.fa.gz',
	'puccinia_triticina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/puccinia_triticina/ncrna/Puccinia_triticina.ASM15152v1.ncrna.fa.gz',
	'punctularia_strigosozonata_hhb_11173_ss5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/punctularia_strigosozonata_hhb_11173_ss5/ncrna/Punctularia_strigosozonata_hhb_11173_ss5.Punctularia_strigosozonata_v1.0.ncrna.fa.gz',
	'purpureocillium_lilacinum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/purpureocillium_lilacinum/ncrna/Purpureocillium_lilacinum.ASM165320v1.ncrna.fa.gz',
	'purpureocillium_lilacinum_gca_001653265'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/purpureocillium_lilacinum_gca_001653265/ncrna/Purpureocillium_lilacinum_gca_001653265.ASM165326v1.ncrna.fa.gz',
	'pyrenochaeta_sp_ds3say3a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pyrenochaeta_sp_ds3say3a/ncrna/Pyrenochaeta_sp_ds3say3a.Pyrsp1.ncrna.fa.gz',
	'pyrenophora_teres'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/pyrenophora_teres/ncrna/Pyrenophora_teres.GCA_000166005.1.ncrna.fa.gz',
	'pyrenophora_triticirepentis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/pyrenophora_triticirepentis/ncrna/Pyrenophora_triticirepentis.GCA_000149985.1.ncrna.fa.gz',
	'pyronema_omphalodes_cbs_100304'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pyronema_omphalodes_cbs_100304/ncrna/Pyronema_omphalodes_cbs_100304.Pcon_v1.ncrna.fa.gz',
	'pythium_aphanidermatum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_aphanidermatum/ncrna/Pythium_aphanidermatum.pag1_scaffolds_v1.ncrna.fa.gz',
	'pythium_arrhenomanes'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_arrhenomanes/ncrna/Pythium_arrhenomanes.par_scaffolds_v1.ncrna.fa.gz',
	'pythium_irregulare'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_irregulare/ncrna/Pythium_irregulare.pir_scaffolds_v1.ncrna.fa.gz',
	'pythium_iwayamai'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_iwayamai/ncrna/Pythium_iwayamai.piw_scaffolds_v1.ncrna.fa.gz',
	'pythium_ultimum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_ultimum/ncrna/Pythium_ultimum.pug.ncrna.fa.gz',
	'pythium_vexans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_vexans/ncrna/Pythium_vexans.pve_scaffolds_v1.ncrna.fa.gz',
	'rachicladosporium_antarcticum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/rachicladosporium_antarcticum/ncrna/Rachicladosporium_antarcticum.ASM207706v1.ncrna.fa.gz',
	'rasamsonia_emersonii_cbs_393_64'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/rasamsonia_emersonii_cbs_393_64/ncrna/Rasamsonia_emersonii_cbs_393_64.ASM96859v1.ncrna.fa.gz',
	'rattus_norvegicus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/rattus_norvegicus/ncrna/Rattus_norvegicus.Rnor_6.0.ncrna.fa.gz',
	'reticulomyxa_filosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_rhizaria1_collection/reticulomyxa_filosa/ncrna/Reticulomyxa_filosa.Reti_assembly1.0.ncrna.fa.gz',
	'rhinocladiella_mackenziei_cbs_650_93'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/rhinocladiella_mackenziei_cbs_650_93/ncrna/Rhinocladiella_mackenziei_cbs_650_93.Rhin_mack_CBS_650_93_V1.ncrna.fa.gz',
	'rhizoctonia_solani'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani/ncrna/Rhizoctonia_solani.AG22IIIB.ncrna.fa.gz',
	'rhizoctonia_solani_123e'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani_123e/ncrna/Rhizoctonia_solani_123e.Rhizoctonia_solani_123E_v1.ncrna.fa.gz',
	'rhizoctonia_solani_ag_1_ia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani_ag_1_ia/ncrna/Rhizoctonia_solani_ag_1_ia.Rhisol_AG1IA_1.0.ncrna.fa.gz',
	'rhizoctonia_solani_ag_1_ib'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani_ag_1_ib/ncrna/Rhizoctonia_solani_ag_1_ib.ASM35025v1.ncrna.fa.gz',
	'rhizoctonia_solani_ag_3_rhs1ap'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani_ag_3_rhs1ap/ncrna/Rhizoctonia_solani_ag_3_rhs1ap.Rhizoctonia_solani_AG-3.ncrna.fa.gz',
	'rhizoctonia_solani_ag_8_wac10335'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani_ag_8_wac10335/ncrna/Rhizoctonia_solani_ag_8_wac10335.RSAG8-1.V1.ncrna.fa.gz',
	'rhizophagus_irregularis_daom_181602_gca_000439145'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/rhizophagus_irregularis_daom_181602_gca_000439145/ncrna/Rhizophagus_irregularis_daom_181602_gca_000439145.Gloin1.ncrna.fa.gz',
	'rhizopogon_vesiculosus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizopogon_vesiculosus/ncrna/Rhizopogon_vesiculosus.Rves_AM-OR11-056_1.0.ncrna.fa.gz',
	'rhizopogon_vinicolor_am_or11_026'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizopogon_vinicolor_am_or11_026/ncrna/Rhizopogon_vinicolor_am_or11_026.Rhivi1.ncrna.fa.gz',
	'rhizopus_delemar_ra_99_880'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/rhizopus_delemar_ra_99_880/ncrna/Rhizopus_delemar_ra_99_880.RO3.ncrna.fa.gz',
	'rhizopus_microsporus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/rhizopus_microsporus/ncrna/Rhizopus_microsporus.Rhimi_ATCC11559_1.ncrna.fa.gz',
	'rhizopus_microsporus_var_microsporus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/rhizopus_microsporus_var_microsporus/ncrna/Rhizopus_microsporus_var_microsporus.Rhimi_ATCC52814_1.ncrna.fa.gz',
	'rhodnius_prolixus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/rhodnius_prolixus/ncrna/Rhodnius_prolixus.RproC1.ncrna.fa.gz',
	'rhodotorula_graminis_wp1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhodotorula_graminis_wp1/ncrna/Rhodotorula_graminis_wp1.Rhoba1_1.ncrna.fa.gz',
	'rhodotorula_sp_jg_1b'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhodotorula_sp_jg_1b/ncrna/Rhodotorula_sp_jg_1b.Rhosp1.ncrna.fa.gz',
	'rhodotorula_toruloides'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhodotorula_toruloides/ncrna/Rhodotorula_toruloides.IFO0880_HGAP3_v1.ncrna.fa.gz',
	'rhodotorula_toruloides_atcc_204091'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhodotorula_toruloides_atcc_204091/ncrna/Rhodotorula_toruloides_atcc_204091.R.glutinis2.ncrna.fa.gz',
	'rhodotorula_toruloides_np11'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhodotorula_toruloides_np11/ncrna/Rhodotorula_toruloides_np11.RHOziaDV1.0.ncrna.fa.gz',
	'rhynchosporium_agropyri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/rhynchosporium_agropyri/ncrna/Rhynchosporium_agropyri.version_1.ncrna.fa.gz',
	'rhynchosporium_commune'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/rhynchosporium_commune/ncrna/Rhynchosporium_commune.version_1.ncrna.fa.gz',
	'rhynchosporium_secalis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/rhynchosporium_secalis/ncrna/Rhynchosporium_secalis.version_1.ncrna.fa.gz',
	'rozella_allomycis_csf55'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_rozellomycota1_collection/rozella_allomycis_csf55/ncrna/Rozella_allomycis_csf55.Rozella_k41_t100.ncrna.fa.gz',
	'saccharomyces_arboricola_h_6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_arboricola_h_6/ncrna/Saccharomyces_arboricola_h_6.SacArb1.0.ncrna.fa.gz',
	'saccharomyces_cerevisiae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/saccharomyces_cerevisiae/ncrna/Saccharomyces_cerevisiae.R64-1-1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_awri796'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_awri796/ncrna/Saccharomyces_cerevisiae_awri796.ScAWRI796_v01.ncrna.fa.gz',
	'saccharomyces_cerevisiae_cen_pk113_7d'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_cen_pk113_7d/ncrna/Saccharomyces_cerevisiae_cen_pk113_7d.ASM26988v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_ec1118'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_ec1118/ncrna/Saccharomyces_cerevisiae_ec1118.ASM21897v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_fostersb'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_fostersb/ncrna/Saccharomyces_cerevisiae_fostersb.ScFostersB_v01.ncrna.fa.gz',
	'saccharomyces_cerevisiae_fosterso'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_fosterso/ncrna/Saccharomyces_cerevisiae_fosterso.ScFostersO_v01.ncrna.fa.gz',
	'saccharomyces_cerevisiae_gca_000091065'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_gca_000091065/ncrna/Saccharomyces_cerevisiae_gca_000091065.ASM9106v2.ncrna.fa.gz',
	'saccharomyces_cerevisiae_gca_001634645'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_gca_001634645/ncrna/Saccharomyces_cerevisiae_gca_001634645.GLBRCY22-3.ncrna.fa.gz',
	'saccharomyces_cerevisiae_gca_001983315'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_gca_001983315/ncrna/Saccharomyces_cerevisiae_gca_001983315.ASM198331v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_kyokai_no_7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_kyokai_no_7/ncrna/Saccharomyces_cerevisiae_kyokai_no_7.K7_1.0.ncrna.fa.gz',
	'saccharomyces_cerevisiae_lalvin_qa23'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_lalvin_qa23/ncrna/Saccharomyces_cerevisiae_lalvin_qa23.ScQA23_v01.ncrna.fa.gz',
	'saccharomyces_cerevisiae_p283'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_p283/ncrna/Saccharomyces_cerevisiae_p283.P283.ncrna.fa.gz',
	'saccharomyces_cerevisiae_p301'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_p301/ncrna/Saccharomyces_cerevisiae_p301.p301.ncrna.fa.gz',
	'saccharomyces_cerevisiae_r008'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_r008/ncrna/Saccharomyces_cerevisiae_r008.R008.ncrna.fa.gz',
	'saccharomyces_cerevisiae_r103'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_r103/ncrna/Saccharomyces_cerevisiae_r103.R103.ncrna.fa.gz',
	'saccharomyces_cerevisiae_rm11_1a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_rm11_1a/ncrna/Saccharomyces_cerevisiae_rm11_1a.ASM14936v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_vin13'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_vin13/ncrna/Saccharomyces_cerevisiae_vin13.ScVIN13_v01.ncrna.fa.gz',
	'saccharomyces_cerevisiae_vl3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_vl3/ncrna/Saccharomyces_cerevisiae_vl3.ScVL3_v01.ncrna.fa.gz',
	'saccharomyces_cerevisiae_x_saccharomyces_kudriavzevii_vin7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_x_saccharomyces_kudriavzevii_vin7/ncrna/Saccharomyces_cerevisiae_x_saccharomyces_kudriavzevii_vin7.ASM32610v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1078'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1078/ncrna/Saccharomyces_cerevisiae_yjm1078.Sc_YJM1078_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1083'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1083/ncrna/Saccharomyces_cerevisiae_yjm1083.Sc_YJM1083_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1129'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1129/ncrna/Saccharomyces_cerevisiae_yjm1129.Sc_YJM1129_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1133'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1133/ncrna/Saccharomyces_cerevisiae_yjm1133.Sc_YJM1133_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1190'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1190/ncrna/Saccharomyces_cerevisiae_yjm1190.Sc_YJM1190_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1199'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1199/ncrna/Saccharomyces_cerevisiae_yjm1199.Sc_YJM1199_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1202'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1202/ncrna/Saccharomyces_cerevisiae_yjm1202.Sc_YJM1202_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1208'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1208/ncrna/Saccharomyces_cerevisiae_yjm1208.Sc_YJM1208_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1242'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1242/ncrna/Saccharomyces_cerevisiae_yjm1242.Sc_YJM1242_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1244'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1244/ncrna/Saccharomyces_cerevisiae_yjm1244.Sc_YJM1244_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1248'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1248/ncrna/Saccharomyces_cerevisiae_yjm1248.Sc_YJM1248_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1250'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1250/ncrna/Saccharomyces_cerevisiae_yjm1250.Sc_YJM1250_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1252'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1252/ncrna/Saccharomyces_cerevisiae_yjm1252.Sc_YJM1252_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1273'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1273/ncrna/Saccharomyces_cerevisiae_yjm1273.Sc_YJM1273_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1304'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1304/ncrna/Saccharomyces_cerevisiae_yjm1304.Sc_YJM1304_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1307'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1307/ncrna/Saccharomyces_cerevisiae_yjm1307.Sc_YJM1307_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1311'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1311/ncrna/Saccharomyces_cerevisiae_yjm1311.Sc_YJM1311_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1326'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1326/ncrna/Saccharomyces_cerevisiae_yjm1326.Sc_YJM1326_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1332'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1332/ncrna/Saccharomyces_cerevisiae_yjm1332.Sc_YJM1332_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1336'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1336/ncrna/Saccharomyces_cerevisiae_yjm1336.Sc_YJM1336_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1338'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1338/ncrna/Saccharomyces_cerevisiae_yjm1338.Sc_YJM1338_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1341'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1341/ncrna/Saccharomyces_cerevisiae_yjm1341.Sc_YJM1341_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1342'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1342/ncrna/Saccharomyces_cerevisiae_yjm1342.Sc_YJM1342_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1355'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1355/ncrna/Saccharomyces_cerevisiae_yjm1355.Sc_YJM1355_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1356'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1356/ncrna/Saccharomyces_cerevisiae_yjm1356.Sc_YJM1356_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1381'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1381/ncrna/Saccharomyces_cerevisiae_yjm1381.Sc_YJM1381_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1383'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1383/ncrna/Saccharomyces_cerevisiae_yjm1383.Sc_YJM1383_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1385'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1385/ncrna/Saccharomyces_cerevisiae_yjm1385.Sc_YJM1385_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1386'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1386/ncrna/Saccharomyces_cerevisiae_yjm1386.Sc_YJM1386_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1387'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1387/ncrna/Saccharomyces_cerevisiae_yjm1387.Sc_YJM1387_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1388'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1388/ncrna/Saccharomyces_cerevisiae_yjm1388.Sc_YJM1388_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1389'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1389/ncrna/Saccharomyces_cerevisiae_yjm1389.Sc_YJM1389_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1399'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1399/ncrna/Saccharomyces_cerevisiae_yjm1399.Sc_YJM1399_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1400'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1400/ncrna/Saccharomyces_cerevisiae_yjm1400.Sc_YJM1400_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1401'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1401/ncrna/Saccharomyces_cerevisiae_yjm1401.Sc_YJM1401_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1402'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1402/ncrna/Saccharomyces_cerevisiae_yjm1402.Sc_YJM1402_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1415'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1415/ncrna/Saccharomyces_cerevisiae_yjm1415.Sc_YJM1415_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1417'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1417/ncrna/Saccharomyces_cerevisiae_yjm1417.Sc_YJM1417_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1418'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1418/ncrna/Saccharomyces_cerevisiae_yjm1418.Sc_YJM1418_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1419'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1419/ncrna/Saccharomyces_cerevisiae_yjm1419.Sc_YJM1419_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1433'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1433/ncrna/Saccharomyces_cerevisiae_yjm1433.Sc_YJM1433_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1434'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1434/ncrna/Saccharomyces_cerevisiae_yjm1434.Sc_YJM1434_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1439'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1439/ncrna/Saccharomyces_cerevisiae_yjm1439.Sc_YJM1439_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1443'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1443/ncrna/Saccharomyces_cerevisiae_yjm1443.Sc_YJM1443_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1444'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1444/ncrna/Saccharomyces_cerevisiae_yjm1444.Sc_YJM1444_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1447'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1447/ncrna/Saccharomyces_cerevisiae_yjm1447.Sc_YJM1447_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1450'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1450/ncrna/Saccharomyces_cerevisiae_yjm1450.Sc_YJM1450_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1460'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1460/ncrna/Saccharomyces_cerevisiae_yjm1460.Sc_YJM1460_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1463'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1463/ncrna/Saccharomyces_cerevisiae_yjm1463.Sc_YJM1463_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1477'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1477/ncrna/Saccharomyces_cerevisiae_yjm1477.Sc_YJM1477_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1478'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1478/ncrna/Saccharomyces_cerevisiae_yjm1478.Sc_YJM1478_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1479'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1479/ncrna/Saccharomyces_cerevisiae_yjm1479.Sc_YJM1479_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1526'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1526/ncrna/Saccharomyces_cerevisiae_yjm1526.Sc_YJM1526_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1527'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1527/ncrna/Saccharomyces_cerevisiae_yjm1527.Sc_YJM1527_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1549'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1549/ncrna/Saccharomyces_cerevisiae_yjm1549.Sc_YJM1549_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1573'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1573/ncrna/Saccharomyces_cerevisiae_yjm1573.Sc_YJM1573_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1574'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1574/ncrna/Saccharomyces_cerevisiae_yjm1574.Sc_YJM1574_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1592'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1592/ncrna/Saccharomyces_cerevisiae_yjm1592.Sc_YJM1592_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm1615'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1615/ncrna/Saccharomyces_cerevisiae_yjm1615.Sc_YJM1615_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm189'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm189/ncrna/Saccharomyces_cerevisiae_yjm189.Sc_YJM189_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm193'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm193/ncrna/Saccharomyces_cerevisiae_yjm193.Sc_YJM193_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm195'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm195/ncrna/Saccharomyces_cerevisiae_yjm195.Sc_YJM195_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm244'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm244/ncrna/Saccharomyces_cerevisiae_yjm244.Sc_YJM244_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm248'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm248/ncrna/Saccharomyces_cerevisiae_yjm248.Sc_YJM248_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm270'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm270/ncrna/Saccharomyces_cerevisiae_yjm270.Sc_YJM270_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm271'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm271/ncrna/Saccharomyces_cerevisiae_yjm271.Sc_YJM271_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm320'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm320/ncrna/Saccharomyces_cerevisiae_yjm320.Sc_YJM320_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm326'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm326/ncrna/Saccharomyces_cerevisiae_yjm326.Sc_YJM326_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm428'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm428/ncrna/Saccharomyces_cerevisiae_yjm428.Sc_YJM428_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm450'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm450/ncrna/Saccharomyces_cerevisiae_yjm450.Sc_YJM450_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm451'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm451/ncrna/Saccharomyces_cerevisiae_yjm451.Sc_YJM451_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm453'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm453/ncrna/Saccharomyces_cerevisiae_yjm453.Sc_YJM453_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm456'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm456/ncrna/Saccharomyces_cerevisiae_yjm456.Sc_YJM456_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm470'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm470/ncrna/Saccharomyces_cerevisiae_yjm470.Sc_YJM470_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm541'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm541/ncrna/Saccharomyces_cerevisiae_yjm541.Sc_YJM541_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm554'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm554/ncrna/Saccharomyces_cerevisiae_yjm554.Sc_YJM554_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm555'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm555/ncrna/Saccharomyces_cerevisiae_yjm555.Sc_YJM555_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm627'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm627/ncrna/Saccharomyces_cerevisiae_yjm627.Sc_YJM627_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm681'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm681/ncrna/Saccharomyces_cerevisiae_yjm681.Sc_YJM681_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm682'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm682/ncrna/Saccharomyces_cerevisiae_yjm682.Sc_YJM682_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm683'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm683/ncrna/Saccharomyces_cerevisiae_yjm683.Sc_YJM683_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm689'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm689/ncrna/Saccharomyces_cerevisiae_yjm689.Sc_YJM689_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm693'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm693/ncrna/Saccharomyces_cerevisiae_yjm693.Sc_YJM693_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm789'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_yjm789/ncrna/Saccharomyces_cerevisiae_yjm789.ASM18143v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm969'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm969/ncrna/Saccharomyces_cerevisiae_yjm969.Sc_YJM969_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm972'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm972/ncrna/Saccharomyces_cerevisiae_yjm972.Sc_YJM972_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm975'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm975/ncrna/Saccharomyces_cerevisiae_yjm975.Sc_YJM975_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm978'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm978/ncrna/Saccharomyces_cerevisiae_yjm978.Sc_YJM978_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm981'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm981/ncrna/Saccharomyces_cerevisiae_yjm981.Sc_YJM981_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm984'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm984/ncrna/Saccharomyces_cerevisiae_yjm984.Sc_YJM984_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm987'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm987/ncrna/Saccharomyces_cerevisiae_yjm987.Sc_YJM987_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm990'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm990/ncrna/Saccharomyces_cerevisiae_yjm990.Sc_YJM990_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm993'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_yjm993/ncrna/Saccharomyces_cerevisiae_yjm993.Sc_YJM993_v1.ncrna.fa.gz',
	'saccharomyces_cerevisiae_yjm996'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm996/ncrna/Saccharomyces_cerevisiae_yjm996.Sc_YJM996_v1.ncrna.fa.gz',
	'saccharomyces_eubayanus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_eubayanus/ncrna/Saccharomyces_eubayanus.SEUB3.0.ncrna.fa.gz',
	'saccharomyces_kudriavzevii_ifo_1802'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_kudriavzevii_ifo_1802/ncrna/Saccharomyces_kudriavzevii_ifo_1802.Saccharomyces_kudriavzevii_strain_IFO1802_v1.0.ncrna.fa.gz',
	'saccharomyces_sp_boulardii_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_sp_boulardii_/ncrna/Saccharomyces_sp_boulardii_.ASM129837v2.ncrna.fa.gz',
	'saccharomyces_sp_boulardii__gca_001413975'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_sp_boulardii__gca_001413975/ncrna/Saccharomyces_sp_boulardii__gca_001413975.ASM141397v1.ncrna.fa.gz',
	'saccharomycetaceae_sp_ashbya_aceri_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomycetaceae_sp_ashbya_aceri_/ncrna/Saccharomycetaceae_sp_ashbya_aceri_.ASM41222v2.ncrna.fa.gz',
	'saitoella_complicata_nrrl_y_17804'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saitoella_complicata_nrrl_y_17804/ncrna/Saitoella_complicata_nrrl_y_17804.Scomplicata_3.0.ncrna.fa.gz',
	'saitoella_complicata_nrrl_y_17804_gca_001661265'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saitoella_complicata_nrrl_y_17804_gca_001661265/ncrna/Saitoella_complicata_nrrl_y_17804_gca_001661265.Saico1.ncrna.fa.gz',
	'salpingoeca_rosetta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_choanoflagellida1_collection/salpingoeca_rosetta/ncrna/Salpingoeca_rosetta.Proterospongia_sp_ATCC50818.ncrna.fa.gz',
	'saprolegnia_diclina_vs20'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/saprolegnia_diclina_vs20/ncrna/Saprolegnia_diclina_vs20.Sap_diclina_VS20_V1.ncrna.fa.gz',
	'saprolegnia_parasitica_cbs_223_65'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/saprolegnia_parasitica_cbs_223_65/ncrna/Saprolegnia_parasitica_cbs_223_65.ASM15154v2.ncrna.fa.gz',
	'sarcophilus_harrisii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/sarcophilus_harrisii/ncrna/Sarcophilus_harrisii.DEVIL7.0.ncrna.fa.gz',
	'sarcoptes_scabiei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/sarcoptes_scabiei/ncrna/Sarcoptes_scabiei.SscaA1.ncrna.fa.gz',
	'scedosporium_apiospermum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/scedosporium_apiospermum/ncrna/Scedosporium_apiospermum.ScApio1.0.ncrna.fa.gz',
	'scheffersomyces_stipitis_cbs_6054'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/scheffersomyces_stipitis_cbs_6054/ncrna/Scheffersomyces_stipitis_cbs_6054.ASM20916v1.ncrna.fa.gz',
	'schistosoma_mansoni'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/schistosoma_mansoni/ncrna/Schistosoma_mansoni.ASM23792v2.ncrna.fa.gz',
	'schizophyllum_commune_h4_8'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/schizophyllum_commune_h4_8/ncrna/Schizophyllum_commune_h4_8.v1.0.ncrna.fa.gz',
	'schizopora_paradoxa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/schizopora_paradoxa/ncrna/Schizopora_paradoxa.Schpa1.ncrna.fa.gz',
	'schizosaccharomyces_cryophilus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/schizosaccharomyces_cryophilus/ncrna/Schizosaccharomyces_cryophilus.GCA_000004155.2.ncrna.fa.gz',
	'schizosaccharomyces_japonicus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/schizosaccharomyces_japonicus/ncrna/Schizosaccharomyces_japonicus.GCA_000149845.2.ncrna.fa.gz',
	'schizosaccharomyces_octosporus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/schizosaccharomyces_octosporus/ncrna/Schizosaccharomyces_octosporus.GCA_000150505.2.ncrna.fa.gz',
	'schizosaccharomyces_pombe'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/schizosaccharomyces_pombe/ncrna/Schizosaccharomyces_pombe.ASM294v2.ncrna.fa.gz',
	'scleroderma_citrinum_foug_a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/scleroderma_citrinum_foug_a/ncrna/Scleroderma_citrinum_foug_a.Scleroderma_citrinum_Foug_A_v1.0.ncrna.fa.gz',
	'sclerotinia_borealis_f_4128'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/sclerotinia_borealis_f_4128/ncrna/Sclerotinia_borealis_f_4128.SBOR_1.ncrna.fa.gz',
	'sclerotinia_sclerotiorum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/sclerotinia_sclerotiorum/ncrna/Sclerotinia_sclerotiorum.ASM14694v1.ncrna.fa.gz',
	'sclerotinia_sclerotiorum_1980_uf_70'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/sclerotinia_sclerotiorum_1980_uf_70/ncrna/Sclerotinia_sclerotiorum_1980_uf_70.ASM185786v1.ncrna.fa.gz',
	'selaginella_moellendorffii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/selaginella_moellendorffii/ncrna/Selaginella_moellendorffii.v1.0.ncrna.fa.gz',
	'serendipita_indica_dsm_11827'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/serendipita_indica_dsm_11827/ncrna/Serendipita_indica_dsm_11827.ASM31354v1.ncrna.fa.gz',
	'serendipita_vermifera_maff_305830'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/serendipita_vermifera_maff_305830/ncrna/Serendipita_vermifera_maff_305830.Sebacina_vermifera_MAFF_305830_v1.0.ncrna.fa.gz',
	'serpula_lacrymans_var_lacrymans_s7_3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/serpula_lacrymans_var_lacrymans_s7_3/ncrna/Serpula_lacrymans_var_lacrymans_s7_3.v1.0.ncrna.fa.gz',
	'serpula_lacrymans_var_lacrymans_s7_9'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/serpula_lacrymans_var_lacrymans_s7_9/ncrna/Serpula_lacrymans_var_lacrymans_s7_9.v1.0.ncrna.fa.gz',
	'setaria_italica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/setaria_italica/ncrna/Setaria_italica.JGIv2.0.ncrna.fa.gz',
	'setosphaeria_turcica_et28a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/setosphaeria_turcica_et28a/ncrna/Setosphaeria_turcica_et28a.Setospaeria_trucica_Et28A_v1.0.ncrna.fa.gz',
	'sistotremastrum_niveocremeum_hhb9708'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/sistotremastrum_niveocremeum_hhb9708/ncrna/Sistotremastrum_niveocremeum_hhb9708.Sisni1.ncrna.fa.gz',
	'sistotremastrum_suecicum_hhb10207_ss_3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/sistotremastrum_suecicum_hhb10207_ss_3/ncrna/Sistotremastrum_suecicum_hhb10207_ss_3.Sissu1.ncrna.fa.gz',
	'solanum_lycopersicum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/solanum_lycopersicum/ncrna/Solanum_lycopersicum.SL2.50.ncrna.fa.gz',
	'solanum_tuberosum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/solanum_tuberosum/ncrna/Solanum_tuberosum.SolTub_3.0.ncrna.fa.gz',
	'solenopsis_invicta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/solenopsis_invicta/ncrna/Solenopsis_invicta.Si_gnG.ncrna.fa.gz',
	'sordaria_macrospora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/sordaria_macrospora/ncrna/Sordaria_macrospora.ASM18280v2.ncrna.fa.gz',
	'sorex_araneus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/sorex_araneus/ncrna/Sorex_araneus.COMMON_SHREW1.ncrna.fa.gz',
	'sorghum_bicolor'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/sorghum_bicolor/ncrna/Sorghum_bicolor.Sorghum_bicolor_v2.ncrna.fa.gz',
	'spathaspora_passalidarum_nrrl_y_27907'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/spathaspora_passalidarum_nrrl_y_27907/ncrna/Spathaspora_passalidarum_nrrl_y_27907.Spathaspora_passalidarum_v2.0.ncrna.fa.gz',
	'sphaerobolus_stellatus_ss14'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/sphaerobolus_stellatus_ss14/ncrna/Sphaerobolus_stellatus_ss14.Sphst1.ncrna.fa.gz',
	'sphaeroforma_arctica_jp610'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_ichthyosporea1_collection/sphaeroforma_arctica_jp610/ncrna/Sphaeroforma_arctica_jp610.Spha_arctica_JP610_V1.ncrna.fa.gz',
	'sphaerulina_musiva_so2202'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/sphaerulina_musiva_so2202/ncrna/Sphaerulina_musiva_so2202.Septoria_musiva_SO2202_v1.0.ncrna.fa.gz',
	'spironucleus_salmonicida'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/spironucleus_salmonicida/ncrna/Spironucleus_salmonicida.SSK3.0.ncrna.fa.gz',
	'spizellomyces_punctatus_daom_br117'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_chytridiomycota1_collection/spizellomyces_punctatus_daom_br117/ncrna/Spizellomyces_punctatus_daom_br117.S_punctatus_V1.ncrna.fa.gz',
	'sporidiobolus_salmonicolor'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/sporidiobolus_salmonicolor/ncrna/Sporidiobolus_salmonicolor.SPOSA68321A01.ncrna.fa.gz',
	'sporisorium_reilianum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/sporisorium_reilianum/ncrna/Sporisorium_reilianum.GCA_000230245.1.ncrna.fa.gz',
	'sporisorium_scitamineum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/sporisorium_scitamineum/ncrna/Sporisorium_scitamineum.Sporisorium_scitamineum.ncrna.fa.gz',
	'sporothrix_brasiliensis_5110'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/sporothrix_brasiliensis_5110/ncrna/Sporothrix_brasiliensis_5110.S_brasiliensis_5110_v1.ncrna.fa.gz',
	'sporothrix_insectorum_rcef_264'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/sporothrix_insectorum_rcef_264/ncrna/Sporothrix_insectorum_rcef_264.SPI_1.0.ncrna.fa.gz',
	'sporothrix_schenckii_1099_18'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/sporothrix_schenckii_1099_18/ncrna/Sporothrix_schenckii_1099_18.S_schenckii_v1.ncrna.fa.gz',
	'sporothrix_schenckii_atcc_58251'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/sporothrix_schenckii_atcc_58251/ncrna/Sporothrix_schenckii_atcc_58251.Spor_sche_ATCC58251_V1.ncrna.fa.gz',
	'spraguea_lophii_42_110'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/spraguea_lophii_42_110/ncrna/Spraguea_lophii_42_110.Sprlop1.0.ncrna.fa.gz',
	'stachybotrys_chartarum_ibt_40288'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/stachybotrys_chartarum_ibt_40288/ncrna/Stachybotrys_chartarum_ibt_40288.S40288v1.ncrna.fa.gz',
	'stachybotrys_chartarum_ibt_40293'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/stachybotrys_chartarum_ibt_40293/ncrna/Stachybotrys_chartarum_ibt_40293.S40293v1.ncrna.fa.gz',
	'stachybotrys_chartarum_ibt_7711'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/stachybotrys_chartarum_ibt_7711/ncrna/Stachybotrys_chartarum_ibt_7711.S7711v1.ncrna.fa.gz',
	'stachybotrys_chlorohalonata_ibt_40285'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/stachybotrys_chlorohalonata_ibt_40285/ncrna/Stachybotrys_chlorohalonata_ibt_40285.S40285v1.ncrna.fa.gz',
	'stagonospora_sp_src1lsm3a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/stagonospora_sp_src1lsm3a/ncrna/Stagonospora_sp_src1lsm3a.Stasp1.ncrna.fa.gz',
	'stegodyphus_mimosarum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/stegodyphus_mimosarum/ncrna/Stegodyphus_mimosarum.Stegodyphus_mimosarum_v1.ncrna.fa.gz',
	'stemphylium_lycopersici'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/stemphylium_lycopersici/ncrna/Stemphylium_lycopersici.ASM119154v1.ncrna.fa.gz',
	'stereum_hirsutum_fp_91666_ss1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/stereum_hirsutum_fp_91666_ss1/ncrna/Stereum_hirsutum_fp_91666_ss1.Stehi1.ncrna.fa.gz',
	'strigamia_maritima'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/strigamia_maritima/ncrna/Strigamia_maritima.Smar1.ncrna.fa.gz',
	'strigomonas_culicis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/strigomonas_culicis/ncrna/Strigomonas_culicis.Strigomonas_culicis_Genome.ncrna.fa.gz',
	'strongylocentrotus_purpuratus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/strongylocentrotus_purpuratus/ncrna/Strongylocentrotus_purpuratus.Spur_3.1.ncrna.fa.gz',
	'sugiyamaella_lignohabitans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/sugiyamaella_lignohabitans/ncrna/Sugiyamaella_lignohabitans.ASM164002v2.ncrna.fa.gz',
	'suillus_luteus_uh_slu_lm8_n1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/suillus_luteus_uh_slu_lm8_n1/ncrna/Suillus_luteus_uh_slu_lm8_n1.Suilu1.ncrna.fa.gz',
	'sus_scrofa'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/sus_scrofa/ncrna/Sus_scrofa.Sscrofa11.1.ncrna.fa.gz',
	'taeniopygia_guttata'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/taeniopygia_guttata/ncrna/Taeniopygia_guttata.taeGut3.2.4.ncrna.fa.gz',
	'takifugu_rubripes'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/takifugu_rubripes/ncrna/Takifugu_rubripes.FUGU4.ncrna.fa.gz',
	'talaromyces_cellulolyticus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/talaromyces_cellulolyticus/ncrna/Talaromyces_cellulolyticus.TcelY94_1.0.ncrna.fa.gz',
	'talaromyces_islandicus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/talaromyces_islandicus/ncrna/Talaromyces_islandicus.PIS.ncrna.fa.gz',
	'talaromyces_marneffei_atcc_18224'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/talaromyces_marneffei_atcc_18224/ncrna/Talaromyces_marneffei_atcc_18224.JCVI-PMFA1-2.0.ncrna.fa.gz',
	'talaromyces_marneffei_pm1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/talaromyces_marneffei_pm1/ncrna/Talaromyces_marneffei_pm1.ASM75011v1.ncrna.fa.gz',
	'talaromyces_stipitatus_atcc_10500'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/talaromyces_stipitatus_atcc_10500/ncrna/Talaromyces_stipitatus_atcc_10500.JCVI-TSTA1-3.0.ncrna.fa.gz',
	'termitomyces_sp_j132'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/termitomyces_sp_j132/ncrna/Termitomyces_sp_j132.TerJ1321.0.ncrna.fa.gz',
	'tetrahymena_thermophila'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/tetrahymena_thermophila/ncrna/Tetrahymena_thermophila.JCVI-TTA1-2.2.ncrna.fa.gz',
	'tetranychus_urticae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/tetranychus_urticae/ncrna/Tetranychus_urticae.ASM23943v1.ncrna.fa.gz',
	'tetraodon_nigroviridis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/tetraodon_nigroviridis/ncrna/Tetraodon_nigroviridis.TETRAODON8.ncrna.fa.gz',
	'tetrapisispora_blattae_cbs_6284'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/tetrapisispora_blattae_cbs_6284/ncrna/Tetrapisispora_blattae_cbs_6284.ASM31591v1.ncrna.fa.gz',
	'tetrapisispora_phaffii_cbs_4417'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/tetrapisispora_phaffii_cbs_4417/ncrna/Tetrapisispora_phaffii_cbs_4417.ASM23690v1.ncrna.fa.gz',
	'thalassiosira_oceanica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/thalassiosira_oceanica/ncrna/Thalassiosira_oceanica.ThaOc_1.0.ncrna.fa.gz',
	'thalassiosira_oceanica_ccmp1005'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/thalassiosira_oceanica_ccmp1005/ncrna/Thalassiosira_oceanica_ccmp1005.ASM19663v1.ncrna.fa.gz',
	'thalassiosira_pseudonana'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/thalassiosira_pseudonana/ncrna/Thalassiosira_pseudonana.ASM14940v2.ncrna.fa.gz',
	'thecamonas_trahens_atcc_50062'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_apusozoa1_collection/thecamonas_trahens_atcc_50062/ncrna/Thecamonas_trahens_atcc_50062.TheTra_May2010.ncrna.fa.gz',
	'theileria_annulata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/theileria_annulata/ncrna/Theileria_annulata.ASM322v1.ncrna.fa.gz',
	'theileria_equi_strain_wa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/theileria_equi_strain_wa/ncrna/Theileria_equi_strain_wa.JCVI-bewag-v1.1.ncrna.fa.gz',
	'theileria_orientalis_strain_shintoku'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/theileria_orientalis_strain_shintoku/ncrna/Theileria_orientalis_strain_shintoku.ASM74089v1.ncrna.fa.gz',
	'theileria_parva'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/theileria_parva/ncrna/Theileria_parva.ASM16536v1.ncrna.fa.gz',
	'thelohanellus_kitauei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/thelohanellus_kitauei/ncrna/Thelohanellus_kitauei.ASM82789v1.ncrna.fa.gz',
	'theobroma_cacao'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/theobroma_cacao/ncrna/Theobroma_cacao.Theobroma_cacao_20110822.ncrna.fa.gz',
	'thermothelomyces_thermophila_atcc_42464'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/thermothelomyces_thermophila_atcc_42464/ncrna/Thermothelomyces_thermophila_atcc_42464.ASM22609v1.ncrna.fa.gz',
	'thielavia_terrestris_nrrl_8126'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/thielavia_terrestris_nrrl_8126/ncrna/Thielavia_terrestris_nrrl_8126.ASM22611v1.ncrna.fa.gz',
	'thielaviopsis_punctulata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/thielaviopsis_punctulata/ncrna/Thielaviopsis_punctulata.ASM96861v1.ncrna.fa.gz',
	'tilletia_caries'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tilletia_caries/ncrna/Tilletia_caries.ASM164500v1.ncrna.fa.gz',
	'tilletia_controversa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tilletia_controversa/ncrna/Tilletia_controversa.ASM164504v1.ncrna.fa.gz',
	'tilletia_indica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tilletia_indica/ncrna/Tilletia_indica.ASM164501v1.ncrna.fa.gz',
	'tilletia_walkeri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tilletia_walkeri/ncrna/Tilletia_walkeri.ASM164505v1.ncrna.fa.gz',
	'tilletiaria_anomala_ubc_951'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tilletiaria_anomala_ubc_951/ncrna/Tilletiaria_anomala_ubc_951.Tilletiaria_anomala_UBC_951_v1.0.ncrna.fa.gz',
	'tolypocladium_ophioglossoides_cbs_100239'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/tolypocladium_ophioglossoides_cbs_100239/ncrna/Tolypocladium_ophioglossoides_cbs_100239.Tophv1.0.ncrna.fa.gz',
	'torrubiella_hemipterigena'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/torrubiella_hemipterigena/ncrna/Torrubiella_hemipterigena.Allpaths-LG.ncrna.fa.gz',
	'tortispora_caseinolytica_nrrl_y_17796'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/tortispora_caseinolytica_nrrl_y_17796/ncrna/Tortispora_caseinolytica_nrrl_y_17796.Canca1.ncrna.fa.gz',
	'torulaspora_delbrueckii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/torulaspora_delbrueckii/ncrna/Torulaspora_delbrueckii.ASM24337v1.ncrna.fa.gz',
	'toxoplasma_gondii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/toxoplasma_gondii/ncrna/Toxoplasma_gondii.ToxoDB-7.1.ncrna.fa.gz',
	'toxoplasma_gondii_ari'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_ari/ncrna/Toxoplasma_gondii_ari.TGARI_v2.ncrna.fa.gz',
	'toxoplasma_gondii_fou'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_fou/ncrna/Toxoplasma_gondii_fou.TGFOU1v02.ncrna.fa.gz',
	'toxoplasma_gondii_gab2_2007_gal_dom2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_gab2_2007_gal_dom2/ncrna/Toxoplasma_gondii_gab2_2007_gal_dom2.TGGABGALDOM2_v2.1.ncrna.fa.gz',
	'toxoplasma_gondii_gt1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_gt1/ncrna/Toxoplasma_gondii_gt1.TGGT1.ncrna.fa.gz',
	'toxoplasma_gondii_mas'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_mas/ncrna/Toxoplasma_gondii_mas.TGMAS1_v2.ncrna.fa.gz',
	'toxoplasma_gondii_p89'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_p89/ncrna/Toxoplasma_gondii_p89.TGP89A_v02.ncrna.fa.gz',
	'toxoplasma_gondii_rub'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_rub/ncrna/Toxoplasma_gondii_rub.TGRUB_v2.ncrna.fa.gz',
	'toxoplasma_gondii_tgcatprc2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_tgcatprc2/ncrna/Toxoplasma_gondii_tgcatprc2.TGCATPRC2_v2.ncrna.fa.gz',
	'toxoplasma_gondii_vand'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_vand/ncrna/Toxoplasma_gondii_vand.TGVAND_v2.ncrna.fa.gz',
	'toxoplasma_gondii_veg'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_veg/ncrna/Toxoplasma_gondii_veg.TGVEG.ncrna.fa.gz',
	'trachipleistophora_hominis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/trachipleistophora_hominis/ncrna/Trachipleistophora_hominis.ASM31613v1.ncrna.fa.gz',
	'trametes_cinnabarina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/trametes_cinnabarina/ncrna/Trametes_cinnabarina.BN946.ncrna.fa.gz',
	'trametes_pubescens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/trametes_pubescens/ncrna/Trametes_pubescens.ASM189594v1.ncrna.fa.gz',
	'trametes_versicolor_fp_101664_ss1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/trametes_versicolor_fp_101664_ss1/ncrna/Trametes_versicolor_fp_101664_ss1.Trametes_versicolor_v1.0.ncrna.fa.gz',
	'tremella_mesenterica_dsm_1558'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tremella_mesenterica_dsm_1558/ncrna/Tremella_mesenterica_dsm_1558.Treme1.ncrna.fa.gz',
	'tribolium_castaneum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/tribolium_castaneum/ncrna/Tribolium_castaneum.Tcas5.2.ncrna.fa.gz',
	'trichoderma_atroviride_imi_206040'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichoderma_atroviride_imi_206040/ncrna/Trichoderma_atroviride_imi_206040.TRIAT_v2.0.ncrna.fa.gz',
	'trichoderma_gamsii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/trichoderma_gamsii/ncrna/Trichoderma_gamsii.ASM148177v1.ncrna.fa.gz',
	'trichoderma_guizhouense'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/trichoderma_guizhouense/ncrna/Trichoderma_guizhouense.ASM202278v1.ncrna.fa.gz',
	'trichoderma_harzianum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/trichoderma_harzianum/ncrna/Trichoderma_harzianum.ASM98886v1.ncrna.fa.gz',
	'trichoderma_reesei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/trichoderma_reesei/ncrna/Trichoderma_reesei.GCA_000167675.2.ncrna.fa.gz',
	'trichoderma_reesei_rut_c_30'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichoderma_reesei_rut_c_30/ncrna/Trichoderma_reesei_rut_c_30.TrireRUTC30_1.ncrna.fa.gz',
	'trichoderma_virens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/trichoderma_virens/ncrna/Trichoderma_virens.ASM17099v1.ncrna.fa.gz',
	'trichomonas_vaginalis_g3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_parabasalia1_collection/trichomonas_vaginalis_g3/ncrna/Trichomonas_vaginalis_g3.ASM282v1.ncrna.fa.gz',
	'trichophyton_benhamiae_cbs_112371'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_benhamiae_cbs_112371/ncrna/Trichophyton_benhamiae_cbs_112371.ASM15112v2.ncrna.fa.gz',
	'trichophyton_equinum_cbs_127_97'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_equinum_cbs_127_97/ncrna/Trichophyton_equinum_cbs_127_97.ASM15117v1.ncrna.fa.gz',
	'trichophyton_interdigitale_h6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_interdigitale_h6/ncrna/Trichophyton_interdigitale_h6.Tric_rubr_H6_V2.ncrna.fa.gz',
	'trichophyton_interdigitale_mr816'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_interdigitale_mr816/ncrna/Trichophyton_interdigitale_mr816.Tric_inte_MR816_V1.ncrna.fa.gz',
	'trichophyton_rubrum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/trichophyton_rubrum/ncrna/Trichophyton_rubrum.CMCC_F_T1i.ncrna.fa.gz',
	'trichophyton_rubrum_cbs_100081'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_100081/ncrna/Trichophyton_rubrum_cbs_100081.Tric_fish_CBS_100081_V1.ncrna.fa.gz',
	'trichophyton_rubrum_cbs_118892'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_118892/ncrna/Trichophyton_rubrum_cbs_118892.ASM15142v1.ncrna.fa.gz',
	'trichophyton_rubrum_cbs_202_88'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_202_88/ncrna/Trichophyton_rubrum_cbs_202_88.Tric_raub_CBS_202_88_V2.ncrna.fa.gz',
	'trichophyton_rubrum_cbs_288_86'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_288_86/ncrna/Trichophyton_rubrum_cbs_288_86.Tric_fish_CBS_288_86_V1.ncrna.fa.gz',
	'trichophyton_rubrum_cbs_289_86'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_289_86/ncrna/Trichophyton_rubrum_cbs_289_86.Tric_kane_CBS_289_86_V1.ncrna.fa.gz',
	'trichophyton_rubrum_cbs_735_88'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_735_88/ncrna/Trichophyton_rubrum_cbs_735_88.Tric_megn_CBS_735_88_V1.ncrna.fa.gz',
	'trichophyton_rubrum_d6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_d6/ncrna/Trichophyton_rubrum_d6.Tric_rubr_D6_V1.ncrna.fa.gz',
	'trichophyton_rubrum_mr1448'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_mr1448/ncrna/Trichophyton_rubrum_mr1448.Tric_rubr_M1448_V1.ncrna.fa.gz',
	'trichophyton_rubrum_mr1459'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_mr1459/ncrna/Trichophyton_rubrum_mr1459.Tric_rubr_MR1459_V1.ncrna.fa.gz',
	'trichophyton_rubrum_mr850'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_mr850/ncrna/Trichophyton_rubrum_mr850.Tric_rubr_MR-850_V1.ncrna.fa.gz',
	'trichophyton_soudanense_cbs_452_61'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_soudanense_cbs_452_61/ncrna/Trichophyton_soudanense_cbs_452_61.Tric_soud_CBS_452_61_V1.ncrna.fa.gz',
	'trichophyton_tonsurans_cbs_112818'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_tonsurans_cbs_112818/ncrna/Trichophyton_tonsurans_cbs_112818.ASM15145v1.ncrna.fa.gz',
	'trichophyton_verrucosum_hki_0517'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_verrucosum_hki_0517/ncrna/Trichophyton_verrucosum_hki_0517.ASM15150v1.ncrna.fa.gz',
	'trichophyton_violaceum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/trichophyton_violaceum/ncrna/Trichophyton_violaceum.CMCC_F_T3l.ncrna.fa.gz',
	'trichoplax_adhaerens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/trichoplax_adhaerens/ncrna/Trichoplax_adhaerens.ASM15027v1.ncrna.fa.gz',
	'trichosporon_asahii_var_asahii_cbs_2479'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/trichosporon_asahii_var_asahii_cbs_2479/ncrna/Trichosporon_asahii_var_asahii_cbs_2479.Trichosporon_asahii_1.ncrna.fa.gz',
	'trichosporon_asahii_var_asahii_cbs_8904'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/trichosporon_asahii_var_asahii_cbs_8904/ncrna/Trichosporon_asahii_var_asahii_cbs_8904.ASM29921v2.ncrna.fa.gz',
	'trifolium_pratense'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/trifolium_pratense/ncrna/Trifolium_pratense.Trpr.ncrna.fa.gz',
	'triticum_aestivum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/triticum_aestivum/ncrna/Triticum_aestivum.TGACv1.ncrna.fa.gz',
	'triticum_urartu'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/triticum_urartu/ncrna/Triticum_urartu.ASM34745v1.ncrna.fa.gz',
	'trypanosoma_brucei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/trypanosoma_brucei/ncrna/Trypanosoma_brucei.TryBru_Apr2005_chr11.ncrna.fa.gz',
	'trypanosoma_cruzi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/trypanosoma_cruzi/ncrna/Trypanosoma_cruzi.ASM20906v1.ncrna.fa.gz',
	'trypanosoma_cruzi_dm28c'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/trypanosoma_cruzi_dm28c/ncrna/Trypanosoma_cruzi_dm28c.T.cruzi.Dm28c_v01.ncrna.fa.gz',
	'tsuchiyaea_wingfieldii_cbs_7118'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tsuchiyaea_wingfieldii_cbs_7118/ncrna/Tsuchiyaea_wingfieldii_cbs_7118.Tsuc_wing_CBS7118_V1.ncrna.fa.gz',
	'tuber_melanosporum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/tuber_melanosporum/ncrna/Tuber_melanosporum.ASM15164v1.ncrna.fa.gz',
	'tulasnella_calospora_mut_4182'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tulasnella_calospora_mut_4182/ncrna/Tulasnella_calospora_mut_4182.Tulasnella_calospora_AL13_4D_v1.0.ncrna.fa.gz',
	'tupaia_belangeri'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/tupaia_belangeri/ncrna/Tupaia_belangeri.TREESHREW.ncrna.fa.gz',
	'tursiops_truncatus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/tursiops_truncatus/ncrna/Tursiops_truncatus.turTru1.ncrna.fa.gz',
	'umbilicaria_pustulata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/umbilicaria_pustulata/ncrna/Umbilicaria_pustulata.Lasallia_pustulata_v1.ncrna.fa.gz',
	'uncinocarpus_reesii_1704'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/uncinocarpus_reesii_1704/ncrna/Uncinocarpus_reesii_1704.ASM351v2.ncrna.fa.gz',
	'ustilaginoidea_virens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/ustilaginoidea_virens/ncrna/Ustilaginoidea_virens.Assembly_for_version_1_of_the_Villosiclava_virens_genome.ncrna.fa.gz',
	'ustilaginoidea_virens_gca_000965225'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ustilaginoidea_virens_gca_000965225/ncrna/Ustilaginoidea_virens_gca_000965225.ASM96522v2.ncrna.fa.gz',
	'ustilago_bromivora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/ustilago_bromivora/ncrna/Ustilago_bromivora.UBRO_v3.ncrna.fa.gz',
	'ustilago_hordei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/ustilago_hordei/ncrna/Ustilago_hordei.ASM28603v1.ncrna.fa.gz',
	'ustilago_maydis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/ustilago_maydis/ncrna/Ustilago_maydis.Umaydis521_2.0.ncrna.fa.gz',
	'valsa_mali'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/valsa_mali/ncrna/Valsa_mali.ASM81815v1.ncrna.fa.gz',
	'valsa_mali_var_pyri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/valsa_mali_var_pyri/ncrna/Valsa_mali_var_pyri.ASM81338v1.ncrna.fa.gz',
	'vanderwaltozyma_polyspora_dsm_70294'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/vanderwaltozyma_polyspora_dsm_70294/ncrna/Vanderwaltozyma_polyspora_dsm_70294.ASM15003v1.ncrna.fa.gz',
	'vavraia_culicis_subsp_floridensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/vavraia_culicis_subsp_floridensis/ncrna/Vavraia_culicis_subsp_floridensis.Vavr_culi_floridensis_V1.ncrna.fa.gz',
	'verruconis_gallopava'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/verruconis_gallopava/ncrna/Verruconis_gallopava.O_gall_CBS43764.ncrna.fa.gz',
	'verticillium_alfalfae_vams_102'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/verticillium_alfalfae_vams_102/ncrna/Verticillium_alfalfae_vams_102.ASM15082v1.ncrna.fa.gz',
	'verticillium_dahliae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/verticillium_dahliae/ncrna/Verticillium_dahliae.ASM15067v2.ncrna.fa.gz',
	'verticillium_dahliaejr2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/verticillium_dahliaejr2/ncrna/Verticillium_dahliaejr2.VDAG_JR2v.4.0.ncrna.fa.gz',
	'verticillium_longisporum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/verticillium_longisporum/ncrna/Verticillium_longisporum.vl2.denovo.v1.ncrna.fa.gz',
	'verticillium_longisporum_gca_001268145'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/verticillium_longisporum_gca_001268145/ncrna/Verticillium_longisporum_gca_001268145.vl1.denovo.v1.ncrna.fa.gz',
	'vicugna_pacos'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/vicugna_pacos/ncrna/Vicugna_pacos.vicPac1.ncrna.fa.gz',
	'vitis_vinifera'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/vitis_vinifera/ncrna/Vitis_vinifera.IGGP_12x.ncrna.fa.gz',
	'vitrella_brassicaformis_ccmp3155'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/vitrella_brassicaformis_ccmp3155/ncrna/Vitrella_brassicaformis_ccmp3155.Vbrassicaformis.ncrna.fa.gz',
	'vittaforma_corneae_atcc_50505'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/vittaforma_corneae_atcc_50505/ncrna/Vittaforma_corneae_atcc_50505.Vitt_corn_V1.ncrna.fa.gz',
	'wallemia_ichthyophaga_exf_994'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/wallemia_ichthyophaga_exf_994/ncrna/Wallemia_ichthyophaga_exf_994.Wallemia_ichthyophaga_version_1.0.ncrna.fa.gz',
	'wallemia_mellicola_cbs_633_66'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/wallemia_mellicola_cbs_633_66/ncrna/Wallemia_mellicola_cbs_633_66.Wallemia_sebi_v1.0.ncrna.fa.gz',
	'wickerhamomyces_anomalus_nrrl_y_366_8'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/wickerhamomyces_anomalus_nrrl_y_366_8/ncrna/Wickerhamomyces_anomalus_nrrl_y_366_8.Wican1.ncrna.fa.gz',
	'wickerhamomyces_ciferrii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/wickerhamomyces_ciferrii/ncrna/Wickerhamomyces_ciferrii.ASM31348v1.ncrna.fa.gz',
	'xanthophyllomyces_dendrorhous'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/xanthophyllomyces_dendrorhous/ncrna/Xanthophyllomyces_dendrorhous.Xden1.ncrna.fa.gz',
	'xenopus_tropicalis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/xenopus_tropicalis/ncrna/Xenopus_tropicalis.JGI_4.2.ncrna.fa.gz',
	'xiphophorus_maculatus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/xiphophorus_maculatus/ncrna/Xiphophorus_maculatus.Xipmac4.4.2.ncrna.fa.gz',
	'xylona_heveae_tc161'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/xylona_heveae_tc161/ncrna/Xylona_heveae_tc161.Xylona_heveae_TC161_v1.0.ncrna.fa.gz',
	'yarrowia_lipolytica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/yarrowia_lipolytica/ncrna/Yarrowia_lipolytica.GCA_000002525.1.ncrna.fa.gz',
	'yarrowia_lipolytica_gca_001761485'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/yarrowia_lipolytica_gca_001761485/ncrna/Yarrowia_lipolytica_gca_001761485.ASM176148v1.ncrna.fa.gz',
	'zea_mays'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/zea_mays/ncrna/Zea_mays.AGPv4.ncrna.fa.gz',
	'zootermopsis_nevadensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/zootermopsis_nevadensis/ncrna/Zootermopsis_nevadensis.ZooNev1.0.ncrna.fa.gz',
	'zygosaccharomyces_bailii_isa1307'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/zygosaccharomyces_bailii_isa1307/ncrna/Zygosaccharomyces_bailii_isa1307.Z_bailii_ISA1307_version_3.ncrna.fa.gz',
	'zygosaccharomyces_parabailii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/zygosaccharomyces_parabailii/ncrna/Zygosaccharomyces_parabailii.ASM198439v2.ncrna.fa.gz',
	'zygosaccharomyces_rouxii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/zygosaccharomyces_rouxii/ncrna/Zygosaccharomyces_rouxii.ASM2636v1.ncrna.fa.gz',
	'zygosaccharomyces_rouxii_gca_001972345'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/zygosaccharomyces_rouxii_gca_001972345/ncrna/Zygosaccharomyces_rouxii_gca_001972345.ZYGR_assembly01.ncrna.fa.gz',
	'zymoseptoria_brevis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/zymoseptoria_brevis/ncrna/Zymoseptoria_brevis.ASM96659v1.ncrna.fa.gz',
	'zymoseptoria_tritici'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/zymoseptoria_tritici/ncrna/Zymoseptoria_tritici.MG2.ncrna.fa.gz',
	);### NCRNA URLS END ###
			}

		if(!$silent){print"\nDownload ncRNA data for $species{$species} from Ensembl database...";}
		$status=getstore("$ensembl_ncRNA{$species}","UNITAS_refdump_$species/ensembl_ncRNA.gz");
		if(is_success($status))
			{
			if(!$silent){print" OK.";}
			$db_versions_info.="Ensembl version/date: ..................... Release $ensembl_release\n";
			$db_versions_info.="EnsemblGenomes version/date: .............. Release $ensemblgenomes_release\n";
			}
		else
			{
			if(!$silent){print" FAILED! $status. Download data from smallRNAgroup-SERVER...";}
			$status=getstore("http://www.smallrnagroup.uni-mainz.de/data/UNITAS/Ensembl/Ensembl-ncRNA_$species.fasta","UNITAS_refdump_$species/ensembl_ncRNA.gz");
			if(is_success($status))
				{
				if(!$silent){print" OK.";}
				$version1=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/Ensembl/release');
				$version2=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/Ensembl/releaseEnsemblGenomes');
				$db_versions_info.="Ensembl version/date: ..................... Release $version1\n";
				$db_versions_info.="EnsemblGenomes version/date: .............. Release $version2\n";
				}
			else
				{
				if(!$silent){print" FAILED! $status.\n\n";}
				}
			}
		if(!$silent){print"\nExtract file...";}
		$ae=Archive::Extract->new(archive=>"UNITAS_refdump_$species/ensembl_ncRNA.gz");
		$ae->extract(to=>"UNITAS_refdump_$species")||die print"\nERROR! Unable to decompress UNITAS_refdump_$species/ensembl_ncRNA.gz.\n$!\n\n";
		if(!$silent){print" OK.\nRemove compressed file...";}
		unlink"UNITAS_refdump_$species/ensembl_ncRNA.gz"||print"\nERROR! Unable to remove compressed file UNITAS_refdump_$species/ensembl_ncRNA.gz.\n$!\n\n";
		if(!$silent){print" OK.\nRemove miRNA precursor sequences from ncRNA data file...";}

		# remove miRNA sequences from ncRNA file. miRNA annotation will base on miRBase data, not Ensembl data.
		open(NCRNA,"UNITAS_refdump_$species/ensembl_ncRNA")||die print"\nERROR! Unable to read UNITAS_refdump_$species/ensembl_ncRNA.\n$!\n\n";
		open(NCRNA_EDIT,">UNITAS_refdump_$species/ncRNA.fas")||die print"\nERROR! Unable to create UNITAS_refdump_$species/ncRNA.fas.\n$!\n\n";
		%ncRNA=();
		%avoid_redundant_names=();
		while(<NCRNA>)
			{
			$_=~s/\s*$//;
			if($_=~/^>/)
				{
				# extract biotype
				if($_=~s/gene_biotype:[^ ]+//)
					{
					$biotype=$&;
					$biotype=~s/gene_biotype://;
					}
				elsif($_=~s/transcript_biotype:[^ ]+//)
					{
					$biotype=$&;
					$biotype=~s/transcript_biotype://;
					}
				else
					{
					$biotype="unknown";
					}

				# extract gene symbol
				if($_=~s/gene_symbol:[^ ]+//)
					{
					$symbol=$&;
					$symbol=~s/gene_symbol://;
					}
				else
					{
					$symbol=$_;
					$symbol=~s/ .*$//;
					}

				# extract gene ID
				if($_=~s/gene:[^ ]+//)
					{
					$geneID=$&;
					$geneID=~s/gene://;
					}
				else
					{
					$geneID="unknownID";
					}

				# extract anticodon for tRNAs
				if($_=~s/ for anticodon ...//)
					{
					$anticodon=$&;
					$anticodon=~s/ /_/g;
					}
				else
					{
					$anticodon="";
					}

				# check if key for hash has been used before
				$avoid_redundant_names{"$biotype|${symbol}$anticodon-$geneID"}++;
				if($avoid_redundant_names{"$biotype|${symbol}$anticodon-$geneID"}==1)
					{
					$ncRNA_key="$biotype|${symbol}${anticodon}-$geneID";
					}
				else
					{
					$red_ID=$avoid_redundant_names{"$biotype|${symbol}$anticodon-$geneID"};
					$ncRNA_key="$biotype|${symbol}${anticodon}-$geneID_($red_ID)";
					}
				}
			elsif($biotype!~/miRNA/)
				{
				$ncRNA{$ncRNA_key}.=$_;
				}
			}
		close NCRNA;
		foreach$head(sort{$a cmp $b}keys%ncRNA)
			{
			print NCRNA_EDIT">$head\n$ncRNA{$head}\n";
			}
		undef%ncRNA;
		undef%avoid_redundant_names;
		if(!$silent){print" OK.";}

		# download and process ensembl cDNA data
		$eval_URL="";
		$eval_URL=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/URLs/Ensembl_cDNA');
		if(length$eval_URL>0)
			{
			eval$eval_URL;
			}
		else
			{
			if(!$silent){print"\nFailed to load current Ensembl URLs for cDNA data from smallRNAgroup-SERVER. Use internal list.";}
### CDNA URLS START ###
%ensembl_cDNA=
	(
	'_candida_auris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_auris/cdna/_candida_auris.ASM118947v1.cdna.all.fa.gz',
	'_candida_glabrata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/_candida_glabrata/cdna/_candida_glabrata.ASM254v2.cdna.all.fa.gz',
	'_candida_glabrata_gca_001466525'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466525/cdna/_candida_glabrata_gca_001466525.ASM146652v1.cdna.all.fa.gz',
	'_candida_glabrata_gca_001466535'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466535/cdna/_candida_glabrata_gca_001466535.ASM146653v1.cdna.all.fa.gz',
	'_candida_glabrata_gca_001466565'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466565/cdna/_candida_glabrata_gca_001466565.ASM146656v1.cdna.all.fa.gz',
	'_candida_glabrata_gca_001466575'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466575/cdna/_candida_glabrata_gca_001466575.ASM146657v1.cdna.all.fa.gz',
	'_candida_glabrata_gca_001466635'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466635/cdna/_candida_glabrata_gca_001466635.ASM146663v1.cdna.all.fa.gz',
	'_candida_glabrata_gca_001466685'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_glabrata_gca_001466685/cdna/_candida_glabrata_gca_001466685.ASM146668v1.cdna.all.fa.gz',
	'_candida_intermedia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_intermedia/cdna/_candida_intermedia.CBS_141442_assembly.cdna.all.fa.gz',
	'_candida_intermedia_gca_900106125'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/_candida_intermedia_gca_900106125/cdna/_candida_intermedia_gca_900106125.PYCC_4715_assembly.cdna.all.fa.gz',
	'_candida_tenuis_atcc_10573'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/_candida_tenuis_atcc_10573/cdna/_candida_tenuis_atcc_10573.Candida_tenuis_v1.0.cdna.all.fa.gz',
	'absidia_glauca'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/absidia_glauca/cdna/Absidia_glauca.AG_v1.cdna.all.fa.gz',
	'acidomyces_richmondensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/acidomyces_richmondensis/cdna/Acidomyces_richmondensis.ASM157207v1.cdna.all.fa.gz',
	'acidomyces_richmondensis_bfw'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/acidomyces_richmondensis_bfw/cdna/Acidomyces_richmondensis_bfw.Acidomyces_richmondensis_BFW_v1.0.cdna.all.fa.gz',
	'acremonium_chrysogenum_atcc_11550'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/acremonium_chrysogenum_atcc_11550/cdna/Acremonium_chrysogenum_atcc_11550.ASM76926v1.cdna.all.fa.gz',
	'acyrthosiphon_pisum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/acyrthosiphon_pisum/cdna/Acyrthosiphon_pisum.Acyr_2.0.cdna.all.fa.gz',
	'adineta_vaga'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/adineta_vaga/cdna/Adineta_vaga.AMS_PRJEB1171_v1.cdna.all.fa.gz',
	'aedes_aegypti'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/aedes_aegypti/cdna/Aedes_aegypti.AaegL3.cdna.abinitio.fa.gz',
	'aegilops_tauschii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/aegilops_tauschii/cdna/Aegilops_tauschii.ASM34733v1.cdna.all.fa.gz',
	'agaricus_bisporus_var_burnettii_jb137_s8'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/agaricus_bisporus_var_burnettii_jb137_s8/cdna/Agaricus_bisporus_var_burnettii_jb137_s8.Agabi_varbur_1.cdna.all.fa.gz',
	'ailuropoda_melanoleuca'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ailuropoda_melanoleuca/cdna/Ailuropoda_melanoleuca.ailMel1.cdna.abinitio.fa.gz',
	'albugo_laibachii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/albugo_laibachii/cdna/Albugo_laibachii.ENA1.cdna.all.fa.gz',
	'allomyces_macrogynus_atcc_38327'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_blastocladiomycota1_collection/allomyces_macrogynus_atcc_38327/cdna/Allomyces_macrogynus_atcc_38327.A_macrogynus_V3.cdna.all.fa.gz',
	'alternaria_alternata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/alternaria_alternata/cdna/Alternaria_alternata.Altal1.cdna.all.fa.gz',
	'amanita_muscaria_koide_bx008'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/amanita_muscaria_koide_bx008/cdna/Amanita_muscaria_koide_bx008.Amanita_muscaria_Koide_BX008_v1.0.cdna.all.fa.gz',
	'amborella_trichopoda'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/amborella_trichopoda/cdna/Amborella_trichopoda.AMTR1.0.cdna.all.fa.gz',
	'amphiamblys_sp_wsbs2006'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/amphiamblys_sp_wsbs2006/cdna/Amphiamblys_sp_wsbs2006.ASM187567v1.cdna.all.fa.gz',
	'amphimedon_queenslandica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/amphimedon_queenslandica/cdna/Amphimedon_queenslandica.Aqu1.cdna.all.fa.gz',
	'anas_platyrhynchos'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/anas_platyrhynchos/cdna/Anas_platyrhynchos.BGI_duck_1.0.cdna.abinitio.fa.gz',
	'angomonas_deanei'=>'',
	'anncaliia_algerae_pra109'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/anncaliia_algerae_pra109/cdna/Anncaliia_algerae_pra109.Annc_alge_PRA109_V4.cdna.all.fa.gz',
	'anncaliia_algerae_pra339'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/anncaliia_algerae_pra339/cdna/Anncaliia_algerae_pra339.Annc_alge_insect_USDA_JJB_V2.cdna.all.fa.gz',
	'anolis_carolinensis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/anolis_carolinensis/cdna/Anolis_carolinensis.AnoCar2.0.cdna.abinitio.fa.gz',
	'anopheles_darlingi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/anopheles_darlingi/cdna/Anopheles_darlingi.AdarC3.cdna.abinitio.fa.gz',
	'anopheles_gambiae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/anopheles_gambiae/cdna/Anopheles_gambiae.AgamP4.cdna.abinitio.fa.gz',
	'anoplophora_glabripennis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/anoplophora_glabripennis/cdna/Anoplophora_glabripennis.Agla_1.0.cdna.all.fa.gz',
	'anthracocystis_flocculosa_pf_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/anthracocystis_flocculosa_pf_1/cdna/Anthracocystis_flocculosa_pf_1.Pflocc_1.0.cdna.all.fa.gz',
	'aphanomyces_astaci'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/aphanomyces_astaci/cdna/Aphanomyces_astaci.Apha_asta_APO3_V1.cdna.all.fa.gz',
	'aphanomyces_invadans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/aphanomyces_invadans/cdna/Aphanomyces_invadans.Apha_inva_NJM9701_V1.cdna.all.fa.gz',
	'apis_mellifera'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/apis_mellifera/cdna/Apis_mellifera.Amel_4.5.cdna.all.fa.gz',
	'arabidopsis_lyrata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/arabidopsis_lyrata/cdna/Arabidopsis_lyrata.v.1.0.cdna.abinitio.fa.gz',
	'arabidopsis_thaliana'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/arabidopsis_thaliana/cdna/Arabidopsis_thaliana.TAIR10.cdna.abinitio.fa.gz',
	'arthrobotrys_oligospora_atcc_24927'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/arthrobotrys_oligospora_atcc_24927/cdna/Arthrobotrys_oligospora_atcc_24927.AOL24927_1.0.cdna.all.fa.gz',
	'arthroderma_otae_cbs_113480'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/arthroderma_otae_cbs_113480/cdna/Arthroderma_otae_cbs_113480.ASM15114v1.cdna.all.fa.gz',
	'aschersonia_aleyrodis_rcef_2490'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aschersonia_aleyrodis_rcef_2490/cdna/Aschersonia_aleyrodis_rcef_2490.AAL_1.0.cdna.all.fa.gz',
	'ascochyta_rabiei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ascochyta_rabiei/cdna/Ascochyta_rabiei.AscRab1.0.cdna.all.fa.gz',
	'ascoidea_rubescens_dsm_1968'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ascoidea_rubescens_dsm_1968/cdna/Ascoidea_rubescens_dsm_1968.Ascru1.cdna.all.fa.gz',
	'ascosphaera_apis_arsef_7405'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ascosphaera_apis_arsef_7405/cdna/Ascosphaera_apis_arsef_7405.AAP_1.0.cdna.all.fa.gz',
	'ashbya_gossypii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/ashbya_gossypii/cdna/Ashbya_gossypii.ASM9102v1.cdna.all.fa.gz',
	'aspergillus_aculeatus_atcc_16872'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_aculeatus_atcc_16872/cdna/Aspergillus_aculeatus_atcc_16872.Aspac1.cdna.all.fa.gz',
	'aspergillus_bombycis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_bombycis/cdna/Aspergillus_bombycis.ASM179269v1.cdna.all.fa.gz',
	'aspergillus_brasiliensis_cbs_101740'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_brasiliensis_cbs_101740/cdna/Aspergillus_brasiliensis_cbs_101740.Aspbr1.cdna.all.fa.gz',
	'aspergillus_calidoustus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_calidoustus/cdna/Aspergillus_calidoustus.Acal_Allpaths_LG.cdna.all.fa.gz',
	'aspergillus_carbonarius_item_5010'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_carbonarius_item_5010/cdna/Aspergillus_carbonarius_item_5010.Aspca3.cdna.all.fa.gz',
	'aspergillus_clavatus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_clavatus/cdna/Aspergillus_clavatus.CADRE.cdna.all.fa.gz',
	'aspergillus_cristatus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_cristatus/cdna/Aspergillus_cristatus.ASM171748v1.cdna.all.fa.gz',
	'aspergillus_flavus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_flavus/cdna/Aspergillus_flavus.JCVI-afl1-v2.0.cdna.all.fa.gz',
	'aspergillus_flavus_af70'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/aspergillus_flavus_af70/cdna/Aspergillus_flavus_af70.ASM95283v1.cdna.all.fa.gz',
	'aspergillus_fumigatus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_fumigatus/cdna/Aspergillus_fumigatus.CADRE.cdna.all.fa.gz',
	'aspergillus_fumigatus_var_rp_2014'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aspergillus_fumigatus_var_rp_2014/cdna/Aspergillus_fumigatus_var_rp_2014.AspFumNiv1.0.cdna.all.fa.gz',
	'aspergillus_fumigatus_z5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_fumigatus_z5/cdna/Aspergillus_fumigatus_z5.ASM102932v1.cdna.all.fa.gz',
	'aspergillus_fumigatusa1163'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_fumigatusa1163/cdna/Aspergillus_fumigatusa1163.CADRE.cdna.all.fa.gz',
	'aspergillus_glaucus_cbs_516_65'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_glaucus_cbs_516_65/cdna/Aspergillus_glaucus_cbs_516_65.Aspgl1.cdna.all.fa.gz',
	'aspergillus_lentulus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_lentulus/cdna/Aspergillus_lentulus.Alt_assembly01.cdna.all.fa.gz',
	'aspergillus_luchuensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_luchuensis/cdna/Aspergillus_luchuensis.AspL_2604.cdna.all.fa.gz',
	'aspergillus_luchuensis_cbs_106_47'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_luchuensis_cbs_106_47/cdna/Aspergillus_luchuensis_cbs_106_47.Aspfo1.cdna.all.fa.gz',
	'aspergillus_nidulans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_nidulans/cdna/Aspergillus_nidulans.ASM1142v1.cdna.all.fa.gz',
	'aspergillus_nidulans_fgsc_a4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/aspergillus_nidulans_fgsc_a4/cdna/Aspergillus_nidulans_fgsc_a4.ASM14920v2.cdna.all.fa.gz',
	'aspergillus_niger'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_niger/cdna/Aspergillus_niger.ASM285v2.cdna.all.fa.gz',
	'aspergillus_niger_atcc_1015'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aspergillus_niger_atcc_1015/cdna/Aspergillus_niger_atcc_1015.ASPNI_v3.0.cdna.all.fa.gz',
	'aspergillus_niger_gca_001515345'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_niger_gca_001515345/cdna/Aspergillus_niger_gca_001515345.ASM151534v1.cdna.all.fa.gz',
	'aspergillus_nomius_nrrl_13137'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_nomius_nrrl_13137/cdna/Aspergillus_nomius_nrrl_13137.ASM120477v1.cdna.all.fa.gz',
	'aspergillus_ochraceoroseus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/aspergillus_ochraceoroseus/cdna/Aspergillus_ochraceoroseus.ASM98666v1.cdna.all.fa.gz',
	'aspergillus_oryzae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_oryzae/cdna/Aspergillus_oryzae.ASM18445v3.cdna.all.fa.gz',
	'aspergillus_oryzae_100_8'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aspergillus_oryzae_100_8/cdna/Aspergillus_oryzae_100_8.Aspergillus_oryzae_100-8.cdna.all.fa.gz',
	'aspergillus_oryzae_3_042'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aspergillus_oryzae_3_042/cdna/Aspergillus_oryzae_3_042.AspOry3042.cdna.all.fa.gz',
	'aspergillus_oryzae_gca_002007945'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_oryzae_gca_002007945/cdna/Aspergillus_oryzae_gca_002007945.ASM200794v1.cdna.all.fa.gz',
	'aspergillus_parasiticus_su_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_parasiticus_su_1/cdna/Aspergillus_parasiticus_su_1.ASM95608v1.cdna.all.fa.gz',
	'aspergillus_rambellii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/aspergillus_rambellii/cdna/Aspergillus_rambellii.ASM98664v1.cdna.all.fa.gz',
	'aspergillus_ruber_cbs_135680'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aspergillus_ruber_cbs_135680/cdna/Aspergillus_ruber_cbs_135680.Eurhe1.cdna.all.fa.gz',
	'aspergillus_sydowii_cbs_593_65'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_sydowii_cbs_593_65/cdna/Aspergillus_sydowii_cbs_593_65.Aspsy1.cdna.all.fa.gz',
	'aspergillus_terreus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/aspergillus_terreus/cdna/Aspergillus_terreus.CADRE.cdna.all.fa.gz',
	'aspergillus_tubingensis_cbs_134_48'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_tubingensis_cbs_134_48/cdna/Aspergillus_tubingensis_cbs_134_48.Asptu1.cdna.all.fa.gz',
	'aspergillus_udagawae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_udagawae/cdna/Aspergillus_udagawae.Aud_assembly01.cdna.all.fa.gz',
	'aspergillus_ustus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/aspergillus_ustus/cdna/Aspergillus_ustus.Austus1.0.cdna.all.fa.gz',
	'aspergillus_versicolor_cbs_583_65'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_versicolor_cbs_583_65/cdna/Aspergillus_versicolor_cbs_583_65.Aspve1.cdna.all.fa.gz',
	'aspergillus_wentii_dto_134e9'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aspergillus_wentii_dto_134e9/cdna/Aspergillus_wentii_dto_134e9.Aspwe1.cdna.all.fa.gz',
	'astyanax_mexicanus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/astyanax_mexicanus/cdna/Astyanax_mexicanus.AstMex102.cdna.abinitio.fa.gz',
	'atta_cephalotes'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/atta_cephalotes/cdna/Atta_cephalotes.Attacep1.0.cdna.all.fa.gz',
	'aureobasidium_melanogenum_cbs_110374'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aureobasidium_melanogenum_cbs_110374/cdna/Aureobasidium_melanogenum_cbs_110374.Aureobasidium_pullulans_var._melanogenum_CBS_110374_v1.0.cdna.all.fa.gz',
	'aureobasidium_namibiae_cbs_147_97'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aureobasidium_namibiae_cbs_147_97/cdna/Aureobasidium_namibiae_cbs_147_97.Aureobasidium_pullulans_var._namibiae_CBS_147.97_v1.0.cdna.all.fa.gz',
	'aureobasidium_pullulans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/aureobasidium_pullulans/cdna/Aureobasidium_pullulans.ASM167811v1.cdna.all.fa.gz',
	'aureobasidium_pullulans_exf_150'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aureobasidium_pullulans_exf_150/cdna/Aureobasidium_pullulans_exf_150.Aureobasidium_pullulans_var._pullulans_EXF-150_assembly_version_1.0.cdna.all.fa.gz',
	'aureobasidium_subglaciale_exf_2481'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/aureobasidium_subglaciale_exf_2481/cdna/Aureobasidium_subglaciale_exf_2481.Aureobasidium_pullulans_var._subglaciale_EXF-2481_v1.0.cdna.all.fa.gz',
	'babesia_bovis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/babesia_bovis/cdna/Babesia_bovis.ASM16539v1.cdna.all.fa.gz',
	'babesia_microti_strain_ri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/babesia_microti_strain_ri/cdna/Babesia_microti_strain_ri.ASM69194v1.cdna.all.fa.gz',
	'babjeviella_inositovora_nrrl_y_12698'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/babjeviella_inositovora_nrrl_y_12698/cdna/Babjeviella_inositovora_nrrl_y_12698.Babin1.cdna.all.fa.gz',
	'batrachochytrium_dendrobatidis_jam81'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_chytridiomycota1_collection/batrachochytrium_dendrobatidis_jam81/cdna/Batrachochytrium_dendrobatidis_jam81.v1.0.cdna.all.fa.gz',
	'batrachochytrium_dendrobatidis_jel423'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_chytridiomycota1_collection/batrachochytrium_dendrobatidis_jel423/cdna/Batrachochytrium_dendrobatidis_jel423.BD_JEL423.cdna.all.fa.gz',
	'batrachochytrium_salamandrivorans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_chytridiomycota1_collection/batrachochytrium_salamandrivorans/cdna/Batrachochytrium_salamandrivorans.Batr_sala_BS_V1.cdna.all.fa.gz',
	'baudoinia_panamericana_uamh_10762'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/baudoinia_panamericana_uamh_10762/cdna/Baudoinia_panamericana_uamh_10762.Bauco1.cdna.all.fa.gz',
	'beauveria_bassiana'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/beauveria_bassiana/cdna/Beauveria_bassiana.ASM168263v1.cdna.all.fa.gz',
	'beauveria_bassiana_arsef_2860'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/beauveria_bassiana_arsef_2860/cdna/Beauveria_bassiana_arsef_2860.ASM28067v1.cdna.all.fa.gz',
	'beauveria_bassiana_d1_5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/beauveria_bassiana_d1_5/cdna/Beauveria_bassiana_d1_5.BBA1.0.cdna.all.fa.gz',
	'belgica_antarctica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/belgica_antarctica/cdna/Belgica_antarctica.ASM77530v1.cdna.all.fa.gz',
	'beta_vulgaris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/beta_vulgaris/cdna/Beta_vulgaris.RefBeet-1.2.2.cdna.all.fa.gz',
	'bigelowiella_natans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/bigelowiella_natans/cdna/Bigelowiella_natans.Bigna1.cdna.all.fa.gz',
	'bigelowiella_natans_gca_000002455'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_rhizaria1_collection/bigelowiella_natans_gca_000002455/cdna/Bigelowiella_natans_gca_000002455.ASM245v1.cdna.all.fa.gz',
	'bipolaris_maydis_atcc_48331'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_maydis_atcc_48331/cdna/Bipolaris_maydis_atcc_48331.CocheC4_1.cdna.all.fa.gz',
	'bipolaris_maydis_c5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_maydis_c5/cdna/Bipolaris_maydis_c5.CocheC5_3.cdna.all.fa.gz',
	'bipolaris_oryzae_atcc_44560'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_oryzae_atcc_44560/cdna/Bipolaris_oryzae_atcc_44560.Cochliobolus_miyabeanus_v1.0.cdna.all.fa.gz',
	'bipolaris_sorokiniana_nd90pr'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_sorokiniana_nd90pr/cdna/Bipolaris_sorokiniana_nd90pr.Cocsa1.cdna.all.fa.gz',
	'bipolaris_victoriae_fi3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_victoriae_fi3/cdna/Bipolaris_victoriae_fi3.Cochliobolus_victoriae_v1.0.cdna.all.fa.gz',
	'bipolaris_zeicola_26_r_13'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/bipolaris_zeicola_26_r_13/cdna/Bipolaris_zeicola_26_r_13.Cochliobolus_carbonum_v1.0.cdna.all.fa.gz',
	'blastomyces_dermatitidis_atcc_18188'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/blastomyces_dermatitidis_atcc_18188/cdna/Blastomyces_dermatitidis_atcc_18188.BD_ATCC18188_V1.cdna.all.fa.gz',
	'blastomyces_dermatitidis_atcc_26199'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/blastomyces_dermatitidis_atcc_26199/cdna/Blastomyces_dermatitidis_atcc_26199.BD_ATCC26199_V2.cdna.all.fa.gz',
	'blastomyces_dermatitidis_er_3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/blastomyces_dermatitidis_er_3/cdna/Blastomyces_dermatitidis_er_3.BD_ER3_V1.cdna.all.fa.gz',
	'blastomyces_gilchristii_slh14081'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/blastomyces_gilchristii_slh14081/cdna/Blastomyces_gilchristii_slh14081.BD_SLH14081_V1.cdna.all.fa.gz',
	'blastomyces_percursus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/blastomyces_percursus/cdna/Blastomyces_percursus.Blas_perc_EI222_V1.cdna.all.fa.gz',
	'blumeria_graminis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/blumeria_graminis/cdna/Blumeria_graminis.EF1.cdna.all.fa.gz',
	'blumeria_graminis_f_sp_tritici_96224'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/blumeria_graminis_f_sp_tritici_96224/cdna/Blumeria_graminis_f_sp_tritici_96224.Bgt_454_newbler_assembly.cdna.all.fa.gz',
	'bodo_saltans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/bodo_saltans/cdna/Bodo_saltans.BSAL.cdna.all.fa.gz',
	'bombus_impatiens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/bombus_impatiens/cdna/Bombus_impatiens.BIMP_2.0.cdna.all.fa.gz',
	'bombyx_mori'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/bombyx_mori/cdna/Bombyx_mori.ASM15162v1.cdna.all.fa.gz',
	'bos_taurus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/bos_taurus/cdna/Bos_taurus.UMD3.1.cdna.abinitio.fa.gz',
	'botryobasidium_botryosum_fd_172_ss1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/botryobasidium_botryosum_fd_172_ss1/cdna/Botryobasidium_botryosum_fd_172_ss1.Botbo1.cdna.all.fa.gz',
	'botrytis_cinerea'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/botrytis_cinerea/cdna/Botrytis_cinerea.ASM83294v1.cdna.all.fa.gz',
	'botrytis_cinerea_bcdw1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/botrytis_cinerea_bcdw1/cdna/Botrytis_cinerea_bcdw1.BcDW1.cdna.all.fa.gz',
	'botrytis_cinerea_t4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/botrytis_cinerea_t4/cdna/Botrytis_cinerea_t4.BotFuc_Mar2011.cdna.all.fa.gz',
	'brachypodium_distachyon'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/brachypodium_distachyon/cdna/Brachypodium_distachyon.v1.0.cdna.abinitio.fa.gz',
	'brassica_napus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/brassica_napus/cdna/Brassica_napus.AST_PRJEB5043_v1.cdna.all.fa.gz',
	'brassica_oleracea'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/brassica_oleracea/cdna/Brassica_oleracea.v2.1.cdna.all.fa.gz',
	'brassica_rapa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/brassica_rapa/cdna/Brassica_rapa.IVFCAASv1.cdna.all.fa.gz',
	'brettanomyces_bruxellensis_awri1499'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/brettanomyces_bruxellensis_awri1499/cdna/Brettanomyces_bruxellensis_awri1499.AWRI1499_v1.0.cdna.all.fa.gz',
	'brugia_malayi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/brugia_malayi/cdna/Brugia_malayi.B_malayi-3.1.cdna.all.fa.gz',
	'byssochlamys_spectabilis_no_5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/byssochlamys_spectabilis_no_5/cdna/Byssochlamys_spectabilis_no_5.PVAR5_assembly01.cdna.all.fa.gz',
	'caenorhabditis_brenneri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/caenorhabditis_brenneri/cdna/Caenorhabditis_brenneri.C_brenneri-6.0.1b.cdna.all.fa.gz',
	'caenorhabditis_briggsae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/caenorhabditis_briggsae/cdna/Caenorhabditis_briggsae.CB4.cdna.all.fa.gz',
	'caenorhabditis_elegans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/caenorhabditis_elegans/cdna/Caenorhabditis_elegans.WBcel235.cdna.all.fa.gz',
	'caenorhabditis_japonica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/caenorhabditis_japonica/cdna/Caenorhabditis_japonica.C_japonica-7.0.1.cdna.all.fa.gz',
	'caenorhabditis_remanei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/caenorhabditis_remanei/cdna/Caenorhabditis_remanei.C_remanei-15.0.1.cdna.all.fa.gz',
	'callithrix_jacchus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/callithrix_jacchus/cdna/Callithrix_jacchus.C_jacchus3.2.1.cdna.abinitio.fa.gz',
	'calocera_cornea_hhb12733'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/calocera_cornea_hhb12733/cdna/Calocera_cornea_hhb12733.Calco1.cdna.all.fa.gz',
	'calocera_viscosa_tufc12733'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/calocera_viscosa_tufc12733/cdna/Calocera_viscosa_tufc12733.Calvi1.cdna.all.fa.gz',
	'candida_albicans_12c'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_12c/cdna/Candida_albicans_12c.Cand_albi_12C_V2.cdna.all.fa.gz',
	'candida_albicans_19f'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_19f/cdna/Candida_albicans_19f.Cand_albi_19F_V2.cdna.all.fa.gz',
	'candida_albicans_ca6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_ca6/cdna/Candida_albicans_ca6.Cand_albi_Ca6_V2.cdna.all.fa.gz',
	'candida_albicans_gc75'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_gc75/cdna/Candida_albicans_gc75.Cand_albi_GC75_V1.cdna.all.fa.gz',
	'candida_albicans_l26'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_l26/cdna/Candida_albicans_l26.Cand_albi_L26_V2.cdna.all.fa.gz',
	'candida_albicans_p34048'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p34048/cdna/Candida_albicans_p34048.Cand_albi_P34048_V1.cdna.all.fa.gz',
	'candida_albicans_p37005'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_p37005/cdna/Candida_albicans_p37005.Cand_albi_P37005_V2.cdna.all.fa.gz',
	'candida_albicans_p37037'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_p37037/cdna/Candida_albicans_p37037.Cand_albi_P37037_V1.cdna.all.fa.gz',
	'candida_albicans_p37039'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p37039/cdna/Candida_albicans_p37039.Cand_albi_P37039_V1.cdna.all.fa.gz',
	'candida_albicans_p57055'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p57055/cdna/Candida_albicans_p57055.Cand_albi_P57055_V1.cdna.all.fa.gz',
	'candida_albicans_p57072'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_p57072/cdna/Candida_albicans_p57072.Cand_albi_P57072_V1.cdna.all.fa.gz',
	'candida_albicans_p60002'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p60002/cdna/Candida_albicans_p60002.Cand_albi_P60002_V1.cdna.all.fa.gz',
	'candida_albicans_p75010'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p75010/cdna/Candida_albicans_p75010.Cand_albi_P75010_V1.cdna.all.fa.gz',
	'candida_albicans_p75016'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p75016/cdna/Candida_albicans_p75016.Cand_albi_P75016_V1.cdna.all.fa.gz',
	'candida_albicans_p75063'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p75063/cdna/Candida_albicans_p75063.Cand_albi_P75063_V1.cdna.all.fa.gz',
	'candida_albicans_p76055'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p76055/cdna/Candida_albicans_p76055.Cand_albi_P76055_V1.cdna.all.fa.gz',
	'candida_albicans_p76067'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p76067/cdna/Candida_albicans_p76067.Cand_albi_P76067_V1.cdna.all.fa.gz',
	'candida_albicans_p78042'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p78042/cdna/Candida_albicans_p78042.Cand_albi_P78042_V1.cdna.all.fa.gz',
	'candida_albicans_p78048'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_p78048/cdna/Candida_albicans_p78048.Cand_albi_P78048_V1.cdna.all.fa.gz',
	'candida_albicans_p87'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p87/cdna/Candida_albicans_p87.Cand_albi_P87_V2.cdna.all.fa.gz',
	'candida_albicans_p94015'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_p94015/cdna/Candida_albicans_p94015.Cand_albi_P94015_V1.cdna.all.fa.gz',
	'candida_albicans_sc5314'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_sc5314/cdna/Candida_albicans_sc5314.Cand_albi_SC5314_V4.cdna.all.fa.gz',
	'candida_albicans_sc5314_gca_000182965'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/candida_albicans_sc5314_gca_000182965/cdna/Candida_albicans_sc5314_gca_000182965.ASM18296v3.cdna.all.fa.gz',
	'candida_albicans_sc5314_gca_000784655'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/candida_albicans_sc5314_gca_000784655/cdna/Candida_albicans_sc5314_gca_000784655.Cand_albi_SC5314_V3.cdna.all.fa.gz',
	'candida_albicans_wo_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_albicans_wo_1/cdna/Candida_albicans_wo_1.ASM14944v2.cdna.all.fa.gz',
	'candida_arabinofermentans_nrrl_yb_2248'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/candida_arabinofermentans_nrrl_yb_2248/cdna/Candida_arabinofermentans_nrrl_yb_2248.Canar1.cdna.all.fa.gz',
	'candida_dubliniensis_cd36'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_dubliniensis_cd36/cdna/Candida_dubliniensis_cd36.ASM2694v1.cdna.all.fa.gz',
	'candida_maltosa_xu316'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_maltosa_xu316/cdna/Candida_maltosa_xu316.Cmaltosa_v01.cdna.all.fa.gz',
	'candida_orthopsilosis_co_90_125'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_orthopsilosis_co_90_125/cdna/Candida_orthopsilosis_co_90_125.ASM31587v1.cdna.all.fa.gz',
	'candida_parapsilosis_cdc317'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/candida_parapsilosis_cdc317/cdna/Candida_parapsilosis_cdc317.ASM18276v2.cdna.all.fa.gz',
	'candida_tanzawaensis_nrrl_y_17324'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/candida_tanzawaensis_nrrl_y_17324/cdna/Candida_tanzawaensis_nrrl_y_17324.Canta1.cdna.all.fa.gz',
	'candida_tropicalis_mya_3404'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/candida_tropicalis_mya_3404/cdna/Candida_tropicalis_mya_3404.ASM633v2.cdna.all.fa.gz',
	'canis_familiaris'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/canis_familiaris/cdna/Canis_familiaris.CanFam3.1.cdna.abinitio.fa.gz',
	'capitella_teleta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/capitella_teleta/cdna/Capitella_teleta.Capitella_teleta_v1.0.cdna.all.fa.gz',
	'capronia_coronata_cbs_617_96'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/capronia_coronata_cbs_617_96/cdna/Capronia_coronata_cbs_617_96.Capr_coro_CBS_617_96_V1.cdna.all.fa.gz',
	'capronia_epimyces_cbs_606_96'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/capronia_epimyces_cbs_606_96/cdna/Capronia_epimyces_cbs_606_96.Capr_epim_CBS_606_96_V1.cdna.all.fa.gz',
	'capsaspora_owczarzaki_atcc_30864'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_ichthyosporea1_collection/capsaspora_owczarzaki_atcc_30864/cdna/Capsaspora_owczarzaki_atcc_30864.C_owczarzaki_V2.cdna.all.fa.gz',
	'carlito_syrichta'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/carlito_syrichta/cdna/Carlito_syrichta.tarSyr1.cdna.abinitio.fa.gz',
	'cavia_aperea'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/cavia_aperea/cdna/Cavia_aperea.CavAp1.0.cdna.abinitio.fa.gz',
	'cavia_porcellus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/cavia_porcellus/cdna/Cavia_porcellus.Cavpor3.0.cdna.abinitio.fa.gz',
	'ceraceosorus_bombacis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/ceraceosorus_bombacis/cdna/Ceraceosorus_bombacis.Ceraceosorus_bombacis.cdna.all.fa.gz',
	'ceratocystis_platani'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/ceratocystis_platani/cdna/Ceratocystis_platani.ASM97888v1.cdna.all.fa.gz',
	'chaetomium_globosum_cbs_148_51'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/chaetomium_globosum_cbs_148_51/cdna/Chaetomium_globosum_cbs_148_51.ASM14336v1.cdna.all.fa.gz',
	'chaetomium_thermophilum_var_thermophilum_dsm_1495'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/chaetomium_thermophilum_var_thermophilum_dsm_1495/cdna/Chaetomium_thermophilum_var_thermophilum_dsm_1495.CTHT_3.0.cdna.all.fa.gz',
	'chinchilla_lanigera'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/chinchilla_lanigera/cdna/Chinchilla_lanigera.ChiLan1.0.cdna.abinitio.fa.gz',
	'chlamydomonas_reinhardtii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/chlamydomonas_reinhardtii/cdna/Chlamydomonas_reinhardtii.v3.1.cdna.all.fa.gz',
	'chlorocebus_sabaeus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/chlorocebus_sabaeus/cdna/Chlorocebus_sabaeus.ChlSab1.1.cdna.abinitio.fa.gz',
	'choloepus_hoffmanni'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/choloepus_hoffmanni/cdna/Choloepus_hoffmanni.choHof1.cdna.abinitio.fa.gz',
	'chondrus_crispus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/chondrus_crispus/cdna/Chondrus_crispus.ASM35022v2.cdna.all.fa.gz',
	'chroomonas_mesostigmatica_ccmp1168'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_cryptophyta1_collection/chroomonas_mesostigmatica_ccmp1168/cdna/Chroomonas_mesostigmatica_ccmp1168.ASM28609v1.cdna.all.fa.gz',
	'ciona_intestinalis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ciona_intestinalis/cdna/Ciona_intestinalis.KH.cdna.abinitio.fa.gz',
	'ciona_savignyi'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ciona_savignyi/cdna/Ciona_savignyi.CSAV2.0.cdna.abinitio.fa.gz',
	'cladophialophora_bantiana_cbs_173_52'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/cladophialophora_bantiana_cbs_173_52/cdna/Cladophialophora_bantiana_cbs_173_52.Clad_bant_CBS_173_52_V1.cdna.all.fa.gz',
	'cladophialophora_carrionii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cladophialophora_carrionii/cdna/Cladophialophora_carrionii.ASM170077v1.cdna.all.fa.gz',
	'cladophialophora_carrionii_cbs_160_54'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/cladophialophora_carrionii_cbs_160_54/cdna/Cladophialophora_carrionii_cbs_160_54.Clad_carr_CBS_160_54_V1.cdna.all.fa.gz',
	'cladophialophora_immunda'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/cladophialophora_immunda/cdna/Cladophialophora_immunda.Clad_immu_CBS83496_V1.cdna.all.fa.gz',
	'cladophialophora_psammophila_cbs_110553'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/cladophialophora_psammophila_cbs_110553/cdna/Cladophialophora_psammophila_cbs_110553.Clad_psam_CBS_110553_V1.cdna.all.fa.gz',
	'cladophialophora_yegresii_cbs_114405'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/cladophialophora_yegresii_cbs_114405/cdna/Cladophialophora_yegresii_cbs_114405.Clad_yegr_CBS_114405_V1.cdna.all.fa.gz',
	'claviceps_purpurea_20_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/claviceps_purpurea_20_1/cdna/Claviceps_purpurea_20_1.ASM34735v1.cdna.all.fa.gz',
	'clavispora_lusitaniae_atcc_42720'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/clavispora_lusitaniae_atcc_42720/cdna/Clavispora_lusitaniae_atcc_42720.ASM383v1.cdna.all.fa.gz',
	'coccidioides_immitis_h538_4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/coccidioides_immitis_h538_4/cdna/Coccidioides_immitis_h538_4.ASM14981v1.cdna.all.fa.gz',
	'coccidioides_immitis_rmscc_2394'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/coccidioides_immitis_rmscc_2394/cdna/Coccidioides_immitis_rmscc_2394.ASM14989v1.cdna.all.fa.gz',
	'coccidioides_immitis_rmscc_3703'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/coccidioides_immitis_rmscc_3703/cdna/Coccidioides_immitis_rmscc_3703.ASM15008v1.cdna.all.fa.gz',
	'coccidioides_immitis_rs'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/coccidioides_immitis_rs/cdna/Coccidioides_immitis_rs.ASM14933v2.cdna.all.fa.gz',
	'coccidioides_posadasii_c735_delta_sowgp'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/coccidioides_posadasii_c735_delta_sowgp/cdna/Coccidioides_posadasii_c735_delta_sowgp.JCVI-cpa1-1.0.cdna.all.fa.gz',
	'coccidioides_posadasii_rmscc_3488'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/coccidioides_posadasii_rmscc_3488/cdna/Coccidioides_posadasii_rmscc_3488.ASM15005v1.cdna.all.fa.gz',
	'coccidioides_posadasii_str_silveira'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/coccidioides_posadasii_str_silveira/cdna/Coccidioides_posadasii_str_silveira.CPS2.cdna.all.fa.gz',
	'colletotrichum_chlorophyti'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_chlorophyti/cdna/Colletotrichum_chlorophyti.ASM193710v1.cdna.all.fa.gz',
	'colletotrichum_fioriniae_pj7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/colletotrichum_fioriniae_pj7/cdna/Colletotrichum_fioriniae_pj7.CFIO01.cdna.all.fa.gz',
	'colletotrichum_gloeosporioides'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/colletotrichum_gloeosporioides/cdna/Colletotrichum_gloeosporioides.GCA_000319635.1.cdna.all.fa.gz',
	'colletotrichum_gloeosporioides_cg_14'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/colletotrichum_gloeosporioides_cg_14/cdna/Colletotrichum_gloeosporioides_cg_14.Colletotrichum_gloeosporioides1.cdna.all.fa.gz',
	'colletotrichum_graminicola'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/colletotrichum_graminicola/cdna/Colletotrichum_graminicola.C_graminicola_M1_001_V1.cdna.all.fa.gz',
	'colletotrichum_higginsianum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/colletotrichum_higginsianum/cdna/Colletotrichum_higginsianum.GCA_000313795.2.cdna.all.fa.gz',
	'colletotrichum_higginsianum_imi_349063'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_higginsianum_imi_349063/cdna/Colletotrichum_higginsianum_imi_349063.ASM167251v1.cdna.all.fa.gz',
	'colletotrichum_incanum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_incanum/cdna/Colletotrichum_incanum.Ci238704v1.cdna.all.fa.gz',
	'colletotrichum_incanum_gca_001855235'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_incanum_gca_001855235/cdna/Colletotrichum_incanum_gca_001855235.ASM185523v1.cdna.all.fa.gz',
	'colletotrichum_nymphaeae_sa_01'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_nymphaeae_sa_01/cdna/Colletotrichum_nymphaeae_sa_01.CNYM01.cdna.all.fa.gz',
	'colletotrichum_orbiculare'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/colletotrichum_orbiculare/cdna/Colletotrichum_orbiculare.GCA_000350065.1.cdna.all.fa.gz',
	'colletotrichum_orchidophilum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_orchidophilum/cdna/Colletotrichum_orchidophilum.CORC01.cdna.all.fa.gz',
	'colletotrichum_salicis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_salicis/cdna/Colletotrichum_salicis.CSAL01.cdna.all.fa.gz',
	'colletotrichum_simmondsii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_simmondsii/cdna/Colletotrichum_simmondsii.CSIM01.cdna.all.fa.gz',
	'colletotrichum_sublineola'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/colletotrichum_sublineola/cdna/Colletotrichum_sublineola.ASM69613v1.cdna.all.fa.gz',
	'colletotrichum_tofieldiae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/colletotrichum_tofieldiae/cdna/Colletotrichum_tofieldiae.Ct0861v1.cdna.all.fa.gz',
	'conidiobolus_coronatus_nrrl_28638'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_entomophthoromycota1_collection/conidiobolus_coronatus_nrrl_28638/cdna/Conidiobolus_coronatus_nrrl_28638.Conidiobolus_coronatus_NRRL28638.cdna.all.fa.gz',
	'coniochaeta_ligniaria_nrrl_30616'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/coniochaeta_ligniaria_nrrl_30616/cdna/Coniochaeta_ligniaria_nrrl_30616.Conlig_v1.0.cdna.all.fa.gz',
	'coniophora_puteana_rwd_64_598_ss2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/coniophora_puteana_rwd_64_598_ss2/cdna/Coniophora_puteana_rwd_64_598_ss2.Conpu1.cdna.all.fa.gz',
	'coniosporium_apollinis_cbs_100218'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/coniosporium_apollinis_cbs_100218/cdna/Coniosporium_apollinis_cbs_100218.Coni_apol_CBS100218_V1.cdna.all.fa.gz',
	'coprinopsis_cinerea_okayama7_130'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/coprinopsis_cinerea_okayama7_130/cdna/Coprinopsis_cinerea_okayama7_130.CC3.cdna.all.fa.gz',
	'corchorus_capsularis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/corchorus_capsularis/cdna/Corchorus_capsularis.CCACVL1_1.0.cdna.all.fa.gz',
	'cordyceps_brongniartii_rcef_3172'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cordyceps_brongniartii_rcef_3172/cdna/Cordyceps_brongniartii_rcef_3172.BBO_1.0.cdna.all.fa.gz',
	'cordyceps_confragosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cordyceps_confragosa/cdna/Cordyceps_confragosa.ASM165321v1.cdna.all.fa.gz',
	'cordyceps_confragosa_rcef_1005'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cordyceps_confragosa_rcef_1005/cdna/Cordyceps_confragosa_rcef_1005.LEL_1.0.cdna.all.fa.gz',
	'cordyceps_militaris_cm01'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/cordyceps_militaris_cm01/cdna/Cordyceps_militaris_cm01.CmilitarisCM01_v01.cdna.all.fa.gz',
	'crassostrea_gigas'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/crassostrea_gigas/cdna/Crassostrea_gigas.oyster_v9.cdna.all.fa.gz',
	'cricetulus_griseus_chok1gshd'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/cricetulus_griseus_chok1gshd/cdna/Cricetulus_griseus_chok1gshd.CHOK1GS_HDv1.cdna.abinitio.fa.gz',
	'cricetulus_griseus_crigri'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/cricetulus_griseus_crigri/cdna/Cricetulus_griseus_crigri.CriGri_1.0.cdna.abinitio.fa.gz',
	'cryptococcus_amylolentus_cbs_6039'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_amylolentus_cbs_6039/cdna/Cryptococcus_amylolentus_cbs_6039.Cryp_amyl_CBS6039_V3.cdna.all.fa.gz',
	'cryptococcus_amylolentus_cbs_6273'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_amylolentus_cbs_6273/cdna/Cryptococcus_amylolentus_cbs_6273.Cryp_amyl_CBS6273_V2.cdna.all.fa.gz',
	'cryptococcus_depauperatus_cbs_7841'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_depauperatus_cbs_7841/cdna/Cryptococcus_depauperatus_cbs_7841.Filo_depa_CBS7841_V1.cdna.all.fa.gz',
	'cryptococcus_depauperatus_cbs_7855'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_depauperatus_cbs_7855/cdna/Cryptococcus_depauperatus_cbs_7855.Filo_depa_CBS7855_V2.cdna.all.fa.gz',
	'cryptococcus_gattii_ca1280'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_ca1280/cdna/Cryptococcus_gattii_ca1280.Cryp_gatt_CA1280_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_ca1873'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_ca1873/cdna/Cryptococcus_gattii_ca1873.Cryp_gatt_CA1873_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_e566'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_e566/cdna/Cryptococcus_gattii_e566.Cryp_gatt_E566_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_ejb2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_ejb2/cdna/Cryptococcus_gattii_ejb2.Cryp_gatt_EJB2_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_nt_10'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_nt_10/cdna/Cryptococcus_gattii_nt_10.Cryp_gatt_NT-10_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_ru294'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_ru294/cdna/Cryptococcus_gattii_ru294.Cryp_gatt_Ru294_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_vgii_2001_935_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_2001_935_1/cdna/Cryptococcus_gattii_vgii_2001_935_1.Cryp_gatt_2001_935-1_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_vgii_99_473'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_99_473/cdna/Cryptococcus_gattii_vgii_99_473.Cryp_gatt_99_473_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_vgii_ca1014'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_ca1014/cdna/Cryptococcus_gattii_vgii_ca1014.Cryp_gatt_CA1014_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_vgii_cbs_10090'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_cbs_10090/cdna/Cryptococcus_gattii_vgii_cbs_10090.Cryp_gatt_CBS10090_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_vgii_la55'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_la55/cdna/Cryptococcus_gattii_vgii_la55.Cryp_gatt_LA55_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_vgii_mmrl2647'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_mmrl2647/cdna/Cryptococcus_gattii_vgii_mmrl2647.Cryp_gatt_MMRL2647_V2.cdna.all.fa.gz',
	'cryptococcus_gattii_vgii_r265'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_r265/cdna/Cryptococcus_gattii_vgii_r265.CNB2.cdna.all.fa.gz',
	'cryptococcus_gattii_vgii_ram5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgii_ram5/cdna/Cryptococcus_gattii_vgii_ram5.Cryp_gatt_Ram5_V1.cdna.all.fa.gz',
	'cryptococcus_gattii_vgiv_ind107'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_vgiv_ind107/cdna/Cryptococcus_gattii_vgiv_ind107.Cryp_gatt_IND107_V2.cdna.all.fa.gz',
	'cryptococcus_gattii_wm276'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_gattii_wm276/cdna/Cryptococcus_gattii_wm276.ASM18594v1.cdna.all.fa.gz',
	'cryptococcus_neoformans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/cryptococcus_neoformans/cdna/Cryptococcus_neoformans.GCA_000091045.1.cdna.all.fa.gz',
	'cryptococcus_neoformans_var_grubii_h99'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_neoformans_var_grubii_h99/cdna/Cryptococcus_neoformans_var_grubii_h99.CNA3.cdna.all.fa.gz',
	'cryptococcus_neoformans_var_neoformans_b_3501a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cryptococcus_neoformans_var_neoformans_b_3501a/cdna/Cryptococcus_neoformans_var_neoformans_b_3501a.ASM14938v1.cdna.all.fa.gz',
	'cryptomonas_paramecium'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_cryptophyta1_collection/cryptomonas_paramecium/cdna/Cryptomonas_paramecium.ASM19445v1.cdna.all.fa.gz',
	'cryptosporidium_muris_rn66'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/cryptosporidium_muris_rn66/cdna/Cryptosporidium_muris_rn66.JCVI-cmg-v1.0.cdna.all.fa.gz',
	'cryptosporidium_parvum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/cryptosporidium_parvum/cdna/Cryptosporidium_parvum.ASM20969v1.cdna.all.fa.gz',
	'cryptosporidium_parvum_iowa_ii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/cryptosporidium_parvum_iowa_ii/cdna/Cryptosporidium_parvum_iowa_ii.ASM16534v1.cdna.all.fa.gz',
	'culex_quinquefasciatus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/culex_quinquefasciatus/cdna/Culex_quinquefasciatus.CpipJ2.cdna.abinitio.fa.gz',
	'cutaneotrichosporon_oleaginosus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cutaneotrichosporon_oleaginosus/cdna/Cutaneotrichosporon_oleaginosus.Triol1.cdna.all.fa.gz',
	'cyberlindnera_fabianii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cyberlindnera_fabianii/cdna/Cyberlindnera_fabianii.ASM198330v1.cdna.all.fa.gz',
	'cyberlindnera_jadinii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cyberlindnera_jadinii/cdna/Cyberlindnera_jadinii.cj1.cdna.all.fa.gz',
	'cyberlindnera_jadinii_nrrl_y_1542'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/cyberlindnera_jadinii_nrrl_y_1542/cdna/Cyberlindnera_jadinii_nrrl_y_1542.Cybja1.cdna.all.fa.gz',
	'cyclospora_cayetanensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/cyclospora_cayetanensis/cdna/Cyclospora_cayetanensis.ASM76915v2.cdna.all.fa.gz',
	'cylindrobasidium_torrendii_fp15055_ss_10'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/cylindrobasidium_torrendii_fp15055_ss_10/cdna/Cylindrobasidium_torrendii_fp15055_ss_10.Cylto1.cdna.all.fa.gz',
	'cyphellophora_europaea_cbs_101466'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/cyphellophora_europaea_cbs_101466/cdna/Cyphellophora_europaea_cbs_101466.Phia_euro_CBS_101466_V1.cdna.all.fa.gz',
	'dacryopinax_primogenitus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/dacryopinax_primogenitus/cdna/Dacryopinax_primogenitus.Dacryopinax_sp._DJM_731_SSP1_v1.0.cdna.all.fa.gz',
	'dactylellina_haptotyla_cbs_200_50'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/dactylellina_haptotyla_cbs_200_50/cdna/Dactylellina_haptotyla_cbs_200_50.MHA_v2.cdna.all.fa.gz',
	'daedalea_quercina_l_15889'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/daedalea_quercina_l_15889/cdna/Daedalea_quercina_l_15889.Daequ1.cdna.all.fa.gz',
	'danaus_plexippus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/danaus_plexippus/cdna/Danaus_plexippus.DanPle_1.0.cdna.all.fa.gz',
	'danio_rerio'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/danio_rerio/cdna/Danio_rerio.GRCz10.cdna.abinitio.fa.gz',
	'daphnia_pulex'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/daphnia_pulex/cdna/Daphnia_pulex.V1.0.cdna.all.fa.gz',
	'dasypus_novemcinctus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/dasypus_novemcinctus/cdna/Dasypus_novemcinctus.Dasnov3.0.cdna.abinitio.fa.gz',
	'debaryomyces_fabryi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/debaryomyces_fabryi/cdna/Debaryomyces_fabryi.debFab1.0.cdna.all.fa.gz',
	'debaryomyces_hansenii_cbs767'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/debaryomyces_hansenii_cbs767/cdna/Debaryomyces_hansenii_cbs767.ASM644v2.cdna.all.fa.gz',
	'dendroctonus_ponderosae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/dendroctonus_ponderosae/cdna/Dendroctonus_ponderosae.DendPond_male_1.0.cdna.all.fa.gz',
	'diaporthe_ampelina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/diaporthe_ampelina/cdna/Diaporthe_ampelina.UCDDA912v1.0.cdna.all.fa.gz',
	'diaporthe_helianthi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/diaporthe_helianthi/cdna/Diaporthe_helianthi.ASM170239v1.cdna.all.fa.gz',
	'dichomitus_squalens_lyad_421_ss1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/dichomitus_squalens_lyad_421_ss1/cdna/Dichomitus_squalens_lyad_421_ss1.Dichomitus_squalens_v1.0.cdna.all.fa.gz',
	'dictyostelium_discoideum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/dictyostelium_discoideum/cdna/Dictyostelium_discoideum.dicty_2.7.cdna.all.fa.gz',
	'dictyostelium_fasciculatum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/dictyostelium_fasciculatum/cdna/Dictyostelium_fasciculatum.DFas_2.0.cdna.all.fa.gz',
	'dictyostelium_lacteum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/dictyostelium_lacteum/cdna/Dictyostelium_lacteum.ASM160615v1.cdna.all.fa.gz',
	'diplodia_corticola'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/diplodia_corticola/cdna/Diplodia_corticola.ASM188384v1.cdna.all.fa.gz',
	'diplodia_seriata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/diplodia_seriata/cdna/Diplodia_seriata.UCDDS831v0.1.cdna.all.fa.gz',
	'diplodia_seriata_gca_001975905'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/diplodia_seriata_gca_001975905/cdna/Diplodia_seriata_gca_001975905.Dipser_v1.cdna.all.fa.gz',
	'dipodomys_ordii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/dipodomys_ordii/cdna/Dipodomys_ordii.Dord_2.0.cdna.abinitio.fa.gz',
	'dothistroma_septosporum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/dothistroma_septosporum/cdna/Dothistroma_septosporum.GCA_000340195.1.cdna.all.fa.gz',
	'drechmeria_coniospora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/drechmeria_coniospora/cdna/Drechmeria_coniospora.ASM162519v1.cdna.all.fa.gz',
	'drechslerella_stenobrocha_248'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/drechslerella_stenobrocha_248/cdna/Drechslerella_stenobrocha_248.DREv1.cdna.all.fa.gz',
	'drosophila_ananassae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_ananassae/cdna/Drosophila_ananassae.dana_caf1.cdna.abinitio.fa.gz',
	'drosophila_erecta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_erecta/cdna/Drosophila_erecta.dere_caf1.cdna.abinitio.fa.gz',
	'drosophila_grimshawi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_grimshawi/cdna/Drosophila_grimshawi.dgri_caf1.cdna.abinitio.fa.gz',
	'drosophila_melanogaster'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_melanogaster/cdna/Drosophila_melanogaster.BDGP6.cdna.abinitio.fa.gz',
	'drosophila_mojavensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_mojavensis/cdna/Drosophila_mojavensis.dmoj_caf1.cdna.abinitio.fa.gz',
	'drosophila_persimilis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_persimilis/cdna/Drosophila_persimilis.dper_caf1.cdna.abinitio.fa.gz',
	'drosophila_pseudoobscura'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_pseudoobscura/cdna/Drosophila_pseudoobscura.Dpse_3.0.cdna.abinitio.fa.gz',
	'drosophila_sechellia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_sechellia/cdna/Drosophila_sechellia.dsec_caf1.cdna.abinitio.fa.gz',
	'drosophila_simulans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_simulans/cdna/Drosophila_simulans.dsim_caf1.cdna.abinitio.fa.gz',
	'drosophila_virilis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_virilis/cdna/Drosophila_virilis.dvir_caf1.cdna.abinitio.fa.gz',
	'drosophila_willistoni'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_willistoni/cdna/Drosophila_willistoni.dwil_caf1.cdna.abinitio.fa.gz',
	'drosophila_yakuba'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/drosophila_yakuba/cdna/Drosophila_yakuba.dyak_caf1.cdna.abinitio.fa.gz',
	'echinops_telfairi'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/echinops_telfairi/cdna/Echinops_telfairi.TENREC.cdna.abinitio.fa.gz',
	'edhazardia_aedis_usnm_41457'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/edhazardia_aedis_usnm_41457/cdna/Edhazardia_aedis_usnm_41457.Edha_aedis_V4b.cdna.all.fa.gz',
	'eimeria_brunetti'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_brunetti/cdna/Eimeria_brunetti.EBH001.cdna.all.fa.gz',
	'eimeria_maxima'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_maxima/cdna/Eimeria_maxima.EMW001.cdna.all.fa.gz',
	'eimeria_mitis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_mitis/cdna/Eimeria_mitis.EMH001.cdna.all.fa.gz',
	'eimeria_praecox'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_praecox/cdna/Eimeria_praecox.EPH001.cdna.all.fa.gz',
	'eimeria_tenella'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_tenella/cdna/Eimeria_tenella.ASM283v1.cdna.all.fa.gz',
	'eimeria_tenella_gca_000499545'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/eimeria_tenella_gca_000499545/cdna/Eimeria_tenella_gca_000499545.ETH001.cdna.all.fa.gz',
	'emergomyces_pasteuriana_ep9510'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/emergomyces_pasteuriana_ep9510/cdna/Emergomyces_pasteuriana_ep9510.Emmo_past_UAMH9510_V1.cdna.all.fa.gz',
	'emiliania_huxleyi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/emiliania_huxleyi/cdna/Emiliania_huxleyi.Emiliana_huxleyi_CCMP1516_main_genome_assembly_v1.0.cdna.all.fa.gz',
	'emmonsia_crescens_uamh_3008'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/emmonsia_crescens_uamh_3008/cdna/Emmonsia_crescens_uamh_3008.ASM100828v1.cdna.all.fa.gz',
	'emmonsia_parva_uamh_139'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/emmonsia_parva_uamh_139/cdna/Emmonsia_parva_uamh_139.ASM101475v1.cdna.all.fa.gz',
	'emmonsia_sp_cac_2015a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/emmonsia_sp_cac_2015a/cdna/Emmonsia_sp_cac_2015a.Emmo_afri_EA111.cdna.all.fa.gz',
	'encephalitozoon_cuniculi_ecuniii_l'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/encephalitozoon_cuniculi_ecuniii_l/cdna/Encephalitozoon_cuniculi_ecuniii_l.ECIIIL.cdna.all.fa.gz',
	'encephalitozoon_cuniculi_gb_m1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/encephalitozoon_cuniculi_gb_m1/cdna/Encephalitozoon_cuniculi_gb_m1.ASM9122v1.cdna.all.fa.gz',
	'encephalitozoon_hellem_atcc_50504'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/encephalitozoon_hellem_atcc_50504/cdna/Encephalitozoon_hellem_atcc_50504.ASM27781v3.cdna.all.fa.gz',
	'encephalitozoon_intestinalis_atcc_50506'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/encephalitozoon_intestinalis_atcc_50506/cdna/Encephalitozoon_intestinalis_atcc_50506.ASM14646v1.cdna.all.fa.gz',
	'encephalitozoon_romaleae_sj_2008'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/encephalitozoon_romaleae_sj_2008/cdna/Encephalitozoon_romaleae_sj_2008.ASM28003v2.cdna.all.fa.gz',
	'endocarpon_pusillum_z07020'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/endocarpon_pusillum_z07020/cdna/Endocarpon_pusillum_z07020.EPUS.cdna.all.fa.gz',
	'entamoeba_histolytica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/entamoeba_histolytica/cdna/Entamoeba_histolytica.JCVI-ESG2-1.0.cdna.all.fa.gz',
	'entamoeba_histolytica_gca_001662325'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/entamoeba_histolytica_gca_001662325/cdna/Entamoeba_histolytica_gca_001662325.Ehistolytica_2016.cdna.all.fa.gz',
	'entamoeba_histolytica_hm_3_imss'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/entamoeba_histolytica_hm_3_imss/cdna/Entamoeba_histolytica_hm_3_imss.EHA.strHM3_v1.cdna.all.fa.gz',
	'entamoeba_histolytica_ku27'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/entamoeba_histolytica_ku27/cdna/Entamoeba_histolytica_ku27.EHA_ku27_v1.cdna.all.fa.gz',
	'entamoeba_nuttalli_p19'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/entamoeba_nuttalli_p19/cdna/Entamoeba_nuttalli_p19.ENU1_v1.cdna.all.fa.gz',
	'enterocytozoon_bieneusi_h348'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/enterocytozoon_bieneusi_h348/cdna/Enterocytozoon_bieneusi_h348.ASM20948v1.cdna.all.fa.gz',
	'enterocytozoon_hepatopenaei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/enterocytozoon_hepatopenaei/cdna/Enterocytozoon_hepatopenaei.ASM208167v1.cdna.all.fa.gz',
	'enterospora_canceri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/enterospora_canceri/cdna/Enterospora_canceri.ASM208791v1.cdna.all.fa.gz',
	'equus_caballus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/equus_caballus/cdna/Equus_caballus.EquCab2.cdna.abinitio.fa.gz',
	'eremothecium_cymbalariae_dbvpg_7215'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/eremothecium_cymbalariae_dbvpg_7215/cdna/Eremothecium_cymbalariae_dbvpg_7215.ASM23536v1.cdna.all.fa.gz',
	'eremothecium_gossypii_fdag1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/eremothecium_gossypii_fdag1/cdna/Eremothecium_gossypii_fdag1.ASM96883v1.cdna.all.fa.gz',
	'eremothecium_sinecaudum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/eremothecium_sinecaudum/cdna/Eremothecium_sinecaudum.ASM154855v1.cdna.all.fa.gz',
	'erinaceus_europaeus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/erinaceus_europaeus/cdna/Erinaceus_europaeus.HEDGEHOG.cdna.abinitio.fa.gz',
	'erysiphe_necator'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/erysiphe_necator/cdna/Erysiphe_necator.ASM79871v1.cdna.all.fa.gz',
	'escovopsis_weberi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/escovopsis_weberi/cdna/Escovopsis_weberi.ASM127849v1.cdna.all.fa.gz',
	'eutypa_lata_ucrel1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/eutypa_lata_ucrel1/cdna/Eutypa_lata_ucrel1.UCREL1V03.cdna.all.fa.gz',
	'exidia_glandulosa_hhb12029'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/exidia_glandulosa_hhb12029/cdna/Exidia_glandulosa_hhb12029.Exigl1.cdna.all.fa.gz',
	'exophiala_aquamarina_cbs_119918'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/exophiala_aquamarina_cbs_119918/cdna/Exophiala_aquamarina_cbs_119918.Exop_aqua_CBS_119918_V1.cdna.all.fa.gz',
	'exophiala_dermatitidis_nih_ut8656'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/exophiala_dermatitidis_nih_ut8656/cdna/Exophiala_dermatitidis_nih_ut8656.Exop_derm_V1.cdna.all.fa.gz',
	'exophiala_mesophila'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/exophiala_mesophila/cdna/Exophiala_mesophila.Exop_meso_CBS40295_V1.cdna.all.fa.gz',
	'exophiala_oligosperma'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/exophiala_oligosperma/cdna/Exophiala_oligosperma.Exop_olig_CBS72588_V1.cdna.all.fa.gz',
	'exophiala_sideris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/exophiala_sideris/cdna/Exophiala_sideris.Exop_side_CBS121828_V1.cdna.all.fa.gz',
	'exophiala_spinifera'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/exophiala_spinifera/cdna/Exophiala_spinifera.Exop_spin_CBS89968_V1.cdna.all.fa.gz',
	'exophiala_xenobiotica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/exophiala_xenobiotica/cdna/Exophiala_xenobiotica.Exop_xeno_CBS118157_V1.cdna.all.fa.gz',
	'felis_catus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/felis_catus/cdna/Felis_catus.Felis_catus_6.2.cdna.abinitio.fa.gz',
	'fibroporia_radiculosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/fibroporia_radiculosa/cdna/Fibroporia_radiculosa.ASM31352v1.cdna.all.fa.gz',
	'fibulorhizoctonia_sp_cbs_109695'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/fibulorhizoctonia_sp_cbs_109695/cdna/Fibulorhizoctonia_sp_cbs_109695.Fibsp1.cdna.all.fa.gz',
	'ficedula_albicollis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ficedula_albicollis/cdna/Ficedula_albicollis.FicAlb_1.4.cdna.abinitio.fa.gz',
	'fistulina_hepatica_atcc_64428'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/fistulina_hepatica_atcc_64428/cdna/Fistulina_hepatica_atcc_64428.Fishe1.cdna.all.fa.gz',
	'fomitiporia_mediterranea_mf3_22'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/fomitiporia_mediterranea_mf3_22/cdna/Fomitiporia_mediterranea_mf3_22.Fomme1.cdna.all.fa.gz',
	'fomitopsis_pinicola_fp_58527_ss1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/fomitopsis_pinicola_fp_58527_ss1/cdna/Fomitopsis_pinicola_fp_58527_ss1.Fompi3.cdna.all.fa.gz',
	'fonsecaea_erecta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fonsecaea_erecta/cdna/Fonsecaea_erecta.ASM165198v1.cdna.all.fa.gz',
	'fonsecaea_monophora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fonsecaea_monophora/cdna/Fonsecaea_monophora.ASM164247v1.cdna.all.fa.gz',
	'fonsecaea_multimorphosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fonsecaea_multimorphosa/cdna/Fonsecaea_multimorphosa.ASM164698v1.cdna.all.fa.gz',
	'fonsecaea_multimorphosa_cbs_102226'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/fonsecaea_multimorphosa_cbs_102226/cdna/Fonsecaea_multimorphosa_cbs_102226.Fons_mult_CBS_102226_V1.cdna.all.fa.gz',
	'fonsecaea_nubica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fonsecaea_nubica/cdna/Fonsecaea_nubica.ASM164696v1.cdna.all.fa.gz',
	'fonsecaea_pedrosoi_cbs_271_37'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/fonsecaea_pedrosoi_cbs_271_37/cdna/Fonsecaea_pedrosoi_cbs_271_37.Fons_pedr_CBS_271_37_V1.cdna.all.fa.gz',
	'fonticula_alba_gca_000388065'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_nucleariidaeandfonticulagroup1_collection/fonticula_alba_gca_000388065/cdna/Fonticula_alba_gca_000388065.Font_alba_ATCC_38817_V2.cdna.all.fa.gz',
	'fukomys_damarensis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/fukomys_damarensis/cdna/Fukomys_damarensis.DMR_v1.0.cdna.abinitio.fa.gz',
	'fusarium_culmorum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_culmorum/cdna/Fusarium_culmorum.EF1.cdna.all.fa.gz',
	'fusarium_fujikuroi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_fujikuroi/cdna/Fusarium_fujikuroi.EF1.cdna.all.fa.gz',
	'fusarium_fujikuroi_gca_001023035'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/fusarium_fujikuroi_gca_001023035/cdna/Fusarium_fujikuroi_gca_001023035.ASM102303v1.cdna.all.fa.gz',
	'fusarium_fujikuroi_gca_001023045'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_fujikuroi_gca_001023045/cdna/Fusarium_fujikuroi_gca_001023045.ASM102304v1.cdna.all.fa.gz',
	'fusarium_fujikuroi_gca_001023065'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/fusarium_fujikuroi_gca_001023065/cdna/Fusarium_fujikuroi_gca_001023065.ASM102306v1.cdna.all.fa.gz',
	'fusarium_graminearum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_graminearum/cdna/Fusarium_graminearum.RR1.cdna.all.fa.gz',
	'fusarium_graminearum_gca_000599445'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_graminearum_gca_000599445/cdna/Fusarium_graminearum_gca_000599445.CS3005v1.cdna.all.fa.gz',
	'fusarium_langsethiae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_langsethiae/cdna/Fusarium_langsethiae.ASM129263v1.cdna.all.fa.gz',
	'fusarium_mangiferae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_mangiferae/cdna/Fusarium_mangiferae.Genome_assembly_version_1.cdna.all.fa.gz',
	'fusarium_oxysporum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_oxysporum/cdna/Fusarium_oxysporum.FO2.cdna.all.fa.gz',
	'fusarium_oxysporum_f_sp_conglutinans_race_2_54008'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_conglutinans_race_2_54008/cdna/Fusarium_oxysporum_f_sp_conglutinans_race_2_54008.FO_PHW808_V1.cdna.all.fa.gz',
	'fusarium_oxysporum_f_sp_cubense_race_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_cubense_race_1/cdna/Fusarium_oxysporum_f_sp_cubense_race_1.Foc1_1.0.cdna.all.fa.gz',
	'fusarium_oxysporum_f_sp_cubense_race_4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_cubense_race_4/cdna/Fusarium_oxysporum_f_sp_cubense_race_4.Foc4_1.0.cdna.all.fa.gz',
	'fusarium_oxysporum_f_sp_cubense_tropical_race_4_54006'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_cubense_tropical_race_4_54006/cdna/Fusarium_oxysporum_f_sp_cubense_tropical_race_4_54006.FO_II5_V1.cdna.all.fa.gz',
	'fusarium_oxysporum_f_sp_lycopersici_mn25'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_lycopersici_mn25/cdna/Fusarium_oxysporum_f_sp_lycopersici_mn25.FO_MN25_V1.cdna.all.fa.gz',
	'fusarium_oxysporum_f_sp_melonis_26406'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_melonis_26406/cdna/Fusarium_oxysporum_f_sp_melonis_26406.FO_melonis_V1.cdna.all.fa.gz',
	'fusarium_oxysporum_f_sp_pisi_hdv247'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_pisi_hdv247/cdna/Fusarium_oxysporum_f_sp_pisi_hdv247.FO_HDV247_V1.cdna.all.fa.gz',
	'fusarium_oxysporum_f_sp_radicis_lycopersici_26381'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_radicis_lycopersici_26381/cdna/Fusarium_oxysporum_f_sp_radicis_lycopersici_26381.FO_CL57_V1.cdna.all.fa.gz',
	'fusarium_oxysporum_f_sp_raphani_54005'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_raphani_54005/cdna/Fusarium_oxysporum_f_sp_raphani_54005.FO_PHW815_V1.cdna.all.fa.gz',
	'fusarium_oxysporum_f_sp_vasinfectum_25433'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_f_sp_vasinfectum_25433/cdna/Fusarium_oxysporum_f_sp_vasinfectum_25433.FO_Cotton_V1.cdna.all.fa.gz',
	'fusarium_oxysporum_fo47'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_fo47/cdna/Fusarium_oxysporum_fo47.FO_Fo47_V1.cdna.all.fa.gz',
	'fusarium_oxysporum_fosc_3_a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/fusarium_oxysporum_fosc_3_a/cdna/Fusarium_oxysporum_fosc_3_a.FO_FOSC_3_a_V1.cdna.all.fa.gz',
	'fusarium_poae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_poae/cdna/Fusarium_poae.FPOA1.0.cdna.all.fa.gz',
	'fusarium_proliferatum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_proliferatum/cdna/Fusarium_proliferatum.F._proliferatum_NRRL62905_version_1.cdna.all.fa.gz',
	'fusarium_proliferatum_et1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/fusarium_proliferatum_et1/cdna/Fusarium_proliferatum_et1.F._proliferatum_ET1_version_1.cdna.all.fa.gz',
	'fusarium_pseudograminearum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_pseudograminearum/cdna/Fusarium_pseudograminearum.GCA_000303195.1.cdna.all.fa.gz',
	'fusarium_solani'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_solani/cdna/Fusarium_solani.v2.0.cdna.all.fa.gz',
	'fusarium_verticillioides'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fusarium_verticillioides/cdna/Fusarium_verticillioides.ASM14955v1.cdna.all.fa.gz',
	'gadus_morhua'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/gadus_morhua/cdna/Gadus_morhua.gadMor1.cdna.abinitio.fa.gz',
	'gaeumannomyces_graminis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/gaeumannomyces_graminis/cdna/Gaeumannomyces_graminis.Gae_graminis_V2.cdna.all.fa.gz',
	'galdieria_sulphuraria'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/galdieria_sulphuraria/cdna/Galdieria_sulphuraria.ASM34128v1.cdna.all.fa.gz',
	'galerina_marginata_cbs_339_88'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/galerina_marginata_cbs_339_88/cdna/Galerina_marginata_cbs_339_88.Galma1.cdna.all.fa.gz',
	'gallus_gallus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/gallus_gallus/cdna/Gallus_gallus.Gallus_gallus-5.0.cdna.abinitio.fa.gz',
	'gasterosteus_aculeatus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/gasterosteus_aculeatus/cdna/Gasterosteus_aculeatus.BROADS1.cdna.abinitio.fa.gz',
	'gelatoporia_subvermispora_b'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/gelatoporia_subvermispora_b/cdna/Gelatoporia_subvermispora_b.Ceriporiopsis_subvermispora_B_v1.0.cdna.all.fa.gz',
	'geotrichum_candidum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/geotrichum_candidum/cdna/Geotrichum_candidum.New2.3_08062011.cdna.all.fa.gz',
	'giardia_intestinalis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/giardia_intestinalis/cdna/Giardia_intestinalis.ASM49873v1.cdna.all.fa.gz',
	'giardia_intestinalis_assemblage_b'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/giardia_intestinalis_assemblage_b/cdna/Giardia_intestinalis_assemblage_b.G_duodenalis_AssB_BAH15c1.cdna.all.fa.gz',
	'giardia_intestinalis_atcc_50581'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/giardia_intestinalis_atcc_50581/cdna/Giardia_intestinalis_atcc_50581.ASM18240v1.cdna.all.fa.gz',
	'giardia_intestinalis_gca_000498715'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/giardia_intestinalis_gca_000498715/cdna/Giardia_intestinalis_gca_000498715.ASM49871v1.cdna.all.fa.gz',
	'giardia_lamblia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/giardia_lamblia/cdna/Giardia_lamblia.GL2.cdna.all.fa.gz',
	'giardia_lamblia_p15'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/giardia_lamblia_p15/cdna/Giardia_lamblia_p15.ASM18266v1.cdna.all.fa.gz',
	'glarea_lozoyensis_74030'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/glarea_lozoyensis_74030/cdna/Glarea_lozoyensis_74030.LBAGla_1.0.cdna.all.fa.gz',
	'glarea_lozoyensis_atcc_20868'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/glarea_lozoyensis_atcc_20868/cdna/Glarea_lozoyensis_atcc_20868.GLAREA.cdna.all.fa.gz',
	'gloeophyllum_trabeum_atcc_11539'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/gloeophyllum_trabeum_atcc_11539/cdna/Gloeophyllum_trabeum_atcc_11539.Glotr1_1.cdna.all.fa.gz',
	'glycine_max'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/glycine_max/cdna/Glycine_max.V1.0.cdna.abinitio.fa.gz',
	'gonapodya_prolifera_jel478'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_chytridiomycota1_collection/gonapodya_prolifera_jel478/cdna/Gonapodya_prolifera_jel478.Ganpr1.cdna.all.fa.gz',
	'gorilla_gorilla'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/gorilla_gorilla/cdna/Gorilla_gorilla.gorGor3.1.cdna.abinitio.fa.gz',
	'gregarina_niphandrodes'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/gregarina_niphandrodes/cdna/Gregarina_niphandrodes.GNI3.cdna.all.fa.gz',
	'grifola_frondosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/grifola_frondosa/cdna/Grifola_frondosa.ASM168373v1.cdna.all.fa.gz',
	'grosmannia_clavigera_kw1407'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/grosmannia_clavigera_kw1407/cdna/Grosmannia_clavigera_kw1407.Sanger-454-IlluminaPA_2.0.cdna.all.fa.gz',
	'guillardia_theta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/guillardia_theta/cdna/Guillardia_theta.Guith1.cdna.all.fa.gz',
	'guillardia_theta_gca_000002975'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_cryptophyta1_collection/guillardia_theta_gca_000002975/cdna/Guillardia_theta_gca_000002975.ASM297v1.cdna.all.fa.gz',
	'gymnopus_luxurians_fd_317_m1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/gymnopus_luxurians_fd_317_m1/cdna/Gymnopus_luxurians_fd_317_m1.Gymlu1.cdna.all.fa.gz',
	'hammondia_hammondi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/hammondia_hammondi/cdna/Hammondia_hammondi.HHA1_v02.cdna.all.fa.gz',
	'hanseniaspora_guilliermondii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hanseniaspora_guilliermondii/cdna/Hanseniaspora_guilliermondii.version_1.cdna.all.fa.gz',
	'hanseniaspora_opuntiae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hanseniaspora_opuntiae/cdna/Hanseniaspora_opuntiae.ASM174979v1.cdna.all.fa.gz',
	'hanseniaspora_osmophila'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hanseniaspora_osmophila/cdna/Hanseniaspora_osmophila.ASM174704v1.cdna.all.fa.gz',
	'hanseniaspora_uvarum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hanseniaspora_uvarum/cdna/Hanseniaspora_uvarum.ASM174705v1.cdna.all.fa.gz',
	'hanseniaspora_uvarum_dsm_2768'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/hanseniaspora_uvarum_dsm_2768/cdna/Hanseniaspora_uvarum_dsm_2768.Huva2.0.cdna.all.fa.gz',
	'hanseniaspora_valbyensis_nrrl_y_1626'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hanseniaspora_valbyensis_nrrl_y_1626/cdna/Hanseniaspora_valbyensis_nrrl_y_1626.Hanva1_1.cdna.all.fa.gz',
	'hebeloma_cylindrosporum_h7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/hebeloma_cylindrosporum_h7/cdna/Hebeloma_cylindrosporum_h7.Hebeloma_cylindrosporum_h7_v2.0.cdna.all.fa.gz',
	'heliconius_melpomene'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/heliconius_melpomene/cdna/Heliconius_melpomene.Hmel1.cdna.all.fa.gz',
	'helobdella_robusta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/helobdella_robusta/cdna/Helobdella_robusta.Helro1.cdna.all.fa.gz',
	'hepatospora_eriocheir'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/hepatospora_eriocheir/cdna/Hepatospora_eriocheir.ASM208787v1.cdna.all.fa.gz',
	'hepatospora_eriocheir_gca_002087885'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/hepatospora_eriocheir_gca_002087885/cdna/Hepatospora_eriocheir_gca_002087885.ASM208788v1.cdna.all.fa.gz',
	'heterobasidion_irregulare_tc_32_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/heterobasidion_irregulare_tc_32_1/cdna/Heterobasidion_irregulare_tc_32_1.Heterobasidion_irregulare_v2.0.cdna.all.fa.gz',
	'heterocephalus_glaber_female'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/heterocephalus_glaber_female/cdna/Heterocephalus_glaber_female.HetGla_female_1.0.cdna.abinitio.fa.gz',
	'heterocephalus_glaber_male'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/heterocephalus_glaber_male/cdna/Heterocephalus_glaber_male.HetGla_1.0.cdna.abinitio.fa.gz',
	'hirsutella_minnesotensis_3608'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/hirsutella_minnesotensis_3608/cdna/Hirsutella_minnesotensis_3608.ASM95604v1.cdna.all.fa.gz',
	'histoplasma_capsulatum_g186ar'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/histoplasma_capsulatum_g186ar/cdna/Histoplasma_capsulatum_g186ar.ASM15011v1.cdna.all.fa.gz',
	'histoplasma_capsulatum_h143'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/histoplasma_capsulatum_h143/cdna/Histoplasma_capsulatum_h143.ASM15103v1.cdna.all.fa.gz',
	'histoplasma_capsulatum_h88'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/histoplasma_capsulatum_h88/cdna/Histoplasma_capsulatum_h88.ASM15100v2.cdna.all.fa.gz',
	'histoplasma_capsulatum_nam1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/histoplasma_capsulatum_nam1/cdna/Histoplasma_capsulatum_nam1.ASM14958v1.cdna.all.fa.gz',
	'homo_sapiens'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/homo_sapiens/cdna/Homo_sapiens.GRCh38.cdna.abinitio.fa.gz',
	'hordeum_vulgare'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/hordeum_vulgare/cdna/Hordeum_vulgare.Hv_IBSC_PGSB_v2.cdna.all.fa.gz',
	'hyaloperonospora_arabidopsidis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/hyaloperonospora_arabidopsidis/cdna/Hyaloperonospora_arabidopsidis.HyaAraEmoy2_2.0.cdna.all.fa.gz',
	'hydnomerulius_pinastri_md_312'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/hydnomerulius_pinastri_md_312/cdna/Hydnomerulius_pinastri_md_312.Hydpi2.cdna.all.fa.gz',
	'hypholoma_sublateritium_fd_334_ss_4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/hypholoma_sublateritium_fd_334_ss_4/cdna/Hypholoma_sublateritium_fd_334_ss_4.Hypsu1.cdna.all.fa.gz',
	'hyphopichia_burtonii_nrrl_y_1933'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/hyphopichia_burtonii_nrrl_y_1933/cdna/Hyphopichia_burtonii_nrrl_y_1933.Hypbu1.cdna.all.fa.gz',
	'hypsizygus_marmoreus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/hypsizygus_marmoreus/cdna/Hypsizygus_marmoreus.ASM160531v1.cdna.all.fa.gz',
	'ichthyophthirius_multifiliis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/ichthyophthirius_multifiliis/cdna/Ichthyophthirius_multifiliis.JCVI-IMG1-V.1.cdna.all.fa.gz',
	'ictidomys_tridecemlineatus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ictidomys_tridecemlineatus/cdna/Ictidomys_tridecemlineatus.SpeTri2.0.cdna.abinitio.fa.gz',
	'isaria_fumosorosea_arsef_2679'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/isaria_fumosorosea_arsef_2679/cdna/Isaria_fumosorosea_arsef_2679.ISF_1.0.cdna.all.fa.gz',
	'ixodes_scapularis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/ixodes_scapularis/cdna/Ixodes_scapularis.IscaW1.cdna.abinitio.fa.gz',
	'jaapia_argillacea_mucl_33604'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/jaapia_argillacea_mucl_33604/cdna/Jaapia_argillacea_mucl_33604.Jaaar1.cdna.all.fa.gz',
	'jaculus_jaculus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/jaculus_jaculus/cdna/Jaculus_jaculus.JacJac1.0.cdna.abinitio.fa.gz',
	'kalmanozyma_brasiliensis_ghg001'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kalmanozyma_brasiliensis_ghg001/cdna/Kalmanozyma_brasiliensis_ghg001.PSEUBRA1.cdna.all.fa.gz',
	'kazachstania_africana_cbs_2517'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/kazachstania_africana_cbs_2517/cdna/Kazachstania_africana_cbs_2517.Ka_CBS2517.cdna.all.fa.gz',
	'kazachstania_naganishii_cbs_8797'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/kazachstania_naganishii_cbs_8797/cdna/Kazachstania_naganishii_cbs_8797.ASM34898v1.cdna.all.fa.gz',
	'kluyveromyces_lactis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/kluyveromyces_lactis/cdna/Kluyveromyces_lactis.ASM251v1.cdna.all.fa.gz',
	'kluyveromyces_marxianus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/kluyveromyces_marxianus/cdna/Kluyveromyces_marxianus.KM1777_03.cdna.all.fa.gz',
	'kluyveromyces_marxianus_dmku3_1042'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/kluyveromyces_marxianus_dmku3_1042/cdna/Kluyveromyces_marxianus_dmku3_1042.Kmar_1.0.cdna.all.fa.gz',
	'komagataella_pastoris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/komagataella_pastoris/cdna/Komagataella_pastoris.GCA_000027005.1.cdna.all.fa.gz',
	'komagataella_pastoris_gca_001708105'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/komagataella_pastoris_gca_001708105/cdna/Komagataella_pastoris_gca_001708105.ASM170810v1.cdna.all.fa.gz',
	'komagataella_phaffii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/komagataella_phaffii/cdna/Komagataella_phaffii.ASM170808v1.cdna.all.fa.gz',
	'komagataella_phaffii_cbs_7435'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/komagataella_phaffii_cbs_7435/cdna/Komagataella_phaffii_cbs_7435.PicPas_Mar2011.cdna.all.fa.gz',
	'komagataella_phaffii_gs115'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/komagataella_phaffii_gs115/cdna/Komagataella_phaffii_gs115.ASM174695v1.cdna.all.fa.gz',
	'kuraishia_capsulata_cbs_1993'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/kuraishia_capsulata_cbs_1993/cdna/Kuraishia_capsulata_cbs_1993.AUH_PRJEB4427_v1.cdna.all.fa.gz',
	'kwoniella_bestiolae_cbs_10118'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_bestiolae_cbs_10118/cdna/Kwoniella_bestiolae_cbs_10118.Cryp_best_CBS10118_V1.cdna.all.fa.gz',
	'kwoniella_dejecticola_cbs_10117'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_dejecticola_cbs_10117/cdna/Kwoniella_dejecticola_cbs_10117.Cryp_deje_CBS10117_V1.cdna.all.fa.gz',
	'kwoniella_heveanensis_bcc8398'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_heveanensis_bcc8398/cdna/Kwoniella_heveanensis_bcc8398.Cryp_heve_BCC8398_V1.cdna.all.fa.gz',
	'kwoniella_heveanensis_cbs_569'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_heveanensis_cbs_569/cdna/Kwoniella_heveanensis_cbs_569.Cryp_heve_CBS569_V2.cdna.all.fa.gz',
	'kwoniella_mangroviensis_cbs_10435'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_mangroviensis_cbs_10435/cdna/Kwoniella_mangroviensis_cbs_10435.Kwon_mang_CBS10435_V2.cdna.all.fa.gz',
	'kwoniella_mangroviensis_cbs_8507'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_mangroviensis_cbs_8507/cdna/Kwoniella_mangroviensis_cbs_8507.Kwon_mang_CBS8507_V2.cdna.all.fa.gz',
	'kwoniella_mangroviensis_cbs_8886'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_mangroviensis_cbs_8886/cdna/Kwoniella_mangroviensis_cbs_8886.Kwon_mang_CBS8886_V1.cdna.all.fa.gz',
	'kwoniella_pini_cbs_10737'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/kwoniella_pini_cbs_10737/cdna/Kwoniella_pini_cbs_10737.Cryp_pinu_CBS10737_V1.cdna.all.fa.gz',
	'laccaria_amethystina_laam_08_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/laccaria_amethystina_laam_08_1/cdna/Laccaria_amethystina_laam_08_1.Laccaria_amethystina_LaAM-08-1_v1.0.cdna.all.fa.gz',
	'laccaria_bicolor_s238n_h82'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/laccaria_bicolor_s238n_h82/cdna/Laccaria_bicolor_s238n_h82.V1.0.cdna.all.fa.gz',
	'lachancea_dasiensis_cbs_10888'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_dasiensis_cbs_10888/cdna/Lachancea_dasiensis_cbs_10888.LADA0.cdna.all.fa.gz',
	'lachancea_fermentati'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_fermentati/cdna/Lachancea_fermentati.LAFE0.cdna.all.fa.gz',
	'lachancea_lanzarotensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/lachancea_lanzarotensis/cdna/Lachancea_lanzarotensis.LALA0.cdna.all.fa.gz',
	'lachancea_meyersii_cbs_8951'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_meyersii_cbs_8951/cdna/Lachancea_meyersii_cbs_8951.LAME0.cdna.all.fa.gz',
	'lachancea_mirantina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_mirantina/cdna/Lachancea_mirantina.LAMI0.cdna.all.fa.gz',
	'lachancea_nothofagi_cbs_11611'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_nothofagi_cbs_11611/cdna/Lachancea_nothofagi_cbs_11611.LANO0.cdna.all.fa.gz',
	'lachancea_sp_cbs_6924'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lachancea_sp_cbs_6924/cdna/Lachancea_sp_cbs_6924.LAFA0.cdna.all.fa.gz',
	'lachancea_thermotolerans_cbs_6340'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/lachancea_thermotolerans_cbs_6340/cdna/Lachancea_thermotolerans_cbs_6340.ASM14280v1.cdna.all.fa.gz',
	'laetiporus_sulphureus_93_53'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/laetiporus_sulphureus_93_53/cdna/Laetiporus_sulphureus_93_53.Laesu1.cdna.all.fa.gz',
	'latimeria_chalumnae'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/latimeria_chalumnae/cdna/Latimeria_chalumnae.LatCha1.cdna.abinitio.fa.gz',
	'leersia_perrieri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/leersia_perrieri/cdna/Leersia_perrieri.Lperr_V1.4.cdna.abinitio.fa.gz',
	'leishmania_braziliensis_mhom_br_75_m2904'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leishmania_braziliensis_mhom_br_75_m2904/cdna/Leishmania_braziliensis_mhom_br_75_m2904.ASM284v2.cdna.all.fa.gz',
	'leishmania_donovani_bpk282a1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leishmania_donovani_bpk282a1/cdna/Leishmania_donovani_bpk282a1.ASM22713v2.cdna.all.fa.gz',
	'leishmania_infantum_jpcm5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leishmania_infantum_jpcm5/cdna/Leishmania_infantum_jpcm5.ASM287v2.cdna.all.fa.gz',
	'leishmania_major'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/leishmania_major/cdna/Leishmania_major.ASM272v2.cdna.all.fa.gz',
	'leishmania_mexicana_mhom_gt_2001_u1103'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leishmania_mexicana_mhom_gt_2001_u1103/cdna/Leishmania_mexicana_mhom_gt_2001_u1103.ASM23466v4.cdna.all.fa.gz',
	'leishmania_panamensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leishmania_panamensis/cdna/Leishmania_panamensis.ASM75516v1.cdna.all.fa.gz',
	'lentinula_edodes'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/lentinula_edodes/cdna/Lentinula_edodes.Lened_assembly01.cdna.all.fa.gz',
	'lepeophtheirus_salmonis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/lepeophtheirus_salmonis/cdna/Lepeophtheirus_salmonis.LSalAtl2s.cdna.all.fa.gz',
	'lepisosteus_oculatus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/lepisosteus_oculatus/cdna/Lepisosteus_oculatus.LepOcu1.cdna.abinitio.fa.gz',
	'leptomonas_pyrrhocoris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leptomonas_pyrrhocoris/cdna/Leptomonas_pyrrhocoris.ASM129339v1.cdna.all.fa.gz',
	'leptomonas_seymouri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/leptomonas_seymouri/cdna/Leptomonas_seymouri.ASM129953v1.cdna.all.fa.gz',
	'leptosphaeria_maculans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/leptosphaeria_maculans/cdna/Leptosphaeria_maculans.ASM23037v1.cdna.all.fa.gz',
	'leucoagaricus_sp_symc_cos'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/leucoagaricus_sp_symc_cos/cdna/Leucoagaricus_sp_symc_cos.ASM156373v1.cdna.all.fa.gz',
	'lingula_anatina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/lingula_anatina/cdna/Lingula_anatina.LinAna1.0.cdna.all.fa.gz',
	'lipomyces_starkeyi_nrrl_y_11557'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/lipomyces_starkeyi_nrrl_y_11557/cdna/Lipomyces_starkeyi_nrrl_y_11557.Lipst1_1.cdna.all.fa.gz',
	'loa_loa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/loa_loa/cdna/Loa_loa.Loa_loa_V3.cdna.all.fa.gz',
	'lodderomyces_elongisporus_nrrl_yb_4239'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/lodderomyces_elongisporus_nrrl_yb_4239/cdna/Lodderomyces_elongisporus_nrrl_yb_4239.ASM14968v1.cdna.all.fa.gz',
	'lotharella_oceanica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_rhizaria1_collection/lotharella_oceanica/cdna/Lotharella_oceanica.ASM69843v2.cdna.all.fa.gz',
	'lottia_gigantea'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/lottia_gigantea/cdna/Lottia_gigantea.Lotgi1.cdna.all.fa.gz',
	'loxodonta_africana'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/loxodonta_africana/cdna/Loxodonta_africana.loxAfr3.cdna.abinitio.fa.gz',
	'lucilia_cuprina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/lucilia_cuprina/cdna/Lucilia_cuprina.ASM118794v1.cdna.all.fa.gz',
	'macaca_mulatta'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/macaca_mulatta/cdna/Macaca_mulatta.Mmul_8.0.1.cdna.abinitio.fa.gz',
	'macrophomina_phaseolina_ms6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/macrophomina_phaseolina_ms6/cdna/Macrophomina_phaseolina_ms6.MphMS6_1.0.cdna.all.fa.gz',
	'madurella_mycetomatis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/madurella_mycetomatis/cdna/Madurella_mycetomatis.ASM127576v2.cdna.all.fa.gz',
	'magnaporthe_oryzae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/magnaporthe_oryzae/cdna/Magnaporthe_oryzae.MG8.cdna.all.fa.gz',
	'magnaporthe_poae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/magnaporthe_poae/cdna/Magnaporthe_poae.Mag_poae_ATCC_64411_V1.cdna.all.fa.gz',
	'malassezia_pachydermatis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/malassezia_pachydermatis/cdna/Malassezia_pachydermatis.MalaPachy.cdna.all.fa.gz',
	'malassezia_sympodialis_atcc_42132'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/malassezia_sympodialis_atcc_42132/cdna/Malassezia_sympodialis_atcc_42132.ASM34930v2.cdna.all.fa.gz',
	'malassezia_sympodialis_atcc_42132_gca_900149145'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/malassezia_sympodialis_atcc_42132_gca_900149145/cdna/Malassezia_sympodialis_atcc_42132_gca_900149145.Msy_ATCC_42132_Feb2016.cdna.all.fa.gz',
	'marssonina_brunnea_f_sp_multigermtubi_mb_m1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/marssonina_brunnea_f_sp_multigermtubi_mb_m1/cdna/Marssonina_brunnea_f_sp_multigermtubi_mb_m1.ASM29877v1.cdna.all.fa.gz',
	'mayetiola_destructor'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/mayetiola_destructor/cdna/Mayetiola_destructor.Mdes_1.0.cdna.all.fa.gz',
	'medicago_truncatula'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/medicago_truncatula/cdna/Medicago_truncatula.MedtrA17_4.0.cdna.all.fa.gz',
	'megaselia_scalaris'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/megaselia_scalaris/cdna/Megaselia_scalaris.Msca1.cdna.all.fa.gz',
	'melampsora_laricipopulina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/melampsora_laricipopulina/cdna/Melampsora_laricipopulina.GCA_000204055.1.cdna.all.fa.gz',
	'meleagris_gallopavo'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/meleagris_gallopavo/cdna/Meleagris_gallopavo.UMD2.cdna.abinitio.fa.gz',
	'melitaea_cinxia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/melitaea_cinxia/cdna/Melitaea_cinxia.MelCinx1.0.cdna.abinitio.fa.gz',
	'mesocricetus_auratus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mesocricetus_auratus/cdna/Mesocricetus_auratus.MesAur1.0.cdna.abinitio.fa.gz',
	'metarhizium_acridum_cqma_102'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/metarhizium_acridum_cqma_102/cdna/Metarhizium_acridum_cqma_102.MetAcr_May2010.cdna.all.fa.gz',
	'metarhizium_album_arsef_1941'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_album_arsef_1941/cdna/Metarhizium_album_arsef_1941.MAM_1.0_for_version_1_of_the_Metarhizium_album_genome.cdna.all.fa.gz',
	'metarhizium_anisopliae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/metarhizium_anisopliae/cdna/Metarhizium_anisopliae.Metarhizium_anisopliae.cdna.all.fa.gz',
	'metarhizium_anisopliae_arsef_23'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/metarhizium_anisopliae_arsef_23/cdna/Metarhizium_anisopliae_arsef_23.MAA_2.0.cdna.all.fa.gz',
	'metarhizium_anisopliae_arsef_549'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_anisopliae_arsef_549/cdna/Metarhizium_anisopliae_arsef_549.MAN_1.0.cdna.all.fa.gz',
	'metarhizium_anisopliae_brip_53284'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_anisopliae_brip_53284/cdna/Metarhizium_anisopliae_brip_53284.ASM42698v1.cdna.all.fa.gz',
	'metarhizium_anisopliae_brip_53293'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_anisopliae_brip_53293/cdna/Metarhizium_anisopliae_brip_53293.ASM42696v1.cdna.all.fa.gz',
	'metarhizium_brunneum_arsef_3297'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_brunneum_arsef_3297/cdna/Metarhizium_brunneum_arsef_3297.MBR_1.0.cdna.all.fa.gz',
	'metarhizium_guizhouense_arsef_977'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_guizhouense_arsef_977/cdna/Metarhizium_guizhouense_arsef_977.MGU_1.0.cdna.all.fa.gz',
	'metarhizium_majus_arsef_297'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/metarhizium_majus_arsef_297/cdna/Metarhizium_majus_arsef_297.MAJ_1.0.cdna.all.fa.gz',
	'metarhizium_rileyi_rcef_4871'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/metarhizium_rileyi_rcef_4871/cdna/Metarhizium_rileyi_rcef_4871.NOR_1.0.cdna.all.fa.gz',
	'metarhizium_robertsii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/metarhizium_robertsii/cdna/Metarhizium_robertsii.MR2010_11_27.cdna.all.fa.gz',
	'metschnikowia_bicuspidata_var_bicuspidata_nrrl_yb_4993'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/metschnikowia_bicuspidata_var_bicuspidata_nrrl_yb_4993/cdna/Metschnikowia_bicuspidata_var_bicuspidata_nrrl_yb_4993.Metbi1.cdna.all.fa.gz',
	'meyerozyma_guilliermondii_atcc_6260'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/meyerozyma_guilliermondii_atcc_6260/cdna/Meyerozyma_guilliermondii_atcc_6260.ASM14942v1.cdna.all.fa.gz',
	'microbotryum_violaceum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/microbotryum_violaceum/cdna/Microbotryum_violaceum.GCA_000166175.1.cdna.all.fa.gz',
	'microcebus_murinus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/microcebus_murinus/cdna/Microcebus_murinus.Mmur_2.0.cdna.abinitio.fa.gz',
	'microdochium_bolleyi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/microdochium_bolleyi/cdna/Microdochium_bolleyi.Microdochium_bolleyi_v1.0.cdna.all.fa.gz',
	'microtus_ochrogaster'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/microtus_ochrogaster/cdna/Microtus_ochrogaster.MicOch1.0.cdna.abinitio.fa.gz',
	'millerozyma_farinosa_cbs_7064'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/millerozyma_farinosa_cbs_7064/cdna/Millerozyma_farinosa_cbs_7064.ASM31589v1.cdna.all.fa.gz',
	'mitosporidium_daphniae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/mitosporidium_daphniae/cdna/Mitosporidium_daphniae.UGP1.0.cdna.all.fa.gz',
	'mixia_osmundae_iam_14324'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/mixia_osmundae_iam_14324/cdna/Mixia_osmundae_iam_14324.Mosmundae_2.0.cdna.all.fa.gz',
	'mixia_osmundae_iam_14324_gca_000708205'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/mixia_osmundae_iam_14324_gca_000708205/cdna/Mixia_osmundae_iam_14324_gca_000708205.Mixia_osmundae_v1.0.cdna.all.fa.gz',
	'mnemiopsis_leidyi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/mnemiopsis_leidyi/cdna/Mnemiopsis_leidyi.MneLei_Aug2011.cdna.all.fa.gz',
	'moesziomyces_antarcticus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/moesziomyces_antarcticus/cdna/Moesziomyces_antarcticus.ASM74776v1.cdna.all.fa.gz',
	'moesziomyces_aphidis_dsm_70725'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/moesziomyces_aphidis_dsm_70725/cdna/Moesziomyces_aphidis_dsm_70725.PseuAph1.0.cdna.all.fa.gz',
	'moniliophthora_perniciosa_fa553'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/moniliophthora_perniciosa_fa553/cdna/Moniliophthora_perniciosa_fa553.ASM18302v1.cdna.all.fa.gz',
	'moniliophthora_roreri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/moniliophthora_roreri/cdna/Moniliophthora_roreri.ASM146670v1.cdna.all.fa.gz',
	'moniliophthora_roreri_mca_2997'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/moniliophthora_roreri_mca_2997/cdna/Moniliophthora_roreri_mca_2997.M_roreri_MCA_2997_v1.cdna.all.fa.gz',
	'monodelphis_domestica'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/monodelphis_domestica/cdna/Monodelphis_domestica.BROADO5.cdna.abinitio.fa.gz',
	'mortierella_elongata_ag_77'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/mortierella_elongata_ag_77/cdna/Mortierella_elongata_ag_77.Mortierella_elongata_AG-77_v2.0.cdna.all.fa.gz',
	'mortierella_verticillata_nrrl_6337'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/mortierella_verticillata_nrrl_6337/cdna/Mortierella_verticillata_nrrl_6337.Mort_vert_NRRL_6337_V1.cdna.all.fa.gz',
	'mucor_ambiguus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/mucor_ambiguus/cdna/Mucor_ambiguus.ASM95059v1.cdna.all.fa.gz',
	'mucor_circinelloides_f_circinelloides_1006phl'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/mucor_circinelloides_f_circinelloides_1006phl/cdna/Mucor_circinelloides_f_circinelloides_1006phl.Muco_sp_1006Ph_V1.cdna.all.fa.gz',
	'mucor_circinelloides_f_lusitanicus_cbs_277_49'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/mucor_circinelloides_f_lusitanicus_cbs_277_49/cdna/Mucor_circinelloides_f_lusitanicus_cbs_277_49.Mucci2.cdna.all.fa.gz',
	'mus_caroli'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_caroli/cdna/Mus_caroli.CAROLI_EIJ_v1.1.cdna.abinitio.fa.gz',
	'mus_musculus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus/cdna/Mus_musculus.GRCm38.cdna.abinitio.fa.gz',
	'mus_musculus_129s1svimj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_129s1svimj/cdna/Mus_musculus_129s1svimj.129S1_SvImJ_v1.cdna.abinitio.fa.gz',
	'mus_musculus_aj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_aj/cdna/Mus_musculus_aj.A_J_v1.cdna.abinitio.fa.gz',
	'mus_musculus_akrj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_akrj/cdna/Mus_musculus_akrj.AKR_J_v1.cdna.abinitio.fa.gz',
	'mus_musculus_balbcj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_balbcj/cdna/Mus_musculus_balbcj.BALB_cJ_v1.cdna.abinitio.fa.gz',
	'mus_musculus_c3hhej'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_c3hhej/cdna/Mus_musculus_c3hhej.C3H_HeJ_v1.cdna.abinitio.fa.gz',
	'mus_musculus_c57bl6nj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_c57bl6nj/cdna/Mus_musculus_c57bl6nj.C57BL_6NJ_v1.cdna.abinitio.fa.gz',
	'mus_musculus_casteij'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_casteij/cdna/Mus_musculus_casteij.CAST_EiJ_v1.cdna.abinitio.fa.gz',
	'mus_musculus_dba2j'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_dba2j/cdna/Mus_musculus_dba2j.DBA_2J_v1.cdna.abinitio.fa.gz',
	'mus_musculus_fvbnj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_fvbnj/cdna/Mus_musculus_fvbnj.FVB_NJ_v1.cdna.abinitio.fa.gz',
	'mus_musculus_lpj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_lpj/cdna/Mus_musculus_lpj.LP_J_v1.cdna.abinitio.fa.gz',
	'mus_musculus_nodshiltj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_nodshiltj/cdna/Mus_musculus_nodshiltj.NOD_ShiLtJ_v1.cdna.abinitio.fa.gz',
	'mus_musculus_nzohlltj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_nzohlltj/cdna/Mus_musculus_nzohlltj.NZO_HlLtJ_v1.cdna.abinitio.fa.gz',
	'mus_musculus_pwkphj'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_pwkphj/cdna/Mus_musculus_pwkphj.PWK_PhJ_v1.cdna.abinitio.fa.gz',
	'mus_musculus_wsbeij'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_musculus_wsbeij/cdna/Mus_musculus_wsbeij.WSB_EiJ_v1.cdna.abinitio.fa.gz',
	'mus_pahari'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_pahari/cdna/Mus_pahari.PAHARI_EIJ_v1.1.cdna.abinitio.fa.gz',
	'mus_spretus_spreteij'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mus_spretus_spreteij/cdna/Mus_spretus_spreteij.SPRET_EiJ_v1.cdna.abinitio.fa.gz',
	'musa_acuminata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/musa_acuminata/cdna/Musa_acuminata.MA1.cdna.all.fa.gz',
	'mustela_putorius_furo'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/mustela_putorius_furo/cdna/Mustela_putorius_furo.MusPutFur1.0.cdna.abinitio.fa.gz',
	'mycosphaerella_eumusae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/mycosphaerella_eumusae/cdna/Mycosphaerella_eumusae.ASM157823v1.cdna.all.fa.gz',
	'myotis_lucifugus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/myotis_lucifugus/cdna/Myotis_lucifugus.Myoluc2.0.cdna.abinitio.fa.gz',
	'nadsonia_fulvescens_var_elongata_dsm_6958'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/nadsonia_fulvescens_var_elongata_dsm_6958/cdna/Nadsonia_fulvescens_var_elongata_dsm_6958.Nadfu1.cdna.all.fa.gz',
	'naegleria_gruberi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_heterolobosea1_collection/naegleria_gruberi/cdna/Naegleria_gruberi.V1.0.cdna.all.fa.gz',
	'nannizzia_gypsea_cbs_118893'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/nannizzia_gypsea_cbs_118893/cdna/Nannizzia_gypsea_cbs_118893.MS_CBS118893.cdna.all.fa.gz',
	'nannochloropsis_gaditana'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/nannochloropsis_gaditana/cdna/Nannochloropsis_gaditana.NagaB31_1.0.cdna.all.fa.gz',
	'nannospalax_galili'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/nannospalax_galili/cdna/Nannospalax_galili.S.galili_v1.0.cdna.abinitio.fa.gz',
	'nasonia_vitripennis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/nasonia_vitripennis/cdna/Nasonia_vitripennis.Nvit_2.1.cdna.all.fa.gz',
	'naumovozyma_castellii_cbs_4309'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/naumovozyma_castellii_cbs_4309/cdna/Naumovozyma_castellii_cbs_4309.ASM23734v1.cdna.all.fa.gz',
	'naumovozyma_dairenensis_cbs_421'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/naumovozyma_dairenensis_cbs_421/cdna/Naumovozyma_dairenensis_cbs_421.ASM22711v2.cdna.all.fa.gz',
	'nematocida_displodere'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_displodere/cdna/Nematocida_displodere.ASM164239v1.cdna.all.fa.gz',
	'nematocida_parisii_ertm1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_parisii_ertm1/cdna/Nematocida_parisii_ertm1.Nema_parisii_ERTm1_V3.cdna.all.fa.gz',
	'nematocida_parisii_ertm3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_parisii_ertm3/cdna/Nematocida_parisii_ertm3.Nema_parisii_ERTm3_V1.cdna.all.fa.gz',
	'nematocida_sp_1_ertm2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_sp_1_ertm2/cdna/Nematocida_sp_1_ertm2.Nema_parisii_ERTm2_V1.cdna.all.fa.gz',
	'nematocida_sp_1_ertm6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_sp_1_ertm6/cdna/Nematocida_sp_1_ertm6.Nema_sp_1_ERTm6_V2.cdna.all.fa.gz',
	'nematocida_sp_ertm5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nematocida_sp_ertm5/cdna/Nematocida_sp_ertm5.ASM164241v1.cdna.all.fa.gz',
	'nematostella_vectensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/nematostella_vectensis/cdna/Nematostella_vectensis.ASM20922v1.cdna.all.fa.gz',
	'neofusicoccum_parvum_ucrnp2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/neofusicoccum_parvum_ucrnp2/cdna/Neofusicoccum_parvum_ucrnp2.UCRNP2V3.cdna.all.fa.gz',
	'neolecta_irregularis_dah_3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/neolecta_irregularis_dah_3/cdna/Neolecta_irregularis_dah_3.NeoIirr1.0.cdna.all.fa.gz',
	'neolentinus_lepideus_hhb14362_ss_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/neolentinus_lepideus_hhb14362_ss_1/cdna/Neolentinus_lepideus_hhb14362_ss_1.Neole1.cdna.all.fa.gz',
	'neonectria_ditissima'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/neonectria_ditissima/cdna/Neonectria_ditissima.R0905_v2.0.cdna.all.fa.gz',
	'neosartorya_fischeri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/neosartorya_fischeri/cdna/Neosartorya_fischeri.CADRE.cdna.all.fa.gz',
	'neurospora_crassa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/neurospora_crassa/cdna/Neurospora_crassa.NC12.cdna.all.fa.gz',
	'neurospora_crassa_gca_000786625'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/neurospora_crassa_gca_000786625/cdna/Neurospora_crassa_gca_000786625.Neucr_trp3_1.cdna.all.fa.gz',
	'neurospora_tetrasperma_fgsc_2508'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/neurospora_tetrasperma_fgsc_2508/cdna/Neurospora_tetrasperma_fgsc_2508.v2.0.cdna.all.fa.gz',
	'neurospora_tetrasperma_fgsc_2509'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/neurospora_tetrasperma_fgsc_2509/cdna/Neurospora_tetrasperma_fgsc_2509.v1.0.cdna.all.fa.gz',
	'nomascus_leucogenys'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/nomascus_leucogenys/cdna/Nomascus_leucogenys.Nleu1.0.cdna.abinitio.fa.gz',
	'nosema_apis_brl_01'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nosema_apis_brl_01/cdna/Nosema_apis_brl_01.NapisBRLv01.cdna.all.fa.gz',
	'nosema_bombycis_cq1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nosema_bombycis_cq1/cdna/Nosema_bombycis_cq1.NosBomCQ1_v1.0.cdna.all.fa.gz',
	'nosema_ceranae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nosema_ceranae/cdna/Nosema_ceranae.ASM98816v1.cdna.all.fa.gz',
	'nosema_ceranae_brl01'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/nosema_ceranae_brl01/cdna/Nosema_ceranae_brl01.ASM18298v1.cdna.all.fa.gz',
	'notamacropus_eugenii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/notamacropus_eugenii/cdna/Notamacropus_eugenii.Meug_1.0.cdna.abinitio.fa.gz',
	'ochotona_princeps'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ochotona_princeps/cdna/Ochotona_princeps.OchPri2.0-Ens.cdna.abinitio.fa.gz',
	'octodon_degus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/octodon_degus/cdna/Octodon_degus.OctDeg1.0.cdna.abinitio.fa.gz',
	'octopus_bimaculoides'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/octopus_bimaculoides/cdna/Octopus_bimaculoides.PRJNA270931.cdna.all.fa.gz',
	'ogataea_parapolymorpha_dl_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/ogataea_parapolymorpha_dl_1/cdna/Ogataea_parapolymorpha_dl_1.Hansenula_2.cdna.all.fa.gz',
	'ogataea_polymorpha'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ogataea_polymorpha/cdna/Ogataea_polymorpha.Hanpo2.cdna.all.fa.gz',
	'oidiodendron_maius_zn'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/oidiodendron_maius_zn/cdna/Oidiodendron_maius_zn.Oidiodendron_maius_Zn_v1.0.cdna.all.fa.gz',
	'onchocerca_volvulus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/onchocerca_volvulus/cdna/Onchocerca_volvulus.O_volvulus_Cameroon_v3.cdna.all.fa.gz',
	'ophiocordyceps_sinensis_co18'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/ophiocordyceps_sinensis_co18/cdna/Ophiocordyceps_sinensis_co18.ASM44836v1.cdna.all.fa.gz',
	'ophiocordyceps_unilateralis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ophiocordyceps_unilateralis/cdna/Ophiocordyceps_unilateralis.ASM127257v1.cdna.all.fa.gz',
	'ophiostoma_piceae_uamh_11346'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/ophiostoma_piceae_uamh_11346/cdna/Ophiostoma_piceae_uamh_11346.Opiceae_UAMHv01.cdna.all.fa.gz',
	'ordospora_colligata_oc4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/ordospora_colligata_oc4/cdna/Ordospora_colligata_oc4.ASM80326v1.cdna.all.fa.gz',
	'oreochromis_niloticus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/oreochromis_niloticus/cdna/Oreochromis_niloticus.Orenil1.0.cdna.abinitio.fa.gz',
	'ornithorhynchus_anatinus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ornithorhynchus_anatinus/cdna/Ornithorhynchus_anatinus.OANA5.cdna.abinitio.fa.gz',
	'oryctolagus_cuniculus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/oryctolagus_cuniculus/cdna/Oryctolagus_cuniculus.OryCun2.0.cdna.abinitio.fa.gz',
	'oryza_barthii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_barthii/cdna/Oryza_barthii.O.barthii_v1.cdna.abinitio.fa.gz',
	'oryza_brachyantha'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_brachyantha/cdna/Oryza_brachyantha.Oryza_brachyantha.v1.4b.cdna.abinitio.fa.gz',
	'oryza_glaberrima'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_glaberrima/cdna/Oryza_glaberrima.AGI1.1.cdna.abinitio.fa.gz',
	'oryza_glumaepatula'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_glumaepatula/cdna/Oryza_glumaepatula.ALNU02000000.cdna.abinitio.fa.gz',
	'oryza_indica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_indica/cdna/Oryza_indica.ASM465v1.cdna.abinitio.fa.gz',
	'oryza_longistaminata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_longistaminata/cdna/Oryza_longistaminata.O_longistaminata_v1.0.cdna.all.fa.gz',
	'oryza_meridionalis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_meridionalis/cdna/Oryza_meridionalis.Oryza_meridionalis_v1.3.cdna.all.fa.gz',
	'oryza_nivara'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_nivara/cdna/Oryza_nivara.AWHD00000000.cdna.abinitio.fa.gz',
	'oryza_punctata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_punctata/cdna/Oryza_punctata.AVCL00000000.cdna.abinitio.fa.gz',
	'oryza_rufipogon'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_rufipogon/cdna/Oryza_rufipogon.OR_W1943.cdna.all.fa.gz',
	'oryza_sativa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/oryza_sativa/cdna/Oryza_sativa.IRGSP-1.0.cdna.abinitio.fa.gz',
	'oryzias_latipes'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/oryzias_latipes/cdna/Oryzias_latipes.MEDAKA1.cdna.abinitio.fa.gz',
	'ostreococcus_lucimarinus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/ostreococcus_lucimarinus/cdna/Ostreococcus_lucimarinus.ASM9206v1.cdna.all.fa.gz',
	'otolemur_garnettii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/otolemur_garnettii/cdna/Otolemur_garnettii.OtoGar3.cdna.abinitio.fa.gz',
	'ovis_aries'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/ovis_aries/cdna/Ovis_aries.Oar_v3.1.cdna.abinitio.fa.gz',
	'pachysolen_tannophilus_nrrl_y_2460'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pachysolen_tannophilus_nrrl_y_2460/cdna/Pachysolen_tannophilus_nrrl_y_2460.Pacta1_2.cdna.all.fa.gz',
	'pan_troglodytes'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/pan_troglodytes/cdna/Pan_troglodytes.CHIMP2.1.4.cdna.abinitio.fa.gz',
	'papio_anubis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/papio_anubis/cdna/Papio_anubis.PapAnu2.0.cdna.abinitio.fa.gz',
	'paracoccidioides_brasiliensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/paracoccidioides_brasiliensis/cdna/Paracoccidioides_brasiliensis.ASM171364v1.cdna.all.fa.gz',
	'paracoccidioides_brasiliensis_gca_001713695'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/paracoccidioides_brasiliensis_gca_001713695/cdna/Paracoccidioides_brasiliensis_gca_001713695.Paracocci_br_PbCNH.cdna.all.fa.gz',
	'paracoccidioides_brasiliensis_pb03'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/paracoccidioides_brasiliensis_pb03/cdna/Paracoccidioides_brasiliensis_pb03.Paracocci_br_Pb03_V2.cdna.all.fa.gz',
	'paracoccidioides_brasiliensis_pb18'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/paracoccidioides_brasiliensis_pb18/cdna/Paracoccidioides_brasiliensis_pb18.Paracocci_br_Pb18_V2.cdna.all.fa.gz',
	'paracoccidioides_sp_lutzii_pb01'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/paracoccidioides_sp_lutzii_pb01/cdna/Paracoccidioides_sp_lutzii_pb01.Paracocci_br_Pb01_V2.cdna.all.fa.gz',
	'paramecium_tetraurelia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/paramecium_tetraurelia/cdna/Paramecium_tetraurelia.ASM16542v1.cdna.all.fa.gz',
	'paraphaeosphaeria_sporulosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/paraphaeosphaeria_sporulosa/cdna/Paraphaeosphaeria_sporulosa.Parsp1.cdna.all.fa.gz',
	'parasitella_parasitica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/parasitella_parasitica/cdna/Parasitella_parasitica.PP.v1.cdna.all.fa.gz',
	'paulinella_chromatophora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_rhizaria1_collection/paulinella_chromatophora/cdna/Paulinella_chromatophora.ASM1792v1.cdna.all.fa.gz',
	'paxillus_involutus_atcc_200175'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/paxillus_involutus_atcc_200175/cdna/Paxillus_involutus_atcc_200175.Paxillus_involutus_ATCC_200175_v1.0.cdna.all.fa.gz',
	'paxillus_rubicundulus_ve08_2h10'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/paxillus_rubicundulus_ve08_2h10/cdna/Paxillus_rubicundulus_ve08_2h10.Paxillus_rubicundulus_Ve08.2h10_v1.0.cdna.all.fa.gz',
	'pediculus_humanus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/pediculus_humanus/cdna/Pediculus_humanus.PhumU2.cdna.all.fa.gz',
	'pelodiscus_sinensis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/pelodiscus_sinensis/cdna/Pelodiscus_sinensis.PelSin_1.0.cdna.abinitio.fa.gz',
	'penicilliopsis_zonata_cbs_506_65'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicilliopsis_zonata_cbs_506_65/cdna/Penicilliopsis_zonata_cbs_506_65.Aspzo1.cdna.all.fa.gz',
	'penicillium_antarcticum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_antarcticum/cdna/Penicillium_antarcticum.ASM207234v1.cdna.all.fa.gz',
	'penicillium_arizonense'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_arizonense/cdna/Penicillium_arizonense.ASM177332v1.cdna.all.fa.gz',
	'penicillium_brasilianum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/penicillium_brasilianum/cdna/Penicillium_brasilianum.Pbras_Allpaths-LG.cdna.all.fa.gz',
	'penicillium_brasilianum_gca_002016555'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_brasilianum_gca_002016555/cdna/Penicillium_brasilianum_gca_002016555.ASM201655v1.cdna.all.fa.gz',
	'penicillium_camemberti_fm_013'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/penicillium_camemberti_fm_013/cdna/Penicillium_camemberti_fm_013.PCAMFM013_20131106.cdna.all.fa.gz',
	'penicillium_chrysogenum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_chrysogenum/cdna/Penicillium_chrysogenum.ASM71027v1.cdna.all.fa.gz',
	'penicillium_coprophilum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_coprophilum/cdna/Penicillium_coprophilum.ASM207240v1.cdna.all.fa.gz',
	'penicillium_decumbens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_decumbens/cdna/Penicillium_decumbens.ASM207224v1.cdna.all.fa.gz',
	'penicillium_digitatum_pd1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_digitatum_pd1/cdna/Penicillium_digitatum_pd1.PdigPd1_v1.cdna.all.fa.gz',
	'penicillium_digitatum_phi26'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_digitatum_phi26/cdna/Penicillium_digitatum_phi26.PdigPHI26_v1.cdna.all.fa.gz',
	'penicillium_expansum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_expansum/cdna/Penicillium_expansum.PEX1.cdna.all.fa.gz',
	'penicillium_expansum_gca_000769735'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_expansum_gca_000769735/cdna/Penicillium_expansum_gca_000769735.ASM76973v1.cdna.all.fa.gz',
	'penicillium_expansum_gca_000769745'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_expansum_gca_000769745/cdna/Penicillium_expansum_gca_000769745.ASM76974v1.cdna.all.fa.gz',
	'penicillium_flavigenum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_flavigenum/cdna/Penicillium_flavigenum.ASM207236v1.cdna.all.fa.gz',
	'penicillium_freii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_freii/cdna/Penicillium_freii.ASM151392v1.cdna.all.fa.gz',
	'penicillium_griseofulvum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_griseofulvum/cdna/Penicillium_griseofulvum.ASM156193v1.cdna.all.fa.gz',
	'penicillium_italicum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_italicum/cdna/Penicillium_italicum.ASM76976v1.cdna.all.fa.gz',
	'penicillium_nalgiovense'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_nalgiovense/cdna/Penicillium_nalgiovense.ASM207242v1.cdna.all.fa.gz',
	'penicillium_nordicum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_nordicum/cdna/Penicillium_nordicum.ASM127859v1.cdna.all.fa.gz',
	'penicillium_oxalicum_114_2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_oxalicum_114_2/cdna/Penicillium_oxalicum_114_2.pde_v1.0.cdna.all.fa.gz',
	'penicillium_polonicum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_polonicum/cdna/Penicillium_polonicum.ASM207226v1.cdna.all.fa.gz',
	'penicillium_roqueforti_fm164'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_roqueforti_fm164/cdna/Penicillium_roqueforti_fm164.PROQFM164_20130607.cdna.all.fa.gz',
	'penicillium_rubens_wisconsin_54_1255'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/penicillium_rubens_wisconsin_54_1255/cdna/Penicillium_rubens_wisconsin_54_1255.PenChr_Nov2007.cdna.all.fa.gz',
	'penicillium_solitum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_solitum/cdna/Penicillium_solitum.ASM207223v1.cdna.all.fa.gz',
	'penicillium_steckii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_steckii/cdna/Penicillium_steckii.ASM207237v1.cdna.all.fa.gz',
	'penicillium_subrubescens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_subrubescens/cdna/Penicillium_subrubescens.ASM190812v1.cdna.all.fa.gz',
	'penicillium_vulpinum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/penicillium_vulpinum/cdna/Penicillium_vulpinum.ASM207225v1.cdna.all.fa.gz',
	'peniophora_sp_cont'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/peniophora_sp_cont/cdna/Peniophora_sp_cont.Ricme1.cdna.all.fa.gz',
	'perkinsus_marinus_atcc_50983'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/perkinsus_marinus_atcc_50983/cdna/Perkinsus_marinus_atcc_50983.JCVI_PMG_1.0.cdna.all.fa.gz',
	'peromyscus_maniculatus_bairdii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/peromyscus_maniculatus_bairdii/cdna/Peromyscus_maniculatus_bairdii.Pman_1.0.cdna.abinitio.fa.gz',
	'pestalotiopsis_fici_w106_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pestalotiopsis_fici_w106_1/cdna/Pestalotiopsis_fici_w106_1.PFICI.cdna.all.fa.gz',
	'petromyzon_marinus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/petromyzon_marinus/cdna/Petromyzon_marinus.Pmarinus_7.0.cdna.abinitio.fa.gz',
	'phaeoacremonium_minimum_ucrpa7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/phaeoacremonium_minimum_ucrpa7/cdna/Phaeoacremonium_minimum_ucrpa7.UCRPA7V03.cdna.all.fa.gz',
	'phaeodactylum_tricornutum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phaeodactylum_tricornutum/cdna/Phaeodactylum_tricornutum.ASM15095v2.cdna.all.fa.gz',
	'phaeomoniella_chlamydospora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/phaeomoniella_chlamydospora/cdna/Phaeomoniella_chlamydospora.UCRPA7V1.0.cdna.all.fa.gz',
	'phaeosphaeria_nodorum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/phaeosphaeria_nodorum/cdna/Phaeosphaeria_nodorum.ASM14691v1.cdna.all.fa.gz',
	'phanerochaete_carnosa_hhb_10118_sp'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/phanerochaete_carnosa_hhb_10118_sp/cdna/Phanerochaete_carnosa_hhb_10118_sp.Phanerochaete_carnosa_HHB-10118-Sp_v1.0.cdna.all.fa.gz',
	'phialocephala_scopiformis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/phialocephala_scopiformis/cdna/Phialocephala_scopiformis.Phisc1.cdna.all.fa.gz',
	'phialocephala_subalpina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/phialocephala_subalpina/cdna/Phialocephala_subalpina.PAC_version_1.cdna.all.fa.gz',
	'phialophora_americana'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/phialophora_americana/cdna/Phialophora_americana.Capr_semi_CBS27337_V1.cdna.all.fa.gz',
	'phialophora_attae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/phialophora_attae/cdna/Phialophora_attae.ASM129925v1.cdna.all.fa.gz',
	'phlebia_centrifuga'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/phlebia_centrifuga/cdna/Phlebia_centrifuga.ASM191385v1.cdna.all.fa.gz',
	'phlebiopsis_gigantea_11061_1_cr5_6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/phlebiopsis_gigantea_11061_1_cr5_6/cdna/Phlebiopsis_gigantea_11061_1_cr5_6.Phlgi1.cdna.all.fa.gz',
	'phycomyces_blakesleeanus_nrrl_1555_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/phycomyces_blakesleeanus_nrrl_1555_/cdna/Phycomyces_blakesleeanus_nrrl_1555_.Phybl2.cdna.all.fa.gz',
	'physcomitrella_patens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/physcomitrella_patens/cdna/Physcomitrella_patens.ASM242v1.cdna.all.fa.gz',
	'phytophthora_infestans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_infestans/cdna/Phytophthora_infestans.ASM14294v1.cdna.all.fa.gz',
	'phytophthora_kernoviae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_kernoviae/cdna/Phytophthora_kernoviae.PhyKer238_432v1.cdna.all.fa.gz',
	'phytophthora_lateralis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_lateralis/cdna/Phytophthora_lateralis.MPF4_v1.0.cdna.all.fa.gz',
	'phytophthora_parasitica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_parasitica/cdna/Phytophthora_parasitica.Phyt_para_P1569_V1.cdna.all.fa.gz',
	'phytophthora_parasitica_cj01a1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_cj01a1/cdna/Phytophthora_parasitica_cj01a1.Phyt_para_CJ01A1_V1.cdna.all.fa.gz',
	'phytophthora_parasitica_gca_000509465'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_gca_000509465/cdna/Phytophthora_parasitica_gca_000509465.Phyt_para_CJ02B3_V1.cdna.all.fa.gz',
	'phytophthora_parasitica_gca_000509485'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_gca_000509485/cdna/Phytophthora_parasitica_gca_000509485.Phyt_para_CJ05E6_V1.cdna.all.fa.gz',
	'phytophthora_parasitica_gca_000509505'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_gca_000509505/cdna/Phytophthora_parasitica_gca_000509505.Phyt_para_CHvinca01_V1.cdna.all.fa.gz',
	'phytophthora_parasitica_gca_000509525'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_gca_000509525/cdna/Phytophthora_parasitica_gca_000509525.Phyt_para_IAC_01_95_V1.cdna.all.fa.gz',
	'phytophthora_parasitica_inra_310'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_inra_310/cdna/Phytophthora_parasitica_inra_310.PP_INRA-310_V2.cdna.all.fa.gz',
	'phytophthora_parasitica_p10297'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_p10297/cdna/Phytophthora_parasitica_p10297.Phyt_para_P10297_V1.cdna.all.fa.gz',
	'phytophthora_parasitica_p1976'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/phytophthora_parasitica_p1976/cdna/Phytophthora_parasitica_p1976.Phyt_para_P1976_V1.cdna.all.fa.gz',
	'phytophthora_ramorum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_ramorum/cdna/Phytophthora_ramorum.ASM14973v1.cdna.all.fa.gz',
	'phytophthora_sojae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/phytophthora_sojae/cdna/Phytophthora_sojae.P_sojae_V3_0.cdna.all.fa.gz',
	'pichia_kudriavzevii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pichia_kudriavzevii/cdna/Pichia_kudriavzevii.ASM76445v1.cdna.all.fa.gz',
	'pichia_kudriavzevii_gca_001983325'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pichia_kudriavzevii_gca_001983325/cdna/Pichia_kudriavzevii_gca_001983325.ASM198332v1.cdna.all.fa.gz',
	'pichia_membranifaciens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pichia_membranifaciens/cdna/Pichia_membranifaciens.P_membrenifaciens-1.0.cdna.all.fa.gz',
	'pichia_membranifaciens_nrrl_y_2026'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pichia_membranifaciens_nrrl_y_2026/cdna/Pichia_membranifaciens_nrrl_y_2026.Picme2.cdna.all.fa.gz',
	'piloderma_croceum_f_1598'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/piloderma_croceum_f_1598/cdna/Piloderma_croceum_f_1598.Piloderma_croceum_F_1598_v1.0.cdna.all.fa.gz',
	'pisolithus_microcarpus_441'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/pisolithus_microcarpus_441/cdna/Pisolithus_microcarpus_441.Pisolithus_microcarpus_441_v1.0.cdna.all.fa.gz',
	'pisolithus_tinctorius_marx_270'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/pisolithus_tinctorius_marx_270/cdna/Pisolithus_tinctorius_marx_270.Pisolithus_tinctorius_Marx_270_v1.0.cdna.all.fa.gz',
	'plasmodium_berghei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/plasmodium_berghei/cdna/Plasmodium_berghei.PBANKA01.cdna.all.fa.gz',
	'plasmodium_berghei_gca_000005395'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_berghei_gca_000005395/cdna/Plasmodium_berghei_gca_000005395.ASM539v1.cdna.all.fa.gz',
	'plasmodium_berghei_gca_900044335'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_berghei_gca_900044335/cdna/Plasmodium_berghei_gca_900044335.PbK173.cdna.all.fa.gz',
	'plasmodium_chabaudi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/plasmodium_chabaudi/cdna/Plasmodium_chabaudi.PCHAS01.cdna.all.fa.gz',
	'plasmodium_chabaudi_chabaudi_gca_000003075'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_chabaudi_chabaudi_gca_000003075/cdna/Plasmodium_chabaudi_chabaudi_gca_000003075.ASM307v1.cdna.all.fa.gz',
	'plasmodium_coatneyi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_coatneyi/cdna/Plasmodium_coatneyi.ASM168000v1.cdna.all.fa.gz',
	'plasmodium_cynomolgi_strain_b'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_cynomolgi_strain_b/cdna/Plasmodium_cynomolgi_strain_b.PcynB_1.0.cdna.all.fa.gz',
	'plasmodium_falciparum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/plasmodium_falciparum/cdna/Plasmodium_falciparum.EPr1.cdna.all.fa.gz',
	'plasmodium_falciparum_7g8'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_7g8/cdna/Plasmodium_falciparum_7g8.Plas_falc_7G8_V1.cdna.all.fa.gz',
	'plasmodium_falciparum_camp_malaysia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_camp_malaysia/cdna/Plasmodium_falciparum_camp_malaysia.Plas_falc_Malayan_Camp_V1.cdna.all.fa.gz',
	'plasmodium_falciparum_dd2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_dd2/cdna/Plasmodium_falciparum_dd2.ASM14979v1.cdna.all.fa.gz',
	'plasmodium_falciparum_fch_4'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_fch_4/cdna/Plasmodium_falciparum_fch_4.Plas_falc_FCH_4_V2.cdna.all.fa.gz',
	'plasmodium_falciparum_hb3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_hb3/cdna/Plasmodium_falciparum_hb3.ASM14966v2.cdna.all.fa.gz',
	'plasmodium_falciparum_igh_cr14'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_igh_cr14/cdna/Plasmodium_falciparum_igh_cr14.ASM18605v2.cdna.all.fa.gz',
	'plasmodium_falciparum_malips096_e11'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_malips096_e11/cdna/Plasmodium_falciparum_malips096_e11.Plas_falc_MaliPS096_E11_V1.cdna.all.fa.gz',
	'plasmodium_falciparum_nf135_5_c10'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_nf135_5_c10/cdna/Plasmodium_falciparum_nf135_5_c10.Plas_falc_NF135_5_C10_V1.cdna.all.fa.gz',
	'plasmodium_falciparum_nf54'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_nf54/cdna/Plasmodium_falciparum_nf54.Plas_falc_NF4_V1.cdna.all.fa.gz',
	'plasmodium_falciparum_palo_alto_uganda'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_palo_alto_uganda/cdna/Plasmodium_falciparum_palo_alto_uganda.Plas_falc_Uganda_Palo-Alto_FUP_H_V1.cdna.all.fa.gz',
	'plasmodium_falciparum_raj116'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_raj116/cdna/Plasmodium_falciparum_raj116.ASM18602v2.cdna.all.fa.gz',
	'plasmodium_falciparum_santa_lucia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_santa_lucia/cdna/Plasmodium_falciparum_santa_lucia.Plas_falc_Santa_Lucia_Salvador_I_V1.cdna.all.fa.gz',
	'plasmodium_falciparum_tanzania_2000708_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_tanzania_2000708_/cdna/Plasmodium_falciparum_tanzania_2000708_.Plas_falc_02000708_V1.cdna.all.fa.gz',
	'plasmodium_falciparum_ugt5_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_ugt5_1/cdna/Plasmodium_falciparum_ugt5_1.Plas_falc_5_1_V1.cdna.all.fa.gz',
	'plasmodium_falciparum_vietnam_oak_knoll_fvo_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_falciparum_vietnam_oak_knoll_fvo_/cdna/Plasmodium_falciparum_vietnam_oak_knoll_fvo_.Plas_falc_Vietnam_Oak-Knoll_FVO_V1.cdna.all.fa.gz',
	'plasmodium_fragile'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_fragile/cdna/Plasmodium_fragile.Plas_frag_nilgiri_V1.cdna.all.fa.gz',
	'plasmodium_gaboni'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_gaboni/cdna/Plasmodium_gaboni.ASM160202v1.cdna.all.fa.gz',
	'plasmodium_inui_san_antonio_1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_inui_san_antonio_1/cdna/Plasmodium_inui_san_antonio_1.Plas_inui_San_Antonio_1_V1.cdna.all.fa.gz',
	'plasmodium_knowlesi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/plasmodium_knowlesi/cdna/Plasmodium_knowlesi.ASM635v1.cdna.all.fa.gz',
	'plasmodium_knowlesi_strain_h_gca_900004885'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_knowlesi_strain_h_gca_900004885/cdna/Plasmodium_knowlesi_strain_h_gca_900004885.PKNA1-C.2.cdna.all.fa.gz',
	'plasmodium_malariae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_malariae/cdna/Plasmodium_malariae.Pmal.cdna.all.fa.gz',
	'plasmodium_ovale_curtisi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_ovale_curtisi/cdna/Plasmodium_ovale_curtisi.Poc1.cdna.all.fa.gz',
	'plasmodium_reichenowi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_reichenowi/cdna/Plasmodium_reichenowi.PREICH001.cdna.all.fa.gz',
	'plasmodium_reichenowi_gca_001601855'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_reichenowi_gca_001601855/cdna/Plasmodium_reichenowi_gca_001601855.ASM160185v1.cdna.all.fa.gz',
	'plasmodium_vinckei_petteri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vinckei_petteri/cdna/Plasmodium_vinckei_petteri.Plas_vinc_pett_CR_V1.cdna.all.fa.gz',
	'plasmodium_vinckei_vinckei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vinckei_vinckei/cdna/Plasmodium_vinckei_vinckei.Plas_vinc_vinckei_V1.cdna.all.fa.gz',
	'plasmodium_vivax'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/plasmodium_vivax/cdna/Plasmodium_vivax.ASM241v2.cdna.all.fa.gz',
	'plasmodium_vivax_brazil_i'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vivax_brazil_i/cdna/Plasmodium_vivax_brazil_i.PV_Brazil_I_V1.cdna.all.fa.gz',
	'plasmodium_vivax_india_vii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vivax_india_vii/cdna/Plasmodium_vivax_india_vii.PV_India_VII_V2.cdna.all.fa.gz',
	'plasmodium_vivax_mauritania_i'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vivax_mauritania_i/cdna/Plasmodium_vivax_mauritania_i.PV_Mauritania_I_V1.cdna.all.fa.gz',
	'plasmodium_vivax_north_korean'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_vivax_north_korean/cdna/Plasmodium_vivax_north_korean.PV_N_Korean_V1.cdna.all.fa.gz',
	'plasmodium_yoelii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_yoelii/cdna/Plasmodium_yoelii.PY17X01.cdna.all.fa.gz',
	'plasmodium_yoelii_17x'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_yoelii_17x/cdna/Plasmodium_yoelii_17x.Plas_yoel_17X_V2.cdna.all.fa.gz',
	'plasmodium_yoelii_gca_900002395'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_yoelii_gca_900002395/cdna/Plasmodium_yoelii_gca_900002395.PYYM01.cdna.all.fa.gz',
	'plasmodium_yoelii_yoelii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/plasmodium_yoelii_yoelii/cdna/Plasmodium_yoelii_yoelii.ASM308v2.cdna.all.fa.gz',
	'plasmopara_halstedii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/plasmopara_halstedii/cdna/Plasmopara_halstedii.Plasmopara_halstedii_genome.cdna.all.fa.gz',
	'pleurotus_ostreatus_pc15'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/pleurotus_ostreatus_pc15/cdna/Pleurotus_ostreatus_pc15.PleosPC15_2.cdna.all.fa.gz',
	'plicaturopsis_crispa_fd_325_ss_3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/plicaturopsis_crispa_fd_325_ss_3/cdna/Plicaturopsis_crispa_fd_325_ss_3.Plicr1.cdna.all.fa.gz',
	'pneumocystis_carinii_b80'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pneumocystis_carinii_b80/cdna/Pneumocystis_carinii_b80.Pneu_cari_B80_V3.cdna.all.fa.gz',
	'pneumocystis_jirovecii_ru7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pneumocystis_jirovecii_ru7/cdna/Pneumocystis_jirovecii_ru7.Pneu_jiro_RU7_V2.cdna.all.fa.gz',
	'pneumocystis_murina_b123'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pneumocystis_murina_b123/cdna/Pneumocystis_murina_b123.Pneumo_murina_B123_V4.cdna.all.fa.gz',
	'pochonia_chlamydosporia_170'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pochonia_chlamydosporia_170/cdna/Pochonia_chlamydosporia_170.ASM165323v1.cdna.all.fa.gz',
	'podospora_anserina_s_mat_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/podospora_anserina_s_mat_/cdna/Podospora_anserina_s_mat_.ASM22654v1.cdna.all.fa.gz',
	'poecilia_formosa'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/poecilia_formosa/cdna/Poecilia_formosa.PoeFor_5.1.2.cdna.abinitio.fa.gz',
	'polysphondylium_pallidum_pn500'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_amoebozoa1_collection/polysphondylium_pallidum_pn500/cdna/Polysphondylium_pallidum_pn500.PolPal_Dec2009.cdna.all.fa.gz',
	'pongo_abelii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/pongo_abelii/cdna/Pongo_abelii.PPYG2.cdna.abinitio.fa.gz',
	'populus_trichocarpa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/populus_trichocarpa/cdna/Populus_trichocarpa.JGI2.0.cdna.all.fa.gz',
	'postia_placenta_mad_698_r'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/postia_placenta_mad_698_r/cdna/Postia_placenta_mad_698_r.Postia_placenta_V1.0.cdna.all.fa.gz',
	'procavia_capensis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/procavia_capensis/cdna/Procavia_capensis.proCap1.cdna.abinitio.fa.gz',
	'prunus_persica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/prunus_persica/cdna/Prunus_persica.Prupe1_0.cdna.all.fa.gz',
	'pseudocercospora_fijiensis_cirad86'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pseudocercospora_fijiensis_cirad86/cdna/Pseudocercospora_fijiensis_cirad86.Mycfi2.cdna.all.fa.gz',
	'pseudocercospora_musae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudocercospora_musae/cdna/Pseudocercospora_musae.ASM157822v1.cdna.all.fa.gz',
	'pseudogymnoascus_destructans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_destructans/cdna/Pseudogymnoascus_destructans.ASM164126v1.cdna.all.fa.gz',
	'pseudogymnoascus_destructans_20631_21'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pseudogymnoascus_destructans_20631_21/cdna/Pseudogymnoascus_destructans_20631_21.Geom_destructans_V1.cdna.all.fa.gz',
	'pseudogymnoascus_sp_03vt05'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_sp_03vt05/cdna/Pseudogymnoascus_sp_03vt05.ASM166264v1.cdna.all.fa.gz',
	'pseudogymnoascus_sp_05ny08'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_sp_05ny08/cdna/Pseudogymnoascus_sp_05ny08.ASM166260v1.cdna.all.fa.gz',
	'pseudogymnoascus_sp_23342_1_i1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_sp_23342_1_i1/cdna/Pseudogymnoascus_sp_23342_1_i1.ASM166257v1.cdna.all.fa.gz',
	'pseudogymnoascus_sp_24mn13'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_sp_24mn13/cdna/Pseudogymnoascus_sp_24mn13.ASM166259v1.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_103'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_103/cdna/Pseudogymnoascus_sp_vkm_f_103.DG30.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_3557'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pseudogymnoascus_sp_vkm_f_3557/cdna/Pseudogymnoascus_sp_vkm_f_3557.DG3.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_3775'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_3775/cdna/Pseudogymnoascus_sp_vkm_f_3775.DG4.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_3808'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/pseudogymnoascus_sp_vkm_f_3808/cdna/Pseudogymnoascus_sp_vkm_f_3808.DG1.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4246'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4246/cdna/Pseudogymnoascus_sp_vkm_f_4246.DG5.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4281_fw_2241_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4281_fw_2241_/cdna/Pseudogymnoascus_sp_vkm_f_4281_fw_2241_.DG6.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4513_fw_928_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4513_fw_928_/cdna/Pseudogymnoascus_sp_vkm_f_4513_fw_928_.DG7.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4514_fw_929_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4514_fw_929_/cdna/Pseudogymnoascus_sp_vkm_f_4514_fw_929_.DG8.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4515_fw_2607_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4515_fw_2607_/cdna/Pseudogymnoascus_sp_vkm_f_4515_fw_2607_.DG10.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4516_fw_969_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4516_fw_969_/cdna/Pseudogymnoascus_sp_vkm_f_4516_fw_969_.DG11.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4517_fw_2822_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4517_fw_2822_/cdna/Pseudogymnoascus_sp_vkm_f_4517_fw_2822_.DG13.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4518_fw_2643_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4518_fw_2643_/cdna/Pseudogymnoascus_sp_vkm_f_4518_fw_2643_.DG36.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4519_fw_2642_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4519_fw_2642_/cdna/Pseudogymnoascus_sp_vkm_f_4519_fw_2642_.DG38.cdna.all.fa.gz',
	'pseudogymnoascus_sp_vkm_f_4520_fw_2644_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/pseudogymnoascus_sp_vkm_f_4520_fw_2644_/cdna/Pseudogymnoascus_sp_vkm_f_4520_fw_2644_.DG39.cdna.all.fa.gz',
	'pseudogymnoascus_sp_wsf_3629'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_sp_wsf_3629/cdna/Pseudogymnoascus_sp_wsf_3629.ASM166258v1.cdna.all.fa.gz',
	'pseudogymnoascus_verrucosus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pseudogymnoascus_verrucosus/cdna/Pseudogymnoascus_verrucosus.ASM166265v1.cdna.all.fa.gz',
	'pseudoloma_neurophilia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/pseudoloma_neurophilia/cdna/Pseudoloma_neurophilia.ASM143216v1.cdna.all.fa.gz',
	'pseudozyma_hubeiensis_sy62'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/pseudozyma_hubeiensis_sy62/cdna/Pseudozyma_hubeiensis_sy62.ASM40351v1.cdna.all.fa.gz',
	'pteropus_vampyrus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/pteropus_vampyrus/cdna/Pteropus_vampyrus.pteVam1.cdna.abinitio.fa.gz',
	'puccinia_graminis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/puccinia_graminis/cdna/Puccinia_graminis.ASM14992v1.cdna.all.fa.gz',
	'puccinia_graminisug99'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/puccinia_graminisug99/cdna/Puccinia_graminisug99.v1.cdna.all.fa.gz',
	'puccinia_sorghi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/puccinia_sorghi/cdna/Puccinia_sorghi.ASM126337v1.cdna.all.fa.gz',
	'puccinia_striiformis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/puccinia_striiformis/cdna/Puccinia_striiformis.PST-130_1.0.cdna.all.fa.gz',
	'puccinia_striiformis_f_sp_tritici_pst_78'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/puccinia_striiformis_f_sp_tritici_pst_78/cdna/Puccinia_striiformis_f_sp_tritici_pst_78.P_striiformis_V1.cdna.all.fa.gz',
	'puccinia_triticina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/puccinia_triticina/cdna/Puccinia_triticina.ASM15152v1.cdna.all.fa.gz',
	'punctularia_strigosozonata_hhb_11173_ss5'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/punctularia_strigosozonata_hhb_11173_ss5/cdna/Punctularia_strigosozonata_hhb_11173_ss5.Punctularia_strigosozonata_v1.0.cdna.all.fa.gz',
	'purpureocillium_lilacinum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/purpureocillium_lilacinum/cdna/Purpureocillium_lilacinum.ASM165320v1.cdna.all.fa.gz',
	'purpureocillium_lilacinum_gca_001653265'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/purpureocillium_lilacinum_gca_001653265/cdna/Purpureocillium_lilacinum_gca_001653265.ASM165326v1.cdna.all.fa.gz',
	'pyrenochaeta_sp_ds3say3a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pyrenochaeta_sp_ds3say3a/cdna/Pyrenochaeta_sp_ds3say3a.Pyrsp1.cdna.all.fa.gz',
	'pyrenophora_teres'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/pyrenophora_teres/cdna/Pyrenophora_teres.GCA_000166005.1.cdna.all.fa.gz',
	'pyrenophora_triticirepentis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/pyrenophora_triticirepentis/cdna/Pyrenophora_triticirepentis.GCA_000149985.1.cdna.all.fa.gz',
	'pyronema_omphalodes_cbs_100304'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/pyronema_omphalodes_cbs_100304/cdna/Pyronema_omphalodes_cbs_100304.Pcon_v1.cdna.all.fa.gz',
	'pythium_aphanidermatum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_aphanidermatum/cdna/Pythium_aphanidermatum.pag1_scaffolds_v1.cdna.all.fa.gz',
	'pythium_arrhenomanes'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_arrhenomanes/cdna/Pythium_arrhenomanes.par_scaffolds_v1.cdna.all.fa.gz',
	'pythium_irregulare'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_irregulare/cdna/Pythium_irregulare.pir_scaffolds_v1.cdna.all.fa.gz',
	'pythium_iwayamai'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_iwayamai/cdna/Pythium_iwayamai.piw_scaffolds_v1.cdna.all.fa.gz',
	'pythium_ultimum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_ultimum/cdna/Pythium_ultimum.pug.cdna.all.fa.gz',
	'pythium_vexans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/pythium_vexans/cdna/Pythium_vexans.pve_scaffolds_v1.cdna.all.fa.gz',
	'rachicladosporium_antarcticum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/rachicladosporium_antarcticum/cdna/Rachicladosporium_antarcticum.ASM207706v1.cdna.all.fa.gz',
	'rasamsonia_emersonii_cbs_393_64'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/rasamsonia_emersonii_cbs_393_64/cdna/Rasamsonia_emersonii_cbs_393_64.ASM96859v1.cdna.all.fa.gz',
	'rattus_norvegicus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/rattus_norvegicus/cdna/Rattus_norvegicus.Rnor_6.0.cdna.abinitio.fa.gz',
	'reticulomyxa_filosa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_rhizaria1_collection/reticulomyxa_filosa/cdna/Reticulomyxa_filosa.Reti_assembly1.0.cdna.all.fa.gz',
	'rhinocladiella_mackenziei_cbs_650_93'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/rhinocladiella_mackenziei_cbs_650_93/cdna/Rhinocladiella_mackenziei_cbs_650_93.Rhin_mack_CBS_650_93_V1.cdna.all.fa.gz',
	'rhizoctonia_solani'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani/cdna/Rhizoctonia_solani.AG22IIIB.cdna.all.fa.gz',
	'rhizoctonia_solani_123e'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani_123e/cdna/Rhizoctonia_solani_123e.Rhizoctonia_solani_123E_v1.cdna.all.fa.gz',
	'rhizoctonia_solani_ag_1_ia'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani_ag_1_ia/cdna/Rhizoctonia_solani_ag_1_ia.Rhisol_AG1IA_1.0.cdna.all.fa.gz',
	'rhizoctonia_solani_ag_1_ib'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani_ag_1_ib/cdna/Rhizoctonia_solani_ag_1_ib.ASM35025v1.cdna.all.fa.gz',
	'rhizoctonia_solani_ag_3_rhs1ap'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani_ag_3_rhs1ap/cdna/Rhizoctonia_solani_ag_3_rhs1ap.Rhizoctonia_solani_AG-3.cdna.all.fa.gz',
	'rhizoctonia_solani_ag_8_wac10335'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizoctonia_solani_ag_8_wac10335/cdna/Rhizoctonia_solani_ag_8_wac10335.RSAG8-1.V1.cdna.all.fa.gz',
	'rhizophagus_irregularis_daom_181602_gca_000439145'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/rhizophagus_irregularis_daom_181602_gca_000439145/cdna/Rhizophagus_irregularis_daom_181602_gca_000439145.Gloin1.cdna.all.fa.gz',
	'rhizopogon_vesiculosus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizopogon_vesiculosus/cdna/Rhizopogon_vesiculosus.Rves_AM-OR11-056_1.0.cdna.all.fa.gz',
	'rhizopogon_vinicolor_am_or11_026'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhizopogon_vinicolor_am_or11_026/cdna/Rhizopogon_vinicolor_am_or11_026.Rhivi1.cdna.all.fa.gz',
	'rhizopus_delemar_ra_99_880'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/rhizopus_delemar_ra_99_880/cdna/Rhizopus_delemar_ra_99_880.RO3.cdna.all.fa.gz',
	'rhizopus_microsporus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/rhizopus_microsporus/cdna/Rhizopus_microsporus.Rhimi_ATCC11559_1.cdna.all.fa.gz',
	'rhizopus_microsporus_var_microsporus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_mucoromycota1_collection/rhizopus_microsporus_var_microsporus/cdna/Rhizopus_microsporus_var_microsporus.Rhimi_ATCC52814_1.cdna.all.fa.gz',
	'rhodnius_prolixus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/rhodnius_prolixus/cdna/Rhodnius_prolixus.RproC1.cdna.abinitio.fa.gz',
	'rhodotorula_graminis_wp1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhodotorula_graminis_wp1/cdna/Rhodotorula_graminis_wp1.Rhoba1_1.cdna.all.fa.gz',
	'rhodotorula_sp_jg_1b'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhodotorula_sp_jg_1b/cdna/Rhodotorula_sp_jg_1b.Rhosp1.cdna.all.fa.gz',
	'rhodotorula_toruloides'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhodotorula_toruloides/cdna/Rhodotorula_toruloides.IFO0880_HGAP3_v1.cdna.all.fa.gz',
	'rhodotorula_toruloides_atcc_204091'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhodotorula_toruloides_atcc_204091/cdna/Rhodotorula_toruloides_atcc_204091.R.glutinis2.cdna.all.fa.gz',
	'rhodotorula_toruloides_np11'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/rhodotorula_toruloides_np11/cdna/Rhodotorula_toruloides_np11.RHOziaDV1.0.cdna.all.fa.gz',
	'rhynchosporium_agropyri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/rhynchosporium_agropyri/cdna/Rhynchosporium_agropyri.version_1.cdna.all.fa.gz',
	'rhynchosporium_commune'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/rhynchosporium_commune/cdna/Rhynchosporium_commune.version_1.cdna.all.fa.gz',
	'rhynchosporium_secalis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/rhynchosporium_secalis/cdna/Rhynchosporium_secalis.version_1.cdna.all.fa.gz',
	'rozella_allomycis_csf55'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_rozellomycota1_collection/rozella_allomycis_csf55/cdna/Rozella_allomycis_csf55.Rozella_k41_t100.cdna.all.fa.gz',
	'saccharomyces_arboricola_h_6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_arboricola_h_6/cdna/Saccharomyces_arboricola_h_6.SacArb1.0.cdna.all.fa.gz',
	'saccharomyces_cerevisiae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/saccharomyces_cerevisiae/cdna/Saccharomyces_cerevisiae.R64-1-1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_awri796'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_awri796/cdna/Saccharomyces_cerevisiae_awri796.ScAWRI796_v01.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_cen_pk113_7d'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_cen_pk113_7d/cdna/Saccharomyces_cerevisiae_cen_pk113_7d.ASM26988v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_ec1118'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_ec1118/cdna/Saccharomyces_cerevisiae_ec1118.ASM21897v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_fostersb'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_fostersb/cdna/Saccharomyces_cerevisiae_fostersb.ScFostersB_v01.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_fosterso'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_fosterso/cdna/Saccharomyces_cerevisiae_fosterso.ScFostersO_v01.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_gca_000091065'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_gca_000091065/cdna/Saccharomyces_cerevisiae_gca_000091065.ASM9106v2.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_gca_001634645'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_gca_001634645/cdna/Saccharomyces_cerevisiae_gca_001634645.GLBRCY22-3.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_gca_001983315'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_gca_001983315/cdna/Saccharomyces_cerevisiae_gca_001983315.ASM198331v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_kyokai_no_7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_kyokai_no_7/cdna/Saccharomyces_cerevisiae_kyokai_no_7.K7_1.0.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_lalvin_qa23'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_lalvin_qa23/cdna/Saccharomyces_cerevisiae_lalvin_qa23.ScQA23_v01.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_p283'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_p283/cdna/Saccharomyces_cerevisiae_p283.P283.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_p301'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_p301/cdna/Saccharomyces_cerevisiae_p301.p301.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_r008'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_r008/cdna/Saccharomyces_cerevisiae_r008.R008.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_r103'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_r103/cdna/Saccharomyces_cerevisiae_r103.R103.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_rm11_1a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_rm11_1a/cdna/Saccharomyces_cerevisiae_rm11_1a.ASM14936v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_vin13'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_vin13/cdna/Saccharomyces_cerevisiae_vin13.ScVIN13_v01.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_vl3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_vl3/cdna/Saccharomyces_cerevisiae_vl3.ScVL3_v01.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_x_saccharomyces_kudriavzevii_vin7'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_x_saccharomyces_kudriavzevii_vin7/cdna/Saccharomyces_cerevisiae_x_saccharomyces_kudriavzevii_vin7.ASM32610v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1078'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1078/cdna/Saccharomyces_cerevisiae_yjm1078.Sc_YJM1078_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1083'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1083/cdna/Saccharomyces_cerevisiae_yjm1083.Sc_YJM1083_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1129'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1129/cdna/Saccharomyces_cerevisiae_yjm1129.Sc_YJM1129_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1133'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1133/cdna/Saccharomyces_cerevisiae_yjm1133.Sc_YJM1133_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1190'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1190/cdna/Saccharomyces_cerevisiae_yjm1190.Sc_YJM1190_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1199'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1199/cdna/Saccharomyces_cerevisiae_yjm1199.Sc_YJM1199_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1202'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1202/cdna/Saccharomyces_cerevisiae_yjm1202.Sc_YJM1202_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1208'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1208/cdna/Saccharomyces_cerevisiae_yjm1208.Sc_YJM1208_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1242'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1242/cdna/Saccharomyces_cerevisiae_yjm1242.Sc_YJM1242_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1244'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1244/cdna/Saccharomyces_cerevisiae_yjm1244.Sc_YJM1244_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1248'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1248/cdna/Saccharomyces_cerevisiae_yjm1248.Sc_YJM1248_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1250'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1250/cdna/Saccharomyces_cerevisiae_yjm1250.Sc_YJM1250_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1252'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1252/cdna/Saccharomyces_cerevisiae_yjm1252.Sc_YJM1252_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1273'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1273/cdna/Saccharomyces_cerevisiae_yjm1273.Sc_YJM1273_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1304'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1304/cdna/Saccharomyces_cerevisiae_yjm1304.Sc_YJM1304_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1307'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1307/cdna/Saccharomyces_cerevisiae_yjm1307.Sc_YJM1307_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1311'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1311/cdna/Saccharomyces_cerevisiae_yjm1311.Sc_YJM1311_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1326'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1326/cdna/Saccharomyces_cerevisiae_yjm1326.Sc_YJM1326_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1332'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1332/cdna/Saccharomyces_cerevisiae_yjm1332.Sc_YJM1332_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1336'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1336/cdna/Saccharomyces_cerevisiae_yjm1336.Sc_YJM1336_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1338'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1338/cdna/Saccharomyces_cerevisiae_yjm1338.Sc_YJM1338_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1341'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1341/cdna/Saccharomyces_cerevisiae_yjm1341.Sc_YJM1341_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1342'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1342/cdna/Saccharomyces_cerevisiae_yjm1342.Sc_YJM1342_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1355'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1355/cdna/Saccharomyces_cerevisiae_yjm1355.Sc_YJM1355_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1356'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1356/cdna/Saccharomyces_cerevisiae_yjm1356.Sc_YJM1356_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1381'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1381/cdna/Saccharomyces_cerevisiae_yjm1381.Sc_YJM1381_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1383'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1383/cdna/Saccharomyces_cerevisiae_yjm1383.Sc_YJM1383_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1385'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1385/cdna/Saccharomyces_cerevisiae_yjm1385.Sc_YJM1385_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1386'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1386/cdna/Saccharomyces_cerevisiae_yjm1386.Sc_YJM1386_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1387'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1387/cdna/Saccharomyces_cerevisiae_yjm1387.Sc_YJM1387_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1388'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1388/cdna/Saccharomyces_cerevisiae_yjm1388.Sc_YJM1388_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1389'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1389/cdna/Saccharomyces_cerevisiae_yjm1389.Sc_YJM1389_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1399'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1399/cdna/Saccharomyces_cerevisiae_yjm1399.Sc_YJM1399_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1400'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1400/cdna/Saccharomyces_cerevisiae_yjm1400.Sc_YJM1400_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1401'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1401/cdna/Saccharomyces_cerevisiae_yjm1401.Sc_YJM1401_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1402'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1402/cdna/Saccharomyces_cerevisiae_yjm1402.Sc_YJM1402_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1415'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1415/cdna/Saccharomyces_cerevisiae_yjm1415.Sc_YJM1415_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1417'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1417/cdna/Saccharomyces_cerevisiae_yjm1417.Sc_YJM1417_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1418'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1418/cdna/Saccharomyces_cerevisiae_yjm1418.Sc_YJM1418_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1419'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1419/cdna/Saccharomyces_cerevisiae_yjm1419.Sc_YJM1419_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1433'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1433/cdna/Saccharomyces_cerevisiae_yjm1433.Sc_YJM1433_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1434'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1434/cdna/Saccharomyces_cerevisiae_yjm1434.Sc_YJM1434_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1439'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1439/cdna/Saccharomyces_cerevisiae_yjm1439.Sc_YJM1439_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1443'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1443/cdna/Saccharomyces_cerevisiae_yjm1443.Sc_YJM1443_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1444'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1444/cdna/Saccharomyces_cerevisiae_yjm1444.Sc_YJM1444_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1447'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1447/cdna/Saccharomyces_cerevisiae_yjm1447.Sc_YJM1447_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1450'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1450/cdna/Saccharomyces_cerevisiae_yjm1450.Sc_YJM1450_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1460'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1460/cdna/Saccharomyces_cerevisiae_yjm1460.Sc_YJM1460_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1463'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1463/cdna/Saccharomyces_cerevisiae_yjm1463.Sc_YJM1463_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1477'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1477/cdna/Saccharomyces_cerevisiae_yjm1477.Sc_YJM1477_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1478'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1478/cdna/Saccharomyces_cerevisiae_yjm1478.Sc_YJM1478_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1479'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1479/cdna/Saccharomyces_cerevisiae_yjm1479.Sc_YJM1479_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1526'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1526/cdna/Saccharomyces_cerevisiae_yjm1526.Sc_YJM1526_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1527'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1527/cdna/Saccharomyces_cerevisiae_yjm1527.Sc_YJM1527_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1549'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1549/cdna/Saccharomyces_cerevisiae_yjm1549.Sc_YJM1549_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1573'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1573/cdna/Saccharomyces_cerevisiae_yjm1573.Sc_YJM1573_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1574'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1574/cdna/Saccharomyces_cerevisiae_yjm1574.Sc_YJM1574_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1592'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm1592/cdna/Saccharomyces_cerevisiae_yjm1592.Sc_YJM1592_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm1615'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm1615/cdna/Saccharomyces_cerevisiae_yjm1615.Sc_YJM1615_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm189'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm189/cdna/Saccharomyces_cerevisiae_yjm189.Sc_YJM189_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm193'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm193/cdna/Saccharomyces_cerevisiae_yjm193.Sc_YJM193_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm195'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm195/cdna/Saccharomyces_cerevisiae_yjm195.Sc_YJM195_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm244'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm244/cdna/Saccharomyces_cerevisiae_yjm244.Sc_YJM244_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm248'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm248/cdna/Saccharomyces_cerevisiae_yjm248.Sc_YJM248_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm270'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm270/cdna/Saccharomyces_cerevisiae_yjm270.Sc_YJM270_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm271'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm271/cdna/Saccharomyces_cerevisiae_yjm271.Sc_YJM271_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm320'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm320/cdna/Saccharomyces_cerevisiae_yjm320.Sc_YJM320_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm326'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm326/cdna/Saccharomyces_cerevisiae_yjm326.Sc_YJM326_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm428'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm428/cdna/Saccharomyces_cerevisiae_yjm428.Sc_YJM428_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm450'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm450/cdna/Saccharomyces_cerevisiae_yjm450.Sc_YJM450_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm451'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm451/cdna/Saccharomyces_cerevisiae_yjm451.Sc_YJM451_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm453'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm453/cdna/Saccharomyces_cerevisiae_yjm453.Sc_YJM453_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm456'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm456/cdna/Saccharomyces_cerevisiae_yjm456.Sc_YJM456_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm470'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm470/cdna/Saccharomyces_cerevisiae_yjm470.Sc_YJM470_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm541'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm541/cdna/Saccharomyces_cerevisiae_yjm541.Sc_YJM541_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm554'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm554/cdna/Saccharomyces_cerevisiae_yjm554.Sc_YJM554_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm555'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm555/cdna/Saccharomyces_cerevisiae_yjm555.Sc_YJM555_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm627'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm627/cdna/Saccharomyces_cerevisiae_yjm627.Sc_YJM627_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm681'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm681/cdna/Saccharomyces_cerevisiae_yjm681.Sc_YJM681_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm682'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm682/cdna/Saccharomyces_cerevisiae_yjm682.Sc_YJM682_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm683'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm683/cdna/Saccharomyces_cerevisiae_yjm683.Sc_YJM683_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm689'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm689/cdna/Saccharomyces_cerevisiae_yjm689.Sc_YJM689_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm693'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm693/cdna/Saccharomyces_cerevisiae_yjm693.Sc_YJM693_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm789'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_yjm789/cdna/Saccharomyces_cerevisiae_yjm789.ASM18143v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm969'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_cerevisiae_yjm969/cdna/Saccharomyces_cerevisiae_yjm969.Sc_YJM969_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm972'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm972/cdna/Saccharomyces_cerevisiae_yjm972.Sc_YJM972_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm975'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm975/cdna/Saccharomyces_cerevisiae_yjm975.Sc_YJM975_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm978'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm978/cdna/Saccharomyces_cerevisiae_yjm978.Sc_YJM978_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm981'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm981/cdna/Saccharomyces_cerevisiae_yjm981.Sc_YJM981_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm984'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm984/cdna/Saccharomyces_cerevisiae_yjm984.Sc_YJM984_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm987'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm987/cdna/Saccharomyces_cerevisiae_yjm987.Sc_YJM987_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm990'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm990/cdna/Saccharomyces_cerevisiae_yjm990.Sc_YJM990_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm993'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_cerevisiae_yjm993/cdna/Saccharomyces_cerevisiae_yjm993.Sc_YJM993_v1.cdna.all.fa.gz',
	'saccharomyces_cerevisiae_yjm996'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saccharomyces_cerevisiae_yjm996/cdna/Saccharomyces_cerevisiae_yjm996.Sc_YJM996_v1.cdna.all.fa.gz',
	'saccharomyces_eubayanus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_eubayanus/cdna/Saccharomyces_eubayanus.SEUB3.0.cdna.all.fa.gz',
	'saccharomyces_kudriavzevii_ifo_1802'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomyces_kudriavzevii_ifo_1802/cdna/Saccharomyces_kudriavzevii_ifo_1802.Saccharomyces_kudriavzevii_strain_IFO1802_v1.0.cdna.all.fa.gz',
	'saccharomyces_sp_boulardii_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_sp_boulardii_/cdna/Saccharomyces_sp_boulardii_.ASM129837v2.cdna.all.fa.gz',
	'saccharomyces_sp_boulardii__gca_001413975'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saccharomyces_sp_boulardii__gca_001413975/cdna/Saccharomyces_sp_boulardii__gca_001413975.ASM141397v1.cdna.all.fa.gz',
	'saccharomycetaceae_sp_ashbya_aceri_'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/saccharomycetaceae_sp_ashbya_aceri_/cdna/Saccharomycetaceae_sp_ashbya_aceri_.ASM41222v2.cdna.all.fa.gz',
	'saitoella_complicata_nrrl_y_17804'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/saitoella_complicata_nrrl_y_17804/cdna/Saitoella_complicata_nrrl_y_17804.Scomplicata_3.0.cdna.all.fa.gz',
	'saitoella_complicata_nrrl_y_17804_gca_001661265'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/saitoella_complicata_nrrl_y_17804_gca_001661265/cdna/Saitoella_complicata_nrrl_y_17804_gca_001661265.Saico1.cdna.all.fa.gz',
	'salpingoeca_rosetta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_choanoflagellida1_collection/salpingoeca_rosetta/cdna/Salpingoeca_rosetta.Proterospongia_sp_ATCC50818.cdna.all.fa.gz',
	'saprolegnia_diclina_vs20'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/saprolegnia_diclina_vs20/cdna/Saprolegnia_diclina_vs20.Sap_diclina_VS20_V1.cdna.all.fa.gz',
	'saprolegnia_parasitica_cbs_223_65'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/saprolegnia_parasitica_cbs_223_65/cdna/Saprolegnia_parasitica_cbs_223_65.ASM15154v2.cdna.all.fa.gz',
	'sarcophilus_harrisii'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/sarcophilus_harrisii/cdna/Sarcophilus_harrisii.DEVIL7.0.cdna.abinitio.fa.gz',
	'sarcoptes_scabiei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/sarcoptes_scabiei/cdna/Sarcoptes_scabiei.SscaA1.cdna.all.fa.gz',
	'scedosporium_apiospermum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/scedosporium_apiospermum/cdna/Scedosporium_apiospermum.ScApio1.0.cdna.all.fa.gz',
	'scheffersomyces_stipitis_cbs_6054'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/scheffersomyces_stipitis_cbs_6054/cdna/Scheffersomyces_stipitis_cbs_6054.ASM20916v1.cdna.all.fa.gz',
	'schistosoma_mansoni'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/schistosoma_mansoni/cdna/Schistosoma_mansoni.ASM23792v2.cdna.all.fa.gz',
	'schizophyllum_commune_h4_8'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/schizophyllum_commune_h4_8/cdna/Schizophyllum_commune_h4_8.v1.0.cdna.all.fa.gz',
	'schizopora_paradoxa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/schizopora_paradoxa/cdna/Schizopora_paradoxa.Schpa1.cdna.all.fa.gz',
	'schizosaccharomyces_cryophilus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/schizosaccharomyces_cryophilus/cdna/Schizosaccharomyces_cryophilus.GCA_000004155.2.cdna.all.fa.gz',
	'schizosaccharomyces_japonicus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/schizosaccharomyces_japonicus/cdna/Schizosaccharomyces_japonicus.GCA_000149845.2.cdna.all.fa.gz',
	'schizosaccharomyces_octosporus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/schizosaccharomyces_octosporus/cdna/Schizosaccharomyces_octosporus.GCA_000150505.2.cdna.all.fa.gz',
	'schizosaccharomyces_pombe'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/schizosaccharomyces_pombe/cdna/Schizosaccharomyces_pombe.ASM294v2.cdna.all.fa.gz',
	'scleroderma_citrinum_foug_a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/scleroderma_citrinum_foug_a/cdna/Scleroderma_citrinum_foug_a.Scleroderma_citrinum_Foug_A_v1.0.cdna.all.fa.gz',
	'sclerotinia_borealis_f_4128'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/sclerotinia_borealis_f_4128/cdna/Sclerotinia_borealis_f_4128.SBOR_1.cdna.all.fa.gz',
	'sclerotinia_sclerotiorum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/sclerotinia_sclerotiorum/cdna/Sclerotinia_sclerotiorum.ASM14694v1.cdna.all.fa.gz',
	'sclerotinia_sclerotiorum_1980_uf_70'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/sclerotinia_sclerotiorum_1980_uf_70/cdna/Sclerotinia_sclerotiorum_1980_uf_70.ASM185786v1.cdna.all.fa.gz',
	'selaginella_moellendorffii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/selaginella_moellendorffii/cdna/Selaginella_moellendorffii.v1.0.cdna.all.fa.gz',
	'serendipita_indica_dsm_11827'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/serendipita_indica_dsm_11827/cdna/Serendipita_indica_dsm_11827.ASM31354v1.cdna.all.fa.gz',
	'serendipita_vermifera_maff_305830'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/serendipita_vermifera_maff_305830/cdna/Serendipita_vermifera_maff_305830.Sebacina_vermifera_MAFF_305830_v1.0.cdna.all.fa.gz',
	'serpula_lacrymans_var_lacrymans_s7_3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/serpula_lacrymans_var_lacrymans_s7_3/cdna/Serpula_lacrymans_var_lacrymans_s7_3.v1.0.cdna.all.fa.gz',
	'serpula_lacrymans_var_lacrymans_s7_9'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/serpula_lacrymans_var_lacrymans_s7_9/cdna/Serpula_lacrymans_var_lacrymans_s7_9.v1.0.cdna.all.fa.gz',
	'setaria_italica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/setaria_italica/cdna/Setaria_italica.JGIv2.0.cdna.abinitio.fa.gz',
	'setosphaeria_turcica_et28a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/setosphaeria_turcica_et28a/cdna/Setosphaeria_turcica_et28a.Setospaeria_trucica_Et28A_v1.0.cdna.all.fa.gz',
	'sistotremastrum_niveocremeum_hhb9708'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/sistotremastrum_niveocremeum_hhb9708/cdna/Sistotremastrum_niveocremeum_hhb9708.Sisni1.cdna.all.fa.gz',
	'sistotremastrum_suecicum_hhb10207_ss_3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/sistotremastrum_suecicum_hhb10207_ss_3/cdna/Sistotremastrum_suecicum_hhb10207_ss_3.Sissu1.cdna.all.fa.gz',
	'solanum_lycopersicum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/solanum_lycopersicum/cdna/Solanum_lycopersicum.SL2.50.cdna.all.fa.gz',
	'solanum_tuberosum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/solanum_tuberosum/cdna/Solanum_tuberosum.SolTub_3.0.cdna.all.fa.gz',
	'solenopsis_invicta'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/solenopsis_invicta/cdna/Solenopsis_invicta.Si_gnG.cdna.all.fa.gz',
	'sordaria_macrospora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/sordaria_macrospora/cdna/Sordaria_macrospora.ASM18280v2.cdna.all.fa.gz',
	'sorex_araneus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/sorex_araneus/cdna/Sorex_araneus.COMMON_SHREW1.cdna.abinitio.fa.gz',
	'sorghum_bicolor'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/sorghum_bicolor/cdna/Sorghum_bicolor.Sorghum_bicolor_v2.cdna.all.fa.gz',
	'spathaspora_passalidarum_nrrl_y_27907'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/spathaspora_passalidarum_nrrl_y_27907/cdna/Spathaspora_passalidarum_nrrl_y_27907.Spathaspora_passalidarum_v2.0.cdna.all.fa.gz',
	'sphaerobolus_stellatus_ss14'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/sphaerobolus_stellatus_ss14/cdna/Sphaerobolus_stellatus_ss14.Sphst1.cdna.all.fa.gz',
	'sphaeroforma_arctica_jp610'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_ichthyosporea1_collection/sphaeroforma_arctica_jp610/cdna/Sphaeroforma_arctica_jp610.Spha_arctica_JP610_V1.cdna.all.fa.gz',
	'sphaerulina_musiva_so2202'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/sphaerulina_musiva_so2202/cdna/Sphaerulina_musiva_so2202.Septoria_musiva_SO2202_v1.0.cdna.all.fa.gz',
	'spironucleus_salmonicida'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_fornicata1_collection/spironucleus_salmonicida/cdna/Spironucleus_salmonicida.SSK3.0.cdna.all.fa.gz',
	'spizellomyces_punctatus_daom_br117'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_chytridiomycota1_collection/spizellomyces_punctatus_daom_br117/cdna/Spizellomyces_punctatus_daom_br117.S_punctatus_V1.cdna.all.fa.gz',
	'sporidiobolus_salmonicolor'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/sporidiobolus_salmonicolor/cdna/Sporidiobolus_salmonicolor.SPOSA68321A01.cdna.all.fa.gz',
	'sporisorium_reilianum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/sporisorium_reilianum/cdna/Sporisorium_reilianum.GCA_000230245.1.cdna.all.fa.gz',
	'sporisorium_scitamineum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/sporisorium_scitamineum/cdna/Sporisorium_scitamineum.Sporisorium_scitamineum.cdna.all.fa.gz',
	'sporothrix_brasiliensis_5110'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/sporothrix_brasiliensis_5110/cdna/Sporothrix_brasiliensis_5110.S_brasiliensis_5110_v1.cdna.all.fa.gz',
	'sporothrix_insectorum_rcef_264'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/sporothrix_insectorum_rcef_264/cdna/Sporothrix_insectorum_rcef_264.SPI_1.0.cdna.all.fa.gz',
	'sporothrix_schenckii_1099_18'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/sporothrix_schenckii_1099_18/cdna/Sporothrix_schenckii_1099_18.S_schenckii_v1.cdna.all.fa.gz',
	'sporothrix_schenckii_atcc_58251'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/sporothrix_schenckii_atcc_58251/cdna/Sporothrix_schenckii_atcc_58251.Spor_sche_ATCC58251_V1.cdna.all.fa.gz',
	'spraguea_lophii_42_110'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/spraguea_lophii_42_110/cdna/Spraguea_lophii_42_110.Sprlop1.0.cdna.all.fa.gz',
	'stachybotrys_chartarum_ibt_40288'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/stachybotrys_chartarum_ibt_40288/cdna/Stachybotrys_chartarum_ibt_40288.S40288v1.cdna.all.fa.gz',
	'stachybotrys_chartarum_ibt_40293'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/stachybotrys_chartarum_ibt_40293/cdna/Stachybotrys_chartarum_ibt_40293.S40293v1.cdna.all.fa.gz',
	'stachybotrys_chartarum_ibt_7711'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/stachybotrys_chartarum_ibt_7711/cdna/Stachybotrys_chartarum_ibt_7711.S7711v1.cdna.all.fa.gz',
	'stachybotrys_chlorohalonata_ibt_40285'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/stachybotrys_chlorohalonata_ibt_40285/cdna/Stachybotrys_chlorohalonata_ibt_40285.S40285v1.cdna.all.fa.gz',
	'stagonospora_sp_src1lsm3a'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/stagonospora_sp_src1lsm3a/cdna/Stagonospora_sp_src1lsm3a.Stasp1.cdna.all.fa.gz',
	'stegodyphus_mimosarum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/stegodyphus_mimosarum/cdna/Stegodyphus_mimosarum.Stegodyphus_mimosarum_v1.cdna.all.fa.gz',
	'stemphylium_lycopersici'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/stemphylium_lycopersici/cdna/Stemphylium_lycopersici.ASM119154v1.cdna.all.fa.gz',
	'stereum_hirsutum_fp_91666_ss1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/stereum_hirsutum_fp_91666_ss1/cdna/Stereum_hirsutum_fp_91666_ss1.Stehi1.cdna.all.fa.gz',
	'strigamia_maritima'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/strigamia_maritima/cdna/Strigamia_maritima.Smar1.cdna.all.fa.gz',
	'strigomonas_culicis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/strigomonas_culicis/cdna/Strigomonas_culicis.Strigomonas_culicis_Genome.cdna.all.fa.gz',
	'strongylocentrotus_purpuratus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/strongylocentrotus_purpuratus/cdna/Strongylocentrotus_purpuratus.Spur_3.1.cdna.abinitio.fa.gz',
	'sugiyamaella_lignohabitans'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/sugiyamaella_lignohabitans/cdna/Sugiyamaella_lignohabitans.ASM164002v2.cdna.all.fa.gz',
	'suillus_luteus_uh_slu_lm8_n1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/suillus_luteus_uh_slu_lm8_n1/cdna/Suillus_luteus_uh_slu_lm8_n1.Suilu1.cdna.all.fa.gz',
	'sus_scrofa'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/sus_scrofa/cdna/Sus_scrofa.Sscrofa11.1.cdna.abinitio.fa.gz',
	'taeniopygia_guttata'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/taeniopygia_guttata/cdna/Taeniopygia_guttata.taeGut3.2.4.cdna.abinitio.fa.gz',
	'takifugu_rubripes'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/takifugu_rubripes/cdna/Takifugu_rubripes.FUGU4.cdna.abinitio.fa.gz',
	'talaromyces_cellulolyticus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/talaromyces_cellulolyticus/cdna/Talaromyces_cellulolyticus.TcelY94_1.0.cdna.all.fa.gz',
	'talaromyces_islandicus'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/talaromyces_islandicus/cdna/Talaromyces_islandicus.PIS.cdna.all.fa.gz',
	'talaromyces_marneffei_atcc_18224'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/talaromyces_marneffei_atcc_18224/cdna/Talaromyces_marneffei_atcc_18224.JCVI-PMFA1-2.0.cdna.all.fa.gz',
	'talaromyces_marneffei_pm1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/talaromyces_marneffei_pm1/cdna/Talaromyces_marneffei_pm1.ASM75011v1.cdna.all.fa.gz',
	'talaromyces_stipitatus_atcc_10500'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/talaromyces_stipitatus_atcc_10500/cdna/Talaromyces_stipitatus_atcc_10500.JCVI-TSTA1-3.0.cdna.all.fa.gz',
	'termitomyces_sp_j132'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/termitomyces_sp_j132/cdna/Termitomyces_sp_j132.TerJ1321.0.cdna.all.fa.gz',
	'tetrahymena_thermophila'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/tetrahymena_thermophila/cdna/Tetrahymena_thermophila.JCVI-TTA1-2.2.cdna.all.fa.gz',
	'tetranychus_urticae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/tetranychus_urticae/cdna/Tetranychus_urticae.ASM23943v1.cdna.all.fa.gz',
	'tetraodon_nigroviridis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/tetraodon_nigroviridis/cdna/Tetraodon_nigroviridis.TETRAODON8.cdna.abinitio.fa.gz',
	'tetrapisispora_blattae_cbs_6284'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/tetrapisispora_blattae_cbs_6284/cdna/Tetrapisispora_blattae_cbs_6284.ASM31591v1.cdna.all.fa.gz',
	'tetrapisispora_phaffii_cbs_4417'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/tetrapisispora_phaffii_cbs_4417/cdna/Tetrapisispora_phaffii_cbs_4417.ASM23690v1.cdna.all.fa.gz',
	'thalassiosira_oceanica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/thalassiosira_oceanica/cdna/Thalassiosira_oceanica.ThaOc_1.0.cdna.all.fa.gz',
	'thalassiosira_oceanica_ccmp1005'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_stramenopiles1_collection/thalassiosira_oceanica_ccmp1005/cdna/Thalassiosira_oceanica_ccmp1005.ASM19663v1.cdna.all.fa.gz',
	'thalassiosira_pseudonana'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/thalassiosira_pseudonana/cdna/Thalassiosira_pseudonana.ASM14940v2.cdna.all.fa.gz',
	'thecamonas_trahens_atcc_50062'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_apusozoa1_collection/thecamonas_trahens_atcc_50062/cdna/Thecamonas_trahens_atcc_50062.TheTra_May2010.cdna.all.fa.gz',
	'theileria_annulata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/theileria_annulata/cdna/Theileria_annulata.ASM322v1.cdna.all.fa.gz',
	'theileria_equi_strain_wa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/theileria_equi_strain_wa/cdna/Theileria_equi_strain_wa.JCVI-bewag-v1.1.cdna.all.fa.gz',
	'theileria_orientalis_strain_shintoku'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/theileria_orientalis_strain_shintoku/cdna/Theileria_orientalis_strain_shintoku.ASM74089v1.cdna.all.fa.gz',
	'theileria_parva'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/theileria_parva/cdna/Theileria_parva.ASM16536v1.cdna.all.fa.gz',
	'thelohanellus_kitauei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/thelohanellus_kitauei/cdna/Thelohanellus_kitauei.ASM82789v1.cdna.all.fa.gz',
	'theobroma_cacao'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/theobroma_cacao/cdna/Theobroma_cacao.Theobroma_cacao_20110822.cdna.all.fa.gz',
	'thermothelomyces_thermophila_atcc_42464'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/thermothelomyces_thermophila_atcc_42464/cdna/Thermothelomyces_thermophila_atcc_42464.ASM22609v1.cdna.all.fa.gz',
	'thielavia_terrestris_nrrl_8126'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/thielavia_terrestris_nrrl_8126/cdna/Thielavia_terrestris_nrrl_8126.ASM22611v1.cdna.all.fa.gz',
	'thielaviopsis_punctulata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/thielaviopsis_punctulata/cdna/Thielaviopsis_punctulata.ASM96861v1.cdna.all.fa.gz',
	'tilletia_caries'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tilletia_caries/cdna/Tilletia_caries.ASM164500v1.cdna.all.fa.gz',
	'tilletia_controversa'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tilletia_controversa/cdna/Tilletia_controversa.ASM164504v1.cdna.all.fa.gz',
	'tilletia_indica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tilletia_indica/cdna/Tilletia_indica.ASM164501v1.cdna.all.fa.gz',
	'tilletia_walkeri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tilletia_walkeri/cdna/Tilletia_walkeri.ASM164505v1.cdna.all.fa.gz',
	'tilletiaria_anomala_ubc_951'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tilletiaria_anomala_ubc_951/cdna/Tilletiaria_anomala_ubc_951.Tilletiaria_anomala_UBC_951_v1.0.cdna.all.fa.gz',
	'tolypocladium_ophioglossoides_cbs_100239'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/tolypocladium_ophioglossoides_cbs_100239/cdna/Tolypocladium_ophioglossoides_cbs_100239.Tophv1.0.cdna.all.fa.gz',
	'torrubiella_hemipterigena'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/torrubiella_hemipterigena/cdna/Torrubiella_hemipterigena.Allpaths-LG.cdna.all.fa.gz',
	'tortispora_caseinolytica_nrrl_y_17796'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/tortispora_caseinolytica_nrrl_y_17796/cdna/Tortispora_caseinolytica_nrrl_y_17796.Canca1.cdna.all.fa.gz',
	'torulaspora_delbrueckii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/torulaspora_delbrueckii/cdna/Torulaspora_delbrueckii.ASM24337v1.cdna.all.fa.gz',
	'toxoplasma_gondii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/toxoplasma_gondii/cdna/Toxoplasma_gondii.ToxoDB-7.1.cdna.all.fa.gz',
	'toxoplasma_gondii_ari'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_ari/cdna/Toxoplasma_gondii_ari.TGARI_v2.cdna.all.fa.gz',
	'toxoplasma_gondii_fou'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_fou/cdna/Toxoplasma_gondii_fou.TGFOU1v02.cdna.all.fa.gz',
	'toxoplasma_gondii_gab2_2007_gal_dom2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_gab2_2007_gal_dom2/cdna/Toxoplasma_gondii_gab2_2007_gal_dom2.TGGABGALDOM2_v2.1.cdna.all.fa.gz',
	'toxoplasma_gondii_gt1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_gt1/cdna/Toxoplasma_gondii_gt1.TGGT1.cdna.all.fa.gz',
	'toxoplasma_gondii_mas'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_mas/cdna/Toxoplasma_gondii_mas.TGMAS1_v2.cdna.all.fa.gz',
	'toxoplasma_gondii_p89'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_p89/cdna/Toxoplasma_gondii_p89.TGP89A_v02.cdna.all.fa.gz',
	'toxoplasma_gondii_rub'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_rub/cdna/Toxoplasma_gondii_rub.TGRUB_v2.cdna.all.fa.gz',
	'toxoplasma_gondii_tgcatprc2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_tgcatprc2/cdna/Toxoplasma_gondii_tgcatprc2.TGCATPRC2_v2.cdna.all.fa.gz',
	'toxoplasma_gondii_vand'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_vand/cdna/Toxoplasma_gondii_vand.TGVAND_v2.cdna.all.fa.gz',
	'toxoplasma_gondii_veg'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/toxoplasma_gondii_veg/cdna/Toxoplasma_gondii_veg.TGVEG.cdna.all.fa.gz',
	'trachipleistophora_hominis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/trachipleistophora_hominis/cdna/Trachipleistophora_hominis.ASM31613v1.cdna.all.fa.gz',
	'trametes_cinnabarina'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/trametes_cinnabarina/cdna/Trametes_cinnabarina.BN946.cdna.all.fa.gz',
	'trametes_pubescens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/trametes_pubescens/cdna/Trametes_pubescens.ASM189594v1.cdna.all.fa.gz',
	'trametes_versicolor_fp_101664_ss1'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/trametes_versicolor_fp_101664_ss1/cdna/Trametes_versicolor_fp_101664_ss1.Trametes_versicolor_v1.0.cdna.all.fa.gz',
	'tremella_mesenterica_dsm_1558'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tremella_mesenterica_dsm_1558/cdna/Tremella_mesenterica_dsm_1558.Treme1.cdna.all.fa.gz',
	'tribolium_castaneum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/tribolium_castaneum/cdna/Tribolium_castaneum.Tcas5.2.cdna.all.fa.gz',
	'trichoderma_atroviride_imi_206040'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichoderma_atroviride_imi_206040/cdna/Trichoderma_atroviride_imi_206040.TRIAT_v2.0.cdna.all.fa.gz',
	'trichoderma_gamsii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/trichoderma_gamsii/cdna/Trichoderma_gamsii.ASM148177v1.cdna.all.fa.gz',
	'trichoderma_guizhouense'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/trichoderma_guizhouense/cdna/Trichoderma_guizhouense.ASM202278v1.cdna.all.fa.gz',
	'trichoderma_harzianum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/trichoderma_harzianum/cdna/Trichoderma_harzianum.ASM98886v1.cdna.all.fa.gz',
	'trichoderma_reesei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/trichoderma_reesei/cdna/Trichoderma_reesei.GCA_000167675.2.cdna.all.fa.gz',
	'trichoderma_reesei_rut_c_30'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichoderma_reesei_rut_c_30/cdna/Trichoderma_reesei_rut_c_30.TrireRUTC30_1.cdna.all.fa.gz',
	'trichoderma_virens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/trichoderma_virens/cdna/Trichoderma_virens.ASM17099v1.cdna.all.fa.gz',
	'trichomonas_vaginalis_g3'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_parabasalia1_collection/trichomonas_vaginalis_g3/cdna/Trichomonas_vaginalis_g3.ASM282v1.cdna.all.fa.gz',
	'trichophyton_benhamiae_cbs_112371'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_benhamiae_cbs_112371/cdna/Trichophyton_benhamiae_cbs_112371.ASM15112v2.cdna.all.fa.gz',
	'trichophyton_equinum_cbs_127_97'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_equinum_cbs_127_97/cdna/Trichophyton_equinum_cbs_127_97.ASM15117v1.cdna.all.fa.gz',
	'trichophyton_interdigitale_h6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_interdigitale_h6/cdna/Trichophyton_interdigitale_h6.Tric_rubr_H6_V2.cdna.all.fa.gz',
	'trichophyton_interdigitale_mr816'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_interdigitale_mr816/cdna/Trichophyton_interdigitale_mr816.Tric_inte_MR816_V1.cdna.all.fa.gz',
	'trichophyton_rubrum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/trichophyton_rubrum/cdna/Trichophyton_rubrum.CMCC_F_T1i.cdna.all.fa.gz',
	'trichophyton_rubrum_cbs_100081'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_100081/cdna/Trichophyton_rubrum_cbs_100081.Tric_fish_CBS_100081_V1.cdna.all.fa.gz',
	'trichophyton_rubrum_cbs_118892'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_118892/cdna/Trichophyton_rubrum_cbs_118892.ASM15142v1.cdna.all.fa.gz',
	'trichophyton_rubrum_cbs_202_88'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_202_88/cdna/Trichophyton_rubrum_cbs_202_88.Tric_raub_CBS_202_88_V2.cdna.all.fa.gz',
	'trichophyton_rubrum_cbs_288_86'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_288_86/cdna/Trichophyton_rubrum_cbs_288_86.Tric_fish_CBS_288_86_V1.cdna.all.fa.gz',
	'trichophyton_rubrum_cbs_289_86'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_289_86/cdna/Trichophyton_rubrum_cbs_289_86.Tric_kane_CBS_289_86_V1.cdna.all.fa.gz',
	'trichophyton_rubrum_cbs_735_88'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_cbs_735_88/cdna/Trichophyton_rubrum_cbs_735_88.Tric_megn_CBS_735_88_V1.cdna.all.fa.gz',
	'trichophyton_rubrum_d6'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_d6/cdna/Trichophyton_rubrum_d6.Tric_rubr_D6_V1.cdna.all.fa.gz',
	'trichophyton_rubrum_mr1448'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_mr1448/cdna/Trichophyton_rubrum_mr1448.Tric_rubr_M1448_V1.cdna.all.fa.gz',
	'trichophyton_rubrum_mr1459'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_mr1459/cdna/Trichophyton_rubrum_mr1459.Tric_rubr_MR1459_V1.cdna.all.fa.gz',
	'trichophyton_rubrum_mr850'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_rubrum_mr850/cdna/Trichophyton_rubrum_mr850.Tric_rubr_MR-850_V1.cdna.all.fa.gz',
	'trichophyton_soudanense_cbs_452_61'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_soudanense_cbs_452_61/cdna/Trichophyton_soudanense_cbs_452_61.Tric_soud_CBS_452_61_V1.cdna.all.fa.gz',
	'trichophyton_tonsurans_cbs_112818'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_tonsurans_cbs_112818/cdna/Trichophyton_tonsurans_cbs_112818.ASM15145v1.cdna.all.fa.gz',
	'trichophyton_verrucosum_hki_0517'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/trichophyton_verrucosum_hki_0517/cdna/Trichophyton_verrucosum_hki_0517.ASM15150v1.cdna.all.fa.gz',
	'trichophyton_violaceum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/trichophyton_violaceum/cdna/Trichophyton_violaceum.CMCC_F_T3l.cdna.all.fa.gz',
	'trichoplax_adhaerens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/trichoplax_adhaerens/cdna/Trichoplax_adhaerens.ASM15027v1.cdna.all.fa.gz',
	'trichosporon_asahii_var_asahii_cbs_2479'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/trichosporon_asahii_var_asahii_cbs_2479/cdna/Trichosporon_asahii_var_asahii_cbs_2479.Trichosporon_asahii_1.cdna.all.fa.gz',
	'trichosporon_asahii_var_asahii_cbs_8904'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/trichosporon_asahii_var_asahii_cbs_8904/cdna/Trichosporon_asahii_var_asahii_cbs_8904.ASM29921v2.cdna.all.fa.gz',
	'trifolium_pratense'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/trifolium_pratense/cdna/Trifolium_pratense.Trpr.cdna.all.fa.gz',
	'triticum_aestivum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/triticum_aestivum/cdna/Triticum_aestivum.TGACv1.cdna.all.fa.gz',
	'triticum_urartu'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/triticum_urartu/cdna/Triticum_urartu.ASM34745v1.cdna.all.fa.gz',
	'trypanosoma_brucei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/trypanosoma_brucei/cdna/Trypanosoma_brucei.TryBru_Apr2005_chr11.cdna.all.fa.gz',
	'trypanosoma_cruzi'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/trypanosoma_cruzi/cdna/Trypanosoma_cruzi.ASM20906v1.cdna.all.fa.gz',
	'trypanosoma_cruzi_dm28c'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_euglenozoa1_collection/trypanosoma_cruzi_dm28c/cdna/Trypanosoma_cruzi_dm28c.T.cruzi.Dm28c_v01.cdna.all.fa.gz',
	'tsuchiyaea_wingfieldii_cbs_7118'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tsuchiyaea_wingfieldii_cbs_7118/cdna/Tsuchiyaea_wingfieldii_cbs_7118.Tsuc_wing_CBS7118_V1.cdna.all.fa.gz',
	'tuber_melanosporum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/tuber_melanosporum/cdna/Tuber_melanosporum.ASM15164v1.cdna.all.fa.gz',
	'tulasnella_calospora_mut_4182'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/tulasnella_calospora_mut_4182/cdna/Tulasnella_calospora_mut_4182.Tulasnella_calospora_AL13_4D_v1.0.cdna.all.fa.gz',
	'tupaia_belangeri'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/tupaia_belangeri/cdna/Tupaia_belangeri.TREESHREW.cdna.abinitio.fa.gz',
	'tursiops_truncatus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/tursiops_truncatus/cdna/Tursiops_truncatus.turTru1.cdna.abinitio.fa.gz',
	'umbilicaria_pustulata'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/umbilicaria_pustulata/cdna/Umbilicaria_pustulata.Lasallia_pustulata_v1.cdna.all.fa.gz',
	'uncinocarpus_reesii_1704'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/uncinocarpus_reesii_1704/cdna/Uncinocarpus_reesii_1704.ASM351v2.cdna.all.fa.gz',
	'ustilaginoidea_virens'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/ustilaginoidea_virens/cdna/Ustilaginoidea_virens.Assembly_for_version_1_of_the_Villosiclava_virens_genome.cdna.all.fa.gz',
	'ustilaginoidea_virens_gca_000965225'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/ustilaginoidea_virens_gca_000965225/cdna/Ustilaginoidea_virens_gca_000965225.ASM96522v2.cdna.all.fa.gz',
	'ustilago_bromivora'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/ustilago_bromivora/cdna/Ustilago_bromivora.UBRO_v3.cdna.all.fa.gz',
	'ustilago_hordei'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/ustilago_hordei/cdna/Ustilago_hordei.ASM28603v1.cdna.all.fa.gz',
	'ustilago_maydis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/ustilago_maydis/cdna/Ustilago_maydis.Umaydis521_2.0.cdna.all.fa.gz',
	'valsa_mali'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/valsa_mali/cdna/Valsa_mali.ASM81815v1.cdna.all.fa.gz',
	'valsa_mali_var_pyri'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/valsa_mali_var_pyri/cdna/Valsa_mali_var_pyri.ASM81338v1.cdna.all.fa.gz',
	'vanderwaltozyma_polyspora_dsm_70294'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/vanderwaltozyma_polyspora_dsm_70294/cdna/Vanderwaltozyma_polyspora_dsm_70294.ASM15003v1.cdna.all.fa.gz',
	'vavraia_culicis_subsp_floridensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/vavraia_culicis_subsp_floridensis/cdna/Vavraia_culicis_subsp_floridensis.Vavr_culi_floridensis_V1.cdna.all.fa.gz',
	'verruconis_gallopava'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/verruconis_gallopava/cdna/Verruconis_gallopava.O_gall_CBS43764.cdna.all.fa.gz',
	'verticillium_alfalfae_vams_102'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/verticillium_alfalfae_vams_102/cdna/Verticillium_alfalfae_vams_102.ASM15082v1.cdna.all.fa.gz',
	'verticillium_dahliae'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/verticillium_dahliae/cdna/Verticillium_dahliae.ASM15067v2.cdna.all.fa.gz',
	'verticillium_dahliaejr2'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/verticillium_dahliaejr2/cdna/Verticillium_dahliaejr2.VDAG_JR2v.4.0.cdna.all.fa.gz',
	'verticillium_longisporum'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/verticillium_longisporum/cdna/Verticillium_longisporum.vl2.denovo.v1.cdna.all.fa.gz',
	'verticillium_longisporum_gca_001268145'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/verticillium_longisporum_gca_001268145/cdna/Verticillium_longisporum_gca_001268145.vl1.denovo.v1.cdna.all.fa.gz',
	'vicugna_pacos'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/vicugna_pacos/cdna/Vicugna_pacos.vicPac1.cdna.abinitio.fa.gz',
	'vitis_vinifera'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/vitis_vinifera/cdna/Vitis_vinifera.IGGP_12x.cdna.all.fa.gz',
	'vitrella_brassicaformis_ccmp3155'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/protists/fasta/protists_alveolata1_collection/vitrella_brassicaformis_ccmp3155/cdna/Vitrella_brassicaformis_ccmp3155.Vbrassicaformis.cdna.all.fa.gz',
	'vittaforma_corneae_atcc_50505'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_microsporidia1_collection/vittaforma_corneae_atcc_50505/cdna/Vittaforma_corneae_atcc_50505.Vitt_corn_V1.cdna.all.fa.gz',
	'wallemia_ichthyophaga_exf_994'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/wallemia_ichthyophaga_exf_994/cdna/Wallemia_ichthyophaga_exf_994.Wallemia_ichthyophaga_version_1.0.cdna.all.fa.gz',
	'wallemia_mellicola_cbs_633_66'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/wallemia_mellicola_cbs_633_66/cdna/Wallemia_mellicola_cbs_633_66.Wallemia_sebi_v1.0.cdna.all.fa.gz',
	'wickerhamomyces_anomalus_nrrl_y_366_8'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/wickerhamomyces_anomalus_nrrl_y_366_8/cdna/Wickerhamomyces_anomalus_nrrl_y_366_8.Wican1.cdna.all.fa.gz',
	'wickerhamomyces_ciferrii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/wickerhamomyces_ciferrii/cdna/Wickerhamomyces_ciferrii.ASM31348v1.cdna.all.fa.gz',
	'xanthophyllomyces_dendrorhous'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_basidiomycota1_collection/xanthophyllomyces_dendrorhous/cdna/Xanthophyllomyces_dendrorhous.Xden1.cdna.all.fa.gz',
	'xenopus_tropicalis'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/xenopus_tropicalis/cdna/Xenopus_tropicalis.JGI_4.2.cdna.abinitio.fa.gz',
	'xiphophorus_maculatus'=>'ftp://ftp.ensembl.org/pub/release-'.$ensembl_release.'/fasta/xiphophorus_maculatus/cdna/Xiphophorus_maculatus.Xipmac4.4.2.cdna.abinitio.fa.gz',
	'xylona_heveae_tc161'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/xylona_heveae_tc161/cdna/Xylona_heveae_tc161.Xylona_heveae_TC161_v1.0.cdna.all.fa.gz',
	'yarrowia_lipolytica'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/yarrowia_lipolytica/cdna/Yarrowia_lipolytica.GCA_000002525.1.cdna.all.fa.gz',
	'yarrowia_lipolytica_gca_001761485'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/yarrowia_lipolytica_gca_001761485/cdna/Yarrowia_lipolytica_gca_001761485.ASM176148v1.cdna.all.fa.gz',
	'zea_mays'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/plants/fasta/zea_mays/cdna/Zea_mays.AGPv4.cdna.all.fa.gz',
	'zootermopsis_nevadensis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/metazoa/fasta/zootermopsis_nevadensis/cdna/Zootermopsis_nevadensis.ZooNev1.0.cdna.all.fa.gz',
	'zygosaccharomyces_bailii_isa1307'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/zygosaccharomyces_bailii_isa1307/cdna/Zygosaccharomyces_bailii_isa1307.Z_bailii_ISA1307_version_3.cdna.all.fa.gz',
	'zygosaccharomyces_parabailii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/zygosaccharomyces_parabailii/cdna/Zygosaccharomyces_parabailii.ASM198439v2.cdna.all.fa.gz',
	'zygosaccharomyces_rouxii'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota1_collection/zygosaccharomyces_rouxii/cdna/Zygosaccharomyces_rouxii.ASM2636v1.cdna.all.fa.gz',
	'zygosaccharomyces_rouxii_gca_001972345'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota3_collection/zygosaccharomyces_rouxii_gca_001972345/cdna/Zygosaccharomyces_rouxii_gca_001972345.ZYGR_assembly01.cdna.all.fa.gz',
	'zymoseptoria_brevis'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/fungi_ascomycota2_collection/zymoseptoria_brevis/cdna/Zymoseptoria_brevis.ASM96659v1.cdna.all.fa.gz',
	'zymoseptoria_tritici'=>'ftp://ftp.ensemblgenomes.org/pub/release-'.$ensemblgenomes_release.'/fungi/fasta/zymoseptoria_tritici/cdna/Zymoseptoria_tritici.MG2.cdna.all.fa.gz',
	);### CDNA URLS END ###
			}

		if(!$silent){print"\nDownload cDNA data for $species{$species} from Ensembl database...";}
		$status=getstore("$ensembl_cDNA{$species}","UNITAS_refdump_$species/ensembl_cDNA.gz");
		if(is_success($status))
			{
			if(!$silent){print" OK.";}
			}
		else
			{
			if(!$silent){print" FAILED! $status. Download data from smallRNAgroup-SERVER...";}
			$status=getstore("http://www.smallrnagroup.uni-mainz.de/data/UNITAS/Ensembl/Ensembl-cDNA.all_$species.fasta","UNITAS_refdump_$species/ensembl_cDNA.gz");
			if(is_success($status))
				{
				if(!$silent){print" OK.";}
				}
			else
				{
				if(!$silent){print" FAILED! $status.\n\n";}
				}
			}
		if(!$silent){print"\nExtract file...";}
		$ae=Archive::Extract->new(archive=>"UNITAS_refdump_$species/ensembl_cDNA.gz");
		$ae->extract(to=>"UNITAS_refdump_$species")||die print"\nERROR! Unable to decompress UNITAS_refdump_$species/ensembl_cDNA.gz.\n$!\n\n";
		if(!$silent){print" OK.\nRemove compressed file...";}
		unlink"UNITAS_refdump_$species/ensembl_cDNA.gz"||print"\nERROR! Unable to remove compressed file UNITAS_refdump_$species/ensembl_cDNA.gz.\n$!\n\n";
		if(!$silent){print" OK.\nProcess cDNA data from Ensembl...";}
		open(CDNA,"UNITAS_refdump_$species/ensembl_cDNA")||die print"\nERROR! Unable to open UNITAS_refdump_$species/ensembl_cDNA.\n$!\n\n";
		open(CDNA_EDIT,">UNITAS_refdump_$species/cDNA.fas")||die print"\nERROR! Unable to create UNITAS_refdump_$species/cDNA.fas.\n$!\n\n";
		%cDNA=();
		$cDNA_seq_ID=0;
		while(<CDNA>)
			{
			$_=~s/\s*$//;
			if($_=~/^>/)
				{
				$cDNA_seq_ID++;
				# extract biotype
				if($_=~s/transcript_biotype:[^ ]+//)
					{
					$biotype=$&;
					$biotype=~s/transcript_biotype://;
					}
				elsif($_=~s/gene_biotype:[^ ]+//)
					{
					$biotype=$&;
					$biotype=~s/gene_biotype://;
					}
				else
					{
					$biotype="unknown";
					}

				# extract gene symbol (gene if no gene symbol is provided)
				if($_=~s/gene_symbol:[^ ]+//)
					{
					$symbol=$&;
					$symbol=~s/gene_symbol://;
					}
				elsif($_=~s/gene:[^ ]+//)
					{
					$symbol=$&;
					$symbol=~s/gene://;
					}
				elsif($_=~s/GENSCAN\d+//)
					{
					$symbol=$&;
					}
				elsif($_=~s/SNAP\d+//)
					{
					$symbol=$&;
					}
				else
					{
					$symbol=$cDNA_seq_ID;
					}
				}
			else
				{
				$cDNA{"$biotype|$symbol"}.=$_;
				}
			}
		close CDNA;
		foreach$head(keys%cDNA)
			{
			print CDNA_EDIT">$head\n$cDNA{$head}\n";
			}
		close CDNA_EDIT;
		undef%cDNA;
		if(!$silent){print" OK.";}

		# add tRNA data from gtRNAdb
		foreach$id(keys%gtRNAdb)
			{
			$i++;
			print NCRNA_EDIT">tRNA|$id\n$gtRNAdb{$id}\n";
			}
		undef%gtRNAdb;

		# download tRF-1 sequences -> add to ncRNA.fas
		if(!$silent){print"\nDownload tRF-1 sequences for $species{$species}...";}
		$status=getstore("http://www.smallrnagroup.uni-mainz.de/data/UNITAS/tRF-1/$species.tRF-1.fas","UNITAS_refdump_$species/tRF-1.fas");
		if(is_success($status))
			{
			$version=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/tRF-1/release');
			$db_versions_info.="tRF-1 sequence data version/date: ......... $version (dd.mm.yyyy)\n";
			if(!$silent){print" OK. $version (dd.mm.yyyy).";}
			}
		else
			{
			if(!$silent){print" FAILED! $status\n\n";}
			}
		if(-e"UNITAS_refdump_$species/tRF-1.fas")
			{
			open(TRF1,"UNITAS_refdump_$species/tRF-1.fas");
			$tRF1_add_count=0;
			while(<TRF1>)
				{
				$_=~s/\s*$//;
				if($_=~/^>/)
					{
					$tRF1_add_count++;
					$head=$_;
					}
				else
					{
					print NCRNA_EDIT"$head\n$_\n";
					}
				}
			close TRF1;
			print"\ntRF-1 sequences: $tRF1_add_count.";
			}
		$i+=$tRF1_add_count;

		# download tRNA-leader sequences -> add to ncRNA.fas
		if(!$silent){print"\nDownload tRNA-leader sequences for $species{$species}...";}
		$status=getstore("http://www.smallrnagroup.uni-mainz.de/data/UNITAS/tRNA_leader/$species.tRNA_leader.fas","UNITAS_refdump_$species/tRNA_leader.fas");
		if(is_success($status))
			{
			$version=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/tRNA_leader/release');
			$db_versions_info.="tRNA-leader sequence data version/date: ... $version (dd.mm.yyyy)\n";
			if(!$silent){print" OK. $version (dd.mm.yyyy).";}
			}
		else
			{
			if(!$silent){print" FAILED! $status\n\n";}
			}
		if(-e"UNITAS_refdump_$species/tRNA_leader.fas")
			{
			open(TRNA_LEADER,"UNITAS_refdump_$species/tRNA_leader.fas");
			$tRNA_leader_add_count=0;
			while(<TRNA_LEADER>)
				{
				$_=~s/\s*$//;
				if($_=~/^>/)
					{
					$tRNA_leader_add_count++;
					$head=$_;
					}
				else
					{
					print NCRNA_EDIT"$head\n$_\n";
					}
				}
			close TRNA_LEADER;
			print"\ntRNA-leader sequences: $tRNA_leader_add_count.";
			}
		$i+=$tRNA_leader_add_count;

		# download silva rRNA data -> add to ncRNA.fas
		if(!$silent){print"\nDownload SILVA SSU rRNA data for $species{$species}...";}
		$status=getstore("http://www.smallrnagroup.uni-mainz.de/data/UNITAS/SILVA_rRNA/SILVA_SSU_$species.fasta","UNITAS_refdump_$species/SILVA_rRNA.SSU");
		if(is_success($status))
			{
			$version=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/SILVA_rRNA/release');
			$db_versions_info.="SILVA rRNA (SSU) database version/date: ... Release $version\n";
			if(!$silent){print" OK. Release $version.";}
			}
		else
			{
			if(!$silent){print" FAILED! $status\n\n";}
			}
		if(!$silent){print"\nDownload SILVA LSU rRNA data for $species{$species}...";}
		$status=getstore("http://www.smallrnagroup.uni-mainz.de/data/UNITAS/SILVA_rRNA/SILVA_LSU_$species.fasta","UNITAS_refdump_$species/SILVA_rRNA.LSU");
		if(is_success($status))
			{
			$version=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/SILVA_rRNA/release');
			$db_versions_info.="SILVA rRNA (LSU) database version/date: ... Release $version\n";
			if(!$silent){print" OK. Release $version.";}
			}
		else
			{
			if(!$silent){print" FAILED! $status\n\n";}
			}
		open(SSU,"UNITAS_refdump_$species/SILVA_rRNA.SSU")||die print"\nERROR! Unable to read UNITAS_refdump_$species/SILVA_rRNA.SSU.\n$!\n\n";
		open(LSU,"UNITAS_refdump_$species/SILVA_rRNA.LSU")||die print"\nERROR! Unable to read UNITAS_refdump_$species/SILVA_rRNA.LSU.\n$!\n\n";
		$i_ssu=0;
		$i_lsu=0;
		while(<SSU>)
			{
			if($_=~/^>/)
				{
				$i_ssu++;
				}
			print NCRNA_EDIT$_;
			}
		while(<LSU>)
			{
			if($_=~/^>/)
				{
				$i_lsu++;
				}
			print NCRNA_EDIT$_;
			}
		close SSU;
		close LSU;
		close NCRNA_EDIT;
		$i+=$i_lsu+$i_ssu;
		if(!$silent){print"\nrRNA sequences: (SSU=$i_ssu LSU=$i_lsu).\nTOTAL: $i ncRNA sequences stored in UNITAS_refdump_$species/ncRNA.fas.";}

		# download miRBase data
		$miRBase_mature='ftp://mirbase.org/pub/mirbase/CURRENT/mature.fa.gz';
		$miRBase_hairpin='ftp://mirbase.org/pub/mirbase/CURRENT/hairpin.fa.gz';
		if(!$silent){print"\nDownload mature miRNA sequences from miRBase...";}
		$status=getstore($miRBase_mature,"UNITAS_refdump_$species/miRBase_mature.gz");
		if(is_success($status))
			{
			$version=get('ftp://mirbase.org/pub/mirbase/CURRENT/README');
			$version=~s/Release \d+//;
			$version=$&;
			$db_versions_info.="miRBase database version/date: ............ $version\n";
			if(!$silent){print" OK. $version.";}
			}
		else
			{
			if(!$silent){print" FAILED! $status. Download data from smallRNAgroup-SERVER...";}
			$status=getstore("http://www.smallrnagroup.uni-mainz.de/data/UNITAS/miRBase/mature.fa.gz","UNITAS_refdump_$species/miRBase_mature.gz");
			if(is_success($status))
				{
				$version=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/miRBase/release');
				if(!$silent){print" OK. Release $version.";}
				$db_versions_info.="miRBase database version/date: ........ Release $version\n";
				}
			else
				{
				die print" FAILED! $status\n\n";
				}
			}
		if(!$silent){print"\nExtract file...";}
		$ae=Archive::Extract->new(archive=>"UNITAS_refdump_$species/miRBase_mature.gz");
		$ae->extract(to=>"UNITAS_refdump_$species")||die print"\nERROR! Unable to decompress UNITAS_refdump_$species/miRBase_mature.gz.\n$!\n\n";
		if(!$silent){print" OK.\nRemove compressed file...";}
		unlink"UNITAS_refdump_$species/miRBase_mature.gz"||print"\nERROR! Unable to remove compressed file UNITAS_refdump_$species/miRBase_mature.gz.\n$!\n\n";
		if(!$silent){print" OK.\nDownload hairpin miRNA sequences from miRBase...";}
		$status=getstore($miRBase_hairpin,"UNITAS_refdump_$species/miRBase_hairpin.gz");
		if(is_success($status))
			{
			$version=get('ftp://mirbase.org/pub/mirbase/CURRENT/README');
			$version=~s/Release \d+//;
			$version=$&;
			if(!$silent){print" OK. $version.";}
			}
		else
			{
			if(!$silent){print" FAILED! $status. Download data from smallRNAgroup-SERVER...";}
			$status=getstore("http://www.smallrnagroup.uni-mainz.de/data/UNITAS/miRBase/hairpin.fa.gz","UNITAS_refdump_$species/miRBase_hairpin.gz");
			if(is_success($status))
				{
				$version=get('http://www.smallrnagroup.uni-mainz.de/data/UNITAS/miRBase/release');
				if(!$silent){print" OK. Release $version.";}
				}
			else
				{
				die print" FAILED! $status\n\n";
				}
			}
		if(!$silent){print"\nExtract file...";}
		$ae=Archive::Extract->new(archive=>"UNITAS_refdump_$species/miRBase_hairpin.gz");
		$ae->extract(to=>"UNITAS_refdump_$species")||die print"\nERROR! Unable to decompress UNITAS_refdump_$species/miRBase_hairpin.gz.\n$!\n\n";
		if(!$silent){print" OK.\nRemove compressed file...";}
		unlink"UNITAS_refdump_$species/miRBase_hairpin.gz"||print"\nERROR! Unable to remove compressed file UNITAS_refdump_$species/miRBase_hairpin.\n$!\n\n";
		if(!$silent){print" OK.";}


		# split hairpin miRNA sequences to species/non-species files
		if(!$silent){print"\nSplit hairpin miRNA sequences into $species{$species}/non-$species{$species} files...";}
		open(MIR_HAIRPIN,"UNITAS_refdump_$species/miRBase_hairpin")||die print"\nERROR! Unable to open miRBase file UNITAS_refdump_$species/miRBase_hairpin.\n$!\n\n";
		open(MIR_HAIRPIN_SPECIES,">UNITAS_refdump_$species/miRBase_hairpin_$species{$species}.fas")||die print"\nERROR! Unable to create file UNITAS_refdump_$species/miRBase_hairpin_$species{$species}.fas.\n$!\n\n";
		open(MIR_HAIRPIN_NONSPECIES,">UNITAS_refdump_$species/miRBase_hairpin_non-$species{$species}.fas")||die print"\nERROR! Unable to create file UNITAS_refdump_$species/miRBase_hairpin_non-$species{$species}.fas.\n$!\n\n";
		%miRhairpin_species=();
		%miRhairpin_nonspecies=();
		$i=0;
		@head=();
		while(<MIR_HAIRPIN>)
			{
			$_=~s/\s*$//;
			if($_=~s/^>//)
				{
				if(lc$head[2].'_'.$head[3]eq$species)
					{
					$i++;
					$miRhairpin_species{$hairpin_seq}=$head[4].'_'.$head[5];
					}
				@head=split(' ',$_);
				$hairpin_seq="";
				}
			else
				{
				$_=~s/U/T/g;
				$hairpin_seq.=$_;
				}
			}
		if(lc$head[2].'_'.$head[3]eq$species)
			{
			$i++;
			$miRhairpin_species{$hairpin_seq}=$head[4].'_'.$head[5];
			}
		close MIR_HAIRPIN;
		if(!$silent){print" $species{$species}: $i.";}

		open(MIR_HAIRPIN,"UNITAS_refdump_$species/miRBase_hairpin")||die print"\nERROR! Unable to open miRBase file UNITAS_refdump_$species/miRBase_hairpin.\n$!\n\n";
		$i=0;
		@head=();
		while(<MIR_HAIRPIN>)
			{
			$_=~s/\s*$//;
			if($_=~s/^>//)
				{
				if(lc$head[2].'_'.$head[3]ne$species&&!$miRhairpin_species{$hairpin_seq}) # species is different and sequence is not in species
					{
					$i++;
					$miRhairpin_nonspecies{$hairpin_seq}.="$head[0]_stem-loop ";
					}
				@head=split(' ',$_);
				$hairpin_seq="";
				}
			else
				{
				$_=~s/U/T/g;
				$hairpin_seq.=$_;
				}
			}
		if(lc$head[2].'_'.$head[3]ne$species&&!$miRhairpin_species{$hairpin_seq})
			{
			$i++;
			$miRhairpin_nonspecies{$hairpin_seq}.="$head[0]_stem-loop ";
			}
		close MIR_HAIRPIN;
		foreach(keys%miRhairpin_nonspecies)
			{
			$miRhairpin_nonspecies{$_}=~s/ $//;
			}
		if(!$silent){print" non-$species{$species}: $i.";}

		#sort keys to make reproducable files
		@keyshairpin_species=keys%miRhairpin_species;
		@keyshairpin_species=sort@keyshairpin_species;
		foreach$miR(@keyshairpin_species)
			{
			print MIR_HAIRPIN_SPECIES">$miRhairpin_species{$miR}\n$miR\n";
			}
		@keyshairpin_nonspecies=keys%miRhairpin_nonspecies;
		@keyshairpin_nonspecies=sort@keyshairpin_nonspecies;
		foreach$miR(@keyshairpin_nonspecies)
			{
			print MIR_HAIRPIN_NONSPECIES">$miRhairpin_nonspecies{$miR}\n$miR\n";
			}
		undef%miRhairpin_species;
		undef%miRhairpin_nonspecies;
		undef@keyshairpin_species;
		undef@keyshairpin_nonspecies;
		close MIR_HAIRPIN_SPECIES;
		close MIR_HAIRPIN_NONSPECIES;
		if(!$silent){print" OK.\n";}

		open(DBVERSIONS,">UNITAS_refdump_$species/db_versions.info");
		print DBVERSIONS$db_versions_info;
		close DBVERSIONS;
		}
	}


##################################
# DIFFERENTIAL EXPRESSION MODULE #
##################################

sub diff_expr
	{
	print"


                unitas: DIFFERENTIAL EXPRESSION MODULE

  |
  |   XXXXXX
  |   XXXXXX            XXXXXX
  |   XXXXXX   XXXXXX   XXXXXX
  |   XXXXXX   XXXXXX   XXXXXX
  |   XXXXXX   XXXXXX   XXXXXX
  |   XXXXXX   XXXXXX   XXXXXX
  |   XXXXXX   XXXXXX   XXXXXX                    OOOOOO
  |   XXXXXX   XXXXXX   XXXXXX           OOOOOO   OOOOOO
  |   XXXXXX   XXXXXX   XXXXXX           OOOOOO   OOOOOO
  |   XXXXXX   XXXXXX   XXXXXX           OOOOOO   OOOOOO   OOOOOO
  |   XXXXXX   XXXXXX   XXXXXX           OOOOOO   OOOOOO   OOOOOO
  |___XXXXXX___XXXXXX___XXXXXX___________OOOOOO___OOOOOO___OOOOOO______
             condition 1                        condition 2

";
	if(@diffex_g1==0||@diffex_g2==0)
		{
		print"\n\nYou must define unitas output folders for each group with -g1 and -g2.\nThe command should look like this:\n\nperl unitas.pl -diffexpr -g1 folderA -g1 folderB -g2 folderC -g2 folderD\n\n";
		exit;
		}

	# remove redundant folders from groups
	%diffex_g1=();
	print"\n\nGROUP 1:";
	foreach(sort@diffex_g1)
		{
		$diffex_g1{$_}=1;
		print"\n $_";
		}
	%diffex_g2=();
	print"\n\nGROUP 2:";
	foreach(sort@diffex_g2)
		{
		$diffex_g2{$_}=1;
		print"\n $_";
		}

	# check number of replicates per group
	if(keys%diffex_g1<2||keys%diffex_g2<2)
		{
		$print_estimated_deviation=$estimated_deviation*100;
		print"\n\nWARNING! There should be at least two replicates in each of the two groups.";
		if($estimated_deviation>0)
			{
			print"\nVariance will be estimated by adding two virtual replicates with rpm values\n+- $print_estimated_deviation%.\n";
			}
		else
			{
			print"\nIf it is not possible to use more replicates, use the option\n-diffexpr_estdev [0..1] to estimate standard deviation.\n";
			}
		}

	# check for existence of each folder
	foreach(keys%diffex_g1,keys%diffex_g2)
		{
		if(!-d$_)
			{
			print"\nERROR! Folder $_ does not exist.\n\n";
			exit;
			}
		}

	#check for occurence of any folder in both groups
	foreach$fld(keys%diffex_g1)
		{
		if($diffex_g2{$fld})
			{
			print"\nERROR! A replicate must not occur in both groups.\n$f1 was assigned to group 1 AND group 2.\n\n";
			exit;
			}
		}

	# collect sequences and calculate rpm values
	print"\n\nCollect sequences and calculate rpm values...";
	%rpm=();
	%abs_reads=();
	$total_reads_group1=0;
	$total_reads_group2=0;
	foreach$fld(keys%diffex_g1,keys%diffex_g2)
		{
		open(SUMMARY,"$fld/$outfile_prefix.annotation_summary.txt")||die print"\nERROR! Unable to open $fld/$outfile_prefix.annotation_summary.txt.\n$!\n\n";
		print"\nRead data from $fld...";
		while(<SUMMARY>)
			{
			next if($_=~/^low_complexity/);
			next if($_=~/^ /);
			$_=~s/\s*$//;
			@d=split("\t",$_);
			$total_reads{$fld}+=$d[1];
			if($diffex_g1{$fld})
				{
				$total_reads_group1+=$d[1];
				}
			elsif($diffex_g2{$fld})
				{
				$total_reads_group2+=$d[1];
				}
			last if($_=~/^\s*$/);
			}
		close SUMMARY;

		opendir(DIR,$fld)||die print"\nERROR! Unable to open directory $fld.\n$!\n\n";
		while($file=readdir(DIR))
			{
			# open unitas fasta files but not those with special format of fasta headers (where header not or not only refers to sequence read counts)
			if($file=~/^$outfile_prefix\..+\.fas$/&&$file!~/^$outfile_prefix\.non-miR\.fas$/&&$file!~/^$outfile_prefix\.piRcandidates\.fas$/&&$file!~/^$outfile_prefix\.phasiRNA\.sorted\.fas$/)
				{
				$class=$file;
				$class=~s/^$outfile_prefix\.//;
				$class=~s/\.fas$//;
				open(FAS,"$fld/$file")||die print"\nERROR! Unable to open fasta file $fld/$file.\n$!\n\n";
				while(<FAS>)
					{
					$_=~s/\s*$//;
					if($_=~s/^>//)
						{
						$reads=$_;
						}
					else
						{
						$rpm{$_}{$fld}=$reads/$total_reads{$fld}*1000000;
						$abs_reads{$_}{$fld}=$reads;
						$annotation{$_}{$class}=1;
						}
					}
				close FAS;
				}
			}
		closedir DIR;
		$print_collected_reads=int($total_reads{$fld}+0.5);
		print" OK.\nTotal reads: $print_collected_reads\n";
		}
	$seqs_to_analyze=keys%rpm;
	print"
Calculate raw p values for diff. expression of $seqs_to_analyze sequences
0%                                  50%                                  100%
|------------------------------------|------------------------------------|
";

	# perform the statistical test for each sequence
	$sig=0;
	$nsig=0;
	$skipped_tests=0;
	$performed_tests=0;
	%uncorrected_p_value=();
	%higher_expression_in_group=();
	$progress=0;
	$progress_dots=0;
	foreach$seq(keys%rpm)
		{
		$progress++;
		if($progress>=$seqs_to_analyze/75)
			{
			print".";
			$progress=0;
			$progress_dots++;
			}
		@i1=();
		@i2=();
		$present_in_all_probes=1;
		foreach$fld_g1(keys%diffex_g1)
			{
			if(!$rpm{$seq}{$fld_g1})
				{
				$rpm{$seq}{$fld_g1}=0;
				$present_in_all_probes=0;
				}
			push(@i1,$rpm{$seq}{$fld_g1});
			}
		foreach$fld_g2(keys%diffex_g2)
			{
			if(!$rpm{$seq}{$fld_g2})
				{
				$rpm{$seq}{$fld_g2}=0;
				$present_in_all_probes=0;
				}
			push(@i2,$rpm{$seq}{$fld_g2});
			}

		if($present_in_all_probes==0&&$diffexpr_nostrays==1)
			{
			$skipped_tests++;
			}
		else
			{
			$performed_tests++;
			calc_shared_area();
			$uncorrected_p_value{$seq}=$p_shared;
			}
		}
	foreach($progress_dots..74)
		{
		print".";
		}
	print"\n\n$performed_tests tests performed ($sig tests with p<=$diff_expr_p)";

	# Boferroni (1) / Bonferroni-Holm (2) correction of alpha error
	$sig=0;
	%corrected_significant=();
	if($alpha_correction==1)
		{
		print"\nApply Bonferroni-Holm correction of alpha error...";
		$i=-1;
		foreach$seq(sort{$uncorrected_p_value{$a}<=>$uncorrected_p_value{$b}}keys%uncorrected_p_value)
			{
			$i++;
			if($uncorrected_p_value{$seq}*($performed_tests-$i)<=$diff_expr_p||$diff_expr_p==1)
				{
				$sig++;
				if($uncorrected_p_value{$seq}>1){$uncorrected_p_value{$seq}=1;}
				$corrected_significant{$seq}=$uncorrected_p_value{$seq};
				}
			else
				{
				last;
				}
			}
		foreach$seq(keys%corrected_significant)
			{
			$corrected_significant{$seq}=$corrected_significant{$seq}*($performed_tests-$i);
			}

		print" done. -> $sig significant results.";
		}
	elsif($alpha_correction==2)
		{
		print"\nApply strict Bonferroni correction of alpha error...";
		foreach$seq(keys%uncorrected_p_value)
			{
			$p_corrected=$uncorrected_p_value{$seq}*$performed_tests;
			if($p_corrected<=$diff_expr_p||$diff_expr_p==1)
				{
				$sig++;
				if($p_corrected>1){$p_corrected=1;}
				$corrected_significant{$seq}=$p_corrected;
				}
			}
		print" done. -> $sig significant results.";
		}
	else
		{
		print"\nNo correction of alpha error (-> consider results as explorative).";
		%corrected_significant=%uncorrected_p_value; # use uncorrected p values for output
		}

	# print significant results to output file
	print"\nPrint results to outfiles...";
	print DIFFEX_OUT_1"sequence";
	print DIFFEX_OUT_2"sequence";
	foreach$fld(@diffex_g1,@diffex_g2)
		{
		print DIFFEX_OUT_1"\tabs_$fld";
		print DIFFEX_OUT_2"\tabs_$fld";
		}
	foreach$fld(@diffex_g1,@diffex_g2)
		{
		print DIFFEX_OUT_1"\trpm_$fld";
		print DIFFEX_OUT_2"\trpm_$fld";
		}
	print DIFFEX_OUT_1"\tavg_group1\tavg_group2\tp-value\tcorr_p-value\tclass\n";
	print DIFFEX_OUT_2"\tavg_group1\tavg_group2\tp-value\tcorr_p-value\tclass\n";

	foreach$seq(sort{$a cmp $b}keys%corrected_significant)
		{
		# group 1 > group 2
		if($higher_expression_in_group{$seq}==1)
			{
			print DIFFEX_OUT_1"${seq}$diffexpr_table_out{$seq}\t$uncorrected_p_value{$seq}\t$corrected_significant{$seq}";
			foreach$class(sort{$a cmp $b}keys%{$annotation{$seq}})
				{
				print DIFFEX_OUT_1"\t$class";
				}
			print DIFFEX_OUT_1"\n";
			}
		# group 2 > group 1
		elsif($higher_expression_in_group{$seq}==2)
			{
			print DIFFEX_OUT_2"${seq}$diffexpr_table_out{$seq}\t$uncorrected_p_value{$seq}\t$corrected_significant{$seq}";
			foreach$class(sort{$a cmp $b}keys%{$annotation{$seq}})
				{
				print DIFFEX_OUT_2"\t$class";
				}
			print DIFFEX_OUT_2"\n";
			}
		}
	close DIFFEX_OUT_1;
	close DIFFEX_OUT_2;
	print" done.\n\n\n";

	sub calc_shared_area
		{
		avg_and_dev();
		sub avg_and_dev
			{
			# calculate average and standard deviation
			$avg1=calc_avg(@i1);
			$avg2=calc_avg(@i2);
			$avg_table_out="\t$avg1\t$avg2";
			if(@i1==1&&$estimated_deviation>0) # simulate variance if there is only one replicate
				{
				push(@i1,$i1[0]*(1-$estimated_deviation));
				push(@i1,$i1[0]*(1+$estimated_deviation));
				}
			if(@i2==1&&$estimated_deviation>0) # simulate variance if there is only one replicate
				{
				push(@i2,$i2[0]*(1-$estimated_deviation));
				push(@i2,$i2[0]*(1+$estimated_deviation));
				}
			$avg=$avg1; $stddev1=calc_stddev(@i1);
			$avg=$avg2; $stddev2=calc_stddev(@i2);

			# inverse group1 and group2 (group1 must have lower avg)
			$higher_expression_in_group{$seq}=2;
			if($avg1>$avg2)
				{
				($avg1,$avg2)=($avg2,$avg1);
				($stddev1,$stddev2)=($stddev2,$stddev1);
				$higher_expression_in_group{$seq}=1;
				}

			# use minimal expected standard deviation (correspond to expected standard deviation in technical replicates -> e.g. resequencing the same library. Depends on rpm and library size)
			if($avg1==0)
				{
				$avg1=1/10**10;
				}
			if($avg2==0)
				{
				$avg2=1/10**10;
				}

			$minimum_relative_stddev1=(1/sqrt($total_reads_group1/1000000))/sqrt($avg1);
			$minimum_relative_stddev2=(1/sqrt($total_reads_group2/1000000))/sqrt($avg2);
			if($stddev1<$minimum_relative_stddev1)
				{
				$stddev1=$minimum_relative_stddev1;
				}
			if($stddev2<$minimum_relative_stddev2)
				{
				$stddev2=$minimum_relative_stddev2;
				}
			}

		# calculate the point of intersection ($xi) of both normal distributions
		if(abs($stddev1-$stddev2)<0.00001)
			{
			$xi=($avg1+$avg2)/2;
			}
		else
			{
			$xi=((($stddev2**2)*$avg1)-(($stddev1**2)*$avg2)+(($stddev1*$stddev2)*(sqrt((($avg1-$avg2)**2)+((2*(($stddev2**2)-($stddev1**2)))*(log($stddev2/$stddev2)))))))/(($stddev2**2)-($stddev1**2));
			}

		# calculate the area spanned by both graphs (=error probability p)
		$A_shared=2*(1-(integral($xi,$avg1,$stddev1)));
		$p_shared=$A_shared/($A_shared+(2*(1-$A_shared)));
		if($p_shared<=$diff_expr_p||$diff_expr_p==1)
			{
			$sig++;
			foreach$fld(@diffex_g1,@diffex_g2)
				{
				$diffexpr_table_out{$seq}.="\t$abs_reads{$seq}{$fld}";
				}
			foreach$fld(@diffex_g1,@diffex_g2)
				{
				$diffexpr_table_out{$seq}.="\t$rpm{$seq}{$fld}";
				}
			$diffexpr_table_out{$seq}.=$avg_table_out;
			}
		else
			{
			$nsig++;
			}
		}

	sub calc_avg
		{
		$avg=0;
		foreach(@_)
			{
			$avg+=$_;
			}
		return ($avg/@_);
		}
	sub calc_stddev
		{
		$var=0;
		foreach(@_)
			{
			$var+=($_-$avg)**2;
			}
		$var=$var/@_;
		return (sqrt($var));
		}
	sub density
		{
		($x,$m,$s)=(0,0,1);
		$x=shift if@_;
		$m=shift if@_;
		$s=shift if@_;
		$z=($x-$m)/$s;
		return exp(-0.5*$z*$z)/(2.506628274631*$s);
		}
	sub integral
		{
		($x,$m,$s)=(0,0,1);
		$x=shift if@_;
		$m=shift if@_;
		$s=shift if@_;
		$z=($x-$m)/$s;
		$t=1.0/(1+0.2316419*abs($z));
		$y=$t*(0.319381530+$t*(-0.356563782+$t*(1.781477937+$t*(-1.821255978+$t*1.330274429))));
		if($z>0)
			{
			return 1-density($z)*$y;
			}
		else
			{
			return density($z)*$y;
			}
		}
	}
